@@ -21,10 +21,6 @@ package org.apache.jcs.access;
 
 import java.io.IOException;
 import java.io.Serializable;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.Map;
-import java.util.Set;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -47,10 +43,10 @@ import org.apache.jcs.engine.stats.behavior.ICacheStats;
  * An instance of this class is tied to a specific cache region. Static methods are provided to get
  * such instances.
  * <p>
- * Using this class you can retrieve an item, the item's wrapper, and the element's configuration.  You can also put an
+ * Using this class you can retrieve an item, the items wrapper, the element configuration, put an
  * item in the cache, remove an item, and clear a region.
  * <p>
- * The JCS class is the preferred way to access these methods.
+ * The JCS class is the prefered way to access these methods.
  */
 public class CacheAccess
     implements ICacheAccess
@@ -58,13 +54,15 @@ public class CacheAccess
     /** The logger. */
     private static final Log log = LogFactory.getLog( CacheAccess.class );
 
-    /** Cache manager use by the various forms of defineRegion and getAccess */
-    private static CompositeCacheManager cacheMgr;
+    /**
+     * Cache manager use by the various forms of defineRegion and getAccess
+     */
+    private static volatile CompositeCacheManager cacheManager;
 
     /**
      * The cache that a given instance of this class provides access to.
      * <p>
-     * @TODO Should this be the interface?
+     * @TODO Should this be the inteface?
      */
     protected CompositeCache cacheControl;
 
@@ -82,7 +80,7 @@ public class CacheAccess
 
     /**
      * Define a new cache region with the given name. In the oracle specification, these attributes
-     * are global and not region specific, regional overrides is a value add each region should be
+     * are global and not region specific, regional overirdes is a value add each region should be
      * able to house both cache and element attribute sets. It is more efficient to define a cache
      * in the props file and then strictly use the get access method. Use of the define region
      * outside of an initialization block should be avoided.
@@ -94,7 +92,7 @@ public class CacheAccess
     public static CacheAccess defineRegion( String name )
         throws CacheException
     {
-        ensureCacheManager();
+        CompositeCacheManager cacheMgr = ensureCacheManager();
 
         return new CacheAccess( cacheMgr.getCache( name ) );
     }
@@ -110,7 +108,7 @@ public class CacheAccess
     public static CacheAccess defineRegion( String name, ICompositeCacheAttributes cattr )
         throws CacheException
     {
-        ensureCacheManager();
+        CompositeCacheManager cacheMgr = ensureCacheManager();
 
         return new CacheAccess( cacheMgr.getCache( name, cattr ) );
     }
@@ -128,7 +126,7 @@ public class CacheAccess
     public static CacheAccess defineRegion( String name, ICompositeCacheAttributes cattr, IElementAttributes attr )
         throws CacheException
     {
-        ensureCacheManager();
+        CompositeCacheManager cacheMgr = ensureCacheManager();
 
         return new CacheAccess( cacheMgr.getCache( name, cattr, attr ) );
     }
@@ -143,7 +141,7 @@ public class CacheAccess
     public static CacheAccess getAccess( String region )
         throws CacheException
     {
-        ensureCacheManager();
+        CompositeCacheManager cacheMgr = ensureCacheManager();
 
         return new CacheAccess( cacheMgr.getCache( region ) );
     }
@@ -159,7 +157,7 @@ public class CacheAccess
     public static CacheAccess getAccess( String region, ICompositeCacheAttributes icca )
         throws CacheException
     {
-        ensureCacheManager();
+        CompositeCacheManager cacheMgr = ensureCacheManager();
 
         return new CacheAccess( cacheMgr.getCache( region, icca ) );
     }
@@ -168,15 +166,19 @@ public class CacheAccess
      * Helper method which checks to make sure the cacheMgr class field is set, and if not requests
      * an instance from CacheManagerFactory.
      */
-    protected static void ensureCacheManager()
+    protected static CompositeCacheManager ensureCacheManager()
     {
-        synchronized ( CacheAccess.class )
-        {
-            if ( cacheMgr == null )
-            {
-                cacheMgr = CompositeCacheManager.getInstance();
+        CompositeCacheManager tmp = cacheManager;
+        if (null == tmp) {
+            synchronized (CacheAccess.class) {
+                tmp = cacheManager;
+                if (null == tmp) {
+                    tmp = CompositeCacheManager.getInstance();
+                    cacheManager = tmp;
+                }
             }
         }
+        return tmp;
     }
 
     // ------------------------------------------------------- instance methods
@@ -187,41 +189,14 @@ public class CacheAccess
      * @param name Key the object is stored as
      * @return The object if found or null
      */
+    @Override
     public Object get( Object name )
     {
         ICacheElement element = this.cacheControl.get( (Serializable) name );
 
         return ( element != null ) ? element.getVal() : null;
     }
-    
-    /**
-     * Retrieve matching objects from the cache region this instance provides access to.
-     * <p>
-     * @param pattern - a key pattern for the objects stored
-     * @return A map of key to values.  These are stripped from the wrapper.
-     */
-    public HashMap getMatching( String pattern )
-    {
-        HashMap unwrappedResults = new HashMap();
-        
-        Map wrappedResults = this.cacheControl.getMatching( pattern );
-        if ( wrappedResults != null )
-        {
-            Set keySet = wrappedResults.keySet();
-            Iterator it = keySet.iterator();
-            while ( it.hasNext() )
-            {
-                Object key = it.next();
-                ICacheElement element = (ICacheElement)wrappedResults.get( key );
-                if ( element != null )
-                {
-                    unwrappedResults.put( key, element.getVal() );
-                }
-            }            
-        }
-        return unwrappedResults;
-    }
-    
+
     /**
      * This method returns the ICacheElement wrapper which provides access to element info and other
      * attributes.
@@ -232,7 +207,7 @@ public class CacheAccess
      * This method is most useful if you want to determine things such as the how long the element
      * has been in the cache.
      * <p>
-     * The last access time in the ElementAttributes should be current.
+     * The last access time in teh ElementAttributes should be current.
      * <p>
      * @param name Key the object is stored as
      * @return The ICacheElement if the object is found or null
@@ -242,50 +217,6 @@ public class CacheAccess
         return this.cacheControl.get( (Serializable) name );
     }
 
-    /**
-     * Get multiple elements from the cache based on a set of cache keys.
-     * <p>
-     * This method returns the ICacheElement wrapper which provides access to element info and other
-     * attributes.
-     * <p>
-     * This returns a reference to the wrapper. Any modifications will be reflected in the cache. No
-     * defensive copy is made.
-     * <p>
-     * This method is most useful if you want to determine things such as the how long the element
-     * has been in the cache.
-     * <p>
-     * The last access time in the ElementAttributes should be current.
-     * <p>
-     * @param names set of Object cache keys
-     * @return a map of Object key to ICacheElement element, or empty map if none of the keys are present
-     */
-    public Map getCacheElements( Set names )
-    {
-        return this.cacheControl.getMultiple( names );
-    }
-
-    /**
-     * Get multiple elements from the cache based on a set of cache keys.
-     * <p>
-     * This method returns the ICacheElement wrapper which provides access to element info and other
-     * attributes.
-     * <p>
-     * This returns a reference to the wrapper. Any modifications will be reflected in the cache. No
-     * defensive copy is made.
-     * <p>
-     * This method is most useful if you want to determine things such as the how long the element
-     * has been in the cache.
-     * <p>
-     * The last access time in the ElementAttributes should be current.
-     * <p>
-     * @param pattern key search pattern
-     * @return a map of Object key to ICacheElement element, or empty map if no keys match the pattern
-     */
-    public Map getMatchingCacheElements( String pattern )
-    {
-        return this.cacheControl.getMatching( pattern );
-    }
-    
     /**
      * Place a new object in the cache, associated with key name. If there is currently an object
      * associated with name in the region an ObjectExistsException is thrown. Names are scoped to a
@@ -296,6 +227,7 @@ public class CacheAccess
      * @exception CacheException and ObjectExistsException is thrown if the item is already in the
      *                cache.
      */
+    @Override
     public void putSafe( Object key, Object value )
         throws CacheException
     {
@@ -315,6 +247,7 @@ public class CacheAccess
      * @param obj Object to store
      * @exception CacheException
      */
+    @Override
     public void put( Object name, Object obj )
         throws CacheException
     {
@@ -324,13 +257,14 @@ public class CacheAccess
     }
 
     /**
-     * Constructs a cache element with these attributes, and puts it into the cache.
+     * Constructs a cache element with these attribures, and puts it into the cache.
      * <p>
      * If the key or the value is null, and InvalidArgumentException is thrown.
      * <p>
      * @see org.apache.jcs.access.behavior.ICacheAccess#put(java.lang.Object, java.lang.Object,
      *      org.apache.jcs.engine.behavior.IElementAttributes)
      */
+    @Override
     public void put( Object key, Object val, IElementAttributes attr )
         throws CacheException
     {
@@ -361,12 +295,14 @@ public class CacheAccess
     }
 
     /**
-     * Destroy the region and all objects within it. After calling this method, the Cache object can
+     * Destory the region and all objects within it. After calling this method, the Cache object can
      * no longer be used as it will be closed.
      * <p>
      * @exception CacheException
      * @deprecated
      */
+    @Deprecated
+    @Override
     public void destroy()
         throws CacheException
     {
@@ -386,6 +322,8 @@ public class CacheAccess
      * @deprecated use clear()
      * @throws CacheException
      */
+    @Deprecated
+    @Override
     public void remove()
         throws CacheException
     {
@@ -418,6 +356,8 @@ public class CacheAccess
      * @exception CacheException
      * @deprecated use remove
      */
+    @Deprecated
+    @Override
     public void destroy( Object name )
         throws CacheException
     {
@@ -430,6 +370,7 @@ public class CacheAccess
      * @param name the name of the item to remove.
      * @throws CacheException
      */
+    @Override
     public void remove( Object name )
         throws CacheException
     {
@@ -438,24 +379,26 @@ public class CacheAccess
 
     /**
      * ResetAttributes allows for some of the attributes of a region to be reset in particular
-     * expiration time attributes, time to live, default time to live and idle time, and event
+     * expiration time attriubtes, time to live, default time to live and idle time, and event
      * handlers. Changing default settings on groups and regions will not affect existing objects.
      * Only object loaded after the reset will use the new defaults. If no name argument is
      * provided, the reset is applied to the region.
      * <p>
      * NOTE: this method is does not reset the attributes for items already in the cache. It could
      * potentially do this for items in memory, and maybe on disk (which would be slow) but not
-     * remote items. Rather than have unpredictable behavior, this method just sets the default
+     * remote items. Rather than have unpredicatble behavior, this method just sets the default
      * attributes.
      * <p>
      * TODO is should be renamed "setDefaultElementAttributes"
      * <p>
      * @deprecated As of release 1.3
-     * @see #setDefaultElementAttributes(IElementAttributes)
+     * @see setDefaultElementAttributes
      * @param attr New attributes for this region.
      * @exception CacheException
      * @exception InvalidHandleException
      */
+    @Deprecated
+    @Override
     public void resetElementAttributes( IElementAttributes attr )
         throws CacheException, InvalidHandleException
     {
@@ -465,7 +408,7 @@ public class CacheAccess
     /**
      * This method is does not reset the attributes for items already in the cache. It could
      * potentially do this for items in memory, and maybe on disk (which would be slow) but not
-     * remote items. Rather than have unpredictable behavior, this method just sets the default
+     * remote items. Rather than have unpredicatble behavior, this method just sets the default
      * attributes. Items subsequently put into the cache will use these defaults if they do not
      * specify specific attributes.
      * <p>
@@ -487,11 +430,11 @@ public class CacheAccess
      * @exception CacheException
      * @exception InvalidHandleException if the item does not exist.
      */
+    @Override
     public void resetElementAttributes( Object name, IElementAttributes attr )
         throws CacheException, InvalidHandleException
     {
         ICacheElement element = this.cacheControl.get( (Serializable) name );
-
         if ( element == null )
         {
             throw new InvalidHandleException( "Object for name [" + name + "] is not in the cache" );
@@ -501,8 +444,8 @@ public class CacheAccess
         // i.e. don't do this:
         // element.setElementAttributes( attr );
         // Another reason to call put is to force the changes to be distributed.
-
         put( element.getKey(), element.getVal(), attr );
+
     }
 
     /**
@@ -512,10 +455,12 @@ public class CacheAccess
      * This was confusing, so I created a new method with a clear name.
      * <p>
      * @deprecated As of release 1.3
-     * @see #getDefaultElementAttributes
+     * @see getDefaultElementAttributes
      * @return Attributes for this region
      * @exception CacheException
      */
+    @Deprecated
+    @Override
     public IElementAttributes getElementAttributes()
         throws CacheException
     {
@@ -547,6 +492,7 @@ public class CacheAccess
      * @return Attributes for the object, null if object not in cache
      * @exception CacheException
      */
+    @Override
     public IElementAttributes getElementAttributes( Object name )
         throws CacheException
     {
@@ -601,6 +547,7 @@ public class CacheAccess
      * @return ICompositeCacheAttributes, the controllers config info, defined in the top section of
      *         a region definition.
      */
+    @Override
     public ICompositeCacheAttributes getCacheAttributes()
     {
         return this.cacheControl.getCacheAttributes();
@@ -611,6 +558,7 @@ public class CacheAccess
      * <p>
      * @param cattr The new ICompositeCacheAttribute value
      */
+    @Override
     public void setCacheAttributes( ICompositeCacheAttributes cattr )
     {
         this.cacheControl.setCacheAttributes( cattr );
@@ -626,6 +574,7 @@ public class CacheAccess
      *         get 3.
      * @throws CacheException
      */
+    @Override
     public int freeMemoryElements( int numberToFree )
         throws CacheException
     {
