@@ -24,7 +24,6 @@ import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -37,7 +36,6 @@ import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.disk.AbstractDiskCache;
 import org.apache.jcs.engine.CacheConstants;
 import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.engine.behavior.IElementSerializer;
 import org.apache.jcs.engine.control.group.GroupAttrName;
 import org.apache.jcs.engine.control.group.GroupId;
 import org.apache.jcs.engine.stats.StatElement;
@@ -83,6 +81,8 @@ public class BlockDiskCache
      * Use this lock to synchronize reads and writes to the underlying storage mechansism. We don't
      * need a reentrant lock, since we only lock one level.
      */
+    // private ReentrantWriterPreferenceReadWriteLock storageLock = new
+    // ReentrantWriterPreferenceReadWriteLock();
     private WriterPreferenceReadWriteLock storageLock = new WriterPreferenceReadWriteLock();
 
     /**
@@ -91,20 +91,8 @@ public class BlockDiskCache
      * @param cacheAttributes
      */
     public BlockDiskCache( BlockDiskCacheAttributes cacheAttributes )
-    {
-        this( cacheAttributes, null );
-    }
-
-    /**
-     * Constructs the BlockDisk after setting up the root directory.
-     * <p>
-     * @param cacheAttributes
-     * @param elementSerializer used if supplied, the super's super will not set a null
-     */
-    public BlockDiskCache( BlockDiskCacheAttributes cacheAttributes, IElementSerializer elementSerializer )
     {
         super( cacheAttributes );
-        setElementSerializer( elementSerializer );
 
         this.blockDiskCacheAttributes = cacheAttributes;
         this.logCacheName = "Region [" + getCacheName() + "] ";
@@ -133,7 +121,7 @@ public class BlockDiskCache
             }
             else
             {
-                this.dataFile = new BlockDisk( new File( rootDirectory, fileName + ".data" ), getElementSerializer() );
+                this.dataFile = new BlockDisk( new File( rootDirectory, fileName + ".data" ) );
             }
 
             keyStore = new BlockDiskKeyStore( this.blockDiskCacheAttributes, this );
@@ -157,6 +145,8 @@ public class BlockDiskCache
             log.error( logCacheName + "Failure initializing for fileName: " + fileName + " and root directory: "
                 + rootDirName, e );
         }
+        ShutdownHook shutdownHook = new ShutdownHook();
+        Runtime.getRuntime().addShutdownHook( shutdownHook );
     }
 
     /**
@@ -183,14 +173,14 @@ public class BlockDiskCache
                 Object data = this.dataFile.read( (int[]) entry.getValue() );
                 if ( data == null )
                 {
-                    throw new Exception( logCacheName + "Couldn't find data for key [" + entry.getKey() + "]" );
+                    throw new Exception( "Couldn't find data for key [" + entry.getKey() + "]" );
                 }
             }
             alright = true;
         }
         catch ( Exception e )
         {
-            log.warn( logCacheName + "Problem verifying disk.  Message [" + e.getMessage() + "]" );
+            log.warn( "Problem verifying disk.  Message [" + e.getMessage() + "]" );
             alright = false;
         }
         return alright;
@@ -231,49 +221,6 @@ public class BlockDiskCache
         return keys;
     }
 
-    /**
-     * Gets matching items from the cache.
-     * <p>
-     * @param pattern
-     * @return a map of Serializable key to ICacheElement element, or an empty map if there is no
-     *         data in cache matching keys
-     */
-    public Map processGetMatching( String pattern )
-    {
-        Map elements = new HashMap();
-        try
-        {
-            Object[] keyArray = null;
-            storageLock.readLock().acquire();
-            try
-            {
-                keyArray = this.keyStore.keySet().toArray();
-            }
-            finally
-            {
-                storageLock.readLock().release();
-            }
-
-            Set matchingKeys = getKeyMatcher().getMatchingKeysFromArray( pattern, keyArray );
-
-            Iterator keyIterator = matchingKeys.iterator();
-            while ( keyIterator.hasNext() )
-            {
-                String key = (String) keyIterator.next();
-                ICacheElement element = processGet( key );
-                if ( element != null )
-                {
-                    elements.put( key, element );
-                }
-            }
-        }
-        catch ( Exception e )
-        {
-            log.error( logCacheName + "Failure getting matching from disk, pattern = " + pattern, e );
-        }
-        return elements;
-    }
-
     /**
      * Returns the number of keys.
      * <p>
@@ -288,16 +235,16 @@ public class BlockDiskCache
     /**
      * Gets the ICacheElement for the key if it is in the cache. The program flow is as follows:
      * <ol>
-     * <li>Make sure the disk cache is alive.</li> <li>Get a read lock.</li> <li>See if the key is
-     * in the key store.</li> <li>If we found a key, ask the BlockDisk for the object at the
-     * blocks..</li> <li>Release the lock.</li>
+     * <li>Make sure the disk cache is alive.</li>
+     * <li>Get a read lock.</li>
+     * <li>See if the key is in the key store.</li>
+     * <li>If we found a key, ask the BlockDisk for the object at the blocks..</li>
+     * <li>Release the lock.</li>
      * </ol>
      * (non-Javadoc)
-     * @param key
-     * @return ICacheElement
      * @see org.apache.jcs.auxiliary.disk.AbstractDiskCache#doGet(java.io.Serializable)
      */
-    protected ICacheElement processGet( Serializable key )
+    protected ICacheElement doGet( Serializable key )
     {
         if ( !alive )
         {
@@ -346,16 +293,17 @@ public class BlockDiskCache
     /**
      * Writes an element to disk. The program flow is as follows:
      * <ol>
-     * <li>Aquire write lock.</li> <li>See id an item exists for this key.</li> <li>If an itme
-     * already exists, add its blocks to the remove list.</li> <li>Have the Block disk write the
-     * item.</li> <li>Create a descriptor and add it to the key map.</li> <li>Release the write
-     * lock.</li>
+     * <li>Aquire write lock.</li>
+     * <li>See id an item exists for this key.</li>
+     * <li>If an itme already exists, add its blocks to the remove list.</li>
+     * <li>Have the Block disk write the item.</li>
+     * <li>Create a descriptor and add it to the key map.</li>
+     * <li>Release the write lock.</li>
      * </ol>
      * (non-Javadoc)
-     * @param element
      * @see org.apache.jcs.auxiliary.disk.AbstractDiskCache#doUpdate(org.apache.jcs.engine.behavior.ICacheElement)
      */
-    protected void processUpdate( ICacheElement element )
+    protected void doUpdate( ICacheElement element )
     {
         if ( !alive )
         {
@@ -409,11 +357,9 @@ public class BlockDiskCache
      * implementation always result in a disk orphan.
      * <p>
      * (non-Javadoc)
-     * @param key
-     * @return true if removed anything
      * @see org.apache.jcs.auxiliary.disk.AbstractDiskCache#doRemove(java.io.Serializable)
      */
-    protected boolean processRemove( Serializable key )
+    protected boolean doRemove( Serializable key )
     {
         if ( !alive )
         {
@@ -511,7 +457,7 @@ public class BlockDiskCache
      * (non-Javadoc)
      * @see org.apache.jcs.auxiliary.disk.AbstractDiskCache#doRemoveAll()
      */
-    protected void processRemoveAll()
+    protected void doRemoveAll()
     {
         try
         {
@@ -528,9 +474,9 @@ public class BlockDiskCache
      * Dispose of the disk cache in a background thread. Joins against this thread to put a cap on
      * the disposal time.
      * <p>
-     * TODO make dispose window configurable.
+     * @todo make dispose window configurable.
      */
-    public void processDispose()
+    public void doDispose()
     {
         Runnable disR = new Runnable()
         {
@@ -650,7 +596,7 @@ public class BlockDiskCache
             }
             else
             {
-                this.dataFile = new BlockDisk( new File( rootDirectory, fileName + ".data" ), getElementSerializer() );
+                this.dataFile = new BlockDisk( new File( rootDirectory, fileName + ".data" ) );
             }
 
             this.keyStore.reset();
@@ -675,6 +621,24 @@ public class BlockDiskCache
         this.dataFile.freeBlocks( blocksToFree );
     }
 
+    /**
+     * Called on shutdown. This gives use a chance to store the keys even if the cache manager's
+     * shutdown method was not called.
+     */
+    class ShutdownHook
+        extends Thread
+    {
+        /** Disposes of the cache. This will result force the keys to be persisted. */
+        public void run()
+        {
+            if ( alive )
+            {
+                log.warn( logCacheName + "Disk cache not shutdown properly, shutting down now." );
+                doDispose();
+            }
+        }
+    }
+
     /**
      * Gets basic stats for the disk cache.
      * <p>
@@ -762,14 +726,4 @@ public class BlockDiskCache
 
         return stats;
     }
-
-    /**
-     * This is used by the event logging.
-     * <p>
-     * @return the location of the disk, either path or ip.
-     */
-    protected String getDiskLocation()
-    {
-        return dataFile.getFilePath();
-    }
 }
