@@ -26,73 +26,47 @@ import java.util.Enumeration;
 import java.util.List;
 import java.util.Properties;
 import java.util.StringTokenizer;
-import java.util.concurrent.atomic.AtomicBoolean;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.jcs.auxiliary.AuxiliaryCache;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
-import org.apache.jcs.auxiliary.AuxiliaryCacheConfigurator;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
-import org.apache.jcs.engine.behavior.ICache;
+import org.apache.jcs.config.OptionConverter;
+import org.apache.jcs.config.PropertySetter;
 import org.apache.jcs.engine.behavior.ICompositeCacheAttributes;
 import org.apache.jcs.engine.behavior.IElementAttributes;
-import org.apache.jcs.engine.behavior.IElementSerializer;
-import org.apache.jcs.engine.logging.behavior.ICacheEventLogger;
-import org.apache.jcs.engine.match.KeyMatcherPatternImpl;
-import org.apache.jcs.engine.match.behavior.IKeyMatcher;
-import org.apache.jcs.utils.config.OptionConverter;
-import org.apache.jcs.utils.config.PropertySetter;
 
 /**
  * This class configures JCS based on a properties object.
  * <p>
- * This class is based on the log4j class org.apache.log4j.PropertyConfigurator which was made by:
- * "Luke Blanshard" <Luke@quiq.com>"Mark DONSZELMANN" <Mark.Donszelmann@cern.ch>"Anders Kristensen"
- * <akristensen@dynamicsoft.com>
+ * This class is based on the log4j class org.apache.log4j.PropertyConfigurator
+ * which was made by: "Luke Blanshard" <Luke@quiq.com>"Mark DONSZELMANN"
+ * <Mark.Donszelmann@cern.ch>"Anders Kristensen" <akristensen@dynamicsoft.com>
+ *
  */
 public class CompositeCacheConfigurator
 {
-    /** The logger */
     private final static Log log = LogFactory.getLog( CompositeCacheConfigurator.class );
 
-    /** default region prefix */
     final static String DEFAULT_REGION = "jcs.default";
 
-    /** normal region prefix */
     final static String REGION_PREFIX = "jcs.region.";
 
-    /** system region prefix. might not be used */
     final static String SYSTEM_REGION_PREFIX = "jcs.system.";
 
-    /** auxiliary prefix */
     final static String AUXILIARY_PREFIX = "jcs.auxiliary.";
 
-    /** .attributes */
     final static String ATTRIBUTE_PREFIX = ".attributes";
 
-    /** .cacheattributes */
     final static String CACHE_ATTRIBUTE_PREFIX = ".cacheattributes";
 
-    /** .elementattributes */
     final static String ELEMENT_ATTRIBUTE_PREFIX = ".elementattributes";
 
-    /**
-     * jcs.auxiliary.NAME.keymatcher=CLASSNAME
-     * <p>
-     * jcs.auxiliary.NAME.keymatcher.attributes.CUSTOMPROPERTY=VALUE
-     */
-    public final static String KEY_MATCHER_PREFIX = ".keymatcher";
-    
-    /** Can't operate on the interface. */
-    private CompositeCacheManager compositeCacheManager;
-
-    /** A flag to track whether already configured */
-    private final AtomicBoolean isConfigured = new AtomicBoolean();
+    private final CompositeCacheManager compositeCacheManager;
 
     /**
      * Constructor for the CompositeCacheConfigurator object
-     *<p>
+     *
      * @param ccMgr
      */
     public CompositeCacheConfigurator( CompositeCacheManager ccMgr )
@@ -103,9 +77,9 @@ public class CompositeCacheConfigurator
     /**
      * Configure cached for file name.
      * <p>
-     * This is only used for testing. The manager handles the translation of a file into a
-     * properties object.
-     * <p>
+     * This is only used for testing. The manager handles the translation of a
+     * file into a properties object.
+     *
      * @param configFileName
      */
     protected void doConfigure( String configFileName )
@@ -139,6 +113,7 @@ public class CompositeCacheConfigurator
      * <li>Setup system caches to be used
      * <li>Setup preconfigured caches
      * </ul>
+     *
      * @param properties
      */
     public void doConfigure( Properties properties )
@@ -146,22 +121,19 @@ public class CompositeCacheConfigurator
         long start = System.currentTimeMillis();
 
         // store props for use by non configured caches
-        compositeCacheManager.setConfigurationProperties( properties );
-
+        compositeCacheManager.props = properties;
         // set default value list
         setDefaultAuxValues( properties );
-
         // set default cache attr
         setDefaultCompositeCacheAttributes( properties );
-
         // set default element attr
         setDefaultElementAttributes( properties );
 
-        // set up system caches to be used by non system caches
-        // need to make sure there is no circularity of reference
+        // set up ssytem caches to be used by non system caches
+        // need to make sure there is no circuarity of reference
         parseSystemRegions( properties );
 
-        // setup pre-configured caches
+        // setup preconfigured caches
         parseRegions( properties );
 
         long end = System.currentTimeMillis();
@@ -187,7 +159,7 @@ public class CompositeCacheConfigurator
         long start = System.currentTimeMillis();
 
         // store props for use by non configured caches
-        compositeCacheManager.addConfigurationProperties( properties );
+        compositeCacheManager.props.putAll(properties);
 
         // setup preconfigured caches
         parseRegions( properties );
@@ -202,7 +174,7 @@ public class CompositeCacheConfigurator
 
     /**
      * Set the default aux list for new caches.
-     * <p>
+     *
      * @param props
      */
     protected void setDefaultAuxValues( Properties props )
@@ -218,7 +190,7 @@ public class CompositeCacheConfigurator
 
     /**
      * Set the default CompositeCacheAttributes for new caches.
-     *<p>
+     *
      * @param props
      */
     protected void setDefaultCompositeCacheAttributes( Properties props )
@@ -232,7 +204,7 @@ public class CompositeCacheConfigurator
 
     /**
      * Set the default ElementAttributes for new caches.
-     *<p>
+     *
      * @param props
      */
     protected void setDefaultElementAttributes( Properties props )
@@ -244,8 +216,9 @@ public class CompositeCacheConfigurator
     }
 
     /**
-     * Create caches used internally. System status gives them creation priority.
-     *<p>
+     * Create caches used internally. System status gives them creation
+     * priority.
+     *
      * @param props
      */
     protected void parseSystemRegions( Properties props )
@@ -258,13 +231,13 @@ public class CompositeCacheConfigurator
             {
                 String regionName = key.substring( SYSTEM_REGION_PREFIX.length() );
                 String value = OptionConverter.findAndSubst( key, props );
-                ICache cache;
+                CompositeCache cache;
                 synchronized ( regionName )
                 {
                     cache = parseRegion( props, regionName, value, null, SYSTEM_REGION_PREFIX );
                 }
                 compositeCacheManager.systemCaches.put( regionName, cache );
-                // to be availiable for remote reference they need to be here as
+                // to be available for remote reference they need to be here as
                 // well
                 compositeCacheManager.caches.put( regionName, cache );
             }
@@ -273,7 +246,7 @@ public class CompositeCacheConfigurator
 
     /**
      * Parse region elements.
-     *<p>
+     *
      * @param props
      */
     protected void parseRegions( Properties props )
@@ -290,11 +263,11 @@ public class CompositeCacheConfigurator
 
                 regionNames.add( regionName );
 
-                String auxiliaryList = OptionConverter.findAndSubst( key, props );
-                ICache cache;
+                String value = OptionConverter.findAndSubst( key, props );
+                CompositeCache cache;
                 synchronized ( regionName )
                 {
-                    cache = parseRegion( props, regionName, auxiliaryList );
+                    cache = parseRegion( props, regionName, value );
                 }
                 compositeCacheManager.caches.put( regionName, cache );
             }
@@ -304,11 +277,12 @@ public class CompositeCacheConfigurator
         {
             log.info( "Parsed regions " + regionNames );
         }
+
     }
 
     /**
      * Create cache region.
-     *<p>
+     *
      * @param props
      * @param regName
      * @param value
@@ -322,8 +296,8 @@ public class CompositeCacheConfigurator
     /**
      * Get all the properties for a region and configure its cache.
      * <p>
-     * This method tells the other parse method the name of the region prefix.
-     *<p>
+     * This method tells the otehr parse method the name of the region prefix.
+     *
      * @param props
      * @param regName
      * @param value
@@ -337,7 +311,7 @@ public class CompositeCacheConfigurator
 
     /**
      * Get all the properties for a region and configure its cache.
-     *<p>
+     *
      * @param props
      * @param regName
      * @param value
@@ -346,7 +320,7 @@ public class CompositeCacheConfigurator
      * @return CompositeCache
      */
     protected CompositeCache parseRegion( Properties props, String regName, String value,
-                                          ICompositeCacheAttributes cca, String regionPrefix )
+                                         ICompositeCacheAttributes cca, String regionPrefix )
     {
         // First, create or get the cache and element attributes, and create
         // the cache.
@@ -413,11 +387,11 @@ public class CompositeCacheConfigurator
     }
 
     /**
-     * Get an ICompositeCacheAttributes for the listed region.
-     *<p>
+     * Get an compositecacheattributes for the listed region.
+     *
      * @param props
      * @param regName
-     * @return ICompositeCacheAttributes
+     * @return
      */
     protected ICompositeCacheAttributes parseCompositeCacheAttributes( Properties props, String regName )
     {
@@ -426,14 +400,14 @@ public class CompositeCacheConfigurator
 
     /**
      * Get the main attributes for a region.
-     *<p>
+     *
      * @param props
      * @param regName
      * @param regionPrefix
      * @return ICompositeCacheAttributes
      */
     protected ICompositeCacheAttributes parseCompositeCacheAttributes( Properties props, String regName,
-                                                                       String regionPrefix )
+                                                                      String regionPrefix )
     {
         ICompositeCacheAttributes ccAttr;
 
@@ -448,8 +422,7 @@ public class CompositeCacheConfigurator
         {
             if ( log.isInfoEnabled() )
             {
-                log.info( "No special CompositeCacheAttributes class defined for key [" + attrName
-                    + "], using default class." );
+                log.info( "No special CompositeCacheAttributes class defined for key [" + attrName + "], using default class." );
             }
 
             ICompositeCacheAttributes ccAttr2 = compositeCacheManager.getDefaultCacheAttributes();
@@ -475,8 +448,9 @@ public class CompositeCacheConfigurator
     }
 
     /**
-     * Create the element attributes from the properties object for a cache region.
-     *<p>
+     * Create the element attributes from the properties object for a cache
+     * region.
+     *
      * @param props
      * @param regName
      * @param regionPrefix
@@ -523,11 +497,15 @@ public class CompositeCacheConfigurator
 
     /**
      * Get an aux cache for the listed aux for a region.
-     *<p>
-     * @param cache the cache manager
-     * @param props the configuration properties
-     * @param auxName the name of the auxiliary cache
-     * @param regName the name of the region.
+     *
+     * @param cache
+     *            the cache manager
+     * @param props
+     *            the configuration propeties
+     * @param auxName
+     *            the name of the auxiliary cache
+     * @param regName
+     *            the name of the region.
      * @return AuxiliaryCache
      */
     protected AuxiliaryCache parseAuxiliary( CompositeCache cache, Properties props, String auxName, String regName )
@@ -569,7 +547,7 @@ public class CompositeCacheConfigurator
             String prefix = AUXILIARY_PREFIX + auxName + ATTRIBUTE_PREFIX;
             auxAttr = (AuxiliaryCacheAttributes) OptionConverter
                 .instantiateByKey( props, prefix, org.apache.jcs.auxiliary.AuxiliaryCacheAttributes.class, null );
-            if ( auxAttr == null )
+            if ( auxFac == null )
             {
                 log.error( "Could not instantiate auxAttr named '" + attrName + "'" );
                 return null;
@@ -595,63 +573,11 @@ public class CompositeCacheConfigurator
 
         // GET CACHE FROM FACTORY WITH ATTRIBUTES
         auxAttr.setCacheName( regName );
-
-        String auxPrefix = AUXILIARY_PREFIX + auxName;
-
-        // CONFIGURE THE EVENT LOGGER
-        ICacheEventLogger cacheEventLogger = AuxiliaryCacheConfigurator.parseCacheEventLogger( props, auxPrefix );
-
-        // CONFIGURE THE ELEMENT SERIALIZER
-        IElementSerializer elementSerializer = AuxiliaryCacheConfigurator.parseElementSerializer( props, auxPrefix );
-
-        // CONFIGURE THE KEYMATCHER
-        //IKeyMatcher keyMatcher = parseKeyMatcher( props, auxPrefix );
-        // TODO add to factory interface
-        
         // Consider putting the compositeCache back in the factory interface
         // since the manager may not know about it at this point.
-        // need to make sure the manager already has the cache
+        // need to make sure the maanger already has the cache
         // before the auxiliary is created.
-        auxCache = auxFac.createCache( auxAttr, compositeCacheManager, cacheEventLogger, elementSerializer );
-
+        auxCache = auxFac.createCache( auxAttr, compositeCacheManager );
         return auxCache;
     }
-    
-    /**
-     * Creates a custom key matcher if one is defined.  Else, it uses the default.
-     * <p>
-     * @param props
-     * @param auxPrefix - ex. AUXILIARY_PREFIX + auxName
-     * @return IKeyMatcher
-     */
-    public static IKeyMatcher parseKeyMatcher( Properties props, String auxPrefix )
-    {
-        IKeyMatcher keyMatcher = null;
-
-        // auxFactory was not previously initialized.
-        String keyMatcherClassName = auxPrefix + KEY_MATCHER_PREFIX;
-        keyMatcher = (IKeyMatcher) OptionConverter
-            .instantiateByKey( props, keyMatcherClassName,
-                               IKeyMatcher.class, null );
-        if ( keyMatcher != null )
-        {
-            String attributePrefix = auxPrefix + KEY_MATCHER_PREFIX + ATTRIBUTE_PREFIX;
-            PropertySetter.setProperties( keyMatcher, props, attributePrefix + "." );
-            if ( log.isInfoEnabled() )
-            {
-                log.info( "Using custom key matcher [" + keyMatcher + "] for auxiliary [" + auxPrefix
-                    + "]" );
-            }
-        }
-        else
-        {
-            // use the default standard serializer
-            keyMatcher = new KeyMatcherPatternImpl();
-            if ( log.isInfoEnabled() )
-            {
-                log.info( "Using standard key matcher [" + keyMatcher + "] for auxiliary [" + auxPrefix + "]" );
-            }
-        }
-        return keyMatcher;
-    }    
 }
