@@ -23,12 +23,14 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.Serializable;
 import java.util.ArrayList;
-import java.util.Enumeration;
+import java.util.Collection;
 import java.util.HashSet;
-import java.util.Hashtable;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Properties;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
@@ -67,10 +69,10 @@ public class CompositeCacheManager
     private final static Log log = LogFactory.getLog( CompositeCacheManager.class );
 
     /** Caches managed by this cache manager */
-    protected Hashtable caches = new Hashtable();
+    protected final ConcurrentMap<String, CompositeCache> caches = new ConcurrentHashMap<>(48, 0.9F, 1);
 
     /** Internal system caches for this cache manager */
-    protected Hashtable systemCaches = new Hashtable();
+    protected final ConcurrentMap<String, CompositeCache> systemCaches = new ConcurrentHashMap<>(16, 0.9F, 1);
 
     /** Number of clients accessing this cache manager */
     private int clients;
@@ -82,10 +84,10 @@ public class CompositeCacheManager
     protected IElementAttributes defaultElementAttr = new ElementAttributes();
 
     /** Used to keep track of configured auxiliaries */
-    protected Hashtable auxFacs = new Hashtable( 11 );
+    protected final ConcurrentMap<String, AuxiliaryCacheFactory> auxFacs = new ConcurrentHashMap<>(4, 0.9F, 1);
 
     /** ??? */
-    protected Hashtable auxAttrs = new Hashtable( 11 );
+    protected final ConcurrentMap<String, AuxiliaryCacheAttributes> auxAttrs = new ConcurrentHashMap<>(4, 0.9F, 1);
 
     /** Properties with which this manager was configured */
     protected Properties props;
@@ -372,6 +374,7 @@ public class CompositeCacheManager
      * @param cacheName
      * @return CompositeCache -- the cache region controller
      */
+    @Override
     public CompositeCache getCache( String cacheName )
     {
         return getCache( cacheName, this.defaultCacheAttr.copy() );
@@ -417,12 +420,12 @@ public class CompositeCacheManager
 
     /**
      * If the cache has already been created, then the CacheAttributes and the
-     * element Attributes will be ignored. Currently there is no overiding the
+     * element Attributes will be ignored. Currently there is no overriding the
      * CacheAttributes once it is set up. You can change the default
      * ElementAttributes for a region later.
      * <p>
-     * Overriding the default elemental atributes will require changing the way
-     * the atributes are assigned to elements. Get cache creates a cache with
+     * Overriding the default elemental attributes will require changing the way
+     * the attributes are assigned to elements. Get cache creates a cache with
      * defaults if none are specified. We might want to create separate method
      * for creating/getting. . .
      *
@@ -432,28 +435,19 @@ public class CompositeCacheManager
      */
     public CompositeCache getCache( ICompositeCacheAttributes cattr, IElementAttributes attr )
     {
-        CompositeCache cache;
+        CompositeCache cache = caches.get(cattr.getCacheName());
+        if (null == cache) {
+            synchronized ( caches ) {
+                cache = caches.get(cattr.getCacheName());
+                if (null == cache) {
+                    cattr.setCacheName( cattr.getCacheName() );
+                    CompositeCacheConfigurator configurator = new CompositeCacheConfigurator( this );
+                    cache = configurator.parseRegion( this.props, cattr.getCacheName(), this.defaultAuxValues, cattr );
+                    caches.put( cattr.getCacheName(), cache );
 
-        if ( log.isDebugEnabled() )
-        {
-            log.debug( "attr = " + attr );
-        }
-
-        synchronized ( caches )
-        {
-            cache = (CompositeCache) caches.get( cattr.getCacheName() );
-            if ( cache == null )
-            {
-                cattr.setCacheName( cattr.getCacheName() );
-
-                CompositeCacheConfigurator configurator = new CompositeCacheConfigurator( this );
-
-                cache = configurator.parseRegion( this.props, cattr.getCacheName(), this.defaultAuxValues, cattr );
-
-                caches.put( cattr.getCacheName(), cache );
+                }
             }
         }
-
         return cache;
     }
 
@@ -471,7 +465,7 @@ public class CompositeCacheManager
      */
     public void freeCache( String name, boolean fromRemote )
     {
-        CompositeCache cache = (CompositeCache) caches.remove( name );
+        CompositeCache cache = caches.remove( name );
 
         if ( cache != null )
         {
@@ -542,12 +536,7 @@ public class CompositeCacheManager
                 log.debug( "Last client called release. There are " + caches.size() + " caches which will be disposed" );
             }
 
-            Enumeration allCaches = caches.elements();
-
-            while ( allCaches.hasMoreElements() )
-            {
-                CompositeCache cache = (CompositeCache) allCaches.nextElement();
-
+            for (CompositeCache cache : caches.values()) {
                 if ( cache != null )
                 {
                     cache.dispose( fromRemote );
@@ -563,13 +552,7 @@ public class CompositeCacheManager
      */
     public String[] getCacheNames()
     {
-        String[] list = new String[caches.size()];
-        int i = 0;
-        for ( Iterator itr = caches.keySet().iterator(); itr.hasNext(); )
-        {
-            list[i++] = (String) itr.next();
-        }
-        return list;
+        return new ArrayList<>(caches.keySet()).toArray(new String[new ArrayList<>(caches.keySet()).size()]);
     }
 
     /**
@@ -602,7 +585,7 @@ public class CompositeCacheManager
      */
     AuxiliaryCacheFactory registryFacGet( String name )
     {
-        return (AuxiliaryCacheFactory) auxFacs.get( name );
+        return auxFacs.get( name );
     }
 
     /**
@@ -619,7 +602,7 @@ public class CompositeCacheManager
      */
     AuxiliaryCacheAttributes registryAttrGet( String name )
     {
-        return (AuxiliaryCacheAttributes) auxAttrs.get( name );
+        return auxAttrs.get( name );
     }
 
     /**
@@ -655,18 +638,16 @@ public class CompositeCacheManager
      */
     public ICacheStats[] getStatistics()
     {
-        ArrayList cacheStats = new ArrayList();
-        Enumeration allCaches = caches.elements();
-        while ( allCaches.hasMoreElements() )
+        Collection<CompositeCache> allCaches = caches.values();
+        List<ICacheStats> cacheStats = new ArrayList<ICacheStats>(allCaches.size());
+        for ( CompositeCache cache : allCaches )
         {
-            CompositeCache cache = (CompositeCache) allCaches.nextElement();
             if ( cache != null )
             {
                 cacheStats.add( cache.getStatistics() );
             }
         }
-        ICacheStats[] stats = (ICacheStats[]) cacheStats.toArray( new CacheStats[0] );
-        return stats;
+        return cacheStats.toArray( new CacheStats[cacheStats.size()] );
     }
 
     /**
@@ -678,6 +659,7 @@ public class CompositeCacheManager
      * <p>
      * @param observer
      */
+    @Override
     public void registerShutdownObserver( IShutdownObserver observer )
     {
         // synchronized to take care of iteration safety
@@ -694,6 +676,7 @@ public class CompositeCacheManager
      *
      * @see org.apache.jcs.engine.behavior.ShutdownObservable#deregisterShutdownObserver(org.apache.jcs.engine.behavior.ShutdownObserver)
      */
+    @Override
     public void deregisterShutdownObserver( IShutdownObserver observer )
     {
         synchronized ( shutdownObservers )
