@@ -131,7 +131,7 @@ public final class CacheEventServiceImpl implements CacheEventService, CacheEven
 
                         // Deliver events
                         for (StampedCacheEvent sce : drained) {
-                            CacheEventServiceImpl.this.notify(sce.listeners, sce.sender, sce.event, sce.fromRemote);
+                            CacheEventServiceImpl.this.notify(sce.listeners, sce.sender, sce.event, sce.fromRemote, true);
                         }
 
                         // Terminate?
@@ -215,12 +215,21 @@ public final class CacheEventServiceImpl implements CacheEventService, CacheEven
          * perform notifications
          */
         if (false == listenersToNotify.isEmpty()) {
-            if (delayedEvents.offerIfAbsentElseReset(listenersToNotify, sender, event, fromRemote)) {
-                /*
-                 * increment offered events
-                 */
-                if (offeredEvents.incrementAndGet() < 0L) {
-                    offeredEvents.set(0L);
+            if (fromRemote) {
+                // Deliver remotely received event immediately to local cache listeners to prevent event being aggregated into another local
+                // event and thus re-distributed remotely again
+                try {
+                    notify(listenersToNotify, sender, event, fromRemote, false);
+                } catch (Exception e) {
+                    LOG.warn("Failed to notify cache listeners about {} event: {}", fromRemote ? "remote" : "local", event, e);
+                }
+            } else {
+                // Schedule locally received event for being processed. Possibly aggregate it into another event.
+                if (delayedEvents.offerIfAbsentElseReset(listenersToNotify, sender, event, fromRemote)) {
+                    // Increment offered events
+                    if (offeredEvents.incrementAndGet() < 0L) {
+                        offeredEvents.set(0L);
+                    }
                 }
             }
         }
@@ -236,9 +245,9 @@ public final class CacheEventServiceImpl implements CacheEventService, CacheEven
         List<CacheListener> listeners = cacheRegionListeners.get(region);
         if (null == listeners) {
             listeners = new CopyOnWriteArrayList<CacheListener>();
-            List<CacheListener> exitingListeners = cacheRegionListeners.putIfAbsent(region, listeners);
-            if (null != exitingListeners) {
-                return exitingListeners;
+            List<CacheListener> existingListeners = cacheRegionListeners.putIfAbsent(region, listeners);
+            if (null != existingListeners) {
+                return existingListeners;
             }
         }
         return listeners;
@@ -251,8 +260,9 @@ public final class CacheEventServiceImpl implements CacheEventService, CacheEven
      * @param sender The sender
      * @param event The event
      * @param fromRemote Whether remotely or locally generated
+     * @param incrementDeliveredEvents Whether number of delivered events should be incremented
      */
-    protected void notify(final List<CacheListener> listeners, final Object sender, final CacheEvent event, final boolean fromRemote) {
+    protected void notify(final List<CacheListener> listeners, final Object sender, final CacheEvent event, final boolean fromRemote, final boolean incrementDeliveredEvents) {
         Runnable notificationRunnable = new Runnable() {
 
             @Override
@@ -272,7 +282,7 @@ public final class CacheEventServiceImpl implements CacheEventService, CacheEven
                 /*
                  * track delivery
                  */
-                if (deliveredEvents.incrementAndGet() < 0L) {
+                if (incrementDeliveredEvents && deliveredEvents.incrementAndGet() < 0L) {
                     deliveredEvents.set(0L);
                 }
             }
