@@ -63,9 +63,6 @@ import com.openexchange.ajax.writer.AppointmentWriter;
 import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.calendar.json.AppointmentAJAXRequest;
 import com.openexchange.calendar.json.AppointmentActionFactory;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.calendar.AppointmentSqlFactoryService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
@@ -81,8 +78,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
  */
-@Action(method = RequestMethod.PUT, name = "new", description = "Create an appointment.", parameters = { @Parameter(name = "session", description = "A session ID previously obtained from the login module.")
-}, requestBody = "Appointment object as described in Common object data, Detailed task and appointment data and Detailed appointment data. The field id is not present.", responseDescription = "If the appointment was created successfully, an object with the attribute id of the newly created appointment. If the appointment could not be created due to conflicts, the response body is an object with the field conflicts, which is an array of appointment objects which caused the conflict. Each appointment object which represents a resource conflict contains an additional field hard_conflict with the Boolean value true. If the user does not have read access to a conflicting appointment, only the fields id, start_date, end_date, shown_as and participants are present and the field participants contains only the participants which caused the conflict.")
 @OAuthAction(AppointmentActionFactory.OAUTH_WRITE_SCOPE)
 public final class NewAction extends AppointmentAction {
 
@@ -90,7 +85,7 @@ public final class NewAction extends AppointmentAction {
 
     /**
      * Initializes a new {@link NewAction}.
-     * 
+     *
      * @param services
      */
     public NewAction(final ServiceLookup services) {
@@ -100,6 +95,9 @@ public final class NewAction extends AppointmentAction {
     @Override
     protected AJAXRequestResult perform(final AppointmentAJAXRequest req) throws OXException, JSONException {
         final JSONObject jData = req.getData();
+        if (null == jData) {
+            throw AjaxExceptionCodes.INVALID_JSON_REQUEST_BODY.create();
+        }
         final TimeZone timeZone;
         {
             final String timeZoneId = req.getParameter(AJAXServlet.PARAMETER_TIMEZONE);
