@@ -51,20 +51,16 @@ package com.openexchange.calendar.itip;
 
 import java.sql.Connection;
 import java.sql.SQLException;
-import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
 import com.openexchange.api2.AppointmentSQLInterface;
 import com.openexchange.calendar.AppointmentDiff;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.attach.AttachmentBatch;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.OXCalendarExceptionCodes;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.CalendarObject;
-import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.groupware.container.GroupParticipant;
-import com.openexchange.groupware.container.Participant;
-import com.openexchange.groupware.container.UserParticipant;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.search.AppointmentSearchObject;
@@ -72,8 +68,6 @@ import com.openexchange.groupware.search.Order;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.oxfolder.OXFolderAccess;
-import com.openexchange.tools.session.ServerSessionAdapter;
 import com.openexchange.user.UserService;
 
 public class ITipConsistencyCalendar extends ITipCalendarWrapper implements AppointmentSQLInterface {
@@ -169,105 +163,12 @@ public class ITipConsistencyCalendar extends ITipCalendarWrapper implements Appo
         @Override
         public void delete(final CalendarDataObject appointmentObject, final int inFolder, final Date clientLastModified, final boolean checkPermissions) throws OXException {
             try {
-                final CalendarDataObject original = delegate.getObjectById(appointmentObject.getObjectID(), inFolder);
-                if (original.containsUntil() && original.containsOccurrence()) {
-                    original.removeUntil();
-                }
-                if (onlyOneParticipantRemaining(original)) {
-                    cleanOccurrencesAndUnitl(original);
-                    delegate.deleteAppointmentObject(appointmentObject, inFolder, clientLastModified, checkPermissions);
-                } else {
-                    removeCurrentUserFromParticipants(original);
-                    original.setExternalOrganizer(true);
-                    original.setIgnoreConflicts(true);
-                    delegate.updateAppointmentObject(original, inFolder, clientLastModified, checkPermissions);
-                }
-            } catch (final SQLException e) {
+                delegate.deleteAppointmentObject(appointmentObject, inFolder, clientLastModified, checkPermissions);
+            } catch (SQLException e) {
                 throw OXCalendarExceptionCodes.SQL_ERROR.create(e);
             }
         }
 
-        private void cleanOccurrencesAndUnitl(CalendarDataObject original) {
-            if (original.containsOccurrence()) {
-                original.removeUntil();
-            }
-        }
-
-        private void removeCurrentUserFromParticipants(final CalendarDataObject original) {
-            // New participants are all externals + all resources + all resolved
-            // users from user participants - the current user participant
-            int folderOwner = getSharedFolderOwner(original, session);
-            final List<Participant> participants = new ArrayList<Participant>();
-            final Participant[] p = original.getParticipants();
-            if (p != null) {
-                for (final Participant participant : p) {
-                    if (!(participant instanceof GroupParticipant)
-                        && !(participant instanceof UserParticipant)) {
-                        participants.add(participant);
-                    }
-                }
-            }
-
-            final UserParticipant[] u = original.getUsers();
-            final List<UserParticipant> newUserParticipants = new ArrayList<UserParticipant>();
-
-            if (u != null) {
-                for (final UserParticipant userParticipant : u) {
-                    if (userParticipant.getIdentifier() != folderOwner) {
-                        participants.add(userParticipant);
-                        newUserParticipants.add(userParticipant);
-                    }
-                }
-            }
-
-            original.setParticipants(participants);
-            original.setUsers(newUserParticipants);
-        }
-
-        private int getSharedFolderOwner(final CalendarDataObject cdao, final Session session) {
-            if (cdao.getFolderType() != FolderObject.SHARED) {
-                return session.getUserId();
-            }
-            try {
-                final OXFolderAccess oxfa = new OXFolderAccess(new ServerSessionAdapter(session).getContext());
-                return oxfa.getFolderOwner(cdao.getParentFolderID());
-            } catch (final OXException e) {
-                e.printStackTrace();
-                return session.getUserId();
-            }
-        }
-
-        private boolean onlyOneParticipantRemaining(final CalendarDataObject original) {
-            int user = getSharedFolderOwner(original, session);
-            final Participant[] participants = original.getParticipants();
-            if (participants != null) {
-                for (final Participant p : participants) {
-                    if (p instanceof UserParticipant) {
-                        final UserParticipant up = (UserParticipant) p;
-                        if (up.getIdentifier() != user) {
-                            return false;
-                        }
-                    }
-                }
-                return true;
-            }
-
-            final UserParticipant[] userParticipants = original.getUsers();
-            if (userParticipants != null) {
-                if (userParticipants.length > 1) {
-                    return false;
-                }
-
-                if (userParticipants.length == 0) {
-                    return true;
-                }
-
-                final UserParticipant up = userParticipants[0];
-                return up.getIdentifier() == user;
-            }
-            return true;
-        }
-
     }
 
     public ITipConsistencyCalendar(final AppointmentSQLInterface delegate,
@@ -552,11 +453,8 @@ public class ITipConsistencyCalendar extends ITipCalendarWrapper implements Appo
     }
 
     @Override
-    public long attachmentAction(final int folderId, final int objectId, final int userId,
-        final Session session, final Context c, final int numberOfAttachments)
-            throws OXException {
-        return delegate.attachmentAction(folderId, objectId, userId, session, c,
-            numberOfAttachments);
+    public long attachmentAction(final int folderId, final int objectId, final int userId, final Session session, final Context c, final int numberOfAttachments, AttachmentBatch batch) throws OXException {
+        return delegate.attachmentAction(folderId, objectId, userId, session, c, numberOfAttachments, batch);
     }
 
     @Override
