@@ -112,7 +112,7 @@ public abstract class AbstractITipAnalyzer implements ITipAnalyzer {
 			Appointment.OBJECT_ID, Appointment.CREATED_BY,
 			Appointment.CREATION_DATE, Appointment.LAST_MODIFIED,
 			Appointment.LAST_MODIFIED_UTC, Appointment.MODIFIED_BY,
-			Appointment.SEQUENCE };
+			Appointment.SEQUENCE, Appointment.ALARM };
 	protected ITipIntegrationUtility util;
 	protected ServiceLookup services;
 
@@ -550,19 +550,23 @@ public abstract class AbstractITipAnalyzer implements ITipAnalyzer {
 
         if (!found) {
             final UserParticipant up = new UserParticipant(owner);
-            if (confirm != -1) {
-                up.setConfirm(confirm);
-            }
+            up.setConfirm(confirm);
             final Participant[] tmp = appointment.getParticipants();
             final List<Participant> participantList = (null == tmp) ? new ArrayList<Participant>(1) : new ArrayList<Participant>(Arrays.asList(tmp));
             participantList.add(up);
             appointment.setParticipants(participantList);
         }
+        
+        List<UserParticipant> users = appointment.getUsers() == null ? new ArrayList<UserParticipant>() : new ArrayList<UserParticipant>(Arrays.asList(appointment.getUsers()));
+        for (Participant p : appointment.getParticipants()) {
+            if (p.getType() == Participant.USER) {
+                users.add((UserParticipant) p);
+            }
+        }
 
         found = false;
-        final UserParticipant[] users = appointment.getUsers();
         if (users != null) {
-            for (final UserParticipant userParticipant : users) {
+            for (UserParticipant userParticipant : users) {
                 if (userParticipant.getIdentifier() == owner) {
                     found = true;
                 }
@@ -570,14 +574,10 @@ public abstract class AbstractITipAnalyzer implements ITipAnalyzer {
         }
 
         if (!found) {
-            final UserParticipant up = new UserParticipant(owner);
-            if (confirm != -1) {
-                up.setConfirm(confirm);
-            }
-            final UserParticipant[] tmp = appointment.getUsers();
-            final List<UserParticipant> participantList = (tmp == null) ? new ArrayList<UserParticipant>(1) : new ArrayList<UserParticipant>(Arrays.asList(tmp));
-            participantList.add(up);
-            appointment.setUsers(participantList);
+            UserParticipant up = new UserParticipant(owner);
+            up.setConfirm(confirm);
+            users.add(up);
         }
+        appointment.setUsers(users);
     }
 }
