@@ -75,12 +75,12 @@ import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.capabilities.Capability;
 import com.openexchange.capabilities.CapabilityChecker;
-import com.openexchange.capabilities.FailureAwareCapabilityChecker;
 import com.openexchange.capabilities.CapabilityExceptionCodes;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.capabilities.CapabilitySet;
 import com.openexchange.capabilities.ConfigurationProperty;
 import com.openexchange.capabilities.DependentCapabilityChecker;
+import com.openexchange.capabilities.FailureAwareCapabilityChecker;
 import com.openexchange.capabilities.osgi.PermissionAvailabilityServiceRegistry;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ComposedConfigProperty;
@@ -98,9 +98,11 @@ import com.openexchange.groupware.userconfiguration.service.PermissionAvailabili
 import com.openexchange.java.BoolReference;
 import com.openexchange.java.ConcurrentEnumMap;
 import com.openexchange.java.Strings;
+import com.openexchange.log.LogProperties;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.session.Session;
 import com.openexchange.share.core.tools.ShareTool;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -302,7 +304,38 @@ public abstract class AbstractCapabilityService implements CapabilityService {
                 }
             }
         }
-        return tmp.booleanValue();
+
+        String hostname = LogProperties.getHostName();
+        if (Strings.isEmpty(hostname)) {
+            return tmp.booleanValue();
+        }
+
+        // Determine "autologin" capability by host name
+        return isAutologinEnabledForHost(hostname, tmp.booleanValue());
+    }
+
+    private boolean isAutologinEnabledForHost(String hostname, boolean defaultValue) {
+        boolean isEnabled = defaultValue;
+        ServerConfigService serverConfigService = services.getService(ServerConfigService.class);
+        if (serverConfigService != null) {
+            try {
+                List<Map<String, Object>> applicableConfigs = serverConfigService.getCustomHostConfigurations(hostname, -1, -1);
+                isEnabled = getBooleanPropertyFromMaps(applicableConfigs, "com.openexchange.sessiond.autologin", isEnabled);
+            } catch (OXException e) {
+                LOG.error("", e);
+            }
+        }
+        return isEnabled;
+    }
+
+    private boolean getBooleanPropertyFromMaps(List<Map<String, Object>> applicableConfigs, String propertyName, boolean defaultValue) {
+        for (Map<String, Object> map : applicableConfigs) {
+            Object obj = map.get(propertyName);
+            if (obj instanceof Boolean) {
+                return ((Boolean) obj).booleanValue();
+            }
+        }
+        return defaultValue;
     }
 
     private static final Capability CAP_AUTO_LOGIN = new Capability("autologin");
@@ -592,13 +625,33 @@ public abstract class AbstractCapabilityService implements CapabilityService {
             for (Map.Entry<String, ComposedConfigProperty<String>> entry : all.entrySet()) {
                 final String propName = entry.getKey();
                 if (propName.startsWith("com.openexchange.capability.", 0)) {
-                    boolean value = Boolean.parseBoolean(entry.getValue().get());
+                    ComposedConfigProperty<String> configProperty = entry.getValue();
+                    /*
+                     * don't apply undefined capabilities
+                     */
+                    if (false == configProperty.isDefined()) {
+                        LOG.debug("Ignoring undefined capability property for user {} in context {}: {}", 
+                            Integer.valueOf(userId), Integer.valueOf(contextId), propName);
+                        continue;
+                    }
+                    /*
+                     * apply capability
+                     */                    
                     String name = toLowerCase(propName.substring(28));
-                    if (value) {
+                    String value = configProperty.get();
+                    if (Boolean.parseBoolean(value)) {
                         capabilities.add(getCapability(name));
                     } else {
                         capabilities.remove(name);
                     }
+                    /*
+                     * additionally check for discouraged use of module permissions
+                     */                    
+                    Permission matchingModulePermission = Permission.get(name);
+                    if (null != matchingModulePermission) {
+                        LOG.debug("Overriding module permission {} with 'capability' property {}={} for user {} in context {}.", 
+                            matchingModulePermission, propName, value, Integer.valueOf(userId), Integer.valueOf(contextId));
+                    }
                 }
             }
 
@@ -971,7 +1024,13 @@ public abstract class AbstractCapabilityService implements CapabilityService {
                 for (Map.Entry<String, ComposedConfigProperty<String>> entry : all.entrySet()) {
                     final String propName = entry.getKey();
                     if (propName.startsWith("com.openexchange.capability.")) {
-                        boolean value = Boolean.parseBoolean(entry.getValue().get());
+                        ComposedConfigProperty<String> configProperty = entry.getValue();
+                        if (false == configProperty.isDefined()) {
+                            LOG.debug("Ignoring undefined capability property for user {} in context {}: {}", 
+                                Integer.valueOf(userId), Integer.valueOf(contextId), propName);
+                            continue;
+                        }
+                        boolean value = Boolean.parseBoolean(configProperty.get());
                         String name = toLowerCase(propName.substring(28));
                         if (value) {
                             grantedCapabilities.add(getCapability(name));
