@@ -59,6 +59,7 @@ import com.openexchange.cluster.lock.ClusterTask;
 import com.openexchange.cluster.lock.policies.RetryPolicy;
 import com.openexchange.cluster.lock.policies.RunOnceRetryPolicy;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.sql.DBUtils;
@@ -80,7 +81,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /**
      * Initialises a new {@link ClusterLockServiceDatabaseImpl}.
-     * 
+     *
      * @param services The {@link ServiceLookup} instance
      */
     public ClusterLockServiceDatabaseImpl(ServiceLookup services) {
@@ -89,7 +90,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.cluster.lock.ClusterLockService#acquireClusterLock(com.openexchange.cluster.lock.ClusterTask)
      */
     @Override
@@ -103,7 +104,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
         ResultSet resultSet = null;
 
         try {
-            long timeNow = System.nanoTime();
+            long timeNow = System.currentTimeMillis();
             if (acquireClusterLock(clusterTask, timeNow, connection)) {
                 return true;
             }
@@ -123,7 +124,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.cluster.lock.ClusterLockService#releaseClusterLock(com.openexchange.cluster.lock.ClusterTask)
      */
     @Override
@@ -133,7 +134,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.cluster.lock.ClusterLockService#runClusterTask(com.openexchange.cluster.lock.ClusterTask)
      */
     @Override
@@ -143,7 +144,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.cluster.lock.ClusterLockService#runClusterTask(com.openexchange.cluster.lock.ClusterTask, com.openexchange.cluster.lock.policies.RetryPolicy)
      */
     @Override
@@ -163,7 +164,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
         /**
          * Initialises a new {@link RefreshLockTask}.
-         * 
+         *
          * @param clusterTask The {@link ClusterTask} to refresh
          */
         public RefreshLockTask(ClusterTask<T> clusterTask) {
@@ -173,7 +174,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
         /*
          * (non-Javadoc)
-         * 
+         *
          * @see java.lang.Runnable#run()
          */
         @Override
@@ -191,7 +192,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
                 statement = connection.prepareStatement(UPDATE_TIMESTAMP);
 
                 int pos = 1;
-                statement.setString(pos++, Long.toString(System.nanoTime()));
+                statement.setString(pos++, Long.toString(System.currentTimeMillis()));
                 statement.setInt(pos++, contextId);
                 statement.setInt(pos++, userId);
                 statement.setString(pos++, clusterTask.getTaskName());
@@ -209,7 +210,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
     /**
      * Inserts the specified timestamp in the database using the specified writable {@link Connection}
-     * 
+     *
      * @param clusterTask The {@link ClusterTask}
      * @param now The timestamp to insert
      * @param connection The writable {@link Connection}
@@ -233,13 +234,13 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
             return statement.executeUpdate() > 0;
         } finally {
-            DBUtils.closeSQLStuff(statement);
+            Databases.closeSQLStuff(statement);
         }
     }
 
     /**
      * Returns the already existing timestamp from the database
-     * 
+     *
      * @param clusterTask The {@link ClusterTask}
      * @param connection The {@link Connection}
      * @return The timestamp
@@ -259,13 +260,13 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
             return Long.parseLong(resultSet.getString(index));
         } finally {
-            DBUtils.closeSQLStuff(statement);
+            Databases.closeSQLStuff(statement);
         }
     }
 
     /**
      * Updates the timestamp for the specified {@link ClusterTask}
-     * 
+     *
      * @param clusterTask The {@link ClusterTask}
      * @param timeNow The time now
      * @param timeThen The time then
@@ -287,13 +288,13 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
 
             return statement.executeUpdate() > 0;
         } finally {
-            DBUtils.closeSQLStuff(statement);
+            Databases.closeSQLStuff(statement);
         }
     }
 
     /**
      * Deletes the timestamp for the specified {@link ClusterTask}
-     * 
+     *
      * @param clusterTask The {@link ClusterTask}
      * @throws OXException if an error is occurred
      */
@@ -316,7 +317,7 @@ public class ClusterLockServiceDatabaseImpl extends AbstractClusterLockServiceIm
         } catch (SQLException e) {
             throw ClusterLockExceptionCodes.SQL_ERROR.create(e.getMessage(), e);
         } finally {
-            DBUtils.closeSQLStuff(statement);
+            Databases.closeSQLStuff(statement);
         }
     }
 }
