@@ -77,6 +77,7 @@ import com.openexchange.contact.storage.rdb.search.ContactSearchAdapter;
 import com.openexchange.contact.storage.rdb.search.FulltextAutocompleteAdapter;
 import com.openexchange.contact.storage.rdb.search.SearchAdapter;
 import com.openexchange.contact.storage.rdb.search.SearchTermAdapter;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contact.helpers.ContactField;
@@ -367,7 +368,7 @@ public class Executor {
              * execute and read out results
              */
             resultSet = logExecuteQuery(stmt);
-            return new ContactReader(contextID, connection, resultSet).readContacts(fields, false);
+            return new ContactReader(contextID, connection, resultSet).readContacts(fields, Arrays.asList(fields).contains(ContactField.USE_COUNT));
         } finally {
             closeSQLStuff(resultSet, stmt);
         }
@@ -575,7 +576,8 @@ public class Executor {
         /*
          * construct query string
          */
-        SearchAdapter adapter = new ContactSearchAdapter(contactSearch, contextID, fields, getCharset(sortOptions), forUser);
+        boolean utf8mb4 = Databases.getCharacterSet(connection).contains("utf8mb4");
+        SearchAdapter adapter = new ContactSearchAdapter(contactSearch, contextID, fields, getCharset(sortOptions), utf8mb4, forUser);
         StringBuilder stringBuilder = adapter.getClause();
         if (null != sortOptions && false == SortOptions.EMPTY.equals(sortOptions)) {
             stringBuilder.append(' ').append(Tools.getOrderClause(sortOptions));
