@@ -54,6 +54,7 @@ import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.contact.vcard.VCardParameters;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.contact.helpers.ContactField;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.java.Strings;
 import ezvcard.VCard;
@@ -71,7 +72,7 @@ public class EMailMapping extends AbstractMapping {
      * Initializes a new {@link EMailMapping}.
      */
     public EMailMapping() {
-        super("EMAIL");
+        super("EMAIL", ContactField.EMAIL1, ContactField.EMAIL2, ContactField.EMAIL3);
     }
 
     @Override
