@@ -52,6 +52,7 @@ package com.openexchange.contact.vcard.impl.mapping;
 import java.util.List;
 import com.openexchange.contact.vcard.VCardParameters;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.contact.helpers.ContactField;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.java.Strings;
 import ezvcard.VCard;
@@ -68,7 +69,7 @@ public class StructuredNameMapping extends AbstractMapping {
      * Initializes a new {@link StructuredNameMapping}.
      */
     public StructuredNameMapping() {
-        super("N");
+        super("N", ContactField.SUR_NAME, ContactField.GIVEN_NAME, ContactField.MIDDLE_NAME, ContactField.TITLE, ContactField.SUFFIX);
     }
 
     @Override
@@ -81,26 +82,20 @@ public class StructuredNameMapping extends AbstractMapping {
             }
             property.setFamily(contact.getSurName());
             property.setGiven(contact.getGivenName());
-            property.getAdditional().clear();
+            property.getAdditionalNames().clear();
             String middleName = contact.getMiddleName();
             if (false == Strings.isEmpty(middleName)) {
-                for (String additional : Strings.splitByWhitespaces(middleName)) {
-                    property.addAdditional(additional);
-                }
+                property.getAdditionalNames().add(middleName);
             }
             property.getPrefixes().clear();
             String title = contact.getTitle();
             if (false == Strings.isEmpty(title)) {
-                for (String prefix : Strings.splitByWhitespaces(title)) {
-                    property.addPrefix(prefix);
-                }
+                property.getPrefixes().add(title);
             }
             property.getSuffixes().clear();
             String suffix = contact.getSuffix();
             if (false == Strings.isEmpty(suffix)) {
-                for (String value : Strings.splitByWhitespaces(suffix)) {
-                    property.addSuffix(value);
-                }
+                property.getSuffixes().add(suffix);
             }
         } else if (null != property) {
             vCard.removeProperty(property);
@@ -118,7 +113,7 @@ public class StructuredNameMapping extends AbstractMapping {
         if (null != property) {
             surName = property.getFamily();
             givenName = property.getGiven();
-            List<String> additional = property.getAdditional();
+            List<String> additional = property.getAdditionalNames();
             middleName = null != additional && 0 < additional.size() ? Strings.join(additional, " ") : null;
             List<String> prefixes = property.getPrefixes();
             title = null != prefixes && 0 < prefixes.size() ? Strings.join(prefixes, " ") : null;
