@@ -51,7 +51,6 @@ package com.openexchange.data.conversion.ical.ical4j;
 
 import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
 import java.io.BufferedReader;
-import java.io.ByteArrayInputStream;
 import java.io.Closeable;
 import java.io.File;
 import java.io.FileOutputStream;
@@ -66,10 +65,8 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -90,8 +87,11 @@ import net.fortuna.ical4j.model.property.DateProperty;
 import net.fortuna.ical4j.util.CompatibilityHints;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
+import com.openexchange.data.conversion.ical.DefaultParseResult;
 import com.openexchange.data.conversion.ical.FreeBusyInformation;
 import com.openexchange.data.conversion.ical.ICalParser;
+import com.openexchange.data.conversion.ical.ParseResult;
+import com.openexchange.data.conversion.ical.TruncationInfo;
 import com.openexchange.data.conversion.ical.ical4j.internal.AppointmentConverters;
 import com.openexchange.data.conversion.ical.ical4j.internal.AttributeConverter;
 import com.openexchange.data.conversion.ical.ical4j.internal.FreeBusyConverters;
@@ -148,32 +148,42 @@ public class ICal4JParser implements ICalParser {
     }
 
     @Override
-    public List<CalendarDataObject> parseAppointments(final String icalText, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
+    public ParseResult<CalendarDataObject> parseAppointments(final String icalText, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         try {
-            return parseAppointments(new ByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
+            return parseAppointments(Streams.newByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
         } catch (final UnsupportedCharsetException e) {
             LOG.error("", e);
         }
-        return Collections.emptyList();
+
+        return DefaultParseResult.emptyParseResult();
     }
 
     @Override
-    public List<CalendarDataObject> parseAppointments(final InputStream ical, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
+    public ParseResult<CalendarDataObject> parseAppointments(final InputStream ical, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         BufferedReader reader = null;
         try {
             reader = new BufferedReader(new InputStreamReader(ical, UTF8));
 
+            TruncationInfo truncationInfo = null;
             List<CalendarDataObject> appointments = null;
-            while (true) {
-                final net.fortuna.ical4j.model.Calendar calendar = parse(reader);
-                if (calendar == null) {
-                    break;
-                }
+            for (net.fortuna.ical4j.model.Calendar calendar; (calendar = parse(reader)) != null;) {
                 final ComponentList vevents = calendar.getComponents("VEVENT");
-                final int myLimit = limit < 0 ? vevents.size() : limit < vevents.size() ? limit : vevents.size();
-                if (null == appointments) {
-                    appointments = new ArrayList<CalendarDataObject>(myLimit);
+
+                int size = vevents.size();
+                int myLimit;
+                if (limit >= 0 && limit < size) {
+                    myLimit = limit;
+                    if (null == appointments) {
+                        appointments = new ArrayList<CalendarDataObject>(myLimit);
+                    }
+                    truncationInfo = new TruncationInfo(myLimit, size);
+                } else {
+                    myLimit = size;
+                    if (null == appointments) {
+                        appointments = new ArrayList<CalendarDataObject>(myLimit);
+                    }
                 }
+
                 for (int i = 0; i < myLimit; i++) {
                     final Object componentObj = vevents.get(i);
                     final Component vevent = (Component) componentObj;
@@ -185,7 +195,7 @@ public class ICal4JParser implements ICalParser {
                 }
             }
 
-            return appointments;
+            return DefaultParseResult.<CalendarDataObject> builder().importedObjects(appointments).truncationInfo(truncationInfo).build();
         } catch (final UnsupportedCharsetException e) {
             // IGNORE
         } catch (final ConversionError e){
@@ -194,51 +204,64 @@ public class ICal4JParser implements ICalParser {
             closeSafe(reader);
         }
 
-        return Collections.emptyList();
+        return DefaultParseResult.emptyParseResult();
     }
 
 	@Override
-	public List<FreeBusyInformation> parseFreeBusy(String icalText, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
+	public ParseResult<FreeBusyInformation> parseFreeBusy(String icalText, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
         try {
-            return parseFreeBusy(new ByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
+            return parseFreeBusy(Streams.newByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
         } catch (UnsupportedCharsetException e) {
             LOG.error("", e);
         }
-        return Collections.emptyList();
+        return DefaultParseResult.emptyParseResult();
 	}
 
 	@Override
-	public List<FreeBusyInformation> parseFreeBusy(InputStream ical, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
-        List<FreeBusyInformation> fbInfos = new ArrayList<FreeBusyInformation>();
+    public ParseResult<FreeBusyInformation> parseFreeBusy(InputStream ical, TimeZone defaultTZ, Context ctx, List<ConversionError> errors, List<ConversionWarning> warnings) throws ConversionError {
         BufferedReader reader = null;
         try {
             reader = new BufferedReader(new InputStreamReader(ical, UTF8));
-            while (true) {
-                net.fortuna.ical4j.model.Calendar calendar = parse(reader);
-                if (null == calendar) {
-                	break;
-                }
+            TruncationInfo truncationInfo = null;
+            List<FreeBusyInformation> fbInfos = null;
+            for (net.fortuna.ical4j.model.Calendar calendar; (calendar = parse(reader)) != null;) {
                 ComponentList freebusies = calendar.getComponents("VFREEBUSY");
-                int myLimit = limit < 0 ? freebusies.size() : limit < freebusies.size() ? limit : freebusies.size();
+                int size = freebusies.size();
+                int myLimit;
+                if (limit >= 0 && limit < size) {
+                    myLimit = limit;
+                    if (null == fbInfos) {
+                        fbInfos = new ArrayList<>(myLimit);
+                    }
+                    truncationInfo = new TruncationInfo(myLimit, size);
+                } else {
+                    myLimit = size;
+                    if (null == fbInfos) {
+                        fbInfos = new ArrayList<>(myLimit);
+                    }
+                }
+
                 for (int i = 0; i < myLimit; i++) {
                     Component vevent = (Component) freebusies.get(i);
                     try {
-                        fbInfos.add(convertFreeBusy(i, (VFreeBusy)vevent, defaultTZ, ctx, warnings));
+                        fbInfos.add(convertFreeBusy(i, (VFreeBusy) vevent, defaultTZ, ctx, warnings));
                     } catch (ConversionError conversionError) {
                         errors.add(conversionError);
                     }
                 }
             }
+            return DefaultParseResult.<FreeBusyInformation> builder().importedObjects(fbInfos).truncationInfo(truncationInfo).build();
         } catch (UnsupportedCharsetException e) {
             LOG.error("", e);
             // IGNORE
         } catch (ConversionError e) {
-        	errors.add(e);
+            errors.add(e);
         } finally {
             closeSafe(reader);
         }
-        return fbInfos;
-	}
+
+        return DefaultParseResult.emptyParseResult();
+    }
 
 	private FreeBusyInformation convertFreeBusy(int index, VFreeBusy freeBusy, TimeZone defaultTZ, Context ctx, List<ConversionWarning> warnings) throws ConversionError {
         FreeBusyInformation fbInfo = new FreeBusyInformation();
@@ -280,27 +303,38 @@ public class ICal4JParser implements ICalParser {
     }
 
     @Override
-    public List<Task> parseTasks(final String icalText, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
+    public ParseResult<Task> parseTasks(final String icalText, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         try {
-            return parseTasks(new ByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
+            return parseTasks(Streams.newByteArrayInputStream(icalText.getBytes(UTF8)), defaultTZ, ctx, errors, warnings);
         } catch (final UnsupportedCharsetException e) {
             LOG.error("", e);
         }
-        return new LinkedList<Task>();
+        return DefaultParseResult.emptyParseResult();
     }
 
     @Override
-    public List<Task> parseTasks(final InputStream ical, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
-        final List<Task> tasks = new ArrayList<Task>();
+    public ParseResult<Task> parseTasks(final InputStream ical, final TimeZone defaultTZ, final Context ctx, final List<ConversionError> errors, final List<ConversionWarning> warnings) throws ConversionError {
         BufferedReader reader = null;
         try {
             reader = new BufferedReader(new InputStreamReader(ical, UTF8));
-            while(true) {
-                final net.fortuna.ical4j.model.Calendar calendar = parse(reader);
-                if(calendar == null) { break; }
-
+            TruncationInfo truncationInfo = null;
+            List<Task> tasks = null;
+            for (net.fortuna.ical4j.model.Calendar calendar; (calendar = parse(reader)) != null;) {
                 ComponentList todos = calendar.getComponents("VTODO");
-                int myLimit = limit < 0 ? todos.size() : limit < todos.size() ? limit : todos.size();
+                int size = todos.size();
+                int myLimit;
+                if (limit >= 0 && limit < size) {
+                    myLimit = limit;
+                    if (null == tasks) {
+                        tasks = new ArrayList<>(myLimit);
+                    }
+                    truncationInfo = new TruncationInfo(myLimit, size);
+                } else {
+                    myLimit = size;
+                    if (null == tasks) {
+                        tasks = new ArrayList<>(myLimit);
+                    }
+                }
 
                 for(int i = 0; i < myLimit; i++) {
                     final Component vtodo = (Component) todos.get(i);
@@ -312,12 +346,14 @@ public class ICal4JParser implements ICalParser {
                 }
             }
 
+            return DefaultParseResult.<Task> builder().importedObjects(tasks).truncationInfo(truncationInfo).build();
         } catch (final UnsupportedCharsetException e) {
             // IGNORE
         } finally {
             closeSafe(reader);
         }
-        return tasks;
+
+        return DefaultParseResult.emptyParseResult();
     }
 
     protected static void closeSafe(final Closeable closeable) {
@@ -396,6 +432,10 @@ public class ICal4JParser implements ICalParser {
 			inTZID = ParserTools.findTzidBySimilarity(tzidName);
 		}
 
+		if (inTZID == null) {
+		    inTZID = ParserTools.findTimeZoneReplacement(tzidName);
+		}
+
         if (null != inTZID) {
             tz = inTZID;
         }
