@@ -188,4 +188,14 @@ public interface ConfigDatabaseService {
     void deleteAssignment(Connection con, int contextId) throws OXException;
 
     void lock(Connection con, int writePoolId) throws OXException;
+
+    /**
+     * Gets all existing schemas in this installation.
+     *
+     * @param con The connection to the config database
+     * @return All existing schemas as a mapping from schema-name to read DB pool ID
+     * @throws OXException If all existing schemas cannot be retrieved from config database
+     */
+    Map<String, Integer> getAllSchemata(Connection con) throws OXException;
+
 }
