@@ -261,8 +261,18 @@ public final class DatabaseServiceImpl implements DatabaseService {
         configDatabaseService.lock(con, writePoolId);
     }
 
+    @Override
+    public Map<String, Integer> getAllSchemata(Connection con) throws OXException {
+        return configDatabaseService.getAllSchemata(con);
+    }
+
     // Delegate global database service methods.
 
+    @Override
+    public boolean isGlobalDatabaseAvailable() {
+        return globalDatabaseService.isGlobalDatabaseAvailable();
+    }
+
     @Override
     public boolean isGlobalDatabaseAvailable(String group) throws OXException {
         return globalDatabaseService.isGlobalDatabaseAvailable(group);
