@@ -57,10 +57,10 @@ import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.database.DBPoolingExceptionCodes;
-import com.openexchange.database.DatabaseService;
 import com.openexchange.database.internal.reloadable.GlobalDbConfigsReloadable;
 import com.openexchange.database.migration.DBMigrationExecutorService;
 import com.openexchange.exception.OXException;
+import com.openexchange.lock.LockService;
 
 /**
  * Contains the code to startup the complete database connection pooling and replication monitor.
@@ -92,6 +92,26 @@ public final class Initialization {
         return CONF_REF.get();
     }
 
+    private static final AtomicReference<LockService> LOCKSERV_REF = new AtomicReference<LockService>();
+
+    /**
+     * Sets the lock service.
+     *
+     * @param configurationService The lock service
+     */
+    public static void setLockService(final LockService configurationService) {
+        LOCKSERV_REF.set(configurationService);
+    }
+
+    /**
+     * Gets the lock service.
+     *
+     * @return The lock service or <code>null</code> if absent
+     */
+    public static LockService getLockService() {
+        return LOCKSERV_REF.get();
+    }
+
     // -------------------------------------------------------------------------------------------------------------- //
 
     private final Timer timer = new Timer();
@@ -125,7 +145,7 @@ public final class Initialization {
      * @param migrationService The database migration service, or <code>null</code> if not available
      * @return The database service
      */
-    public DatabaseService start(ConfigurationService configurationService, ConfigViewFactory configViewFactory, DBMigrationExecutorService migrationService) throws OXException {
+    public DatabaseServiceImpl start(ConfigurationService configurationService, ConfigViewFactory configViewFactory, DBMigrationExecutorService migrationService) throws OXException {
         if (null != databaseService) {
             throw DBPoolingExceptionCodes.ALREADY_INITIALIZED.create(Initialization.class.getName());
         }
