@@ -55,14 +55,18 @@ import java.util.Collection;
  * {@link AnnotatedServices}
  *
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
+ * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
  */
+@Deprecated
 public interface AnnotatedServices {
 
     /**
      * Gets the supported services, which may be decorated with {@link Action} annotations.
      *
      * @return The supported services
+     * @deprecated Never used & obsolete, therefore to be removed with <b>v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
      */
+    @Deprecated
     Collection<?> getSupportedServices();
 
 }
