@@ -56,7 +56,9 @@ import java.lang.annotation.RetentionPolicy;
  * {@link Actions} - Annotation for multiple actions.
  *
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
+ * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
  */
+@Deprecated
 @Retention(RetentionPolicy.RUNTIME)
 public @interface Actions {
 
