@@ -57,7 +57,9 @@ import java.lang.annotation.RetentionPolicy;
  *
  * @see com.openexchange.documentation.descriptions.ModuleDescription
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
+ * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
  */
+@Deprecated
 @Retention(RetentionPolicy.RUNTIME)
 public @interface Module {
 
