@@ -51,7 +51,6 @@ package com.openexchange.documentation.annotations;
 
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
-
 import com.openexchange.documentation.Type;
 
 /**
@@ -59,7 +58,9 @@ import com.openexchange.documentation.Type;
  *
  * @see com.openexchange.documentation.descriptions.ParameterDescription
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
+ * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
  */
+@Deprecated
 @Retention(RetentionPolicy.RUNTIME)
 public @interface Parameter {
 
