@@ -55,7 +55,9 @@ package com.openexchange.documentation.descriptions;
  *
  * @see com.openexchange.documentation.annotations.Module
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
+ * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
  */
+@Deprecated
 public interface ModuleDescription extends Description {
 
 	/**
