@@ -218,6 +218,27 @@ public interface IDBasedFolderAccess extends TransactionAware, WarningsAware {
      */
     String updateFolder(String identifier, FileStorageFolder toUpdate) throws OXException;
 
+    /**
+     * Updates an existing file storage folder identified through given identifier. All attributes set in given file storage folder instance are
+     * applied.
+     * <p>
+     * The currently known attributes that make sense being updated are:
+     * <ul>
+     * <li>permissions</li>
+     * <li>subscription</li>
+     * </ul>
+     * Of course more folder attributes may be checked by implementation to enhance update operations.
+     * <p>
+     * <b>Note</b>: If underlying file storage system does not support the corresponding capability, the update fails with an exception.
+     *
+     * @param identifier The identifier of the file storage folder to update
+     * @param toUpdate The file storage folder to update containing only the modified fields
+     * @param cascadePermissions <code>true</code> to apply permission changes to all subfolders, <code>false</code>, otherwise
+     * @return The identifier of the updated file storage folder
+     * @throws OXException If either folder does not exist or cannot be updated
+     */
+    String updateFolder(String identifier, FileStorageFolder toUpdate, boolean cascadePermissions) throws OXException;
+
     /**
      * Moves the folder identified through given identifier to the parent specified through argument <code>newParentId</code>.
      * <p>
