@@ -50,8 +50,8 @@
 package com.openexchange.file.storage.json.actions.accounts;
 
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.Map;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
@@ -70,12 +70,13 @@ public class AccountActionFactory implements AJAXActionServiceFactory {
      * Initializes a new {@link AccountActionFactory}.
      */
     public AccountActionFactory(final FileStorageServiceRegistry registry) {
-        actions = new HashMap<String, AJAXActionService>(8, 0.9F);
-        actions.put("all", new AllAction(registry));
-        actions.put("delete", new DeleteAction(registry));
-        actions.put("get", new GetAction(registry));
-        actions.put("new", new NewAction(registry));
-        actions.put("update", new UpdateAction(registry));
+        ImmutableMap.Builder<String, AJAXActionService> builder = ImmutableMap.builder();
+        builder.put("all", new AllAction(registry));
+        builder.put("delete", new DeleteAction(registry));
+        builder.put("get", new GetAction(registry));
+        builder.put("new", new NewAction(registry));
+        builder.put("update", new UpdateAction(registry));
+        this.actions = builder.build();
     }
 
     @Override
