@@ -127,13 +127,13 @@ public class AllAction extends AbstractFileStorageAccountAction {
                         result.put(writer.write(account, rootFolder, caps));
                     }
                 } catch (OXException e) {
-                    LOG.debug(e.getMessage());
+                    LOG.debug(e.getMessage(), e);
                     if (e.equalsCode(6, "OAUTH")) {
                         // "OAUTH-0006" --> OAuth account not found
                         try {
                             fsService.getAccountManager().deleteAccount(account, session);
                         } catch (Exception x) {
-                            // Ignore
+                            LOG.debug("Failed to delete the file storage account '{}' for user '{}' in context '{}'", account.getId(), session.getUserId(), session.getContextId(), x);
                         }
                     } else {
                         // Add account with error
@@ -195,6 +195,21 @@ public class AllAction extends AbstractFileStorageAccountAction {
             caps.add(FileStorageCapability.ZIPPABLE_FOLDER.name());
         }
 
+        supported = capabilityAware.supports(FileStorageCapability.COUNT_TOTAL);
+        if (null != supported && supported.booleanValue()) {
+            caps.add(FileStorageCapability.COUNT_TOTAL.name());
+        }
+
+        supported = capabilityAware.supports(FileStorageCapability.CASE_INSENSITIVE);
+        if (null != supported && supported.booleanValue()) {
+            caps.add(FileStorageCapability.CASE_INSENSITIVE.name());
+        }
+
+        supported = capabilityAware.supports(FileStorageCapability.AUTO_RENAME_FOLDERS);
+        if (null != supported && supported.booleanValue()) {
+            caps.add(FileStorageCapability.AUTO_RENAME_FOLDERS.name());
+        }
+
         return caps;
     }
 
