@@ -50,12 +50,10 @@
 package com.openexchange.file.storage.json.actions.files;
 
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
@@ -64,7 +62,6 @@ import com.openexchange.tools.servlet.AjaxExceptionCodes;
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
-@Module(name = "infostore", description = "The infostore module combines the knowledge database, bookmarks and documents.")
 public class FileActionFactory implements AJAXActionServiceFactory {
 
     /**
@@ -79,7 +76,7 @@ public class FileActionFactory implements AJAXActionServiceFactory {
      */
     protected FileActionFactory() {
         super();
-        final Map<String, AJAXActionService> actions = new ConcurrentHashMap<String, AJAXActionService>(24, 0.9f, 1);
+        ImmutableMap.Builder<String, AJAXActionService> actions = ImmutableMap.builder();
         actions.put("new", new NewAction());
         actions.put("update", new UpdateAction());
         actions.put("delete", new DeleteAction());
@@ -110,7 +107,7 @@ public class FileActionFactory implements AJAXActionServiceFactory {
         actions.put("documentpatch", new DocumentPatchAction());
 
         actions.put("checkname", new CheckNameAction());
-        this.actions = Collections.unmodifiableMap(actions);
+        this.actions = actions.build();
     }
 
     @Override
