@@ -49,12 +49,12 @@
 
 package com.openexchange.file.storage.json.actions.files;
 
+import java.util.Map;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.File;
+import com.openexchange.file.storage.FileStorageConstants;
+import com.openexchange.file.storage.FileStorageUtility;
 import com.openexchange.file.storage.composition.IDBasedFileAccess;
 
 
@@ -63,18 +63,30 @@ import com.openexchange.file.storage.composition.IDBasedFileAccess;
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
-@Action(method = RequestMethod.GET, name = "get", description = "Get an infoitem", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "id", description = "Object ID of the requested infoitem."),
-    @Parameter(name = "version", optional=true, description = "If present the infoitem data describes the given version. Otherwise the current version is returned.")
-}, responseDescription = "Response with timestamp: An object containing all data of the requested infoitem. The fields of the object are listed in Common object data and Detailed infoitem data. The field id is not included.")
 public class GetAction extends AbstractFileAction {
 
+    private static final String METADATA_KEY_ENCRYPTED = FileStorageConstants.METADATA_KEY_ENCRYPTED;
+
     @Override
     public AJAXRequestResult handle(InfostoreRequest request) throws OXException {
         request.require(Param.ID);
         IDBasedFileAccess fileAccess = request.getFileAccess();
         File fileMetadata = fileAccess.getFileMetadata(request.getId(), request.getVersion());
+
+        if (FileStorageUtility.isEncryptedFile(fileMetadata)) {
+            Map<String, Object> meta = fileMetadata.getMeta();
+            fileMetadata = new MetaDataAddingFile(fileMetadata);
+            if (null == meta) {
+                meta = new java.util.LinkedHashMap<>(2);
+                meta.put(METADATA_KEY_ENCRYPTED, Boolean.TRUE);
+                fileMetadata.setMeta(meta);
+            } else if (!meta.containsKey(METADATA_KEY_ENCRYPTED)) {
+                meta = new java.util.LinkedHashMap<>(meta);
+                meta.put(METADATA_KEY_ENCRYPTED, Boolean.TRUE);
+                fileMetadata.setMeta(meta);
+            }
+        }
+
         return result(fileMetadata, request);
     }
 
