@@ -113,6 +113,12 @@ public class FileStorageCapabilityTools {
             return Boolean.valueOf(FileStorageIgnorableVersionFileAccess.class.isAssignableFrom(fileAccessClass));
         case ZIPPABLE_FOLDER:
             return Boolean.valueOf(FileStorageZippableFolderFileAccess.class.isAssignableFrom(fileAccessClass));
+        case COUNT_TOTAL:
+            return Boolean.valueOf(FileStorageCountableFolderFileAccess.class.isAssignableFrom(fileAccessClass));
+        case CASE_INSENSITIVE:
+            return Boolean.valueOf(FileStorageCaseInsensitiveAccess.class.isAssignableFrom(fileAccessClass));
+        case AUTO_RENAME_FOLDERS:
+            return Boolean.valueOf(FileStorageAutoRenameFoldersAccess.class.isAssignableFrom(fileAccessClass));
         default:
             org.slf4j.LoggerFactory.getLogger(FileStorageCapabilityTools.class).warn("Unknown capability: {}", capability);
             return Boolean.FALSE;
@@ -166,6 +172,12 @@ public class FileStorageCapabilityTools {
             return FileStorageIgnorableVersionFileAccess.class.isInstance(fileAccess);
         case ZIPPABLE_FOLDER:
             return FileStorageZippableFolderFileAccess.class.isInstance(fileAccess);
+        case COUNT_TOTAL:
+            return FileStorageCountableFolderFileAccess.class.isInstance(fileAccess);
+        case CASE_INSENSITIVE:
+            return FileStorageCaseInsensitiveAccess.class.isInstance(fileAccess);
+        case AUTO_RENAME_FOLDERS:
+            return FileStorageAutoRenameFoldersAccess.class.isInstance(fileAccess);
         default:
             org.slf4j.LoggerFactory.getLogger(FileStorageCapabilityTools.class).warn("Unknown capability: {}", capability);
             return false;
