@@ -336,7 +336,7 @@ public enum FileStorageExceptionCodes implements DisplayableOXExceptionCode {
     RESERVED_NAME("File name is a reserved name: \"%1$s\"", Category.CATEGORY_USER_INPUT, 66, FileStorageExceptionMessages.RESERVED_NAME_MSG),
 
     /**
-     * File name must not be \".\" or \"..\".
+     * File name must not be <code>"."</code> or <code>".."</code>.
      */
     ONLY_DOTS_NAME("File name must not be \".\" or \"..\".", Category.CATEGORY_USER_INPUT, 67, FileStorageExceptionMessages.ONLY_DOTS_MSG),
 
@@ -345,6 +345,16 @@ public enum FileStorageExceptionCodes implements DisplayableOXExceptionCode {
      */
     WHITESPACE_END("File name must not end with a dot or whitespace.", Category.CATEGORY_USER_INPUT, 68, FileStorageExceptionMessages.WHITESPACE_END_MSG),
 
+    /**
+     * A file with that name already exists.
+     */
+    FILE_ALREADY_EXISTS("A file with that name already exists.", Category.CATEGORY_USER_INPUT, 69, FileStorageExceptionMessages.FILE_ALREADY_EXISTS),
+
+    /**
+     * The file(s) were not moved due to possible data loss. Please review the warnings for details.
+     */
+    FILE_MOVE_ABORTED("The file(s) were not moved due to possible data loss. Please review the warnings for details.", Category.CATEGORY_CONFLICT, 70, FileStorageExceptionMessages.FILE_MOVE_ABORTED_MSG),
+
     /**
      * The specified MIME type is not allowed being set
      */
