@@ -49,7 +49,10 @@
 
 package com.openexchange.file.storage.osgi;
 
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.file.storage.FileStorageAccountManagerLookupService;
+import com.openexchange.file.storage.internal.FileStorageConfigReloadable;
 import com.openexchange.file.storage.internal.FileStorageQuotaProvider;
 import com.openexchange.file.storage.registry.FileStorageServiceRegistry;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -76,7 +79,7 @@ public final class FileStorageActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return EMPTY_CLASSES;
+        return new Class<?>[] { ConfigurationService.class };
     }
 
     @Override
@@ -108,6 +111,7 @@ public final class FileStorageActivator extends HousekeepingActivator {
             registerService(FileStorageServiceRegistry.class, registry);
             registerService(FileStorageAccountManagerLookupService.class, lookupService);
             registerService(QuotaProvider.class, new FileStorageQuotaProvider(registry));
+            registerService(Reloadable.class, FileStorageConfigReloadable.getInstance());
         } catch (final Exception e) {
             log.error("Starting bundle \"com.openexchange.file.storage\" failed.", e);
             throw e;
