@@ -70,6 +70,7 @@ import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorage2EntitiesResolver;
 import com.openexchange.filestore.FileStorageService;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorageExceptionCodes;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.filestore.impl.osgi.Services;
@@ -100,24 +101,24 @@ public class DbFileStorage2EntitiesResolver implements FileStorage2EntitiesResol
         List<FileStorage> fileStorages = new LinkedList<FileStorage>();
         if (quotaAware) {
             // Add the one used by context itself
-            fileStorages.add(qfsService.getQuotaFileStorage(contextId));
+            fileStorages.add(qfsService.getQuotaFileStorage(contextId, Info.administrative()));
 
             // Add the ones referenced by context's users
             Set<FsInfo> infos = retrieveFileStoragesFromUsers(contextId, databaseService);
             for (FsInfo fsInfo : infos) {
-                fileStorages.add(qfsService.getQuotaFileStorage(fsInfo.owner, contextId));
+                fileStorages.add(qfsService.getQuotaFileStorage(fsInfo.owner, contextId, Info.administrative()));
             }
         } else {
             // Get raw service to obtain non-quota-aware instances
             FileStorageService fsService = FileStorages.getFileStorageService();
 
             // Add the one used by context itself
-            fileStorages.add(fsService.getFileStorage(qfsService.getQuotaFileStorage(contextId).getUri()));
+            fileStorages.add(fsService.getFileStorage(qfsService.getQuotaFileStorage(contextId, Info.administrative()).getUri()));
 
             //Add the ones referenced by context's users
             Set<FsInfo> infos = retrieveFileStoragesFromUsers(contextId, databaseService);
             for (FsInfo fsInfo : infos) {
-                fileStorages.add(fsService.getFileStorage(qfsService.getQuotaFileStorage(fsInfo.owner, contextId).getUri()));
+                fileStorages.add(fsService.getFileStorage(qfsService.getQuotaFileStorage(fsInfo.owner, contextId, Info.administrative()).getUri()));
             }
         }
 
@@ -166,13 +167,13 @@ public class DbFileStorage2EntitiesResolver implements FileStorage2EntitiesResol
 
         if (quotaAware) {
             // Add the one used by context itself
-            return qfsService.getQuotaFileStorage(contextId);
+            return qfsService.getQuotaFileStorage(contextId, Info.general());
         } else {
             // Get raw service to obtain non-quota-aware instances
             FileStorageService fsService = FileStorages.getFileStorageService();
 
             // Add the one used by context itself
-            return fsService.getFileStorage(qfsService.getQuotaFileStorage(contextId).getUri());
+            return fsService.getFileStorage(qfsService.getQuotaFileStorage(contextId, Info.administrative()).getUri());
         }
     }
 
@@ -375,10 +376,10 @@ public class DbFileStorage2EntitiesResolver implements FileStorage2EntitiesResol
             FsInfo fsInfo = retrieveFileStoragesFromUser(contextId, userId, schemaCon);
 
             if (quotaAware) {
-                return qfsService.getQuotaFileStorage(fsInfo.owner, contextId);
+                return qfsService.getQuotaFileStorage(fsInfo.owner, contextId, Info.drive());
             } else {
                 FileStorageService fsService = FileStorages.getFileStorageService();
-                return fsService.getFileStorage(qfsService.getQuotaFileStorage(fsInfo.owner, contextId).getUri());
+                return fsService.getFileStorage(qfsService.getQuotaFileStorage(fsInfo.owner, contextId, Info.administrative()).getUri());
             }
 
         } finally {
