@@ -49,10 +49,10 @@
 
 package com.openexchange.find.basic.mail;
 
-import static com.openexchange.find.basic.mail.Constants.FIELD_FILENAME_NAME;
 import static com.openexchange.find.basic.mail.Constants.FIELD_BCC;
 import static com.openexchange.find.basic.mail.Constants.FIELD_BODY;
 import static com.openexchange.find.basic.mail.Constants.FIELD_CC;
+import static com.openexchange.find.basic.mail.Constants.FIELD_FILENAME_NAME;
 import static com.openexchange.find.basic.mail.Constants.FIELD_FROM;
 import static com.openexchange.find.basic.mail.Constants.FIELD_SUBJECT;
 import static com.openexchange.find.basic.mail.Constants.FIELD_TO;
@@ -70,15 +70,15 @@ import static com.openexchange.find.common.CommonStrings.LAST_WEEK;
 import static com.openexchange.find.common.CommonStrings.LAST_YEAR;
 import static com.openexchange.find.facet.Facets.newSimpleBuilder;
 import static com.openexchange.find.mail.MailFacetType.CONTACTS;
+import static com.openexchange.find.mail.MailFacetType.FILENAME;
 import static com.openexchange.find.mail.MailFacetType.MAIL_TEXT;
 import static com.openexchange.find.mail.MailFacetType.SUBJECT;
-import static com.openexchange.find.mail.MailFacetType.FILENAME;
+import static com.openexchange.find.mail.MailStrings.FACET_FILENAME_NAME;
 import static com.openexchange.find.mail.MailStrings.FACET_FROM;
 import static com.openexchange.find.mail.MailStrings.FACET_FROM_AND_TO;
 import static com.openexchange.find.mail.MailStrings.FACET_MAIL_TEXT;
 import static com.openexchange.find.mail.MailStrings.FACET_SUBJECT;
 import static com.openexchange.find.mail.MailStrings.FACET_TO;
-import static com.openexchange.find.mail.MailStrings.FACET_FILENAME_NAME;
 import static com.openexchange.java.SimpleTokenizer.tokenize;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -91,6 +91,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Set;
+import java.util.TimeZone;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.config.cascade.ConfigView;
@@ -134,22 +135,22 @@ import com.openexchange.java.util.TimeZones;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.IndexRange;
 import com.openexchange.mail.MailField;
+import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.MailSortField;
 import com.openexchange.mail.OrderDirection;
 import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.mail.api.IMailMessageStorage;
-import com.openexchange.mail.api.IMailMessageStorageExt;
-import com.openexchange.mail.api.MailAccess;
+import com.openexchange.mail.api.MailCapabilities;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.search.ANDTerm;
-import com.openexchange.mail.search.FileNameTerm;
 import com.openexchange.mail.search.BccTerm;
 import com.openexchange.mail.search.BodyTerm;
 import com.openexchange.mail.search.CatenatingTerm;
 import com.openexchange.mail.search.CcTerm;
 import com.openexchange.mail.search.ComparablePattern;
 import com.openexchange.mail.search.ComparisonType;
+import com.openexchange.mail.search.FileNameTerm;
 import com.openexchange.mail.search.FromTerm;
 import com.openexchange.mail.search.ORTerm;
 import com.openexchange.mail.search.ReceivedDateTerm;
@@ -157,9 +158,7 @@ import com.openexchange.mail.search.SearchTerm;
 import com.openexchange.mail.search.SentDateTerm;
 import com.openexchange.mail.search.SubjectTerm;
 import com.openexchange.mail.search.ToTerm;
-import com.openexchange.mail.service.MailService;
 import com.openexchange.mail.utils.MailFolderUtility;
-import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -227,15 +226,15 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
         List<Facet> facets = new ArrayList<Facet>(5);
         List<String> prefixTokens = null;
         int minimumSearchCharacters = ServerConfig.getInt(ServerConfig.Property.MINIMUM_SEARCH_CHARACTERS);
-        
+
         final boolean prefixAvailable = Strings.isNotEmpty(prefix) && prefix.length() >= minimumSearchCharacters;
-        Object[] values = accessMailStorage(autocompleteRequest, session, new MailAccessClosure<Object[]>() {
+        Object[] values = accessMailStorage(autocompleteRequest, session, new MailServletClosure<Object[]>() {
 
             @Override
-            public Object[] call(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess, MailFolder folder) throws OXException {
+            public Object[] call(MailServletInterface mailServletInterface, MailFolder folder) throws OXException {
                 Object[] vals = new Object[2];
                 vals[0] = folder;
-                vals[1] = prefixAvailable ? Boolean.valueOf(mailAccess.getMailConfig().getCapabilities().hasFileNameSearch()) : Boolean.FALSE;
+                vals[1] = prefixAvailable ? Boolean.valueOf(mailServletInterface.getMailConfig().getCapabilities().hasFileNameSearch()) : Boolean.FALSE;
                 return vals;
             }
         });
@@ -276,19 +275,13 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
             headers = searchRequest.getColumns().getStringColumns();
         }
 
-        List<MailMessage> messages = accessMailStorage(searchRequest, session, new MailAccessClosure<List<MailMessage>>() {
+        final TimeZone tz = TimeZone.getTimeZone(session.getUser().getTimeZone());
+
+        List<MailMessage> messages = accessMailStorage(searchRequest, session, new MailServletClosure<List<MailMessage>>() {
             @Override
-            public List<MailMessage> call(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess, MailFolder folder) throws OXException {
-                SearchTerm<?> searchTerm = prepareSearchTerm(folder, searchRequest);
-                IMailMessageStorage messageStorage = mailAccess.getMessageStorage();
-                List<MailMessage> messages = searchMessages(
-                    messageStorage,
-                    folder,
-                    searchTerm,
-                    mailFields,
-                    headers,
-                    searchRequest.getStart(),
-                    searchRequest.getSize());
+            public List<MailMessage> call(MailServletInterface mailServletInterface, MailFolder folder) throws OXException {
+                SearchTerm<?> searchTerm = prepareSearchTerm(folder, searchRequest, mailServletInterface.getMailAccess().getMailConfig().getCapabilities(), tz);
+                List<MailMessage> messages = searchMessages(mailServletInterface, folder, searchTerm, mailFields, headers, searchRequest.getStart(), searchRequest.getSize());
                 return messages;
             }
         });
@@ -301,42 +294,39 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
         return new SearchResult(-1, searchRequest.getStart(), documents, searchRequest.getActiveFacets());
     }
 
-    private <R> R accessMailStorage(AbstractFindRequest request, ServerSession session, MailAccessClosure<R> closure) throws OXException {
+    private <R> R accessMailStorage(AbstractFindRequest request, ServerSession session, MailServletClosure<R> closure) throws OXException {
         long start = System.currentTimeMillis();
-        FullnameArgument fullnameArgument = determineFolder(session, request);
-        MailService mailService = Services.getMailService();
-        MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = null;
+        String folderId = request.getFolderId();
+        FullnameArgument fullnameArgument = determineFolder(session, folderId);
+        MailServletInterface mailServletInterface = MailServletInterface.getInstance(session);
         try {
-            mailAccess = mailService.getMailAccess(session, fullnameArgument.getAccountId());
-            mailAccess.connect(false);
-            IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
+            mailServletInterface.openFor(MailFolderUtility.prepareFullname(fullnameArgument.getAccountId(), fullnameArgument.getFullname()));
+            IMailFolderStorage folderStorage = mailServletInterface.getMailAccess().getFolderStorage();
             MailFolder folder = folderStorage.getFolder(fullnameArgument.getFullname());
-            return closure.call(mailAccess, folder);
+            return closure.call(mailServletInterface, folder);
         } finally {
-            MailAccess.closeInstance(mailAccess);
+            mailServletInterface.close(true);
             long diff = System.currentTimeMillis() - start;
             LOG.debug("Transaction for MailAccess lasted {}ms. Request type: {}", Long.valueOf(diff), request.getClass().getSimpleName());
         }
     }
 
-    private static interface MailAccessClosure<R> {
+    private static interface MailServletClosure<R> {
 
-        R call(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess, MailFolder folder) throws OXException;
+        R call(MailServletInterface mailServletInterface, MailFolder folder) throws OXException;
 
     }
 
-    private FullnameArgument determineFolder(ServerSession session, AbstractFindRequest request) throws OXException {
-        String folderName = request.getFolderId();
-
-        if (folderName == null) {
+    private FullnameArgument determineFolder(ServerSession session, String folderId) throws OXException {
+        if (folderId == null) {
             String allMessageFolder = getAllMessageFolder(session);
             if (Strings.isEmpty(allMessageFolder)) {
                 throw FindExceptionCode.MISSING_MANDATORY_FACET.create(CommonFacetType.FOLDER.getId());
             }
-            folderName = allMessageFolder;
+            folderId = allMessageFolder;
         }
 
-        return MailFolderUtility.prepareMailFolderParam(folderName);
+        return MailFolderUtility.prepareMailFolderParam(folderId);
     }
 
     private static void addSimpleFacets(List<Facet> facets, String prefix, List<String> prefixTokens, boolean addFileNameSearch) {
@@ -360,7 +350,7 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
                 prefix,
                 FIELD_BODY,
                 prefixTokens));
-            
+
             if (addFileNameSearch) {
                 facets.add(buildSimpleFacet(FILENAME, FACET_FILENAME_NAME, prefix, FIELD_FILENAME_NAME, prefixTokens));
             }
@@ -433,25 +423,13 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
             .build();
     }
 
-    static List<MailMessage> searchMessages(IMailMessageStorage messageStorage, MailFolder folder, SearchTerm<?> searchTerm, MailField[] fields, String headers[], int start, int size) throws OXException {
+    static List<MailMessage> searchMessages(MailServletInterface mailServletInterface, MailFolder folder, SearchTerm<?> searchTerm, MailField[] fields, String headers[], int start, int size) throws OXException {
         MailSortField sortField = folder.isSent() ? MailSortField.SENT_DATE : MailSortField.RECEIVED_DATE;
         IndexRange indexRange = new IndexRange(start, start + size);
         OrderDirection orderDirection = OrderDirection.DESC;
         String fullname = folder.getFullname();
 
-        MailMessage[] messages;
-        if (null != headers && 0 < headers.length) {
-            if (messageStorage instanceof IMailMessageStorageExt) {
-                IMailMessageStorageExt ext = (IMailMessageStorageExt) messageStorage;
-                messages = ext.searchMessages(fullname, indexRange, sortField, orderDirection, searchTerm, fields, headers);
-            } else {
-                messages = messageStorage.searchMessages(fullname, indexRange, sortField, orderDirection, searchTerm, fields);
-                MessageUtility.enrichWithHeaders(fullname, messages, headers, messageStorage);
-            }
-        } else {
-            messages = messageStorage.searchMessages(fullname, indexRange, sortField, orderDirection, searchTerm, fields);
-        }
-
+        MailMessage[] messages = mailServletInterface.searchMails(fullname, indexRange, sortField, orderDirection, searchTerm, fields, headers);
         List<MailMessage> resultMessages = new ArrayList<MailMessage>(messages.length);
         Collections.addAll(resultMessages, messages);
         return resultMessages;
@@ -503,32 +481,37 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
         return fields;
     }
 
-    protected SearchTerm<?> prepareSearchTerm(MailFolder folder, SearchRequest searchRequest) throws OXException {
+    protected SearchTerm<?> prepareSearchTerm(MailFolder folder, SearchRequest searchRequest, MailCapabilities mailCapabilities) throws OXException {
+        return prepareSearchTerm(folder, searchRequest, mailCapabilities, TimeZone.getDefault());
+    }
+
+    protected SearchTerm<?> prepareSearchTerm(MailFolder folder, SearchRequest searchRequest, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         List<String> queryFields = searchMailBody ? Constants.QUERY_FIELDS_BODY : Constants.QUERY_FIELDS;
-        SearchTerm<?> queryTerm = prepareQueryTerm(folder, queryFields, searchRequest.getQueries());
+        SearchTerm<?> queryTerm = prepareQueryTerm(folder, queryFields, searchRequest.getQueries(), mailCapabilities, userTimeZone);
 
         List<SearchTerm<?>> facetTerms = new LinkedList<SearchTerm<?>>();
-        SearchTerm<?> timeTerm = prepareDateTerm(searchRequest, folder);
+        SearchTerm<?> timeTerm = prepareDateTerm(searchRequest, folder, userTimeZone);
         if (timeTerm != null) {
             facetTerms.add(timeTerm);
         }
 
-        SearchTerm<?> subjectTerm = prepareTermForFacet(searchRequest, MailFacetType.SUBJECT, folder, OP.AND, OP.AND, OP.AND);
+        SearchTerm<?> subjectTerm = prepareTermForFacet(searchRequest, MailFacetType.SUBJECT, folder, OP.AND, OP.AND, OP.AND, mailCapabilities, userTimeZone);
         if (subjectTerm != null) {
             facetTerms.add(subjectTerm);
         }
 
-        SearchTerm<?> bodyTerm = prepareTermForFacet(searchRequest, MailFacetType.MAIL_TEXT, folder, OP.AND, OP.AND, OP.AND);
+        SearchTerm<?> bodyTerm = prepareTermForFacet(searchRequest, MailFacetType.MAIL_TEXT, folder, OP.AND, OP.AND, OP.AND, mailCapabilities, userTimeZone);
         if (bodyTerm != null) {
             facetTerms.add(bodyTerm);
         }
 
-        SearchTerm<?> attachmentTerm = prepareTermForFacet(searchRequest, MailFacetType.FILENAME, folder, OP.AND, OP.AND, OP.AND);
+        SearchTerm<?> attachmentTerm = prepareTermForFacet(searchRequest, MailFacetType.FILENAME, folder, OP.AND, OP.AND, OP.AND, mailCapabilities, userTimeZone);
         if (attachmentTerm != null) {
             facetTerms.add(attachmentTerm);
         }
 
-        SearchTerm<?> contactsTerm = prepareTermForFacet(searchRequest, MailFacetType.CONTACTS, folder, OP.AND, OP.OR, OP.OR);
+
+        SearchTerm<?> contactsTerm = prepareTermForFacet(searchRequest, MailFacetType.CONTACTS, folder, OP.AND, OP.OR, OP.OR, mailCapabilities, userTimeZone);
         if (contactsTerm != null) {
             facetTerms.add(contactsTerm);
         }
@@ -564,15 +547,15 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
         return searchTerm;
     }
 
-    private static SearchTerm<?> prepareQueryTerm(MailFolder folder, List<String> fields, List<String> queries) throws OXException {
+    private static SearchTerm<?> prepareQueryTerm(MailFolder folder, List<String> fields, List<String> queries, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         if (queries == null || queries.isEmpty()) {
             return null;
         }
 
-        return termFor(fields, queries, OP.OR, OP.AND, folder.isSent());
+        return termFor(fields, queries, OP.OR, OP.AND, folder.isSent(), mailCapabilities, userTimeZone);
     }
 
-    private static SearchTerm<?> prepareDateTerm(SearchRequest searchRequest, MailFolder folder) throws OXException {
+    private static SearchTerm<?> prepareDateTerm(SearchRequest searchRequest, MailFolder folder, TimeZone userTimeZone) throws OXException {
         List<ActiveFacet> dateFacets = searchRequest.getActiveFacets(DATE);
         if (dateFacets != null && !dateFacets.isEmpty()) {
             ActiveFacet dateFacet = dateFacets.get(0);
@@ -581,9 +564,9 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
                 Pair<Comparison, Long> parsed = parseDateQuery(filter.getQueries().get(0));
                 Comparison comparison = parsed.getFirst();
                 Long timestamp = parsed.getSecond();
-                return buildDateTerm(comparison, timestamp.longValue(), folder.isSent());
+                return buildDateTerm(comparison, timestamp.longValue(), folder.isSent(), userTimeZone);
             }
-            
+
             // No filter...
             String timeFramePattern = dateFacet.getValueId();
             TimeFrame timeFrame = TimeFrame.valueOf(timeFramePattern);
@@ -604,18 +587,18 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
             long from = timeFrame.getFrom();
             long to = timeFrame.getTo();
             if (to < 0L) {
-                return buildDateTerm(fromComparison, from, folder.isSent());
+                return buildDateTerm(fromComparison, from, folder.isSent(), userTimeZone);
             }
 
-            SearchTerm<?> fromTerm = buildDateTerm(fromComparison, from, folder.isSent());
-            SearchTerm<?> toTerm = buildDateTerm(toComparison, to, folder.isSent());
+            SearchTerm<?> fromTerm = buildDateTerm(fromComparison, from, folder.isSent(), userTimeZone);
+            SearchTerm<?> toTerm = buildDateTerm(toComparison, to, folder.isSent(), userTimeZone);
             return new ANDTerm(fromTerm, toTerm);
         }
 
         return null;
     }
 
-    private static SearchTerm<?> prepareTermForFacet(SearchRequest searchRequest, FacetType type, MailFolder folder, OP filterOP, OP fieldOP, OP queryOP) throws OXException {
+    private static SearchTerm<?> prepareTermForFacet(SearchRequest searchRequest, FacetType type, MailFolder folder, OP filterOP, OP fieldOP, OP queryOP, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         List<ActiveFacet> facets = searchRequest.getActiveFacets(type);
         if (facets != null && !facets.isEmpty()) {
             List<Filter> filters = new LinkedList<Filter>();
@@ -626,34 +609,34 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
                 }
             }
 
-            return prepareFilterTerm(folder, filters, filterOP, fieldOP, queryOP);
+            return prepareFilterTerm(folder, filters, filterOP, fieldOP, queryOP, mailCapabilities, userTimeZone);
         }
 
         return null;
     }
 
-    private static SearchTerm<?> prepareFilterTerm(MailFolder folder, List<Filter> filters, OP filterOP, OP fieldOP, OP queryOP) throws OXException {
+    private static SearchTerm<?> prepareFilterTerm(MailFolder folder, List<Filter> filters, OP filterOP, OP fieldOP, OP queryOP, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         if (filters == null || filters.isEmpty()) {
             return null;
         }
 
         if (filters.size() == 1) {
-            return termFor(filters.get(0), fieldOP, queryOP, folder.isSent());
+            return termFor(filters.get(0), fieldOP, queryOP, folder.isSent(), mailCapabilities, userTimeZone);
         }
 
         Iterator<Filter> it = filters.iterator();
         Filter f1 = it.next();
         Filter f2 = it.next();
-        CatenatingTerm finalTerm = catenationFor(filterOP, termFor(f1, fieldOP, queryOP, folder.isSent()), termFor(f2, fieldOP, queryOP, folder.isSent()));
+        CatenatingTerm finalTerm = catenationFor(filterOP, termFor(f1, fieldOP, queryOP, folder.isSent(), mailCapabilities, userTimeZone), termFor(f2, fieldOP, queryOP, folder.isSent(), mailCapabilities, userTimeZone));
         while (it.hasNext()) {
-            CatenatingTerm newTerm = catenationFor(filterOP, finalTerm.getSecondTerm(), termFor(it.next(), fieldOP, queryOP, folder.isSent()));
+            CatenatingTerm newTerm = catenationFor(filterOP, finalTerm.getSecondTerm(), termFor(it.next(), fieldOP, queryOP, folder.isSent(), mailCapabilities, userTimeZone));
             finalTerm.setSecondTerm(newTerm);
         }
 
         return finalTerm;
     }
 
-    private static SearchTerm<?> termFor(Filter filter, OP fieldOP, OP queryOP, boolean isOutgoingFolder) throws OXException {
+    private static SearchTerm<?> termFor(Filter filter, OP fieldOP, OP queryOP, boolean isOutgoingFolder, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         List<String> fields = filter.getFields();
         if (fields == null || fields.isEmpty()) {
             throw FindExceptionCode.INVALID_FILTER_NO_FIELDS.create(filter);
@@ -664,46 +647,46 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
             throw FindExceptionCode.INVALID_FILTER_NO_QUERIES.create(filter);
         }
 
-        return termFor(fields, queries, fieldOP, queryOP, isOutgoingFolder);
+        return termFor(fields, queries, fieldOP, queryOP, isOutgoingFolder, mailCapabilities, userTimeZone);
     }
 
-    private static SearchTerm<?> termFor(List<String> fields, List<String> queries, OP fieldOP, OP queryOP, boolean isOutgoingFolder) throws OXException {
+    private static SearchTerm<?> termFor(List<String> fields, List<String> queries, OP fieldOP, OP queryOP, boolean isOutgoingFolder, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         if (fields.size() > 1) {
             Iterator<String> it = fields.iterator();
             String f1 = it.next();
             String f2 = it.next();
-            CatenatingTerm finalTerm = catenationFor(fieldOP, termForField(f1, queries, queryOP, isOutgoingFolder), termForField(f2, queries, queryOP, isOutgoingFolder));
+            CatenatingTerm finalTerm = catenationFor(fieldOP, termForField(f1, queries, queryOP, isOutgoingFolder, mailCapabilities, userTimeZone), termForField(f2, queries, queryOP, isOutgoingFolder, mailCapabilities, userTimeZone));
             while (it.hasNext()) {
                 String f = it.next();
-                CatenatingTerm newTerm = catenationFor(fieldOP, finalTerm.getSecondTerm(), termForField(f, queries, queryOP, isOutgoingFolder));
+                CatenatingTerm newTerm = catenationFor(fieldOP, finalTerm.getSecondTerm(), termForField(f, queries, queryOP, isOutgoingFolder, mailCapabilities, userTimeZone));
                 finalTerm.setSecondTerm(newTerm);
             }
 
             return finalTerm;
         }
 
-        return termForField(fields.iterator().next(), queries, queryOP, isOutgoingFolder);
+        return termForField(fields.iterator().next(), queries, queryOP, isOutgoingFolder, mailCapabilities, userTimeZone);
     }
 
-    private static SearchTerm<?> termForField(String field, List<String> queries, OP queryOP, boolean isOutgoingFolder) throws OXException {
+    private static SearchTerm<?> termForField(String field, List<String> queries, OP queryOP, boolean isOutgoingFolder, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         if (queries.size() > 1) {
             Iterator<String> it = queries.iterator();
             String q1 = it.next();
             String q2 = it.next();
-            CatenatingTerm finalTerm = catenationFor(queryOP, termForQuery(field, q1, isOutgoingFolder), termForQuery(field, q2, isOutgoingFolder));
+            CatenatingTerm finalTerm = catenationFor(queryOP, termForQuery(field, q1, isOutgoingFolder, mailCapabilities, userTimeZone), termForQuery(field, q2, isOutgoingFolder, mailCapabilities, userTimeZone));
             while (it.hasNext()) {
                 String q = it.next();
-                CatenatingTerm newTerm = catenationFor(queryOP, finalTerm.getSecondTerm(), termForQuery(field, q, isOutgoingFolder));
+                CatenatingTerm newTerm = catenationFor(queryOP, finalTerm.getSecondTerm(), termForQuery(field, q, isOutgoingFolder, mailCapabilities, userTimeZone));
                 finalTerm.setSecondTerm(newTerm);
             }
 
             return finalTerm;
         }
 
-        return termForQuery(field, queries.iterator().next(), isOutgoingFolder);
+        return termForQuery(field, queries.iterator().next(), isOutgoingFolder, mailCapabilities, userTimeZone);
     }
 
-    private static SearchTerm<?> termForQuery(String field, String query, boolean isOutgoingFolder) throws OXException {
+    private static SearchTerm<?> termForQuery(String field, String query, boolean isOutgoingFolder, MailCapabilities mailCapabilities, TimeZone userTimeZone) throws OXException {
         if (FIELD_FROM.equals(field)) {
             return new FromTerm(query);
         } else if (FIELD_TO.equals(field)) {
@@ -720,7 +703,7 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
             Pair<Comparison, Long> parsed = parseDateQuery(query);
             Comparison comparison = parsed.getFirst();
             Long timestamp = parsed.getSecond();
-            return buildDateTerm(comparison, timestamp.longValue(), isOutgoingFolder);
+            return buildDateTerm(comparison, timestamp.longValue(), isOutgoingFolder, userTimeZone);
         } else if (FIELD_FILENAME_NAME.equals(field)) {
             return new FileNameTerm(query);
         }
@@ -728,8 +711,10 @@ public class BasicMailDriver extends AbstractContactFacetingModuleSearchDriver {
         throw FindExceptionCode.UNSUPPORTED_FILTER_FIELD.create(field);
     }
 
-    private static SearchTerm<?> buildDateTerm(Comparison comparison, long timestamp, boolean isOutgoingFolder) {
-        Date date = new Date(timestamp);
+    private static SearchTerm<?> buildDateTerm(Comparison comparison, long timestamp, boolean isOutgoingFolder, TimeZone tz) {
+        Calendar instance = Calendar.getInstance(tz);
+        instance.setTimeInMillis(timestamp);
+        Date date = new Date(timestamp + tz.getOffset(timestamp) - TimeZone.getDefault().getOffset(timestamp));
         ComparisonType type;
         switch (comparison) {
             case EQUALS:
