@@ -131,7 +131,11 @@ public enum FindExceptionCode implements DisplayableOXExceptionCode {
      */
     MODULE_DISABLED("Searching in module \"%1$s\" is disabled for user %2$d in context %3$d.", Category.CATEGORY_PERMISSION_DENIED, 17, FindExceptionMessages.MODULE_DISABLED),
 
-    INVALID_ACCOUNT_ID("The account id \"%1$s\" is invalid for module \"%2$s\".", Category.CATEGORY_USER_INPUT, 18)
+    INVALID_ACCOUNT_ID("The account id \"%1$s\" is invalid for module \"%2$s\".", Category.CATEGORY_USER_INPUT, 18),
+    /**
+     * The query yielded too many results to be displayed. Please refine your search options and try again.
+     */
+    TOO_MANY_RESULTS(FindExceptionMessages.TOO_MANY_RESULTS, Category.CATEGORY_USER_INPUT, 19, FindExceptionMessages.TOO_MANY_RESULTS),
 
     ;
 
