@@ -49,7 +49,10 @@
 
 package com.openexchange.find;
 
+import java.util.List;
 import com.openexchange.exception.OXException;
+import com.openexchange.find.facet.FacetInfo;
+import com.openexchange.find.spi.ModuleSearchDriver;
 import com.openexchange.osgi.annotation.SingletonService;
 import com.openexchange.tools.session.ServerSession;
 
@@ -83,4 +86,15 @@ public interface SearchService {
      */
     SearchResult search(SearchRequest searchRequest, Module module, ServerSession session) throws OXException;
 
+    /**
+     * Gets the appropriate driver for given module.
+     *
+     * @param facetInfos The basic facet information
+     * @param module The module
+     * @param session The associated session
+     * @return The driver
+     * @throws OXException If no suitable driver exists
+     */
+    ModuleSearchDriver getDriver(List<FacetInfo> facetInfos, Module module, ServerSession session) throws OXException;
+
 }
