@@ -156,6 +156,10 @@ public enum FolderField {
      * The folders account ID
      */
     ACCOUNT_ID(318, "account_id"),
+    /**
+     * The folders raw name
+     */
+    FOLDER_NAME_RAW(319, "folder_name"),
     /**
      * The permissions bits
      */
