@@ -56,6 +56,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.TimeZone;
@@ -86,6 +87,9 @@ import com.openexchange.folderstorage.database.contentType.CalendarContentType;
 import com.openexchange.folderstorage.database.contentType.ContactContentType;
 import com.openexchange.folderstorage.database.contentType.TaskContentType;
 import com.openexchange.groupware.notify.hostname.HostData;
+import com.openexchange.i18n.I18nService;
+import com.openexchange.i18n.I18nServiceRegistry;
+import com.openexchange.i18n.LocaleTools;
 import com.openexchange.java.Strings;
 import com.openexchange.oauth.provider.exceptions.OAuthInsufficientScopeException;
 import com.openexchange.oauth.provider.resourceserver.OAuthAccess;
@@ -106,6 +110,8 @@ import com.openexchange.tools.session.ServerSession;
  */
 public abstract class AbstractFolderAction implements AJAXActionService {
 
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AbstractFolderAction.class);
+
     /**
      * <code>"ignoreTranslation"</code>.
      */
@@ -158,6 +164,47 @@ public abstract class AbstractFolderAction implements AJAXActionService {
         return uc.startsWith("USM-EAS") || uc.startsWith("USM-JSON");
     }
 
+    /**
+     * Gets the possibly specified <code>"language"</code> parameter from given request and parses its value to an appropriate instance of {@link Locale}.
+     *
+     * @param request The request to get the parameter from
+     * @return The locale or <code>null</code>
+     */
+    protected static Locale optLocale(AJAXRequestData request) {
+        String sLocale = request.getParameter("language");
+        if (Strings.isEmpty(sLocale)) {
+            return null;
+        }
+
+        Locale locale = LocaleTools.getLocale(sLocale);
+        if (null == locale) {
+            LOG.warn("Specified \"language\" parameter (\"{}\") cannot be parsed to a locale. Using user's locale instead.", sLocale);
+        }
+
+        return tryBestFitFor(locale);
+    }
+
+    private static Locale tryBestFitFor(Locale locale) {
+        I18nServiceRegistry i18nServiceRegistry = ServiceRegistry.getInstance().getService(I18nServiceRegistry.class);
+        if (null == i18nServiceRegistry) {
+            // Don't know better
+            return null;
+        }
+
+        try {
+            I18nService i18nService = i18nServiceRegistry.getBestFittingI18nService(locale);
+            if (null == i18nService) {
+                LOG.warn("No suitable support for locale \"{}\". Using user's locale instead.", locale.toString());
+                return null;
+            }
+
+            return i18nService.getLocale();
+        } catch (OXException e) {
+            LOG.warn("Failed to check support for locale \"{}\". Using user's locale instead.", locale.toString(), e);
+            return null;
+        }
+    }
+
     /**
      * Gets the default tree identifier to use if request does not provide any.
      *
@@ -589,18 +636,20 @@ public abstract class AbstractFolderAction implements AJAXActionService {
      * @throws OXException If the request body is invalid
      */
     protected UpdateData parseRequestBody(String treeId, String folderId, AJAXRequestData request, ServerSession session) throws OXException {
-        JSONObject folderObject;
-        JSONObject data = (JSONObject) request.requireData();
         UpdateData updateData = new UpdateData();
-        if (data.hasAndNotNull("folder")) {
-            try {
-                folderObject = data.getJSONObject("folder");
-                updateData.setNotificationData(parseNotificationData(data.optJSONObject("notification")));
-            } catch (JSONException e) {
-                throw AjaxExceptionCodes.INVALID_JSON_REQUEST_BODY.create(e);
+        JSONObject folderObject;
+        {
+            JSONObject data = (JSONObject) request.requireData();
+            if (data.hasAndNotNull("folder")) {
+                try {
+                    folderObject = data.getJSONObject("folder");
+                    updateData.setNotificationData(parseNotificationData(data.optJSONObject("notification")));
+                } catch (JSONException e) {
+                    throw AjaxExceptionCodes.INVALID_JSON_REQUEST_BODY.create(e);
+                }
+            } else {
+                folderObject = data;
             }
-        } else {
-            folderObject = data;
         }
 
         final ParsedFolder folder = new FolderParser(ServiceRegistry.getInstance().getService(ContentTypeDiscoveryService.class)).parseFolder(folderObject, getTimeZone(request, session));
