@@ -49,13 +49,20 @@
 
 package com.openexchange.folder.json.actions;
 
+import static com.openexchange.folder.json.FolderField.FOLDER_ID;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
+import com.openexchange.ajax.requesthandler.DispatcherNotes;
+import com.openexchange.ajax.requesthandler.EnqueuableAJAXActionService;
+import com.openexchange.ajax.requesthandler.EnqueuableAJAXActionServices;
+import com.openexchange.ajax.requesthandler.jobqueue.JobKey;
 import com.openexchange.exception.OXException;
 import com.openexchange.folder.json.parser.ParsedFolder;
 import com.openexchange.folder.json.services.ServiceRegistry;
@@ -80,7 +87,8 @@ import com.openexchange.tools.session.ServerSession;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 @OAuthAction(OAuthAction.CUSTOM)
-public final class UpdateAction extends AbstractFolderAction {
+@DispatcherNotes(enqueueable = true)
+public final class UpdateAction extends AbstractFolderAction implements EnqueuableAJAXActionService {
 
     public static final String ACTION = AJAXServlet.ACTION_UPDATE;
 
@@ -91,6 +99,37 @@ public final class UpdateAction extends AbstractFolderAction {
         super();
     }
 
+    @Override
+    public EnqueuableAJAXActionService.Result isEnqueueable(AJAXRequestData request, ServerSession session) throws OXException {
+        JSONObject data = (JSONObject) request.requireData();
+        JSONObject jFolder = data.optJSONObject("folder");
+        if (null == jFolder) {
+            jFolder = data;
+        }
+
+        String newParent = jFolder.optString(FOLDER_ID.getName(), null);
+        if (null == newParent) {
+            return EnqueuableAJAXActionServices.resultFor(false);
+        }
+
+        String id = request.getParameter("id");
+        if (null == id) {
+            throw AjaxExceptionCodes.MISSING_PARAMETER.create("id");
+        }
+
+        try {
+            JSONObject jKeyDesc = new JSONObject(4);
+            jKeyDesc.put("module", "folder");
+            jKeyDesc.put("action", "update");
+            jKeyDesc.put("id", id);
+            jKeyDesc.put("parent", newParent);
+
+            return EnqueuableAJAXActionServices.resultFor(true, new JobKey(session.getUserId(), session.getContextId(), jKeyDesc.toString()));
+        } catch (JSONException e) {
+            throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+        }
+    }
+
     @Override
     protected AJAXRequestResult doPerform(final AJAXRequestData request, final ServerSession session) throws OXException {
         /*
