@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -91,4 +91,20 @@ public interface AuthenticatorMBean {
      */
     void doUserAuthentication(String login, String password, int contextId) throws MBeanException;
 
+    /**
+     * Checks if master authentication has been disabled for associated machine.
+     *
+     * @return <code>true</code> if master authentication has been disabled; otherwise <code>false</code>
+     * @throws MBeanException If operation fails
+     */
+    boolean isMasterAuthenticationDisabled() throws MBeanException;
+
+    /**
+     * Checks if context authentication has been disabled for associated machine.
+     *
+     * @return <code>true</code> if context authentication has been disabled; otherwise <code>false</code>
+     * @throws MBeanException If operation fails
+     */
+    boolean isContextAuthenticationDisabled() throws MBeanException;
+
 }
