@@ -785,7 +785,8 @@ public class OXException extends Exception implements OXExceptionConstants {
      * @return The first category.
      */
     public Category getCategory() {
-        return getCategories().get(0);
+        List<Category> categories = getCategories();
+        return categories.isEmpty() ? CATEGORY_ERROR : categories.get(0);
     }
 
     /**
@@ -794,18 +795,19 @@ public class OXException extends Exception implements OXExceptionConstants {
      * @return The (sorted) categories
      */
     public List<Category> getCategories() {
-        if (categories.isEmpty()) {
-            /*
-             * No category specified. Fall back to default one.
-             */
-            return Collections.<Category> singletonList(CATEGORY_ERROR);
+        List<Category> categories = new ArrayList<>(this.categories);
+        int size = categories.size();
+        switch (size) {
+            case 0:
+                // No category specified. Fall back to default one.
+                return Collections.<Category> singletonList(CATEGORY_ERROR);
+            case 1:
+                return categories;
+            default:
+                // Sort before return
+                sortCategories(categories);
+                return categories;
         }
-        if (1 == categories.size()) {
-            return Collections.unmodifiableList(categories);
-        }
-        // Sort before return
-        sortCategories(categories);
-        return Collections.unmodifiableList(categories);
     }
 
     /**
@@ -1053,6 +1055,10 @@ public class OXException extends Exception implements OXExceptionConstants {
 
     /**
      * Checks if this exception is similar to specified exception code regarding category and code number.
+     * <p>
+     * <div style="margin-left: 0.1in; margin-right: 0.5in; margin-bottom: 0.1in; background-color:#FFDDDD;">
+     * Note: To check for code number and prefix equality, please use {@link OXExceptionCode#equals(OXException)} instead!
+     * </div>
      *
      * @param exceptionCode The exception code to check against
      * @return <code>true</code> if this exception is similar to specified exception code; otherwise <code>false</code>
@@ -1063,6 +1069,10 @@ public class OXException extends Exception implements OXExceptionConstants {
 
     /**
      * Checks if this exception is similar to specified exception regarding category and code number.
+     * <p>
+     * <div style="margin-left: 0.1in; margin-right: 0.5in; margin-bottom: 0.1in; background-color:#FFDDDD;">
+     * Note: To check for code number and prefix equality, please use {@link OXExceptionCode#equals(OXException)} instead!
+     * </div>
      *
      * @param other The exception to check against
      * @return <code>true</code> if this exception is similar to specified exception; otherwise <code>false</code>
