@@ -230,6 +230,10 @@ public final class LogProperties {
          * com.openexchange.mail.host
          */
         MAIL_HOST("com.openexchange.mail.host"),
+        /**
+         * com.openexchange.mail.host.remoteAddress
+         */
+        MAIL_HOST_REMOTE_ADDRESS("com.openexchange.mail.host.remoteAddress"),
         /**
          * com.openexchange.mail.fullName
          */
@@ -297,7 +301,12 @@ public final class LogProperties {
          * com.openexchange.hostname
          */
         HOSTNAME("com.openexchange.hostname"),
-
+        /**
+         * mail.imap.discardresponses
+         * <p>
+         * A special log property that controls whether regular untagged IMAP responses are supposed to be discarded
+         */
+        IMAP_DISCARD_RESPONSES("mail.imap.discardresponses"),
         ;
 
         private final String name;
@@ -854,4 +863,17 @@ public final class LogProperties {
         return sb.toString();
     }
 
+    /**
+     * Gets the available host name
+     *
+     * @return The host name or <code>null</code>
+     */
+    public static String getHostName() {
+        String hostname = LogProperties.get(Name.HOSTNAME);
+        if (null == hostname) {
+            hostname = LogProperties.get(Name.GRIZZLY_SERVER_NAME);
+        }
+        return hostname;
+    }
+
 }
