@@ -70,8 +70,8 @@ import com.hazelcast.config.QueueConfig;
 import com.hazelcast.config.SemaphoreConfig;
 import com.hazelcast.config.SymmetricEncryptionConfig;
 import com.hazelcast.config.TopicConfig;
-import com.hazelcast.instance.GroupProperty;
 import com.hazelcast.nio.serialization.ClassDefinition;
+import com.hazelcast.spi.properties.GroupProperty;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.WildcardNamePropertyFilter;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
@@ -158,9 +158,9 @@ public class HazelcastConfigurationServiceImpl implements HazelcastConfiguration
     }
 
     /**
-     * Gets the Hazelcast cofiguration.
+     * Gets the Hazelcast configuration.
      *
-     * @return The Hazelcast cofiguration or <code>null</code>
+     * @return The Hazelcast configuration or <code>null</code>
      */
     public Config getConfigDirect() {
         return config;
@@ -203,6 +203,7 @@ public class HazelcastConfigurationServiceImpl implements HazelcastConfiguration
             }
             config.getGroupConfig().setPassword(groupPassword);
         }
+        config.setLiteMember(configService.getBoolProperty("com.openexchange.hazelcast.liteMember", false));
         /*
          * Network Join
          */
@@ -263,10 +264,10 @@ public class HazelcastConfigurationServiceImpl implements HazelcastConfiguration
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("com.openexchange.hazelcast.network.join");
         }
         String mergeFirstRunDelay = configService.getProperty("com.openexchange.hazelcast.merge.firstRunDelay", "120s");
-        config.setProperty(GroupProperty.MERGE_FIRST_RUN_DELAY_SECONDS,
+        config.setProperty(GroupProperty.MERGE_FIRST_RUN_DELAY_SECONDS.getName(),
             String.valueOf(TimeSpanParser.parseTimespan(mergeFirstRunDelay).longValue() / 1000));
         String mergeRunDelay = configService.getProperty("com.openexchange.hazelcast.merge.runDelay", "120s");
-        config.setProperty(GroupProperty.MERGE_NEXT_RUN_DELAY_SECONDS,
+        config.setProperty(GroupProperty.MERGE_NEXT_RUN_DELAY_SECONDS.getName(),
             String.valueOf(TimeSpanParser.parseTimespan(mergeRunDelay).longValue() / 1000));
         /*
          * Network Config
@@ -292,9 +293,9 @@ public class HazelcastConfigurationServiceImpl implements HazelcastConfiguration
             }
         }
         if (configService.getBoolProperty("com.openexchange.hazelcast.network.enableIPv6Support", false)) {
-            config.setProperty(GroupProperty.PREFER_IPv4_STACK, "false");
+            config.setProperty(GroupProperty.PREFER_IPv4_STACK.getName(), "false");
         }
-        config.setProperty(GroupProperty.SOCKET_BIND_ANY, String.valueOf(
+        config.setProperty(GroupProperty.SOCKET_BIND_ANY.getName(), String.valueOf(
             configService.getBoolProperty("com.openexchange.hazelcast.socket.bindAny", false)));
         /*
          * Encryption
@@ -312,14 +313,14 @@ public class HazelcastConfigurationServiceImpl implements HazelcastConfiguration
          */
         String loggingType = configService.getBoolProperty("com.openexchange.hazelcast.logging.enabled", true) ? "slf4j" : "none";
         System.setProperty(GroupProperty.LOGGING_TYPE.getName(), loggingType);
-        config.setProperty(GroupProperty.LOGGING_TYPE, loggingType);
-        config.setProperty(GroupProperty.PHONE_HOME_ENABLED, "false");
-        config.setProperty(GroupProperty.HEALTH_MONITORING_LEVEL, configService.getProperty("com.openexchange.hazelcast.healthMonitorLevel", "silent").toUpperCase());
-        config.setProperty(GroupProperty.OPERATION_CALL_TIMEOUT_MILLIS, configService.getProperty("com.openexchange.hazelcast.maxOperationTimeout", "30000"));
-        config.setProperty(GroupProperty.ENABLE_JMX, configService.getProperty("com.openexchange.hazelcast.jmx", "true"));
-        config.setProperty(GroupProperty.ENABLE_JMX_DETAILED, configService.getProperty("com.openexchange.hazelcast.jmxDetailed", "true"));
-        config.setProperty(GroupProperty.MEMCACHE_ENABLED, configService.getProperty("com.openexchange.hazelcast.memcache.enabled", "false"));
-        config.setProperty(GroupProperty.REST_ENABLED, configService.getProperty("com.openexchange.hazelcast.rest.enabled", "false"));
+        config.setProperty(GroupProperty.LOGGING_TYPE.getName(), loggingType);
+        config.setProperty(GroupProperty.PHONE_HOME_ENABLED.getName(), "false");
+        config.setProperty(GroupProperty.HEALTH_MONITORING_LEVEL.getName(), configService.getProperty("com.openexchange.hazelcast.healthMonitorLevel", "silent").toUpperCase());
+        config.setProperty(GroupProperty.OPERATION_CALL_TIMEOUT_MILLIS.getName(), configService.getProperty("com.openexchange.hazelcast.maxOperationTimeout", "30000"));
+        config.setProperty(GroupProperty.ENABLE_JMX.getName(), configService.getProperty("com.openexchange.hazelcast.jmx", "true"));
+        config.setProperty(GroupProperty.ENABLE_JMX_DETAILED.getName(), configService.getProperty("com.openexchange.hazelcast.jmxDetailed", "true"));
+        config.setProperty(GroupProperty.MEMCACHE_ENABLED.getName(), configService.getProperty("com.openexchange.hazelcast.memcache.enabled", "false"));
+        config.setProperty(GroupProperty.REST_ENABLED.getName(), configService.getProperty("com.openexchange.hazelcast.rest.enabled", "false"));
         /*
          * Arbitrary Hazelcast properties
          */
