@@ -92,6 +92,16 @@ public interface CustomPortable extends Portable {
      * Unique id for PortableLogoutRequestInfo
      */
     public static final int PORTABLE_SAML_LOGOUT_REQUEST_INFO = 301;
+    
+    /**
+     * Unique id for OpenId authentication request
+     */
+    public static final int PORTABLE_OIDC_AUTHN_REQUEST_INFO = 310;
+
+    /**
+     * Unique id for OpenId logout request
+     */
+    public static final int PORTABLE_OIDC_LOGOUT_REQUEST_INFO = 311;
 
     /**
      * Gets the ID of the dynamic portable factory.<p/>
@@ -161,6 +171,7 @@ public interface CustomPortable extends Portable {
      *   &bull; 401 --> com.openexchange.sessionstorage.hazelcast.serialization.PortableSessionRemoteLookUp
      *   &bull; 402 --> com.openexchange.sessionstorage.hazelcast.serialization.PortableMultipleSessionRemoteLookUp
      *   &bull; 403 --> com.openexchange.sessionstorage.hazelcast.serialization.PortableSessionCollection
+     *   &bull; 404 --> com.openexchange.sessionstorage.hazelcast.serialization.PortableSessionRemoteRetrieval
      *   &bull; 500 --> com.openexchange.sms.tools.internal.SMSBucket
      *   &bull; 600 --> com.openexchange.websockets.grizzly.remote.portable.PortableMessageDistributor
      *   &bull; 700 --> com.openexchange.oauth.impl.internal.hazelcast.PortableCallbackRegistryFetch
