@@ -73,6 +73,7 @@ import com.openexchange.hazelcast.HazelcastMBeanImpl;
 import com.openexchange.hazelcast.configuration.HazelcastConfigurationService;
 import com.openexchange.java.Strings;
 import com.openexchange.management.ManagementService;
+import com.openexchange.osgi.Tools;
 
 /**
  * {@link HazelcastActivator} - The activator for Hazelcast bundle (registers a {@link HazelcastInstance} for this JVM)
@@ -152,7 +153,7 @@ public class HazelcastActivator implements BundleActivator {
 
             @Override
             public void removedService(ServiceReference<HazelcastConfigurationService> reference, HazelcastConfigurationService service) {
-                context.ungetService(reference);
+                Tools.ungetServiceSafe(reference, context);
                 stop();
             }
         };
@@ -167,7 +168,7 @@ public class HazelcastActivator implements BundleActivator {
 
             @Override
             public void removedService(ServiceReference<HazelcastInstanceNotActiveException> reference, HazelcastInstanceNotActiveException service) {
-                context.ungetService(reference);
+                Tools.ungetServiceSafe(reference, context);
             }
 
             @Override
@@ -227,17 +228,27 @@ public class HazelcastActivator implements BundleActivator {
         ServiceTracker<HazelcastConfigurationService, HazelcastConfigurationService> tracker = this.configTracker;
         if (null != tracker) {
             this.configTracker = null;
-            tracker.close();
+            closeTrackerSafe(tracker);
         }
         ServiceTracker<HazelcastInstanceNotActiveException, HazelcastInstanceNotActiveException> inactiveTracker = this.inactiveTracker;
         if (null != inactiveTracker) {
             this.inactiveTracker = null;
-            inactiveTracker.close();
+            closeTrackerSafe(inactiveTracker);
         }
         ServiceTracker<ManagementService, ManagementService> managementTracker = this.managementTracker;
         if (null != managementTracker) {
             this.managementTracker = null;
-            managementTracker.close();
+            closeTrackerSafe(managementTracker);
+        }
+    }
+
+    private <S, T> void closeTrackerSafe(ServiceTracker<S, T> tracker) {
+        if (null != tracker) {
+            try {
+                tracker.close();
+            } catch (java.lang.IllegalStateException e) {
+                // Apparently already closed, since BundleContext is no longer valid
+            }
         }
     }
 
