@@ -51,6 +51,7 @@ package com.openexchange.html;
 
 import java.io.Reader;
 import com.openexchange.exception.OXException;
+import com.openexchange.html.whitelist.Whitelist;
 import com.openexchange.osgi.annotation.SingletonService;
 
 
@@ -138,10 +139,19 @@ public interface HtmlService {
      * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status
      * @param cssPrefix The optional CSS prefix
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited. Below 10000 will be ignor
-     * @return {@link HtmlSanitizeResult} with the content and additional information, e. g. if the content was truncated
+     * @return {@link HtmlSanitizeResult} with the content and additional information, e.g. if the content was truncated
      */
     HtmlSanitizeResult sanitize(String htmlContent, String optConfigName, boolean dropExternalImages, boolean[] modified, String cssPrefix, int maxContentSize) throws OXException;
 
+    /**
+     * Sanitizes specified HTML content by limiting the content size to the character count provided with maxContentSize.
+     *
+     * @param htmlContent The HTML content to sanitize
+     * @param options The options for performing the sanitizing
+     * @return {@link HtmlSanitizeResult} with the content and additional information, e.g. if the content was truncated
+     */
+    HtmlSanitizeResult sanitize(String htmlContent, HtmlSanitizeOptions options) throws OXException;
+
     /**
      * Sanitizes specified HTML content.
      *
@@ -354,4 +364,12 @@ public interface HtmlService {
      * @return input encoded for use as an HTML attribute
      */
     String encodeForHTMLAttribute(String input);
+
+    /**
+     * Gets the currently applicable white-lists for HTML and CSS
+     *
+     * @param withCss Whether returned white-list should also contain the CSS stuff (if <code>false</code> an empty map is returned for {@link Whitelist#getStyleWhitelist()})
+     * @return The HTML/CSS white-lists
+     */
+    Whitelist getWhitelist(boolean withCss);
 }
