@@ -59,6 +59,7 @@ import java.util.concurrent.Callable;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import org.apache.commons.codec.net.URLCodec;
+import org.slf4j.Logger;
 import com.google.common.collect.ImmutableSet;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.html.internal.GlobalEventHandler;
@@ -75,7 +76,7 @@ import net.htmlparser.jericho.HTMLElementName;
 public final class HtmlServices {
 
     public static void main(String[] args) {
-        boolean nonJavaScriptURL = isNonJavaScriptURL("java&#09;script:alert(document.domain)", null);
+        boolean nonJavaScriptURL = containsEventHandler("on'onerror=\"alert(document.cookie)\";'");
 
         System.out.println(nonJavaScriptURL);
     }
@@ -173,7 +174,7 @@ public final class HtmlServices {
                     return Result.DENY;
                 }
             } catch (Exception e) {
-                org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(HtmlServices.class);
+                Logger logger = org.slf4j.LoggerFactory.getLogger(HtmlServices.class);
                 logger.error("Failed to check condition", e);
                 return Result.DENY;
             }
@@ -389,7 +390,7 @@ public final class HtmlServices {
         if (null == maxLength) {
             synchronized (HtmlServices.class) {
                 i = maxLength;
-                if (null == maxLength) {
+                if (null == i) {
                     // Default is 1MB
                     ConfigurationService service = Services.optService(ConfigurationService.class);
                     int defaultMaxLength = 1048576;
@@ -417,7 +418,7 @@ public final class HtmlServices {
         if (null == maxCssLength) {
             synchronized (HtmlServices.class) {
                 i = maxCssLength;
-                if (null == maxCssLength) {
+                if (null == i) {
                     // Default is 96KB
                     ConfigurationService service = Services.optService(ConfigurationService.class);
                     int defaultMaxLength = 98304;
@@ -432,6 +433,32 @@ public final class HtmlServices {
         return i.intValue();
     }
 
+    private static volatile Boolean useJericho;
+
+    /**
+     * Checks whether to use Jericho HTML parser or Jsoup (<code>"<i>com.openexchange.html.jericho</i>"</code> property).
+     *
+     * @return <code>true</code> for Jericho; otherwise <code>false</code>
+     */
+    public static boolean useJericho() {
+        Boolean i = useJericho;
+        if (null == useJericho) {
+            synchronized (HtmlServices.class) {
+                i = useJericho;
+                if (null == i) {
+                    ConfigurationService service = Services.optService(ConfigurationService.class);
+                    boolean def = true;
+                    if (null == service) {
+                        return def;
+                    }
+                    i = Boolean.valueOf(service.getBoolProperty("com.openexchange.html.jericho", def));
+                    useJericho = i;
+                }
+            }
+        }
+        return i.booleanValue();
+    }
+
     // ------------------------------------------------------------------------------------------------------------------------ //
 
     private static char[] lowercases = {
