@@ -49,10 +49,8 @@
 
 package com.openexchange.html.internal;
 
+import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Strings.isEmpty;
-import gnu.inet.encoding.IDNAException;
-import gnu.trove.map.TIntObjectMap;
-import gnu.trove.map.hash.TIntObjectHashMap;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -76,16 +74,6 @@ import java.util.Set;
 import java.util.UUID;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import net.htmlparser.jericho.Attribute;
-import net.htmlparser.jericho.Attributes;
-import net.htmlparser.jericho.Element;
-import net.htmlparser.jericho.EndTag;
-import net.htmlparser.jericho.HTMLElementName;
-import net.htmlparser.jericho.OutputDocument;
-import net.htmlparser.jericho.Renderer;
-import net.htmlparser.jericho.Segment;
-import net.htmlparser.jericho.Source;
-import net.htmlparser.jericho.StartTag;
 import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpException;
@@ -106,26 +94,38 @@ import org.jsoup.Jsoup;
 import org.jsoup.nodes.Comment;
 import org.jsoup.nodes.Document;
 import org.jsoup.nodes.Node;
+import org.jsoup.parser.InterruptedParsingException;
 import org.jsoup.select.NodeVisitor;
 import org.owasp.esapi.codecs.HTMLEntityCodec;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.html.HtmlExceptionCodes;
+import com.openexchange.html.HtmlSanitizeOptions;
 import com.openexchange.html.HtmlSanitizeResult;
 import com.openexchange.html.HtmlService;
 import com.openexchange.html.HtmlServices;
 import com.openexchange.html.internal.emoji.EmojiRegistry;
+import com.openexchange.html.internal.html2text.control.Html2TextControl;
+import com.openexchange.html.internal.html2text.control.Html2TextControlTask;
+import com.openexchange.html.internal.html2text.control.Html2TextTask;
+import com.openexchange.html.internal.filtering.FilterMaps;
 import com.openexchange.html.internal.image.DroppingImageHandler;
 import com.openexchange.html.internal.image.ImageProcessor;
 import com.openexchange.html.internal.image.ProxyRegistryImageHandler;
 import com.openexchange.html.internal.jericho.JerichoParser;
 import com.openexchange.html.internal.jericho.handler.FilterJerichoHandler;
 import com.openexchange.html.internal.jericho.handler.UrlReplacerJerichoHandler;
+import com.openexchange.html.internal.jsoup.JsoupParser;
+import com.openexchange.html.internal.jsoup.handler.CleaningJsoupHandler;
+import com.openexchange.html.internal.jsoup.handler.UrlReplacerJsoupHandler;
 import com.openexchange.html.internal.parser.HtmlParser;
 import com.openexchange.html.internal.parser.handler.HTMLFilterHandler;
 import com.openexchange.html.internal.parser.handler.HTMLImageFilterHandler;
 import com.openexchange.html.services.ServiceRegistry;
+import com.openexchange.html.whitelist.Whitelist;
 import com.openexchange.java.AllocatingStringWriter;
 import com.openexchange.java.Charsets;
+import com.openexchange.java.InterruptibleCharSequence;
 import com.openexchange.java.Streams;
 import com.openexchange.java.StringBuilderStringer;
 import com.openexchange.java.Stringer;
@@ -134,6 +134,19 @@ import com.openexchange.proxy.ProxyRegistry;
 import de.l3s.boilerpipe.BoilerpipeExtractor;
 import de.l3s.boilerpipe.BoilerpipeProcessingException;
 import de.l3s.boilerpipe.extractors.CommonExtractors;
+import gnu.inet.encoding.IDNAException;
+import gnu.trove.map.TIntObjectMap;
+import gnu.trove.map.hash.TIntObjectHashMap;
+import net.htmlparser.jericho.Attribute;
+import net.htmlparser.jericho.Attributes;
+import net.htmlparser.jericho.Element;
+import net.htmlparser.jericho.EndTag;
+import net.htmlparser.jericho.HTMLElementName;
+import net.htmlparser.jericho.OutputDocument;
+import net.htmlparser.jericho.Renderer;
+import net.htmlparser.jericho.Segment;
+import net.htmlparser.jericho.Source;
+import net.htmlparser.jericho.StartTag;
 
 /**
  * {@link HtmlServiceImpl}
@@ -142,7 +155,8 @@ import de.l3s.boilerpipe.extractors.CommonExtractors;
  */
 public final class HtmlServiceImpl implements HtmlService {
 
-    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HtmlServiceImpl.class);
+    /** The logger */
+    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HtmlServiceImpl.class);
 
     private static final String CHARSET_UTF_8 = "UTF-8";
 
@@ -163,6 +177,10 @@ public final class HtmlServiceImpl implements HtmlService {
     private final Tika tika;
     private final String lineSeparator;
     private final HTMLEntityCodec htmlCodec;
+    private final DefaultWhitelist fullWhitelist;
+    private final DefaultWhitelist htmlOnlyWhitelist;
+    private final int htmlParseTimeoutSec;
+    private volatile Thread html2TextControlRunner;
 
     /**
      * Initializes a new {@link HtmlServiceImpl}.
@@ -184,6 +202,33 @@ public final class HtmlServiceImpl implements HtmlService {
         this.htmlEntityMap = htmlEntityMap;
         tika = new Tika();
         htmlCodec = new HTMLEntityCodec();
+        
+        DefaultWhitelist.Builder builder = DefaultWhitelist.builder();
+        builder.setHtmlWhitelistMap(FilterMaps.getStaticHTMLMap());
+        builder.setStyleWhitelistMap(FilterMaps.getStaticStyleMap());
+        fullWhitelist = builder.build();
+
+        builder = DefaultWhitelist.builder();
+        builder.setHtmlWhitelistMap(FilterMaps.getStaticHTMLMap());
+        htmlOnlyWhitelist = builder.build();
+
+        ConfigurationService service = ServiceRegistry.getInstance().getService(ConfigurationService.class);
+        int defaultValue = 10;
+        htmlParseTimeoutSec = null == service ? defaultValue : service.getIntProperty("com.openexchange.html.parse.timeout", defaultValue);
+    }
+
+    /**
+     * Stops this HTML service instance.
+     */
+    public void stop() {
+        if (htmlParseTimeoutSec > 0) {
+            Html2TextControl.getInstance().add(Html2TextTask.POISON);
+        }
+        Thread html2TextControlRunner = this.html2TextControlRunner;
+        if (null != html2TextControlRunner) {
+            this.html2TextControlRunner = null;
+            html2TextControlRunner.interrupt();
+        }
     }
 
     @Override
@@ -331,6 +376,7 @@ public final class HtmlServiceImpl implements HtmlService {
             }
             builder.append(checkedUrl).append("\" target=\"_blank\">").append(url).append("</a>");
         } catch (final MalformedURLException e) {
+            LOG.debug("Malformed URL", e);
             // Append as-is
             builder.append(url);
         }
@@ -479,6 +525,11 @@ public final class HtmlServiceImpl implements HtmlService {
         return htmlCodec.encode(immune, input);
     }
 
+    @Override
+    public Whitelist getWhitelist(boolean withCss) {
+        return withCss ? fullWhitelist : htmlOnlyWhitelist;
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -516,61 +567,65 @@ public final class HtmlServiceImpl implements HtmlService {
         return tmp.toString();
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
-    public HtmlSanitizeResult sanitize(final String htmlContent, final String optConfigName, final boolean dropExternalImages, final boolean[] modified, final String cssPrefix, final int maxContentSize) throws OXException {
+    public HtmlSanitizeResult sanitize(String htmlContent, String optConfigName, boolean dropExternalImages, boolean[] modified, String cssPrefix, int maxContentSize) throws OXException {
+        return sanitize(htmlContent, HtmlSanitizeOptions.builder().setCssPrefix(cssPrefix).setDropExternalImages(dropExternalImages).setMaxContentSize(maxContentSize).setModified(modified).setOptConfigName(optConfigName).build());
+    }
+
+    @Override
+    public HtmlSanitizeResult sanitize(String htmlContent, HtmlSanitizeOptions options) throws OXException {
         HtmlSanitizeResult htmlSanitizeResult = new HtmlSanitizeResult(htmlContent);
         if (isEmpty(htmlContent)) {
             return htmlSanitizeResult;
         }
+
         try {
             String html = htmlContent;
 
             // Check if input is a full HTML document or a fragment of HTML to parse
             boolean hasBody = html.indexOf("<body") >= 0 || html.indexOf("<BODY") >= 0;
 
-            // Normalize the string
-            {
-                Matcher matcher = PATTERN_URL.matcher(html);
-                if (matcher.find()) {
-                    StringBuffer sb = new StringBuffer(html.length());
-                    do {
-                        matcher.appendReplacement(sb, Matcher.quoteReplacement(normalize(matcher.group())));
-                    } while (matcher.find());
-                    matcher.appendTail(sb);
-                    html = sb.toString();
+            boolean useJericho = HtmlServices.useJericho();
+            if (useJericho) {
+                // Normalize the string
+                {
+                    Matcher matcher = PATTERN_URL.matcher(html);
+                    if (matcher.find()) {
+                        StringBuffer sb = new StringBuffer(html.length());
+                        do {
+                            matcher.appendReplacement(sb, Matcher.quoteReplacement(normalize(matcher.group())));
+                        } while (matcher.find());
+                        matcher.appendTail(sb);
+                        html = sb.toString();
+                    }
                 }
-            }
 
-            html = removeComments(html, hasBody);
+                html = removeComments(html, hasBody, options);
 
-            // Perform one-shot sanitizing
-            html = replacePercentTags(html);
-            html = replaceHexEntities(html);
-            html = processDownlevelRevealedConditionalComments(html);
-            html = dropWeirdXmlNamespaceDeclarations(html);
-            html = dropDoubleAccents(html);
-            html = dropSlashedTags(html);
-            html = dropExtraChar(html);
+                // Perform one-shot sanitizing
+                html = replacePercentTags(html);
+                html = replaceHexEntities(html);
+                html = processDownlevelRevealedConditionalComments(html);
+                html = dropWeirdXmlNamespaceDeclarations(html);
+                html = dropDoubleAccents(html);
+                html = dropSlashedTags(html);
+                html = dropExtraChar(html);
 
-            // Repetitive sanitizing until no further replacement/changes performed
-            final boolean[] sanitized = new boolean[] { true };
-            while (sanitized[0]) {
-                sanitized[0] = false;
-                // Start sanitizing round
-                html = SaneScriptTags.saneScriptTags(html, sanitized);
-            }
+                // Repetitive sanitizing until no further replacement/changes performed
+                final boolean[] sanitized = new boolean[] { true };
+                while (sanitized[0]) {
+                    sanitized[0] = false;
+                    // Start sanitizing round
+                    html = SaneScriptTags.saneScriptTags(html, sanitized);
+                }
 
-            // CSS- and tag-wise sanitizing
-            {
-                // Initialize the handler
-                FilterJerichoHandler handler = getHandlerFor(html.length(), optConfigName);
-                handler.setDropExternalImages(dropExternalImages).setCssPrefix(cssPrefix).setMaxContentSize(maxContentSize);
+                // // CSS- and tag-wise sanitizing -- Initialize the handler
+                FilterJerichoHandler handler = getHandlerFor(html.length(), options.getOptConfigName());
+                handler.setDropExternalImages(options.isDropExternalImages()).setCssPrefix(options.getCssPrefix()).setMaxContentSize(options.getMaxContentSize()).setSuppressLinks(options.isSuppressLinks());
 
                 // Drop external images using regular expression
-                if (dropExternalImages) {
+                boolean[] modified = options.getModified();
+                if (options.isDropExternalImages()) {
                     DroppingImageHandler imageHandler = new DroppingImageHandler();
                     html = ImageProcessor.getInstance().replaceImages(html, imageHandler);
                     if (null != modified) {
@@ -579,16 +634,49 @@ public final class HtmlServiceImpl implements HtmlService {
                 }
 
                 // Parse the HTML content
-                JerichoParser.getInstance().parse(html, handler, maxContentSize <= 0);
+                JerichoParser.getInstance().parse(html, handler, true);
 
                 // Check if modified by handler
-                if (dropExternalImages && null != modified) {
+                if (options.isDropExternalImages() && null != modified) {
                     modified[0] |= handler.isImageURLFound();
                 }
 
                 // Get HTML content
                 html = handler.getHTML();
                 htmlSanitizeResult.setTruncated(handler.isMaxContentSizeExceeded());
+            } else {
+                // First, check size
+                int maxLength = HtmlServices.htmlThreshold();
+                if (maxLength > 0 && html.length() > maxLength) {
+                    LOG.info("HTML content is too big: max. '{}', but is '{}'.", I(maxLength), I(html.length()));
+                    throw HtmlExceptionCodes.TOO_BIG.create(I(maxLength), I(html.length()));
+                }
+
+                CleaningJsoupHandler handler = getJsoupHandlerFor(options.getOptConfigName());
+                handler.setDropExternalImages(options.isDropExternalImages()).setCssPrefix(options.getCssPrefix()).setMaxContentSize(options.getMaxContentSize());
+                handler.setSuppressLinks(options.isSuppressLinks()).setReplaceBodyWithDiv(options.isReplaceBodyWithDiv());
+
+                boolean[] modified = options.getModified();
+
+                // Parse the HTML content
+                JsoupParser.getInstance().parse(html, handler, false);
+
+                // Check if modified by handler
+                if (options.isDropExternalImages() && null != modified) {
+                    modified[0] |= handler.isImageURLFound();
+                }
+
+                // Get HTML content
+                if (options.isReplaceBodyWithDiv()) {
+                    html = handler.getHtml();
+                    htmlSanitizeResult.setTruncated(handler.isMaxContentSizeExceeded());
+                    htmlSanitizeResult.setBodyReplacedWithDiv(true);
+                } else {
+                    Document document = handler.getDocument();
+                    handlePrettyPrint(options, document);
+                    html = hasBody ? document.outerHtml() : document.body().html();
+                    htmlSanitizeResult.setTruncated(handler.isMaxContentSizeExceeded());
+                }
             }
 
             // Replace HTML entities
@@ -602,7 +690,13 @@ public final class HtmlServiceImpl implements HtmlService {
         }
     }
 
-    private static String removeComments(String html, boolean hasBody) {
+    private static void handlePrettyPrint(HtmlSanitizeOptions options, Document document) {
+        if (false == options.isPrettyPrint()) {
+            document.outputSettings(new Document.OutputSettings().prettyPrint(false));
+        }
+    }
+
+    private static String removeComments(String html, boolean hasBody, HtmlSanitizeOptions options) {
         Document document = Jsoup.parse(html);
         final Set<Node> removedNodes = new HashSet<>(16, 0.9F);
         document.traverse(new NodeVisitor() {
@@ -622,6 +716,7 @@ public final class HtmlServiceImpl implements HtmlService {
         for (Node node : removedNodes) {
             node.remove();
         }
+        handlePrettyPrint(options, document);
         return hasBody ? document.outerHtml() : document.body().html();
     }
 
@@ -633,6 +728,14 @@ public final class HtmlServiceImpl implements HtmlService {
         return null == definition ? new FilterJerichoHandler(initialCapacity, this) : new FilterJerichoHandler(initialCapacity, definition, this);
     }
 
+    private CleaningJsoupHandler getJsoupHandlerFor(String optionalConfigName) {
+        if (null == optionalConfigName) {
+            return new CleaningJsoupHandler();
+        }
+        String definition = getConfiguration().getText(optionalConfigName.endsWith(".properties") ? optionalConfigName : optionalConfigName + ".properties");
+        return null == definition ? new CleaningJsoupHandler() : new CleaningJsoupHandler(definition);
+    }
+
     private static final Pattern PATTERN_FIX_START_TAG = Pattern.compile("(<[a-zA-Z_0-9-]+)/+([a-zA-Z_0-9-][^>]+)");
 
     private static String dropSlashedTags(final String html) {
@@ -768,10 +871,42 @@ public final class HtmlServiceImpl implements HtmlService {
         }
     }
 
-    private static final Pattern PATTERN_HEADING_WS = Pattern.compile("(\r?\n|^) +");
-
     @Override
     public String html2text(final String htmlContent, final boolean appendHref) {
+        int timeout = htmlParseTimeoutSec;
+        if (timeout <= 0) {
+            return doHtml2Text(htmlContent, appendHref);
+        }
+
+        // Ensure control thread is running
+        Thread html2TextControlRunner = this.html2TextControlRunner;
+        if (null == html2TextControlRunner) {
+            synchronized (this) {
+                html2TextControlRunner = this.html2TextControlRunner;
+                if (null == html2TextControlRunner) {
+                    html2TextControlRunner = new Thread(new Html2TextControlTask(), "Html2TextControl");
+                    html2TextControlRunner.start();
+                    this.html2TextControlRunner = html2TextControlRunner;
+                }
+            }
+        }
+
+        // Run as a monitored task
+        return new Html2TextTask(htmlContent, appendHref, timeout, this).call();
+    }
+
+    private static final Pattern PATTERN_HEADING_WS = Pattern.compile("(\r?\n|^) +");
+
+    /**
+     * Converts specified HTML content to plain text.
+     *
+     * @param htmlContent The <b>validated</b> HTML content
+     * @param appendHref <code>true</code> to append URLs contained in <i>href</i>s and <i>src</i>s; otherwise <code>false</code>.<br>
+     *            Example: <code>&lt;a&nbsp;href=\"www.somewhere.com\"&gt;Link&lt;a&gt;</code> would be
+     *            <code>Link&nbsp;[www.somewhere.com]</code>
+     * @return The plain text representation of specified HTML content
+     */
+    public String doHtml2Text(final String htmlContent, final boolean appendHref) {
         if (isEmpty(htmlContent)) {
             return htmlContent;
         }
@@ -781,7 +916,7 @@ public final class HtmlServiceImpl implements HtmlService {
 
             // Keep considerable content inside <head> element
             {
-                Source source = new Source(prepared);
+                Source source = new Source(InterruptibleCharSequence.valueOf(prepared));
                 source.fullSequentialParse();
                 OutputDocument outputDocument = new OutputDocument(source);
 
@@ -820,12 +955,12 @@ public final class HtmlServiceImpl implements HtmlService {
                 }
             }
 
-            prepared = prepareSignatureStart(prepared);
-            prepared = prepareHrTag(prepared);
-            prepared = prepareAnchorTag(prepared);
-            prepared = insertBlockquoteMarker(prepared);
-            prepared = insertSpaceMarker(prepared);
-            Renderer renderer = new Renderer(new Segment(new Source(prepared), 0, prepared.length())) {
+            prepared = prepareSignatureStart(InterruptibleCharSequence.valueOf(prepared));
+            prepared = prepareHrTag(InterruptibleCharSequence.valueOf(prepared));
+            prepared = prepareAnchorTag(InterruptibleCharSequence.valueOf(prepared));
+            prepared = insertBlockquoteMarker(InterruptibleCharSequence.valueOf(prepared));
+            prepared = insertSpaceMarker(InterruptibleCharSequence.valueOf(prepared));
+            Renderer renderer = new Renderer(new Segment(new Source(InterruptibleCharSequence.valueOf(prepared)), 0, prepared.length())) {
                 @Override
                 public String renderHyperlinkURL(final StartTag startTag) {
                     /*
@@ -847,6 +982,7 @@ public final class HtmlServiceImpl implements HtmlService {
                             return null;
                         }
                     } catch (URISyntaxException ex) {
+                        LOG.debug("Invalid URI", ex);
                         return null;
                     }
                     return href;
@@ -855,27 +991,35 @@ public final class HtmlServiceImpl implements HtmlService {
             renderer.setConvertNonBreakingSpaces(true).setMaxLineLength(9999).setIncludeHyperlinkURLs(appendHref);
             String text = quoteText(renderer.toString());
             // Drop heading whitespaces
-            text = PATTERN_HEADING_WS.matcher(text).replaceAll("$1");
+            text = PATTERN_HEADING_WS.matcher(InterruptibleCharSequence.valueOf(text)).replaceAll("$1");
             // ... but keep enforced ones
-            text = whitespaceText(text);
+            text = whitespaceText(InterruptibleCharSequence.valueOf(text));
             return text;
-        } catch (final StackOverflowError soe) {
-            // Unfortunately it may happen...
-            LOG.warn("Stack-overflow during processing HTML content.", soe);
+        } catch (InterruptedParsingException ipe) {
+            LOG.warn("Timeout during html2text conversion.", ipe);
             // Retry with Tika framework
-            try {
-                return extractFrom(new java.io.ByteArrayInputStream(htmlContent.getBytes(Charsets.ISO_8859_1)));
-            } catch (final Exception e) {
-                LOG.error("Error during processing HTML content.", e);
-                return "";
-            }
+            return tikaHtml2Text(htmlContent);
+        } catch (StackOverflowError soe) {
+            // Unfortunately it may happen...
+            LOG.warn("Stack-overflow during html2text conversion.", soe);
+            // Retry with Tika framework
+            return tikaHtml2Text(htmlContent);
+        }
+    }
+
+    private String tikaHtml2Text(String htmlContent) {
+        try {
+            return extractFrom(Streams.newByteArrayInputStream(htmlContent.getBytes(Charsets.UTF_8)));
+        } catch (final Exception e) {
+            LOG.error("Error during html2text conversion.", e);
+            return "";
         }
     }
 
     private String extractFrom(final InputStream inputStream) throws OXException {
         try {
             final Metadata metadata = new Metadata();
-            metadata.set(Metadata.CONTENT_ENCODING, "ISO-8859-1");
+            metadata.set(Metadata.CONTENT_ENCODING, "UTF-8");
             metadata.set(Metadata.CONTENT_TYPE, "text/html");
             return tika.parseToString(inputStream, metadata);
         } catch (final IOException e) {
@@ -888,10 +1032,10 @@ public final class HtmlServiceImpl implements HtmlService {
     }
 
     private static final Pattern PATTERN_ANCHOR = Pattern.compile("<a[^>]+href=[\"']([^\"']+)[\"'][^>]*>(.*?)</a>", Pattern.DOTALL | Pattern.CASE_INSENSITIVE);
-    private static String prepareAnchorTag(final String htmlContent) {
+    private static String prepareAnchorTag(final CharSequence htmlContent) {
         final Matcher m = PATTERN_ANCHOR.matcher(htmlContent);
         if (!m.find()) {
-            return htmlContent;
+            return htmlContent.toString();
         }
         final StringBuffer sb = new StringBuffer(htmlContent.length());
         do {
@@ -905,10 +1049,10 @@ public final class HtmlServiceImpl implements HtmlService {
     }
 
     private static final Pattern PATTERN_HR = Pattern.compile("<hr[^>]*>(.*?</hr>)?", Pattern.DOTALL | Pattern.CASE_INSENSITIVE);
-    private static String prepareHrTag(final String htmlContent) {
+    private static String prepareHrTag(final CharSequence htmlContent) {
         final Matcher m = PATTERN_HR.matcher(htmlContent);
         if (!m.find()) {
-            return htmlContent;
+            return htmlContent.toString();
         }
         final StringBuffer sb = new StringBuffer(htmlContent.length());
         final String repl = "<br>---------------------------------------------<br>";
@@ -925,10 +1069,10 @@ public final class HtmlServiceImpl implements HtmlService {
     }
 
     private static final Pattern PATTERN_SIGNATURE_START = Pattern.compile("(?:\r?\n|^)([ \t]*)-- (\r?\n)");
-    private static String prepareSignatureStart(final String htmlContent) {
+    private static String prepareSignatureStart(final CharSequence htmlContent) {
         final Matcher m = PATTERN_SIGNATURE_START.matcher(htmlContent);
         if (!m.find()) {
-            return htmlContent;
+            return htmlContent.toString();
         }
         final StringBuffer sb = new StringBuffer(htmlContent.length());
         m.appendReplacement(sb, "$1--&#160;$2");
@@ -940,13 +1084,13 @@ public final class HtmlServiceImpl implements HtmlService {
 
     private static final Pattern PATTERN_SPACE_MARKER = Pattern.compile(Pattern.quote(SPACE_MARKER));
 
-    private static String whitespaceText(final String text) {
+    private static String whitespaceText(final CharSequence text) {
         return PATTERN_SPACE_MARKER.matcher(text).replaceAll(" ");
     }
 
     private static final Pattern PATTERN_HTML_MANDATORY_SPACE = Pattern.compile("&#160;");
 
-    private static String insertSpaceMarker(final String html) {
+    private static String insertSpaceMarker(final CharSequence html) {
         return PATTERN_HTML_MANDATORY_SPACE.matcher(html).replaceAll(SPACE_MARKER);
     }
 
@@ -997,7 +1141,7 @@ public final class HtmlServiceImpl implements HtmlService {
         if (retval.indexOf(SPECIAL) < 0) {
             return retval;
         }
-        return PATTERN_MARKER.matcher(retval).replaceAll("");
+        return PATTERN_MARKER.matcher(InterruptibleCharSequence.valueOf(retval)).replaceAll("");
     }
 
     private static String getPrefixFor(final int quote) {
@@ -1015,7 +1159,7 @@ public final class HtmlServiceImpl implements HtmlService {
 
     private static final Pattern PATTERN_BLOCKQUOTE_END = Pattern.compile("(</blockquote>)", Pattern.CASE_INSENSITIVE);
 
-    private static String insertBlockquoteMarker(final String html) {
+    private static String insertBlockquoteMarker(final CharSequence html) {
         return PATTERN_BLOCKQUOTE_END.matcher(PATTERN_BLOCKQUOTE_START.matcher(html).replaceAll("$1"+BLOCKQUOTE_MARKER)).replaceAll("$1"+BLOCKQUOTE_MARKER_END);
     }
 
@@ -1031,12 +1175,13 @@ public final class HtmlServiceImpl implements HtmlService {
         String content = PATTERN_CRLF.matcher(escape(plainText, withQuote, commentId)).replaceAll(HTML_BR);
         HtmlSanitizeResult htmlSanitizeResult = new HtmlSanitizeResult(content);
 
-        if (!(maxContentSize >= 10000) && !(maxContentSize <= 0)) {
-            maxContentSize = 10000;
+        int maxSize = maxContentSize;
+        if (!(maxSize >= 10000) && !(maxSize <= 0)) {
+            maxSize = 10000;
         }
 
-        if ((maxContentSize > 0) && (maxContentSize < content.length())) {
-            int endOfSentence = content.indexOf('.', maxContentSize) + 1;
+        if ((maxSize > 0) && (maxSize < content.length())) {
+            int endOfSentence = content.indexOf('.', maxSize) + 1;
             content = content.substring(0, endOfSentence);
             htmlSanitizeResult.setTruncated(true);
         }
@@ -1290,6 +1435,7 @@ public final class HtmlServiceImpl implements HtmlService {
         try {
             return Integer.parseInt(possibleNum, radix);
         } catch (final NumberFormatException e) {
+            LOG.trace("", e);
             return -1;
         }
     }
@@ -1687,9 +1833,16 @@ public final class HtmlServiceImpl implements HtmlService {
 
         // Check URLs
         if (replaceUrls) {
-            UrlReplacerJerichoHandler handler = new UrlReplacerJerichoHandler(html.length());
-            JerichoParser.getInstance().parse(html, handler, false);
-            html = handler.getHTML();
+            boolean useJericho = HtmlServices.useJericho();
+            if (useJericho) {
+                UrlReplacerJerichoHandler handler = new UrlReplacerJerichoHandler(html.length());
+                JerichoParser.getInstance().parse(html, handler, false);
+                html = handler.getHTML();
+            } else {
+                UrlReplacerJsoupHandler handler = new UrlReplacerJsoupHandler();
+                JsoupParser.getInstance().parse(html, handler, false);
+                html = handler.getDocument().toString();
+            }
         }
 
         return html;
