@@ -487,8 +487,7 @@ public final class JerichoParser {
             }
         }
 
-        @SuppressWarnings("resource")
-        StreamedSource nestedSource = new StreamedSource(dropWeirdAttributes(startTag)); // No need to close since String-backed (all in memory)!
+        @SuppressWarnings("resource") StreamedSource nestedSource = new StreamedSource(dropWeirdAttributes(startTag)); // No need to close since String-backed (all in memory)!
         Thread thread = Thread.currentThread();
 
         Iterator<Segment> iter = nestedSource.iterator();
