@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,11 +51,11 @@ package com.openexchange.http.client.apache;
 
 import java.io.File;
 import java.io.FileNotFoundException;
+import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
 import java.util.List;
-
 import org.apache.commons.httpclient.HttpMethodBase;
 import org.apache.commons.httpclient.methods.PostMethod;
 import org.apache.commons.httpclient.methods.multipart.ByteArrayPartSource;
@@ -64,7 +64,7 @@ import org.apache.commons.httpclient.methods.multipart.FilePartSource;
 import org.apache.commons.httpclient.methods.multipart.MultipartRequestEntity;
 import org.apache.commons.httpclient.methods.multipart.Part;
 import org.apache.commons.httpclient.methods.multipart.PartSource;
-
+import org.apache.commons.httpclient.methods.multipart.StringPart;
 import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.filemanagement.ManagedFileManagement;
@@ -76,14 +76,14 @@ public class ApacheMultipartPostRequestBuilder extends CommonApacheHTTPRequest<H
 
 	private ManagedFileManagement fileManager;
 	private List<Part> parts = new ArrayList<Part>();
-	
+
 	private List<ManagedFile> managedFiles = new ArrayList<ManagedFile>();
-	
+
 	public ApacheMultipartPostRequestBuilder(
 			ApacheClientRequestBuilder coreBuilder, ManagedFileManagement fileManager) {
 		super(coreBuilder);
 		this.fileManager = fileManager;
-		
+
 	}
 
 	@Override
@@ -130,16 +130,28 @@ public class ApacheMultipartPostRequestBuilder extends CommonApacheHTTPRequest<H
 		return this;
 	}
 
+	@Override
+    public HTTPMultipartPostRequestBuilder part(String fieldName, InputStream is, String contentType, long length, String filename) throws OXException {
+            parts.add(new FilePart(fieldName, partSource(length, filename, is), contentType, "UTF-8"));
+        return this;
+    }
+
+	@Override
+    public HTTPMultipartPostRequestBuilder stringPart(String fieldName, String fieldValue) {
+        parts.add(new StringPart(fieldName, fieldValue, "UTF-8"));
+        return this;
+    }
+
 	@Override
 	protected HttpMethodBase createMethod(String encodedSite) {
 		PostMethod m = new PostMethod(encodedSite);
-		
+
 		MultipartRequestEntity multipart = new MultipartRequestEntity(parts.toArray(new Part[parts.size()]), m.getParams());
 		m.setRequestEntity( multipart );
-		
+
 		return m;
 	}
-	
+
 	private PartSource partSource(String filename, InputStream is) throws OXException {
 		try {
 			ManagedFile managedFile = fileManager.createManagedFile(is);
@@ -149,7 +161,28 @@ public class ApacheMultipartPostRequestBuilder extends CommonApacheHTTPRequest<H
 			throw OxHttpClientExceptionCodes.APACHE_CLIENT_ERROR.create(e.getMessage(), e);
 		}
 	}
-	
+
+	private PartSource partSource(final long size, final String filename, final InputStream is) throws OXException {
+	    PartSource source = new PartSource() {
+
+            @Override
+            public long getLength() {
+                return size;
+            }
+
+            @Override
+            public String getFileName() {
+                return filename;
+            }
+
+            @Override
+            public InputStream createInputStream() throws IOException {
+                return is;
+            }
+        };
+        return source;
+    }
+
 	@Override
 	public void done() {
 		for (ManagedFile managedFile : managedFiles) {
@@ -160,4 +193,6 @@ public class ApacheMultipartPostRequestBuilder extends CommonApacheHTTPRequest<H
 	}
 
 
+
+
 }
