@@ -63,9 +63,11 @@ import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
+import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.TimeZone;
@@ -89,6 +91,7 @@ import com.openexchange.groupware.generic.FolderUpdaterServiceV2;
 import com.openexchange.groupware.generic.TargetFolderDefinition;
 import com.openexchange.groupware.importexport.ImportResult;
 import com.openexchange.groupware.importexport.csv.CSVParser;
+import com.openexchange.groupware.importexport.csv.CsvExceptionCodes;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.importexport.exceptions.ImportExportExceptionCodes;
 import com.openexchange.importexport.formats.Format;
@@ -116,6 +119,14 @@ public class CSVContactImporter extends AbstractImporter {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CSVContactImporter.class);
 
+    /**
+     * A list of fields which should not be imported and dropped silently
+     */
+    protected static final EnumSet<ContactField> UNSUPPORTED_FIELDS = EnumSet.of(
+        ContactField.OBJECT_ID, ContactField.CREATED_BY, ContactField.CREATION_DATE, ContactField.LAST_MODIFIED, ContactField.MODIFIED_BY,
+        ContactField.FOLDER_ID
+    );
+
     private LinkedList<ContactFieldMapper> mappers;
 
     private ContactFieldMapper currentMapper;
@@ -209,7 +220,7 @@ public class CSVContactImporter extends AbstractImporter {
         {
             final int size = csv.size();
             intentions = new ArrayList<ImportIntention>(size);
-            final ContactSwitcher conSet = getContactSwitcher();
+            final ContactSwitcher conSet = getContactSwitcher(sessObj.getUser().getLocale());
             for (int lineNumber = 1; lineNumber < size; lineNumber++) {
                 // ...and writing them
                 final List<String> row = csv.get(lineNumber);
@@ -320,13 +331,17 @@ public class CSVContactImporter extends AbstractImporter {
             }
         } catch (final OXException e) {
             if (e.getCategory() != Category.CATEGORY_TRUNCATED || (e.getCategory() == Category.CATEGORY_TRUNCATED && !canOverrideInCaseOfTruncation)) {
-                result.setException(e);
+                result.setException(wrapException(e, lineNumber, session));
                 addErrorInformation(result, lineNumber, fields);
             }
         }
         return new ImportIntention(result);
     }
 
+    private OXException wrapException(OXException ex, int lineNumber, ServerSession session){
+        return CsvExceptionCodes.NESTED_ERROR.create(lineNumber, ex.getDisplayMessage(session.getUser().getLocale()));
+    }
+
     public Contact convertCsvToContact(List<String> fields, List<String> entry, ContactSwitcher conSet, int lineNumber, ImportResult result, boolean[] atLeastOneFieldInserted) throws OXException {
         final Contact contactObj = new Contact();
         final Collection<OXException> warnings = new LinkedList<OXException>();
@@ -343,6 +358,17 @@ public class CSVContactImporter extends AbstractImporter {
                 markAsDistributionlist = true;
             }
 
+            // skip unsupported import fields
+            boolean skip = false;
+            for(ContactField field: UNSUPPORTED_FIELDS){
+                if(field.getReadableName().equals(fieldName)){
+                    skip=true;
+                    break;
+                }
+            }
+            if(skip){
+                continue;
+            }
             final ContactField currField = getRelevantField(fieldName);
             if (currField == null) {
                 final boolean worked = conSet._unknownfield(contactObj, fieldName, currEntry);
@@ -391,24 +417,26 @@ public class CSVContactImporter extends AbstractImporter {
         result.setEntryNumber(lineNumber);
     }
 
-    public ContactSwitcher getContactSwitcher() {
+    public ContactSwitcher getContactSwitcher(Locale locale) {
         final ContactSwitcherForSimpleDateFormat dateSwitch = new ContactSwitcherForSimpleDateFormat();
         dateSwitch.addDateFormat(DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM));
-
+        
         final TimeZone utc = TimeZoneUtils.getTimeZone("UTC");
         final SimpleDateFormat df1 = new SimpleDateFormat("dd.MM.yyyy");
         df1.setTimeZone(utc);
 
-        final SimpleDateFormat df2 = new SimpleDateFormat("MM/dd/yyyy");
-        df2.setTimeZone(utc);
-
-        final SimpleDateFormat df3 = new SimpleDateFormat("yyyy-MM-dd");
-        df3.setTimeZone(utc);
-
+        final SimpleDateFormat df2 = new SimpleDateFormat("yyyy-MM-dd");
+        df2.setTimeZone(utc);        
+        
         dateSwitch.addDateFormat(df1);
         dateSwitch.addDateFormat(df2);
-        dateSwitch.addDateFormat(df3);
-
+        
+        if (null != locale) {
+            final DateFormat df3 = DateFormat.getDateInstance(DateFormat.SHORT, locale);
+            df3.setTimeZone(utc);
+            dateSwitch.addDateFormat(df3);
+        }             
+        
         final ContactSwitcherForTimestamp timestampSwitch = new ContactSwitcherForTimestamp();
         final ContactSwitcherForBooleans boolSwitch = new ContactSwitcherForBooleans();
         ContactSwitcherForEmailAddresses emailSwitch = new ContactSwitcherForEmailAddresses();
@@ -517,7 +545,7 @@ public class CSVContactImporter extends AbstractImporter {
                 }
                 for (ContactFieldMapper mapper : entry.getValue()) {
                     int mappedFields = getMappedFields(mapper, parsedFirstLine.get(0));
-                    if (mappedFields > maxMappedFields) {
+                    if (mappedFields > maxMappedFields || mappedFields == maxMappedFields && entry.getKey().equals(detectedCharset)) {
                         maxMappedFields = mappedFields;
                         bestMapper = mapper;
                         bestParser = csvParser;
