@@ -72,6 +72,8 @@ import com.openexchange.api2.TasksSQLInterface;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.ICalParser;
+import com.openexchange.data.conversion.ical.ParseResult;
+import com.openexchange.data.conversion.ical.TruncationInfo;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXException.Generic;
@@ -219,7 +221,7 @@ public class ICalImporter extends AbstractImporter {
 	}
 
 	@Override
-    public List<ImportResult> importData(final ServerSession session,
+    public ImportResults importData(final ServerSession session,
 			final Format format, final InputStream is,
 			final List<String> folders,
 			final Map<String, String[]> optionalParams)
@@ -240,26 +242,28 @@ public class ICalImporter extends AbstractImporter {
 		final List<ImportResult> list = new ArrayList<ImportResult>();
 		final List<ConversionError> errors = new ArrayList<ConversionError>();
 		final List<ConversionWarning> warnings = new ArrayList<ConversionWarning>();
+		TruncationInfo truncationInfo = null;
 
 		if (appointmentFolderId != -1) {
-			importAppointment(session, is, optionalParams, appointmentFolderId,
+			truncationInfo = importAppointment(session, is, optionalParams, appointmentFolderId,
 					appointmentInterface, parser, ctx, defaultTz, list, errors,
 					warnings);
 		}
 		if (taskFolderId != -1) {
-			importTask(is, optionalParams, taskFolderId, taskInterface, parser, ctx, defaultTz,
+			truncationInfo = importTask(is, optionalParams, taskFolderId, taskInterface, parser, ctx, defaultTz,
 					list, errors, warnings);
 		}
-		return list;
+		return new DefaultImportResults(list, truncationInfo);
 	}
 
-	private void importTask(final InputStream is, final Map<String, String[]> optionalParams, final int taskFolderId,
+	private TruncationInfo importTask(final InputStream is, final Map<String, String[]> optionalParams, final int taskFolderId,
 			final TasksSQLInterface taskInterface, final ICalParser parser,
 			final Context ctx, final TimeZone defaultTz,
 			final List<ImportResult> list, final List<ConversionError> errors,
 			final List<ConversionWarning> warnings)
 			throws OXException {
-		List<Task> tasks = parser.parseTasks(is, defaultTz, ctx, errors, warnings);
+		ParseResult<Task> tasks = parser.parseTasks(is, defaultTz, ctx, errors, warnings);
+		TruncationInfo truncationInfo = tasks.getTruncationInfo();
 		final TIntObjectMap<ConversionError> errorMap = new TIntObjectHashMap<ConversionError>();
 
 		for (final ConversionError error : errors) {
@@ -281,7 +285,7 @@ public class ICalImporter extends AbstractImporter {
         boolean ignoreUIDs = isIgnoreUIDs(optionalParams);
         Map<String, String> uidReplacements = ignoreUIDs ? new HashMap<String, String>() : null;
 		int index = 0;
-		final Iterator<Task> iter = tasks.iterator();
+		final Iterator<Task> iter = tasks.getImportedObjects().iterator();
 		while (iter.hasNext()) {
 			final ImportResult importResult = new ImportResult();
 			final ConversionError error = errorMap.get(index);
@@ -340,9 +344,10 @@ public class ICalImporter extends AbstractImporter {
 				}
 			});
 		}
+		return truncationInfo;
 	}
 
-	private void importAppointment(final ServerSession session,
+	private TruncationInfo importAppointment(final ServerSession session,
 			final InputStream is, final Map<String, String[]> optionalParams,
 			final int appointmentFolderId,
 			final AppointmentSQLInterface appointmentInterface,
@@ -351,14 +356,16 @@ public class ICalImporter extends AbstractImporter {
 			final List<ConversionError> errors,
 			final List<ConversionWarning> warnings)
 			throws OXException {
-		List<CalendarDataObject> appointments = parser.parseAppointments(is, defaultTz, ctx, errors, warnings);
+	    ParseResult<CalendarDataObject> parseResult = parser.parseAppointments(is, defaultTz, ctx, errors, warnings);
+	    List<CalendarDataObject> appointments = parseResult.getImportedObjects();
+	    TruncationInfo truncationInfo = parseResult.getTruncationInfo();
 		final TIntObjectMap<ConversionError> errorMap = new TIntObjectHashMap<ConversionError>();
 
 		for (final ConversionError error : errors) {
 			errorMap.put(error.getIndex(), error);
 		}
 		if (null == appointments) {
-		    appointments = Collections.emptyList();
+		    appointments = Collections.<CalendarDataObject> emptyList();
 		}
 
 		sortSeriesMastersFirst(appointments);
@@ -501,6 +508,7 @@ public class ICalImporter extends AbstractImporter {
 				}
 			});
 		}
+		return truncationInfo;
 	}
 
 	private OXException makeMoreInformative(OXException e) {
@@ -673,8 +681,7 @@ public class ICalImporter extends AbstractImporter {
             }
         }
         if (false == containsInternalParticpiant) {
-            UserParticipant userParticipant = new UserParticipant(
-                FolderObject.SHARED == targetFolder.getType() ? targetFolder.getCreatedBy() : session.getUserId());
+            UserParticipant userParticipant = new UserParticipant(targetFolder.getType() == FolderObject.PUBLIC ? session.getUserId() : targetFolder.getCreatedBy());
             userParticipant.setConfirm(Appointment.ACCEPT);
             Participant[] newParticipants = null == currentParticipants ?
                 new Participant[1] : Arrays.copyOf(currentParticipants, 1 + currentParticipants.length);
