@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,6 +57,8 @@ import org.json.JSONObject;
 import com.openexchange.ajax.itip.ITipAnalysisWriter;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.calendar.itip.ITipAnalysis;
+import com.openexchange.calendar.itip.ITipAnalyzerService;
+import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
@@ -67,8 +69,8 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class AnalyzeAction extends AbstractITipAction {
 
-    public AnalyzeAction(ServiceLookup services) {
-        super(services);
+    public AnalyzeAction(ServiceLookup services, RankingAwareNearRegistryServiceTracker<ITipAnalyzerService> analyzerListing) {
+        super(services, analyzerListing);
     }
 
     @Override
