@@ -53,7 +53,9 @@ import java.util.AbstractQueue;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.NoSuchElementException;
 import java.util.PriorityQueue;
@@ -225,10 +227,10 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      * @throws NullPointerException if the specified element is null
      */
     public boolean offer(E e, long delayDuration, long maxDelayDuration) {
-        BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
         ReentrantLock lock = this.lock;
         lock.lock();
         try {
+            BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
             q.offer(delayedE);
             if (q.peek() == delayedE) {
                 leader = null;
@@ -273,10 +275,10 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      * @throws NullPointerException if the specified element is <code>null</code>
      */
     public boolean offerIfAbsent(E e, long delayDuration, long maxDelayDuration) {
-        BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
         ReentrantLock lock = this.lock;
         lock.lock();
         try {
+            BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
             if (contains(delayedE)) {
                 return false;
             }
@@ -314,11 +316,11 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      * @throws NullPointerException if the specified element is <code>null</code>
      */
     public boolean offerIfAbsentElseReset(E e, long delayDuration, long maxDelayDuration) {
-        BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
         ReentrantLock lock = this.lock;
         lock.lock();
         try {
             // Check if already contained
+            BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
             {
                 BufferedElement<E> prev = null;
                 for (Iterator<BufferedElement<E>> it = q.iterator(); null == prev && it.hasNext();) {
@@ -473,6 +475,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      *
      * @param e The element to add
      * @return The previous value if it was replaced, or <code>null</code> if there was no equal element in the queue before
+     * @see #transfer(Object, BufferedElement)
      */
     public E offerOrReplaceAndReset(E e) {
         return offerOrReplaceAndReset(e, defaultDelayDuration, defaultMaxDelayDuration);
@@ -486,6 +489,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      * @param delayDuration The delay duration (in milliseconds) to use initially and for reseting due to repeated offer operations
      * @param maxDelayDuration The the maximum delay duration (in milliseconds) to use, independently of repeated offer operations
      * @return The previous value if it was replaced, or <code>null</code> if there was no equal element in the queue before
+     * @see #transfer(Object, BufferedElement)
      */
     public E offerOrReplaceAndReset(E e, long delayDuration, long maxDelayDuration) {
         BufferedElement<E> delayedE = new BufferedElement<E>(e, delayDuration, maxDelayDuration);
@@ -498,7 +502,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
                 BufferedElement<E> next = it.next();
                 if (delayedE.equals(next)) {
                     prev = next;
-                    delayedE = new BufferedElement<E>(e, prev);
+                    delayedE = transfer(e, prev);
                     delayedE.reset(); // Resets to prev
                     it.remove();
                 }
@@ -514,6 +518,17 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
         }
     }
 
+    /**
+     * Transfers the element to offer to the existing <code>BufferedElement</code> wrapper.
+     *
+     * @param toOffer The element to offer
+     * @param existing The existing <code>BufferedElement</code> wrapper
+     * @return The <code>BufferedElement</code> wrapper holding the transferred element
+     */
+    protected BufferedElement<E> transfer(E toOffer, BufferedElement<E> existing) {
+        return new BufferedElement<E>(toOffer, existing);
+    }
+
     /**
      * Inserts the specified element into this delay queue. As the queue is
      * unbounded this method will never block.
@@ -692,6 +707,38 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
         }
     }
 
+    /**
+     * Removes all elements with an expired delay from this queue and returns them.
+     *
+     * @return The drained elements
+     */
+    public Collection<E> drain() {
+        ReentrantLock lock = this.lock;
+        lock.lock();
+        try {
+            BufferedElement<E> first = q.peek();
+            if (first == null || first.getDelay(TimeUnit.NANOSECONDS) > 0) {
+                return Collections.emptyList();
+            }
+
+            Collection<E> c = new LinkedList<>();
+            c.add(q.poll().getElement());
+
+            boolean peek = true;
+            while (peek) {
+                BufferedElement<E> be = q.peek();
+                if (be == null || be.getDelay(TimeUnit.NANOSECONDS) > 0) {
+                    peek = false;
+                } else {
+                    c.add(q.poll().getElement());
+                }
+            }
+            return c;
+        } finally {
+            lock.unlock();
+        }
+    }
+
     /**
      * @throws UnsupportedOperationException {@inheritDoc}
      * @throws ClassCastException            {@inheritDoc}
@@ -860,7 +907,14 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
         ReentrantLock lock = this.lock;
         lock.lock();
         try {
-            return q.remove(o);
+            for (Iterator<BufferedElement<E>> it = q.iterator(); it.hasNext();) {
+                BufferedElement<E> next = it.next();
+                if (o.equals(next.getElement())) {
+                    it.remove();
+                    return true;
+                }
+            }
+            return false;
         } finally {
             lock.unlock();
         }
@@ -942,7 +996,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
      * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
      */
-    private static class BufferedElement<T> implements Delayed {
+    protected static class BufferedElement<T> implements Delayed {
 
         private volatile long stamp;
         private final long delayDuration;
@@ -958,7 +1012,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
          * @param maxDelayDuration The the maximum delay duration (in milliseconds) to apply, or <code>0</code> for no maximum
          * @throws IllegalArgumentException If <code>delayDuration</code> is greater than <code>maxDelayDuration</code>
          */
-        BufferedElement(T element, long delayDuration, long maxDelayDuration) {
+        public BufferedElement(T element, long delayDuration, long maxDelayDuration) {
             super();
             if (delayDuration > maxDelayDuration && 0 != maxDelayDuration) {
                 throw new IllegalArgumentException("delayDuration is greater than maxDelayDuration.");
@@ -977,7 +1031,7 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
          * @param element The actual payload element
          * @param source The other element
          */
-        BufferedElement(T element, BufferedElement<T> source) {
+        public BufferedElement(T element, BufferedElement<T> source) {
             super();
             this.element = element;
             this.delayDuration = source.delayDuration;
@@ -1004,9 +1058,9 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
         }
 
         /**
-         * Get the wrapped pushMsObject.
+         * Gets the wrapped element.
          *
-         * @return the wrapped pushMsObject
+         * @return the wrapped element
          */
         public T getElement() {
             return element;
@@ -1031,9 +1085,6 @@ public class BufferingQueue<E> extends AbstractQueue<E> implements BlockingQueue
             if (this == obj) {
                 return true;
             }
-            if (null == obj) {
-                return false;
-            }
             if (!(obj instanceof BufferedElement)) {
                 return obj.equals(element);
             }
