@@ -208,4 +208,33 @@ public class ConcurrentSet<E> implements Set<E> {
         } while (!ref.compareAndSet(expected, set));
     }
 
+    /**
+     * Returns a string representation of this collection.  The string
+     * representation consists of a list of the collection's elements in the
+     * order they are returned by its iterator, enclosed in square brackets
+     * (<tt>"[]"</tt>).  Adjacent elements are separated by the characters
+     * <tt>", "</tt> (comma and space).  Elements are converted to strings as
+     * by {@link String#valueOf(Object)}.
+     *
+     * @return a string representation of this collection
+     */
+    @Override
+    public String toString() {
+        Iterator<E> it = iterator();
+        if (! it.hasNext()) {
+            return "[]";
+        }
+
+        StringBuilder sb = new StringBuilder(32);
+        sb.append('[');
+        for (;;) {
+            E e = it.next();
+            sb.append(e == this ? "(this Collection)" : e);
+            if (! it.hasNext()) {
+                return sb.append(']').toString();
+            }
+            sb.append(',').append(' ');
+        }
+    }
+
 }
