@@ -49,9 +49,7 @@
 
 package com.openexchange.java;
 
-import static com.openexchange.java.Strings.isEmpty;
 import static com.openexchange.java.Strings.toLowerCase;
-import static com.openexchange.java.Strings.toUpperCase;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Arrays;
@@ -96,52 +94,9 @@ public final class HTMLDetector {
     }
 
     /**
-     * Checks if given String contains common HTML tags.
+     * Checks if given string contains common HTML tags.
      *
-     * @param sequence The String to check
-     * @return <code>true</code> if given String contains common HTML tags; otherwise <code>false</code>
-     */
-    public static boolean containsHTMLTags(final String sequence) {
-        if (sequence == null) {
-            throw new NullPointerException();
-        }
-        final String lc = toLowerCase(sequence);
-        if ((lc.indexOf("<html>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<head>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<body>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<script") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("javascript") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<img") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<object") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<embed") >= 0)) {
-            return true;
-        }
-        for (final String jsEventHandler : JS_EVENT_HANDLER) {
-            if (lc.indexOf(jsEventHandler) >= 0) {
-                return true;
-            }
-        }
-        return false;
-    }
-
-    /**
-     * Checks if given String contains common HTML tags.
-     *
-     * @param sequence The String to check
+     * @param sequence The string to check
      * @param strict <code>true</code> for strict checking; otherwise <code>false</code>
      * @return <code>true</code> if given String contains common HTML tags; otherwise <code>false</code>
      */
@@ -150,9 +105,9 @@ public final class HTMLDetector {
     }
 
     /**
-     * Checks if given String contains common HTML tags.
+     * Checks if given string contains common HTML tags.
      *
-     * @param sequence The String to check
+     * @param sequence The string to check
      * @param tags Additional tags to look for
      * @return <code>true</code> if given String contains common HTML tags; otherwise <code>false</code>
      */
@@ -160,65 +115,70 @@ public final class HTMLDetector {
         if (sequence == null) {
             throw new NullPointerException();
         }
-        final String lc = toLowerCase(sequence);
-        if ((lc.indexOf("html>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("head>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("body>") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<script") >= 0)) {
-            return true;
+
+        String lc = Strings.asciiLowerCase(sequence);
+        if (lc.indexOf('<') >= 0) {
+            if ((lc.indexOf("html>") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("head>") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("body>") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("<script") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("<img") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("<object") >= 0)) {
+                return true;
+            }
+            if ((lc.indexOf("<embed") >= 0)) {
+                return true;
+            }
+            if (null != tags && tags.length > 0) {
+                for (int i = tags.length; i-- > 0;) {
+                    final String tag = tags[i];
+                    if (!Strings.isEmpty(tag) && (lc.indexOf(tag) >= 0)) {
+                        return true;
+                    }
+                }
+            }
         }
+
         if ((lc.indexOf("javascript") >= 0)) {
             return true;
         }
-        if ((lc.indexOf("<img") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<object") >= 0)) {
-            return true;
-        }
-        if ((lc.indexOf("<embed") >= 0)) {
-            return true;
-        }
-        for (final String jsEventHandler : JS_EVENT_HANDLER) {
+        for (String jsEventHandler : JS_EVENT_HANDLER) {
             if (lc.indexOf(jsEventHandler) >= 0) {
                 return true;
             }
         }
-        if (null != tags) {
-            for (int i = tags.length; i-- > 0;) {
-                final String tag = tags[i];
-                if (!Strings.isEmpty(tag) && (lc.indexOf(tag) >= 0)) {
-                    return true;
-                }
-            }
-        }
+
         return false;
     }
 
     /**
-     * Checks if given String contains specified HTML tag.
+     * Checks if given string contains specified HTML tag.
      *
-     * @param sequence The String to check
+     * @param sequence The string to check
      * @param tag The HTML tag; e.g. <code>"body"</code>
      * @return <code>true</code> if given String contains specified HTML tag; otherwise <code>false</code>
      */
     public static boolean containsHTMLTag(final String sequence, final String tag) {
-        if (sequence == null) {
+        if (sequence == null || tag == null) {
             throw new NullPointerException();
         }
-        return containsIgnoreCase(sequence, new StringBuilder(tag.length() + 2).append('<').append(tag).append('>').toString());
+        return containsIgnoreCase(sequence, tag.startsWith("<") ? tag : new StringBuilder(tag.length() + 2).append('<').append(tag).append('>').toString());
     }
 
     /**
-     * Checks if given String contains specified string.
+     * Checks if given string contains specified string.
      *
-     * @param sequence The String to check
+     * @param sequence The string to check
      * @param str The string
      * @return <code>true</code> if given String contains specified string; otherwise <code>false</code>
      */
@@ -228,48 +188,6 @@ public final class HTMLDetector {
 
     // ----------------------------------------------------------------------------------------- //
 
-    /**
-     * Checks if given byte sequence contains common HTML tags.
-     *
-     * @param sequence The byte sequence to check
-     * @return <code>true</code> if given byte sequence contains common HTML tags; otherwise <code>false</code>
-     */
-    public static boolean containsHTMLTags(final byte[] sequence) {
-        if (sequence == null) {
-            throw new NullPointerException();
-        }
-        if (containsHTMLTag(sequence, "html")) {
-            return true;
-        }
-        if (containsHTMLTag(sequence, "head")) {
-            return true;
-        }
-        if (containsHTMLTag(sequence, "body")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, "<script")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, "javascript")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, "<img")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, "<object")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, "<embed")) {
-            return true;
-        }
-        for (final String jsEventHandler : JS_EVENT_HANDLER) {
-            if (containsIgnoreCase(sequence, jsEventHandler)) {
-                return true;
-            }
-        }
-        return false;
-    }
-
     /**
      * Checks if given byte sequence contains common HTML tags.
      *
@@ -301,7 +219,7 @@ public final class HTMLDetector {
 
             boolean found = false;
             for (int read; !found && (read = in.read(buf, 0, buflen)) > 0;) {
-                found = strict ? containsHTMLTags(buf, 0, read, "<br", "<p>") : containsHTMLTags(buf, 0, read);
+                found = containsHTMLTags(Charsets.toAsciiString(buf, 0, read), strict);
                 if (oneShot) {
                     return found;
                 }
@@ -312,6 +230,19 @@ public final class HTMLDetector {
         }
     }
 
+    /**
+     * Checks if given byte sequence contains common HTML tags.
+     *
+     * @param sequence The byte sequence to check
+     * @return <code>true</code> if given byte sequence contains common HTML tags; otherwise <code>false</code>
+     */
+    public static boolean containsHTMLTags(final byte[] sequence) {
+        if (sequence == null) {
+            throw new NullPointerException();
+        }
+        return containsHTMLTags(Charsets.toAsciiString(sequence));
+    }
+
     /**
      * Checks if given byte sequence contains common HTML tags.
      *
@@ -320,7 +251,10 @@ public final class HTMLDetector {
      * @return <code>true</code> if given byte sequence contains common HTML tags; otherwise <code>false</code>
      */
     public static boolean containsHTMLTags(final byte[] sequence, final boolean strict) {
-        return strict ? containsHTMLTags(sequence, "<br", "<p>") : containsHTMLTags(sequence);
+        if (sequence == null) {
+            throw new NullPointerException();
+        }
+        return containsHTMLTags(Charsets.toAsciiString(sequence), strict);
     }
 
     /**
@@ -331,18 +265,10 @@ public final class HTMLDetector {
      * @return <code>true</code> if given byte sequence contains common HTML tags; otherwise <code>false</code>
      */
     public static boolean containsHTMLTags(final byte[] sequence, final String... tags) {
-        if (containsHTMLTags(sequence)) {
-            return true;
+        if (sequence == null) {
+            throw new NullPointerException();
         }
-        if (null != tags) {
-            for (int i = tags.length; i-- > 0;) {
-                final String tag = tags[i];
-                if (!isEmpty(tag) && containsIgnoreCase(sequence, tag)) {
-                    return true;
-                }
-            }
-        }
-        return false;
+        return containsHTMLTags(Charsets.toAsciiString(sequence), tags);
     }
 
     /**
@@ -355,18 +281,13 @@ public final class HTMLDetector {
      * @return <code>true</code> if given byte sequence contains common HTML tags; otherwise <code>false</code>
      */
     public static boolean containsHTMLTags(final byte[] sequence, final int off, final int len, final String... tags) {
-        if (containsHTMLTags(sequence, off, len)) {
-            return true;
+        if (sequence == null) {
+            throw new NullPointerException();
         }
-        if (null != tags) {
-            for (int i = tags.length; i-- > 0;) {
-                final String tag = tags[i];
-                if (!isEmpty(tag) && containsIgnoreCase(sequence, off, len, tag)) {
-                    return true;
-                }
-            }
+        if (off < 0 || len < 0 || len > sequence.length - off) {
+            throw new IndexOutOfBoundsException();
         }
-        return false;
+        return containsHTMLTags(Charsets.toAsciiString(sequence, off, len), tags);
     }
 
     /**
@@ -384,37 +305,7 @@ public final class HTMLDetector {
         if (off < 0 || len < 0 || len > sequence.length - off) {
             throw new IndexOutOfBoundsException();
         }
-
-        if (containsHTMLTag(sequence, off, len, "html")) {
-            return true;
-        }
-        if (containsHTMLTag(sequence, off, len, "head")) {
-            return true;
-        }
-        if (containsHTMLTag(sequence, off, len, "body")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, off, len, "<script")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, off, len, "javascript")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, off, len, "<img")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, off, len, "<object")) {
-            return true;
-        }
-        if (containsIgnoreCase(sequence, off, len, "<embed")) {
-            return true;
-        }
-        for (final String jsEventHandler : JS_EVENT_HANDLER) {
-            if (containsIgnoreCase(sequence, off, len, jsEventHandler)) {
-                return true;
-            }
-        }
-        return false;
+        return containsHTMLTags(Charsets.toAsciiString(sequence, off, len));
     }
 
     /**
@@ -428,7 +319,7 @@ public final class HTMLDetector {
         if (sequence == null) {
             throw new NullPointerException();
         }
-        return containsIgnoreCase(sequence, new StringBuilder(tag.length() + 2).append('<').append(tag).append('>').toString());
+        return containsHTMLTag(Charsets.toAsciiString(sequence), tag);
     }
 
     /**
@@ -447,112 +338,7 @@ public final class HTMLDetector {
         if (off < 0 || len < 0 || len > sequence.length - off) {
             throw new IndexOutOfBoundsException();
         }
-        return containsIgnoreCase(sequence, off, len, new StringBuilder(tag.length() + 2).append('<').append(tag).append('>').toString());
-    }
-
-    /**
-     * Checks if given byte sequence contains specified string.
-     *
-     * @param sequence The byte sequence to check
-     * @param str The string
-     * @return <code>true</code> if given byte sequence contains specified string; otherwise <code>false</code>
-     */
-    private static boolean containsIgnoreCase(final byte[] sequence, final String str) {
-        // lower-case
-        if (indexOf(sequence, Charsets.toAsciiBytes(toLowerCase(str)), 0, sequence.length) >= 0) {
-            return true;
-        }
-        // upper-case
-        return (indexOf(sequence, Charsets.toAsciiBytes(toUpperCase(str)), 0, sequence.length) >= 0);
-    }
-
-    /**
-     * Checks if given byte sequence contains specified string.
-     *
-     * @param sequence The byte sequence to check
-     * @param str The string
-     * @return <code>true</code> if given byte sequence contains specified string; otherwise <code>false</code>
-     */
-    private static boolean containsIgnoreCase(final byte[] sequence, final int off, final int len, final String str) {
-        // lower-case
-        if (indexOf(sequence, Charsets.toAsciiBytes(toLowerCase(str)), off, len) >= 0) {
-            return true;
-        }
-        // upper-case
-        return (indexOf(sequence, Charsets.toAsciiBytes(toUpperCase(str)), off, len) >= 0);
-    }
-
-    /**
-     * Finds the first occurrence of the pattern in the byte (sub-)array using KMP algorithm.
-     * <p>
-     * The sub-array to search in begins at the specified <code>beginIndex</code> and extends to the byte at index <code>endIndex - 1</code>
-     * . Thus the length of the sub-array is <code>endIndex-beginIndex</code>.
-     *
-     * @param data The byte array to search in
-     * @param pattern The byte pattern to search for
-     * @param beginIndex The beginning index, inclusive.
-     * @param endIndex The ending index, exclusive.
-     * @return The index of the first occurrence of the pattern in the byte array starting from given index or <code>-1</code> if none
-     *         found.
-     */
-    private static int indexOf(final byte[] data, final byte[] pattern, final int beginIndex, final int endIndex) {
-        if ((beginIndex < 0) || (beginIndex > data.length)) {
-            throw new IndexOutOfBoundsException(Integer.toString(beginIndex));
-        }
-        if ((endIndex < 0) || (endIndex > data.length)) {
-            throw new IndexOutOfBoundsException(Integer.toString(endIndex));
-        }
-        if ((beginIndex > endIndex)) {
-            throw new IndexOutOfBoundsException(Integer.toString(endIndex - beginIndex));
-        }
-
-        if (data.length == 0) {
-            return -1;
-        }
-
-        int[] failure = computeFailure(pattern);
-        if (failure == null) {
-            throw new IllegalArgumentException("pattern is null");
-        }
-
-        int j = 0;
-        for (int i = beginIndex; i < endIndex; i++) {
-            while (j > 0 && pattern[j] != data[i]) {
-                j = failure[j - 1];
-            }
-            if (pattern[j] == data[i]) {
-                j++;
-            }
-            if (j == pattern.length) {
-                return i - pattern.length + 1;
-            }
-        }
-        return -1;
-    }
-
-    /**
-     * Computes the failure function using a boot-strapping process, where the pattern matches against itself.
-     *
-     * @param pattern The pattern
-     * @return The failures
-     */
-    private static int[] computeFailure(final byte[] pattern) {
-        if (pattern == null) {
-            return null;
-        }
-
-        int[] failure = new int[pattern.length];
-        int j = 0;
-        for (int i = 1; i < pattern.length; i++) {
-            while (j > 0 && pattern[j] != pattern[i]) {
-                j = failure[j - 1];
-            }
-            if (pattern[j] == pattern[i]) {
-                j++;
-            }
-            failure[i] = j;
-        }
-        return failure;
+        return containsHTMLTag(Charsets.toAsciiString(sequence, off, len), tag);
     }
 
 }
