@@ -306,7 +306,6 @@ public class Strings {
      * @return <code>true</code> if the indicated character is a punctuation; otherwise <code>false</code>
      */
     public static boolean isPunctuation(char ch) {
-        // !"#$%&'()*+,-./:;<=>?@[\]^_`\u00b4{|}~
         switch (ch) {
             case '!':
             case '"':
@@ -406,7 +405,7 @@ public class Strings {
         if (null == str) {
             return null;
         }
-        List<String> splitted = new LinkedList<>();
+        List<String> splitted = new LinkedList<String>();
         int inQuotes = 0;
         boolean escaped = false;
         StringBuilder s = new StringBuilder(16);
@@ -455,7 +454,7 @@ public class Strings {
         if (null == str) {
             return null;
         }
-        List<String> splitted = new LinkedList<>();
+        List<String> splitted = new LinkedList<String>();
         boolean inQuotes = false;
         boolean escaped = false;
         StringBuilder s = new StringBuilder(16);
@@ -874,7 +873,7 @@ public class Strings {
      * @return connected strings or null if collection == null or empty string if collection is empty
      */
     public static void join(final int[] arr, final String connector, final StringBuilder builder) {
-        final List<Integer> list = new LinkedList<>();
+        final List<Integer> list = new LinkedList<Integer>();
         for (final int i : arr) {
             list.add(Autoboxing.I(i));
         }
@@ -886,7 +885,7 @@ public class Strings {
     }
 
     public static String join(final int[] arr, final String connector) {
-        final List<Integer> list = new LinkedList<>();
+        final List<Integer> list = new LinkedList<Integer>();
         for (final int i : arr) {
             list.add(Autoboxing.I(i));
         }
@@ -894,7 +893,7 @@ public class Strings {
     }
 
     public static String join(final byte[] arr, final String connector) {
-        final List<Byte> list = new LinkedList<>();
+        final List<Byte> list = new LinkedList<Byte>();
         for (final Byte i : arr) {
             list.add(i);
         }
@@ -1235,16 +1234,17 @@ public class Strings {
         if (Strings.isEmpty(separator)) {
             throw new IllegalArgumentException("Missing separator");
         }
-        ArrayList<String> trimmedSplits = new ArrayList<>();
+
         try {
             String[] splits = input.split(separator);
+            ArrayList<String> trimmedSplits = new ArrayList<String>(splits.length);
             for (String string : splits) {
                 trimmedSplits.add(string.trim());
             }
+            return trimmedSplits;
         } catch (PatternSyntaxException pse) {
-            throw new IllegalArgumentException("Illegal pattern syntax");
+            throw new IllegalArgumentException("Illegal pattern syntax", pse);
         }
-        return trimmedSplits;
     }
 
     /**
@@ -1552,7 +1552,7 @@ public class Strings {
     }
 
     /**
-     * 
+     *
      * @param array
      * @return
      */
@@ -1568,7 +1568,7 @@ public class Strings {
     }
 
     /**
-     * 
+     *
      * @param array
      * @return
      */
