@@ -53,7 +53,7 @@ import org.json.JSONObject;
 
 /**
  * {@link DefaultJSlob} - A JSlob holding a JSON object.
- *
+ * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class DefaultJSlob implements JSlob, Cloneable {
@@ -64,8 +64,8 @@ public class DefaultJSlob implements JSlob, Cloneable {
 
         private static final long serialVersionUID = 870193683123103886L;
 
-        EmptyJSlob() {
-            super(null, null);
+        protected EmptyJSlob() {
+            super();
         }
 
         @Override
@@ -93,29 +93,30 @@ public class DefaultJSlob implements JSlob, Cloneable {
 
     private JSONObject jsonObject;
     private JSONObject metaObject;
-    private JSlobId id;
 
-    /**
-     * Initializes a new {@link DefaultJSlob} with given JSON object.
-     *
-     * @param jsonObject The JSON object initially applied to this JSlob
-     */
-    public DefaultJSlob(final JSONObject jsonObject) {
-        this(jsonObject, new JSONObject(4));
-    }
+    private JSlobId id;
 
     /**
      * Initializes a new empty {@link DefaultJSlob}.
      */
-    protected DefaultJSlob(JSONObject jsonObject, JSONObject metaObject) {
+    public DefaultJSlob() {
         super();
-        this.jsonObject = jsonObject;
-        this.metaObject = metaObject;
     }
 
     /**
      * Initializes a new {@link DefaultJSlob}.
-     *
+     * 
+     * @param jsonObject The JSON object initially applied to this JSlob
+     */
+    public DefaultJSlob(final JSONObject jsonObject) {
+        super();
+        this.jsonObject = jsonObject;
+        this.metaObject = new JSONObject();
+    }
+
+    /**
+     * Initializes a new {@link DefaultJSlob}.
+     * 
      * @param other The other JSlob
      */
     public DefaultJSlob(final JSlob other) {
@@ -176,7 +177,7 @@ public class DefaultJSlob implements JSlob, Cloneable {
 
     /**
      * Sets the JSON object stored in this JSlob.
-     *
+     * 
      * @param jsonObject The JSON object
      * @return This JSlob with new JSON object applied
      */
@@ -192,7 +193,7 @@ public class DefaultJSlob implements JSlob, Cloneable {
 
     /**
      * Sets the json object with unmodifiable metadata describing the regular payload data
-     *
+     * 
      * @param The metadata object
      * @return This JSlob with new metadata object applied
      */
