@@ -49,6 +49,7 @@
 
 package com.openexchange.jslob;
 
+import static com.openexchange.java.util.Tools.getUnsignedInteger;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.regex.Pattern;
@@ -370,95 +371,4 @@ public final class JSONPathElement {
     public int getIndex() {
         return index;
     }
-
-    /*-
-     * ---------------------- HELPER --------------------------
-     */
-
-    /**
-     * The radix for base <code>10</code>.
-     */
-    private static final int RADIX = 10;
-
-    /**
-     * Parses a positive <code>int</code> value from passed {@link String} instance.
-     *
-     * @param s The string to parse
-     * @return The parsed positive <code>int</code> value or <code>-1</code> if parsing failed
-     */
-    private static final int getUnsignedInteger(final String s) {
-        if (s == null) {
-            return -1;
-        }
-
-        final int max = s.length();
-
-        if (max <= 0) {
-            return -1;
-        }
-        if (s.charAt(0) == '-') {
-            return -1;
-        }
-
-        int result = 0;
-        int i = 0;
-
-        final int limit = -Integer.MAX_VALUE;
-        final int multmin = limit / RADIX;
-        int digit;
-
-        if (i < max) {
-            digit = digitFor(s.charAt(i++));
-            if (digit < 0) {
-                return -1;
-            }
-            result = -digit;
-        }
-        while (i < max) {
-            /*
-             * Accumulating negatively avoids surprises near MAX_VALUE
-             */
-            digit = digitFor(s.charAt(i++));
-            if (digit < 0) {
-                return -1;
-            }
-            if (result < multmin) {
-                return -1;
-            }
-            result *= RADIX;
-            if (result < limit + digit) {
-                return -1;
-            }
-            result -= digit;
-        }
-        return -result;
-    }
-
-    private static int digitFor(final char c) {
-        switch (c) {
-        case '0':
-            return 0;
-        case '1':
-            return 1;
-        case '2':
-            return 2;
-        case '3':
-            return 3;
-        case '4':
-            return 4;
-        case '5':
-            return 5;
-        case '6':
-            return 6;
-        case '7':
-            return 7;
-        case '8':
-            return 8;
-        case '9':
-            return 9;
-        default:
-            return -1;
-        }
-    }
-
 }
