@@ -105,7 +105,7 @@ public class ConfigServer extends AbstractProxyAwareConfigSource {
             try {
                 url = new URL(sUrl);
             } catch (MalformedURLException e) {
-                LOG.warn("Unable to parse URL: {}", sUrl, e);
+                LOG.warn("Unable to parse URL: {}. Skipping config server source for mail auto-config", sUrl, e);
                 return null;
             }
         }
@@ -128,10 +128,12 @@ public class ConfigServer extends AbstractProxyAwareConfigSource {
                 int readTimeout = 10000;
                 int connecTimeout = 3000;
                 HttpClients.ClientConfig clientConfig = HttpClients.ClientConfig.newInstance().setConnectionTimeout(connecTimeout).setSocketReadTimeout(readTimeout).setUserAgent("Open-Xchange Auto-Config Client").setDenyLocalRedirect(false == isLocalAddress);
+                httpclient = HttpClients.getHttpClient(clientConfig);
+            }
 
+            {
                 ConfigViewFactory configViewFactory = services.getService(ConfigViewFactory.class);
                 ConfigView view = configViewFactory.getView(userId, contextId);
-                httpclient = HttpClients.getHttpClient(clientConfig);
                 HttpHost proxy = getHttpProxyIfEnabled(httpclient, view);
                 if (null != proxy) {
                     httpclient.getParams().setParameter(ConnRoutePNames.DEFAULT_PROXY, proxy);
@@ -201,8 +203,11 @@ public class ConfigServer extends AbstractProxyAwareConfigSource {
             // When HttpClient instance is no longer needed,
             // shut down the connection manager to ensure
             // immediate deallocation of all system resources
-            HttpClients.shutDown(httpclient);
+            if (null != httpclient) {
+                httpclient.close(); // Performs 'getConnectionManager().shutdown();'
+            }
         }
     }
+
 }
 
