@@ -55,6 +55,7 @@ import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.mail.autoconfig.AutoconfigService;
 import com.openexchange.mail.autoconfig.json.actions.AutoconfigActionFactory;
 import com.openexchange.mail.autoconfig.json.converter.AutoconfigResultConverter;
+import com.openexchange.mail.oauth.MailOAuthService;
 
 /**
  * {@link Activator}
@@ -63,21 +64,15 @@ import com.openexchange.mail.autoconfig.json.converter.AutoconfigResultConverter
  */
 public class Activator extends AJAXModuleActivator {
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.server.osgiservice.DeferredActivator#getNeededServices()
-     */
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { AutoconfigService.class };
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.server.osgiservice.DeferredActivator#startBundle()
-     */
     @Override
     protected void startBundle() throws Exception {
+        trackService(MailOAuthService.class);
+        openTrackers();
         registerModule(new AutoconfigActionFactory(this), "autoconfig");
         registerService(ResultConverter.class, new AutoconfigResultConverter());
     }
