@@ -74,11 +74,13 @@ import com.openexchange.logback.extensions.ExtendedPatternLayoutEncoder;
 import com.openexchange.net.HostList;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
+import com.planetj.math.rabinhash.RabinHashFunction32;
 import ch.qos.logback.classic.LoggerContext;
 import ch.qos.logback.classic.spi.ILoggingEvent;
 import ch.qos.logback.core.rolling.FixedWindowRollingPolicy;
 import ch.qos.logback.core.rolling.RollingFileAppender;
 import ch.qos.logback.core.rolling.SizeBasedTriggeringPolicy;
+import ch.qos.logback.core.util.FileSize;
 
 /**
  * {@link TracingSocketMonitor}
@@ -311,7 +313,7 @@ public class TracingSocketMonitor implements SocketMonitor {
 
             SizeBasedTriggeringPolicy<ILoggingEvent> triggeringPolicy = new SizeBasedTriggeringPolicy<ILoggingEvent>();
             triggeringPolicy.setContext(context);
-            triggeringPolicy.setMaxFileSize(Integer.toString(config.getLoggingFileLimit()));
+            triggeringPolicy.setMaxFileSize(FileSize.valueOf(Integer.toString(config.getLoggingFileLimit())));
 
             FixedWindowRollingPolicy rollingPolicy = new FixedWindowRollingPolicy();
             rollingPolicy.setContext(context);
@@ -411,6 +413,7 @@ public class TracingSocketMonitor implements SocketMonitor {
     public TracingSocketMonitor(TracingSocketMonitorConfig config, TimerService timerService) {
         super();
         this.config = config;
+
         final ConcurrentMap<Socket, SocketTrace> socketTraces = new ConcurrentHashMap<>(256, 0.9F, 1);
         this.socketTraces = socketTraces;
 
@@ -427,8 +430,7 @@ public class TracingSocketMonitor implements SocketMonitor {
                 try {
                     long tombstone = System.currentTimeMillis() - thrsh;
                     for (Iterator<SocketTrace> iter = socketTraces.values().iterator(); iter.hasNext();) {
-                        SocketTrace trace = iter.next();
-                        if (trace.lastAccessed() < tombstone) {
+                        if (iter.next().lastAccessed() < tombstone) {
                             iter.remove();
                         }
                     }
@@ -569,9 +571,16 @@ public class TracingSocketMonitor implements SocketMonitor {
 
     @Override
     public void connectError(Socket socket, ConnectFailure failure) throws IOException {
-        org.slf4j.Logger fileLogger = this.fileLogger;
-        if (null != fileLogger && isAllowed(socket)) {
-            fileLogger.error("Failed to connect to socket {}", socket, failure.getE());
+        if (isAllowed(socket)) {
+            SocketTrace trace = optSocketTraceFor(socket);
+            if (null != trace && false == trace.isRecordingSamples()) {
+                socketTraces.remove(socket);
+            }
+
+            org.slf4j.Logger fileLogger = this.fileLogger;
+            if (null != fileLogger) {
+                fileLogger.error("Failed to connect to socket {}", socket, failure.getE());
+            }
         }
     }
 
@@ -585,50 +594,86 @@ public class TracingSocketMonitor implements SocketMonitor {
 
     @Override
     public void closed(Socket socket) throws IOException {
-        org.slf4j.Logger fileLogger = this.fileLogger;
-        if (null != fileLogger && isAllowed(socket)) {
-            fileLogger.info("Closed connection to socket {}", socket);
+        if (isAllowed(socket)) {
+            SocketTrace trace = optSocketTraceFor(socket);
+            if (null != trace && false == trace.isRecordingSamples()) {
+                // No samples are recorded, hence drop associated SocketTrace instance
+                socketTraces.remove(socket);
+            }
+
+            org.slf4j.Logger fileLogger = this.fileLogger;
+            if (null != fileLogger) {
+                fileLogger.info("Closed connection to socket {}", socket);
+            }
         }
     }
 
     // ------------------------------------------------------------------------------
 
     /**
-     * Puts socket-specific log properties.
+     * Puts socket-specific log properties.<br>
+     * Example:
+     * <pre>
+     *  com.openexchange.monitoring.sockets.166120149.accumulatedWaitMillis=523
+     *  com.openexchange.monitoring.sockets.166120149.host=imap.domain.tld
+     *  com.openexchange.monitoring.sockets.166120149.port=143
+     *  com.openexchange.monitoring.sockets.166120149.status=OK
+     * </pre>
      *
      * @param name The property name
      * @param value The property value
      */
     static void putLogProperties(Socket socket, long duration, SocketStatus socketStatus) {
         // Build log property prefix for specified socket
-        StringBuilder sb = new StringBuilder("com.openexchange.monitoring.sockets.");
+        InetAddress address = socket.getInetAddress();
+        String host = address.getHostName();
+        if (Strings.isEmpty(host)) {
+            host = address.getHostAddress();
+        }
+        int port = socket.getPort();
+
+        StringBuilder keyBuilder = new StringBuilder(76);
         {
-            InetAddress address = socket.getInetAddress();
-            String host = address.getHostName();
-            if (Strings.isEmpty(host)) {
-                host = address.getHostAddress();
-            }
-            sb.append('[').append(host).append(':').append(socket.getPort()).append("].").append(socket.hashCode()).append('.');
+            // Calculate hash from <host> + ":" + <port> + "-" + <hashcode>
+            keyBuilder.append(host).append(':').append(port).append('-').append(socket.hashCode());
+            int hash = Math.abs(RabinHashFunction32.DEFAULT_HASH_FUNCTION.hash(keyBuilder.toString()));
+            // Build key prefix
+            keyBuilder.setLength(0);
+            keyBuilder.append("com.openexchange.monitoring.sockets.").append(hash).append('.');
+        }
+        int resetLen = keyBuilder.length();
+
+        // Host
+        {
+            String key = keyBuilder.append("host").toString();
+            MDC.put(key, host);
+        }
+
+        // Port
+        keyBuilder.setLength(resetLen);
+        {
+            String key = keyBuilder.append("port").toString();
+            MDC.put(key, Integer.toString(port));
         }
-        int len = sb.length();
 
         // Duration
+        keyBuilder.setLength(resetLen);
         {
-            String name = sb.append("accumulatedWaitMillis").toString();
-            String sDuration = MDC.get(name);
+            String key = keyBuilder.append("accumulatedWaitMillis").toString();
+            String sDuration = MDC.get(key);
             if (null == sDuration) {
-                MDC.put(name, Long.toString(duration));
+                MDC.put(key, Long.toString(duration));
             } else {
                 long prevDur = parseLong(sDuration);
-                MDC.put(name, Long.toString(prevDur >= 0 ? prevDur + duration : duration));
+                MDC.put(key, Long.toString(prevDur > 0 ? prevDur + duration : duration));
             }
         }
 
         // Status
-        sb.setLength(len);
+        keyBuilder.setLength(resetLen);
         {
-            String name = sb.append("status").toString();
-            MDC.put(name, socketStatus.getId());
+            String key = keyBuilder.append("status").toString();
+            MDC.put(key, socketStatus.getId());
         }
     }
 
@@ -689,6 +734,10 @@ public class TracingSocketMonitor implements SocketMonitor {
             this.fileLogger = fileLogger;
         }
 
+        boolean isRecordingSamples() {
+            return null != samples;
+        }
+
         long lastAccessed() {
             return lastAccessed.get();
         }
