@@ -97,15 +97,19 @@ public class TrustedSSLSocketFactory extends SSLSocketFactory implements Handsha
 
     private static List<TrustManager> initTrustManagers() {
         ImmutableList.Builder<TrustManager> lTrustManagers = ImmutableList.builder();
-        DefaultTrustManager defaultTrustManager = new DefaultTrustManager();
-        if (defaultTrustManager.isInitialized()) {
+
+        // Default trust manager
+        DefaultTrustManager defaultTrustManager = DefaultTrustManager.newInstance();
+        if (null != defaultTrustManager) {
             lTrustManagers.add(defaultTrustManager);
         }
 
-        CustomTrustManager customTrustManager = new CustomTrustManager();
-        if (customTrustManager.isInitialized()) {
+        // Custom trust manager
+        CustomTrustManager customTrustManager = CustomTrustManager.newInstance();
+        if (null != customTrustManager) {
             lTrustManagers.add(customTrustManager);
         }
+
         return lTrustManagers.build();
     }
 
@@ -242,7 +246,8 @@ public class TrustedSSLSocketFactory extends SSLSocketFactory implements Handsha
     }
 
     @Override
-    public void handshakeCompleted(HandshakeCompletedEvent event) {
-        LOG.debug("Successfully handshaked with host {}", event.getSocket().getInetAddress().getHostAddress());
+    public void handshakeCompleted(final HandshakeCompletedEvent event) {
+        Object arg = new Object() { @Override public String toString() { return event.getSocket().getInetAddress().getHostAddress(); }};
+        LOG.debug("Successfully handshaked with host {}", arg);
     }
 }
