@@ -50,16 +50,18 @@
 package com.openexchange.net;
 
 import java.net.InetAddress;
+import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
+import com.google.common.collect.ImmutableSet;
 import com.openexchange.net.utils.Strings;
 
 /**
- * 
+ *
  * {@link HostList}
  *
  * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
@@ -70,7 +72,7 @@ public class HostList {
     /**
      * The empty host list.
      */
-    public static final HostList EMPTY = new HostList(Collections.<IPRange> emptyList(), Collections.<String> emptySet(), Collections.<String> emptySet());
+    public static final HostList EMPTY = new HostList(Collections.<IPRange> emptyList(), Collections.<String> emptySet(), Collections.<String> emptySet(), "");
 
     /**
      * Accepts a comma-separated list of IP addresses, IP address ranges, and host names.
@@ -89,7 +91,7 @@ public class HostList {
         Set<String> matchingAppendixHostNames = new HashSet<String>(tokens.length);
         List<IPRange> ipRanges = new ArrayList<IPRange>(tokens.length);
         for (String token : tokens) {
-            if (false == Strings.isEmpty(token)) {
+            if (!Strings.isEmpty(token)) {
                 token = Strings.asciiLowerCase(token);
                 boolean isIp = false;
                 try {
@@ -119,7 +121,7 @@ public class HostList {
             }
         }
 
-        return new HostList(ipRanges, matchingAppendixHostNames, matchingHostNames);
+        return new HostList(ipRanges, matchingAppendixHostNames, matchingHostNames, hostList);
     }
 
     // ----------------------------------------------------------------------------------------------------------------------------------
@@ -127,15 +129,17 @@ public class HostList {
     private final List<IPRange> ipRanges;
     private final Set<String> matchingAppendixHostNames;
     private final Set<String> matchingHostNames;
+    private final String hostString;
 
     /**
      * Initializes a new {@link HostList}.
      */
-    private HostList(List<IPRange> ipRanges, Set<String> matchingAppendixHostNames, Set<String> matchingHostNames) {
+    private HostList(List<IPRange> ipRanges, Set<String> matchingAppendixHostNames, Set<String> matchingHostNames, String hostString) {
         super();
         this.ipRanges = ipRanges;
-        this.matchingAppendixHostNames = matchingAppendixHostNames.isEmpty() ? null : matchingAppendixHostNames;
-        this.matchingHostNames = matchingHostNames;
+        this.hostString = hostString;
+        this.matchingAppendixHostNames = ImmutableSet.copyOf(matchingAppendixHostNames);
+        this.matchingHostNames = ImmutableSet.copyOf(matchingHostNames);
     }
 
     private final static int INADDR4SZ = 4;
@@ -162,6 +166,24 @@ public class HostList {
         return sb.toString();
     }
 
+    /**
+     * Checks if this host list is empty.
+     *
+     * @return <code>true</code> if empty; otherwise <code>false</code>
+     */
+    public boolean isEmpty() {
+        return ipRanges.isEmpty() && matchingAppendixHostNames.isEmpty() && matchingHostNames.isEmpty();
+    }
+
+    /**
+     * Gets the host string from which this instance was parsed.
+     *
+     * @return The host string
+     */
+    public String getHostString() {
+        return hostString;
+    }
+
     /**
      * Checks if specified host name is contained in this host list.
      * <p>
@@ -171,6 +193,14 @@ public class HostList {
      * @return <code>true</code> if contained; otherwise <code>false</code>
      */
     public boolean contains(InetAddress hostAddress) {
+        return contains(hostAddress, true);
+    }
+
+    private boolean contains(InetAddress hostAddress, boolean checkHostName) {
+        if (null == hostAddress) {
+            return false;
+        }
+
         byte[] octets = hostAddress.getAddress();
         if (null != octets) {
             if (INADDR4SZ == octets.length) {
@@ -190,7 +220,7 @@ public class HostList {
             }
         }
 
-        return contains(hostAddress.getHostName());
+        return checkHostName ? contains(hostAddress.getHostName()) : false;
     }
 
     /**
@@ -245,7 +275,18 @@ public class HostList {
                 }
             }
         }
-        return this.matchingHostNames.contains(Strings.asciiLowerCase(toCheck));
+
+        if (this.matchingHostNames.contains(toCheck)) {
+            return true;
+        }
+
+        // Need to resolve as last resort
+        try {
+            return contains(InetAddress.getByName(toCheck), false);
+        } catch (UnknownHostException e) {
+            // Cannot be resolved
+            return false;
+        }
     }
 
     @Override
