@@ -78,7 +78,7 @@ public final class IPAddressUtil {
         }
 
         final byte[] res = new byte[INADDR4SZ];
-        final String[] s = src.split("\\.", -1);
+        String[] s = SPLIT.split(src, -1);
         long val;
         try {
             switch (s.length) {
@@ -87,7 +87,7 @@ public final class IPAddressUtil {
                  * When only one part is given, the value is stored directly in the network address without any byte rearrangement.
                  */
 
-                val = Long.parseLong(s[0]);
+                val = parseUnsignedLong(s[0]);
                 if (val < 0 || val > 0xffffffffL) {
                     return null;
                 }
@@ -103,12 +103,12 @@ public final class IPAddressUtil {
                  * as net.host.
                  */
 
-                val = Integer.parseInt(s[0]);
+                val = parseUnsignedInteger(s[0]);
                 if (val < 0 || val > 0xff) {
                     return null;
                 }
                 res[0] = (byte) (val & 0xff);
-                val = Integer.parseInt(s[1]);
+                val = parseUnsignedInteger(s[1]);
                 if (val < 0 || val > 0xffffff) {
                     return null;
                 }
@@ -123,13 +123,13 @@ public final class IPAddressUtil {
                  * addresses as 128.net.host.
                  */
                 for (int i = 0; i < 2; i++) {
-                    val = Integer.parseInt(s[i]);
+                    val = parseUnsignedInteger(s[i]);
                     if (val < 0 || val > 0xff) {
                         return null;
                     }
                     res[i] = (byte) (val & 0xff);
                 }
-                val = Integer.parseInt(s[2]);
+                val = parseUnsignedInteger(s[2]);
                 if (val < 0 || val > 0xffff) {
                     return null;
                 }
@@ -142,7 +142,7 @@ public final class IPAddressUtil {
                  * of an IPv4 address.
                  */
                 for (int i = 0; i < 4; i++) {
-                    val = Integer.parseInt(s[i]);
+                    val = parseUnsignedInteger(s[i]);
                     if (val < 0 || val > 0xff) {
                         return null;
                     }
@@ -327,7 +327,7 @@ public final class IPAddressUtil {
         }
         final byte[] octetBytes = new byte[INADDR4SZ];
         for (int i = 0; i < INADDR4SZ; ++i) {
-            octetBytes[i] = (byte) Integer.parseInt(octets[i]);
+            octetBytes[i] = (byte) parseUnsignedInteger(octets[i]);
         }
         return convertIPv4ToMappedIPv6(octetBytes);
     }
