@@ -61,9 +61,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
+import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.modules.Module;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.publish.Entity;
 import com.openexchange.publish.PublicationStorage;
 import com.openexchange.publish.helpers.AbstractPublicationService;
@@ -110,13 +112,14 @@ public class IsPublished implements AdditionalFolderField {
     }
 
     @Override
-    public Object renderJSON(final Object value) {
+    public Object renderJSON(AJAXRequestData requestData, final Object value) {
         return value;
     }
 
     @Override
     public List<Object> getValues(List<FolderObject> folder, ServerSession session) {
-        if (!session.getUserPermissionBits().isPublication()) {
+        UserPermissionBits permissionBits = session.getUserPermissionBits();
+        if (null == permissionBits || !permissionBits.isPublication()) {
             return allFalse(folder.size());
         }
         List<Entity> folderIdsToQuery = new ArrayList<Entity>(folder.size());
