@@ -58,6 +58,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -203,6 +204,9 @@ public class PublicationSQLStorage implements PublicationStorage {
             }
         }
 
+        if (null == retval) {
+            retval = Collections.emptyList();
+        }
         return retval;
     }
 
