@@ -493,11 +493,14 @@ public final class PushManagerRegistry implements PushListenerService {
             return false;
         }
 
+        PermanentListenerRescheduler useThisInstanceToReschedule = null;
+
+        boolean inserted;
         synchronized (this) {
             int contextId = session.getContextId();
             int userId = session.getUserId();
 
-            boolean inserted = PushDbUtils.insertPushRegistration(userId, contextId, clientId);
+            inserted = PushDbUtils.insertPushRegistration(userId, contextId, clientId);
 
             if (inserted) {
                 // Not registered
@@ -512,22 +515,18 @@ public final class PushManagerRegistry implements PushListenerService {
                 }
 
                 // Start for push user
+                PermanentListenerRescheduler rescheduler = reschedulerRef.get();
                 boolean allowPermanentPush = isPermanentPushAllowed();
                 Collection<PushUser> toStart = Collections.singletonList(new PushUser(userId, contextId));
                 for (Iterator<PushManagerService> pushManagersIterator = map.values().iterator(); pushManagersIterator.hasNext();) {
                     PushManagerService pushManager = pushManagersIterator.next();
                     if (pushManager instanceof PushManagerExtendedService) {
                         PushManagerExtendedService extendedService = (PushManagerExtendedService) pushManager;
-                        PermanentListenerRescheduler rescheduler = reschedulerRef.get();
                         if (null == rescheduler) {
                             startPermanentListenersFor(toStart, extendedService, allowPermanentPush);
                         } else {
                             if (extendedService.supportsPermanentListeners()) {
-                                try {
-                                    rescheduler.planReschedule(true);
-                                } catch (OXException e) {
-                                    LOG.error("Failed to plan rescheduling", e);
-                                }
+                                useThisInstanceToReschedule = rescheduler;
                             }
                         }
 
@@ -547,9 +546,17 @@ public final class PushManagerRegistry implements PushListenerService {
                     }
                 }
             }
+        } // End of synchronized block
 
-            return inserted;
+        if (null != useThisInstanceToReschedule) {
+            try {
+                useThisInstanceToReschedule.planReschedule(true);
+            } catch (OXException e) {
+                LOG.error("Failed to plan rescheduling", e);
+            }
         }
+
+        return inserted;
     }
 
     @Override
@@ -687,8 +694,10 @@ public final class PushManagerRegistry implements PushListenerService {
 
     /**
      * Stops all permanent listeners.
+     *
+     * @param tryToReconnect Whether a reconnect attempt is supposed to be performed
      */
-    public void stopAllPermanentListener() {
+    public void stopAllPermanentListener(boolean tryToReconnect) {
         synchronized (this) {
             for (Iterator<PushManagerService> pushManagersIterator = map.values().iterator(); pushManagersIterator.hasNext();) {
                 PushManagerService pushManager = pushManagersIterator.next();
@@ -711,7 +720,7 @@ public final class PushManagerRegistry implements PushListenerService {
                             int contextId = pushUserInfo.getContextId();
                             try {
                                 // Stop listener for session
-                                boolean stopped = stopPermanentListenerFor(pushUserInfo.getPushUser(), extendedService, true);
+                                boolean stopped = stopPermanentListenerFor(pushUserInfo.getPushUser(), extendedService, tryToReconnect);
                                 if (stopped) {
                                     LOG.debug("Stopped push listener for user {} in context {} by push manager \"{}\"", Integer.valueOf(userId), Integer.valueOf(contextId), pushManager);
                                 }
@@ -761,11 +770,11 @@ public final class PushManagerRegistry implements PushListenerService {
 
         // Password
         {
-            PasswordSource passwordSource = MailProperties.getInstance().getPasswordSource();
+            PasswordSource passwordSource = MailProperties.getInstance().getPasswordSource(userId, contextId);
             switch (passwordSource) {
                 case GLOBAL: {
                     // Just for convenience
-                    String masterPassword = MailProperties.getInstance().getMasterPassword();
+                    String masterPassword = MailProperties.getInstance().getMasterPassword(userId, contextId);
                     if (null == masterPassword) {
                         throw PushExceptionCodes.MISSING_MASTER_PASSWORD.create();
                     }
@@ -809,7 +818,7 @@ public final class PushManagerRegistry implements PushListenerService {
             LOG.debug("Denied registration of a push listener for client {} from user {} in context {}: Missing \"webmail\" permission.", session.getClient(), I(session.getUserId()), I(session.getContextId()));
             return null;
         }
-        if (false == PushUtility.allowedClient(session.getClient(), null, true)) {
+        if (false == PushUtility.allowedClient(session.getClient(), session, true)) {
             /*
              * No push listener for the client associated with current session.
              */
