@@ -50,15 +50,17 @@
 package com.openexchange.report.appsuite;
 
 import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import javax.annotation.concurrent.NotThreadSafe;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.report.appsuite.serialization.Report;
 
-
 /**
  * A {@link ContextReport} holds the information discovered about a certain context. See {@link Report}
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
+ * @author <a href="mailto:vitali.sjablow@open-xchange.com">Vitali Sjablow</a>
  */
 public @NotThreadSafe class ContextReport extends Report {
 
@@ -66,8 +68,21 @@ public @NotThreadSafe class ContextReport extends Report {
 
     private final Context ctx;
 
+    /**
+     * capSToContext - This value is used to store the contexts/users for each capabilitySet
+     * in this ContextReport. Each Context can have n users with different capability sets.
+     */
+    private final LinkedHashMap<String, LinkedHashMap<Integer, ArrayList<Integer>>> capSToContext;
+    
+    
+    /**
+     * userList - This value stores all user ids, that are in this context.
+     */
+    private final ArrayList<Integer> userList;
+
     /**
      * Initializes a new {@link ContextReport}.
+     * 
      * @param uuid The UUID of the report this context report belongs to
      * @param type The report type. This determines which analyzers and cumulators partake in this report run.
      * @param ctx The context about which this report is
@@ -75,6 +90,8 @@ public @NotThreadSafe class ContextReport extends Report {
     public ContextReport(String uuid, String type, Context ctx) {
         super(uuid, type, -1);
         this.ctx = ctx;
+        this.capSToContext = new LinkedHashMap<>();
+        this.userList = new ArrayList<>();
     }
 
     /**
@@ -90,4 +107,13 @@ public @NotThreadSafe class ContextReport extends Report {
         return ctx;
     }
 
+    public LinkedHashMap<String, LinkedHashMap<Integer, ArrayList<Integer>>> getCapSToContext() {
+        return capSToContext;
+    }
+
+    public ArrayList<Integer> getUserList() {
+        return userList;
+    }
+
+    
 }
