@@ -72,6 +72,7 @@ import com.openexchange.context.ContextService;
 import com.openexchange.context.PoolAndSchema;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorage;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.groupware.contexts.Context;
@@ -121,7 +122,7 @@ public class CapabilityHandler implements ReportUserHandler, ReportContextHandle
             if (null == storageService) {
                 throw ServiceExceptionCode.absentService(QuotaFileStorageService.class);
             }
-            QuotaFileStorage userStorage = storageService.getQuotaFileStorage(ctx.getContextId());
+            QuotaFileStorage userStorage = storageService.getQuotaFileStorage(ctx.getContextId(), Info.administrative());
             long quota = userStorage.getQuota();
             contextReport.set(Report.MACDETAIL_QUOTA, Report.QUOTA, quota);
         } catch (OXException e) {
