@@ -136,4 +136,9 @@ public class Total implements ContextReportCumulator{
         timeframeMap.put(Report.TIMEFRAME_END, report.getConsideredTimeframeEnd());
         report.set(Report.TOTAL, Report.TIMEFRAME, timeframeMap);
     }
+
+    @Override
+    public void storeAndMergeReportParts(Report report) {
+        // Method not needed in this class, nothing to do here
+    }
 }
