@@ -49,41 +49,23 @@
 
 package com.openexchange.report.appsuite.management;
 
-import java.util.Date;
+import java.util.Map;
 import com.openexchange.exception.OXException;
 import com.openexchange.report.appsuite.ReportService;
-import com.openexchange.report.appsuite.internal.HazelcastReportService;
+import com.openexchange.report.appsuite.internal.LocalReportService;
 import com.openexchange.report.appsuite.internal.Services;
 import com.openexchange.report.appsuite.serialization.Report;
 import com.openexchange.report.appsuite.serialization.ReportConfigs;
 
 /**
  * The {@link ReportMXBeanImpl} implements the MXBean interface by delegating all calls to
- * the {@link HazelcastReportService} singleton and wrapping reports as {@link JMXReport} instances
+ * the {@link LocalReportService} singleton and wrapping reports as {@link JMXReport} instances
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  * @author <a href="mailto:vitali.sjablow@open-xchange.com">Vitali Sjablow</a>
  */
 public class ReportMXBeanImpl implements ReportMXBean {
 
-//    @Override
-//    public String run() throws Exception {
-//        try {
-//            return Services.getService(ReportService.class).run();
-//        } catch (OXException e) {
-//            throw new Exception(e.getMessage());
-//        }
-//    }
-//
-//    @Override
-//    public String run(String reportType) throws Exception {
-//        try {
-//            return Services.getService(ReportService.class).run(reportType);
-//        } catch (OXException e) {
-//            throw new Exception(e.getMessage());
-//        }
-//    }
-
     @Override
     public JMXReport retrieveLastReport(String reportType) throws Exception {
         Report lastReport = Services.getService(ReportService.class).getLastReport(reportType);
@@ -122,31 +104,18 @@ public class ReportMXBeanImpl implements ReportMXBean {
         return null == lastReport ? null : new JMXReport(lastReport);
     }
     
-//    @Override
-//    public String run(String reportType, Date startDate, Date endDate) throws Exception {
-//        try {
-//            return Services.getService(ReportService.class).run(reportType, startDate, endDate);
-//        } catch (OXException e) {
-//            throw new Exception(e.getMessage());
-//        }
-//    }
-//
-//    @Override
-//    public String run(String reportType, Date startDate, Date endDate, Boolean isCustomTimerange, Boolean isShowSingleTenant, Long singleTenantId, Boolean isIgnoreAdmin, Boolean isShowDriveMetrics, Boolean isShowMailMetrics) throws Exception {
-//        try {
-//            return Services.getService(ReportService.class).run(reportType, startDate, endDate, isCustomTimerange, isShowSingleTenant, singleTenantId, isIgnoreAdmin, isShowDriveMetrics, isShowMailMetrics);
-//        } catch (OXException e) {
-//            throw new Exception(e.getMessage());
-//        }
-//    }
-
     @Override
-    public String run(ReportConfigs reportConfig) throws Exception {
+    public String run(String reportType, Boolean isSingleDeployment, Boolean isConfigureTimerange, Long timeframeStart, Long timeframeEnd) throws Exception {
         try {
+            ReportConfigs reportConfig = new ReportConfigs.ReportConfigsBuilder(reportType)
+                .isSingleDeployment(isSingleDeployment)
+                .isConfigTimerange(isConfigureTimerange)
+                .consideredTimeframeStart(timeframeStart)
+                .consideredTimeframeEnd(timeframeEnd)
+                .build();
             return Services.getService(ReportService.class).run(reportConfig);
         } catch (OXException e) {
             throw new Exception(e.getMessage());
         }
     }
-    
 }
