@@ -66,6 +66,7 @@ import org.apache.http.HttpResponse;
 import org.apache.http.HttpResponseInterceptor;
 import org.apache.http.ProtocolException;
 import org.apache.http.client.HttpClient;
+import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.client.params.HttpClientParams;
 import org.apache.http.client.utils.DateUtils;
@@ -75,6 +76,7 @@ import org.apache.http.conn.routing.HttpRoute;
 import org.apache.http.conn.scheme.PlainSocketFactory;
 import org.apache.http.conn.scheme.Scheme;
 import org.apache.http.conn.scheme.SchemeRegistry;
+import org.apache.http.conn.ssl.AllowAllHostnameVerifier;
 import org.apache.http.conn.ssl.SSLSocketFactory;
 import org.apache.http.conn.ssl.StrictHostnameVerifier;
 import org.apache.http.cookie.ClientCookie;
@@ -97,6 +99,7 @@ import org.apache.http.params.HttpProtocolParams;
 import org.apache.http.pool.PoolStats;
 import org.apache.http.protocol.HTTP;
 import org.apache.http.protocol.HttpContext;
+import org.apache.http.util.EntityUtils;
 import org.apache.http.util.TextUtils;
 import com.openexchange.java.InetAddresses;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
@@ -162,7 +165,10 @@ public final class HttpClients {
     public static DefaultHttpClient getHttpClient(final ClientConfig config) {
         SSLSocketFactoryProvider factoryProvider = RestClientServices.getOptionalService(SSLSocketFactoryProvider.class);
         if (null != factoryProvider) {
-            return getHttpClient(config, factoryProvider);
+            SSLConfigurationService sslConfig = RestClientServices.getOptionalService(SSLConfigurationService.class);
+            if (null != sslConfig) {
+                return getHttpClient(config, factoryProvider, sslConfig);
+            }
         }
 
         return WrappedClientsRegistry.getInstance().createWrapped(config);
@@ -173,23 +179,23 @@ public final class HttpClients {
      *
      * @param config The configuration settings for the client
      * @param factoryProvider The provider for the appropriate <code>SSLSocketFactory</code> instance to use
+     * @param sslConfig The SSL configuration service to use
      * @return A newly created {@link DefaultHttpClient} instance
      */
-    public static DefaultHttpClient getHttpClient(ClientConfig config, SSLSocketFactoryProvider factoryProvider) {
+    public static DefaultHttpClient getHttpClient(ClientConfig config, SSLSocketFactoryProvider factoryProvider, SSLConfigurationService sslConfig) {
         // Initialize ClientConnectionManager
-        ClientConnectionManager ccm = initializeClientConnectionManagerUsing(config, factoryProvider);
+        ClientConnectionManager ccm = initializeClientConnectionManagerUsing(config, factoryProvider, sslConfig);
 
         // Initialize DefaultHttpClient using the ClientConnectionManager and client configuration
         return initializeHttpClientUsing(config, ccm);
     }
 
-    private static ClientConnectionManager initializeClientConnectionManagerUsing(ClientConfig config, SSLSocketFactoryProvider factoryProvider) {
+    private static ClientConnectionManager initializeClientConnectionManagerUsing(ClientConfig config, SSLSocketFactoryProvider factoryProvider, SSLConfigurationService sslConfig) {
         javax.net.ssl.SSLSocketFactory f = factoryProvider.getDefault();
 
-        SSLConfigurationService sslConfig = RestClientServices.getService(SSLConfigurationService.class);
         final SchemeRegistry schemeRegistry = new SchemeRegistry();
         schemeRegistry.register(new Scheme("http", 80, PlainSocketFactory.getSocketFactory()));
-        schemeRegistry.register(new Scheme("https", 443, new SSLSocketFactory(f, sslConfig.getSupportedProtocols(), sslConfig.getSupportedCipherSuites(), new StrictHostnameVerifier())));
+        schemeRegistry.register(new Scheme("https", 443, new SSLSocketFactory(f, sslConfig.getSupportedProtocols(), sslConfig.getSupportedCipherSuites(), sslConfig.isVerifyHostname() ? new StrictHostnameVerifier() : new AllowAllHostnameVerifier())));
 
         ClientConnectionManager ccm = new ClientConnectionManager(schemeRegistry, config.maxConnectionsPerRoute, config.maxTotalConnections, config.keepAliveMonitorInterval);
         ccm.setIdleConnectionCloser(new IdleConnectionCloser(ccm, config.keepAliveDuration));
@@ -433,6 +439,23 @@ public final class HttpClients {
             return this;
         }
 
+        @Override
+        public String toString() {
+            StringBuilder builder = new StringBuilder(256);
+            builder.append("[");
+            builder.append("socketReadTimeout=").append(socketReadTimeout);
+            builder.append(", connectionTimeout=").append(connectionTimeout);
+            builder.append(", maxTotalConnections=").append(maxTotalConnections);
+            builder.append(", maxConnectionsPerRoute=").append(maxConnectionsPerRoute);
+            builder.append(", keepAliveDuration=").append(keepAliveDuration);
+            builder.append(", keepAliveMonitorInterval=").append(keepAliveMonitorInterval);
+            builder.append(", socketBufferSize=").append(socketBufferSize);
+            if (userAgent != null) {
+                builder.append(", userAgent=").append(userAgent);
+            }
+            builder.append("]");
+            return builder.toString();
+        }
     }
 
     /**
@@ -478,6 +501,37 @@ public final class HttpClients {
         }
     }
 
+    /**
+     * Closes the supplied HTTP request / response resources silently.
+     * <p>
+     * <ul>
+     * <li>Resets internal state of the HTTP request making it reusable.</li>
+     * <li>Ensures that the response's content is fully consumed and the content stream, if exists, is closed</li>
+     * </ul>
+     *
+     * @param request The HTTP request to reset
+     * @param response The HTTP response to consume and close
+     */
+    public static void close(HttpRequestBase request, HttpResponse response) {
+        if (null != response) {
+            HttpEntity entity = response.getEntity();
+            if (null != entity) {
+                try {
+                    EntityUtils.consumeQuietly(entity);
+                } catch (Exception e) {
+                    // Ignore...
+                }
+            }
+        }
+        if (null != request) {
+            try {
+                request.reset();
+            } catch (Exception e) {
+                // Ignore
+            }
+        }
+    }
+
     /*------------------------------------------------------ CLASSES ------------------------------------------------------*/
 
     private static class ClientConnectionManager extends PoolingClientConnectionManager {
@@ -523,8 +577,6 @@ public final class HttpClients {
 
     private static class IdleConnectionCloser implements Runnable {
 
-        private final static org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(IdleConnectionCloser.class);
-
         private final ClientConnectionManager manager;
         private final int idleTimeoutSeconds;
         private volatile ScheduledTimerTask timerTask;
@@ -589,7 +641,7 @@ public final class HttpClients {
         @Override
         public long getKeepAliveDuration(HttpResponse response, HttpContext context) {
             // Keep-alive for the shorter of 20 seconds or what the server specifies.
-            long timeout = keepAliveSeconds * 1000;
+            long timeout = keepAliveSeconds * 1000L;
 
             final HeaderElementIterator i = new BasicHeaderElementIterator(response.headerIterator(HTTP.CONN_KEEP_ALIVE));
             while (i.hasNext()) {
