@@ -52,6 +52,7 @@ package com.openexchange.ajax;
 import static com.openexchange.html.HtmlServices.fullUrlDecode;
 import static com.openexchange.java.Streams.close;
 import static com.openexchange.java.Strings.isEmpty;
+import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStreamWriter;
@@ -70,6 +71,13 @@ import org.apache.commons.codec.net.URLCodec;
 import org.apache.commons.httpclient.URI;
 import org.apache.tika.Tika;
 import org.apache.tika.config.TikaConfig;
+import org.apache.tika.detect.CompositeDetector;
+import org.apache.tika.detect.Detector;
+import org.apache.tika.metadata.Metadata;
+import org.apache.tika.mime.MediaType;
+import org.apache.tika.mime.MimeTypes;
+import com.google.common.escape.Escaper;
+import com.google.common.escape.Escapers;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
@@ -114,18 +122,46 @@ public final class AJAXUtility {
     /**
      * Detects the MIME type from given input stream using <a href="http://tika.apache.org/">Apache Tika - a content analysis toolkit</a>.
      *
-     * @param in The input stream
+     * @param stream The input stream
      * @return The detected input stream
      * @throws IOException If an I/O error occurs
      */
-    public static String detectMimeType(final InputStream in) throws IOException {
-        if (null == in) {
+    public static String detectMimeType(final InputStream stream) throws IOException {
+        if (null == stream) {
             return null;
         }
+
+        InputStream in = stream;
+        InputStream inToUse= null;
         try {
-            return TIKA.detect(in);
+            Detector detector = TIKA.getDetector();
+            if (false == (detector instanceof CompositeDetector)) {
+                if (in.markSupported()) {
+                    return detector.detect(in, new Metadata()).toString();
+                }
+                return detector.detect(new BufferedInputStream(in), new Metadata()).toString();
+            }
+
+            if (in.markSupported()) {
+                inToUse = in;
+                in = null;
+            } else {
+                inToUse = new BufferedInputStream(in);
+                in = null;
+            }
+            for (Detector d : ((CompositeDetector) detector).getDetectors()) {
+                if (d instanceof MimeTypes) {
+                    MediaType mediaType = d.detect(inToUse, new Metadata());
+                    if (null != mediaType && false == MediaType.OCTET_STREAM.equals(mediaType)) {
+                        return mediaType.toString();
+                    }
+                }
+            }
+
+            // As last resort
+            return TIKA.detect(inToUse);
         } finally {
-            close(in);
+            close(inToUse, in);
         }
     }
 
@@ -388,4 +424,36 @@ public final class AJAXUtility {
         }
     }
 
+    /**
+     * Returns an {@link Escaper} instance that escapes HTML metacharacters as
+     * specified by <a href="http://www.w3.org/TR/html4/">HTML 4.01</a>. The
+     * resulting strings can be used both in attribute values and in <em>most</em>
+     * elements' text contents, provided that the HTML document's character
+     * encoding can encode any non-ASCII code points in the input (as UTF-8 and
+     * other Unicode encodings can).
+     * <p>
+     * In addition also CRLF sequences are replaced with an empty string.
+     *
+     * <p><b>Note:</b> This escaper only performs minimal escaping to make content
+     * structurally compatible with HTML. Specifically, it does not perform entity
+     * replacement (symbolic or numeric), so it does not replace non-ASCII code
+     * points with character references. This escaper escapes only the following
+     * five ASCII characters: {@code '"&<>}.
+     */
+    public static Escaper htmlEscaper() {
+      return HTML_ESCAPER_WITH_CRLF;
+    }
+
+    private static final Escaper HTML_ESCAPER_WITH_CRLF =
+        Escapers.builder()
+            .addEscape('"', "&quot;")
+            // Note: "&apos;" is not defined in HTML 4.01.
+            .addEscape('\'', "&#39;")
+            .addEscape('&', "&amp;")
+            .addEscape('<', "&lt;")
+            .addEscape('>', "&gt;")
+            .addEscape('\r', "")
+            .addEscape('\n', "")
+            .build();
+
 }
