@@ -57,11 +57,9 @@ import java.io.IOException;
 import java.lang.reflect.UndeclaredThrowableException;
 import java.util.Collections;
 import java.util.EnumSet;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletException;
@@ -73,6 +71,7 @@ import org.json.JSONObject;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.fields.LoginFields;
 import com.openexchange.ajax.helper.Send;
+import com.openexchange.ajax.ipcheck.IPCheckService;
 import com.openexchange.ajax.login.AnonymousLogin;
 import com.openexchange.ajax.login.AutoLogin;
 import com.openexchange.ajax.login.FormLogin;
@@ -92,8 +91,8 @@ import com.openexchange.ajax.login.TokenLogin;
 import com.openexchange.ajax.login.Tokens;
 import com.openexchange.ajax.writer.LoginWriter;
 import com.openexchange.ajax.writer.ResponseWriter;
+import com.openexchange.capabilities.Capability;
 import com.openexchange.config.ConfigTools;
-import com.openexchange.configuration.ClientWhitelist;
 import com.openexchange.configuration.CookieHashSource;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.configuration.ServerConfig.Property;
@@ -113,12 +112,12 @@ import com.openexchange.login.LoginResult;
 import com.openexchange.login.internal.LoginPerformer;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.session.Reply;
 import com.openexchange.session.Session;
 import com.openexchange.session.SessionResult;
 import com.openexchange.sessiond.SessionExceptionCodes;
 import com.openexchange.sessiond.SessiondService;
-import com.openexchange.sessiond.impl.IPRange;
 import com.openexchange.tools.io.IOTools;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.servlet.http.Cookies;
@@ -181,7 +180,7 @@ public class LoginServlet extends AJAXServlet {
     /**
      * <code>"open-xchange-share-"</code>
      */
-    private static final String SHARE_PREFIX = "open-xchange-share-".intern();
+    public static final String SHARE_PREFIX = "open-xchange-share-".intern();
 
     /**
      * <code>"open-xchange-public-session-"</code>
@@ -284,11 +283,11 @@ public class LoginServlet extends AJAXServlet {
 
     // --------------------------------------------------------------------------------------- //
 
-    private final Map<String, LoginRequestHandler> handlerMap;
+    private final ConcurrentMap<String, LoginRequestHandler> handlerMap;
 
     public LoginServlet() {
         super();
-        Map<String, LoginRequestHandler> handlerMap = new ConcurrentHashMap<String, LoginRequestHandler>(16, 0.9f, 1);
+        ConcurrentMap<String, LoginRequestHandler> handlerMap = new ConcurrentHashMap<String, LoginRequestHandler>(16, 0.9f, 1);
         handlerMap.put(ACTION_STORE, new LoginRequestHandler() {
 
             @Override
@@ -329,34 +328,49 @@ public class LoginServlet extends AJAXServlet {
                     resp.sendError(HttpServletResponse.SC_BAD_REQUEST);
                     return;
                 }
+
                 try {
-                    final Session session = LoginPerformer.getInstance().lookupSession(sessionId);
-                    if (session != null) {
-                        final LoginConfiguration conf = getLoginConfiguration(session);
-                        SessionUtility.checkIP(conf.isIpCheck(), conf.getRanges(), session, req.getRemoteAddr(), conf.getIpCheckWhitelist());
-                        String[] additionalsForHash;
-                        if (Boolean.TRUE.equals(session.getParameter(Session.PARAM_GUEST))) {
-                            /*
-                             * inject context- and user-id to allow parallel guest sessions
-                             */
-                            additionalsForHash = new String[] { String.valueOf(session.getContextId()), String.valueOf(session.getUserId()) };
-                        } else {
-                            additionalsForHash = null;
-                        }
-                        final String secret = SessionUtility.extractSecret(conf.getHashSource(), req, session.getHash(), session.getClient(), null, additionalsForHash);
-
-                        if (secret == null || !session.getSecret().equals(secret)) {
-                            LOG.info("Status code 403 (FORBIDDEN): Missing or non-matching secret.");
-                            resp.sendError(HttpServletResponse.SC_FORBIDDEN);
-                            return;
-                        }
-
-                        LoginPerformer.getInstance().doLogout(sessionId);
-                        // Drop relevant cookies
-                        SessionUtility.removeOXCookies(session, req, resp);
-                        SessionUtility.removeJSESSIONID(req, resp);
+                    Session session = LoginPerformer.getInstance().lookupSession(sessionId);
+                    if (session == null) {
+                        LOG.info("Status code 403 (FORBIDDEN): No such session.");
+                        resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                        return;
                     }
-                } catch (final OXException e) {
+
+                    SessionUtility.checkIP(session, req.getRemoteAddr());
+
+                    String[] additionalsForHash;
+                    if (Boolean.TRUE.equals(session.getParameter(Session.PARAM_GUEST))) {
+                        /*
+                         * inject context- and user-id to allow parallel guest sessions
+                         */
+                        additionalsForHash = new String[] { Integer.toString(session.getContextId()), Integer.toString(session.getUserId()) };
+                    } else {
+                        additionalsForHash = null;
+                    }
+
+                    LoginConfiguration conf = getLoginConfiguration(session);
+                    String secret = SessionUtility.extractSecret(conf.getHashSource(), req, session.getHash(), session.getClient(), null, additionalsForHash);
+                    if (secret == null || !session.getSecret().equals(secret)) {
+                        LOG.info("Status code 403 (FORBIDDEN): Missing or non-matching secret.");
+                        resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                        return;
+                    }
+
+                    // Do the logout
+                    LoginPerformer.getInstance().doLogout(sessionId);
+
+                    // Drop relevant cookies
+                    SessionUtility.removeOXCookies(session, req, resp);
+                    SessionUtility.removeJSESSIONID(req, resp);
+                } catch (OXException e) {
+                    if (SessionUtility.isIpCheckError(e)) {
+                        LOG.info("Status code 403 (FORBIDDEN): Wrong client IP address.");
+                        resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                        return;
+                    }
+                    LOG.error("Logout failed", e);
+                } catch (RuntimeException e) {
                     LOG.error("Logout failed", e);
                 }
             }
@@ -393,13 +407,30 @@ public class LoginServlet extends AJAXServlet {
                     } else {
                         session = sessiondService.getSessionByRandomToken(randomToken);
                         if (null != session) {
-                            final String oldIP = session.getLocalIp();
-                            if (null == oldIP || SessionUtility.isWhitelistedFromIPCheck(oldIP, conf.getRanges())) {
-                                final String newIP = req.getRemoteAddr();
-                                if (!newIP.equals(oldIP)) {
-                                    LOG.info("Changing IP of session {} with authID: {} from {} to {}.", session.getSessionID(), session.getAuthId(), oldIP, newIP);
-                                    session.setLocalIp(newIP);
+                            try {
+                                String oldIP = session.getLocalIp();
+
+                                boolean changeIp = false;
+                                if (null == oldIP) {
+                                    changeIp = true;
+                                } else {
+                                    IPCheckService ipCheckService = ServerServiceRegistry.getInstance().getService(IPCheckService.class);
+                                    if (SessionUtility.isWhitelistedFromIPCheck(oldIP,  ipCheckService.getConfigurationFor(session).getRanges())) {
+                                        changeIp = true;
+                                    }
                                 }
+
+                                if (changeIp) {
+                                    String newIP = req.getRemoteAddr();
+                                    if (!newIP.equals(oldIP)) {
+                                        LOG.info("Changing IP of session {} with authID: {} from {} to {}.", session.getSessionID(), session.getAuthId(), oldIP, newIP);
+                                        sessiondService.setLocalIp(session.getSessionID(), newIP);
+                                    }
+                                }
+                            } catch (OXException e) {
+                                LOG.error("", e);
+                                resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                                return;
                             }
                         }
                     }
@@ -481,9 +512,9 @@ public class LoginServlet extends AJAXServlet {
                         // Add session log properties
                         LogProperties.putSessionProperties(session);
                         // Check
-                        final LoginConfiguration conf = confReference.get();
-                        SessionUtility.checkIP(conf.isIpCheck(), conf.getRanges(), session, req.getRemoteAddr(), conf.getIpCheckWhitelist());
-                        final String secret = SessionUtility.extractSecret(conf.getHashSource(), req, session.getHash(), session.getClient());
+                        SessionUtility.checkIP(session, req.getRemoteAddr());
+                        LoginConfiguration conf = confReference.get();
+                        String secret = SessionUtility.extractSecret(conf.getHashSource(), req, session.getHash(), session.getClient());
                         if (secret == null || !session.getSecret().equals(secret)) {
                             if (null != secret) {
                                 LOG.info("Session secret is different. Given secret \"{}\" differs from secret in session \"{}\".", secret, session.getSecret());
@@ -548,13 +579,30 @@ public class LoginServlet extends AJAXServlet {
                     } else {
                         session = sessiondService.getSessionByRandomToken(randomToken);
                         if (null != session) {
-                            final String oldIP = session.getLocalIp();
-                            if (null == oldIP || SessionUtility.isWhitelistedFromIPCheck(oldIP, conf.getRanges())) {
-                                final String newIP = req.getRemoteAddr();
-                                if (!newIP.equals(oldIP)) {
-                                    LOG.info("Changing IP of session {} with authID: {} from {} to {}.", session.getSessionID(), session.getAuthId(), oldIP, newIP);
-                                    session.setLocalIp(newIP);
+                            try {
+                                String oldIP = session.getLocalIp();
+
+                                boolean changeIp = false;
+                                if (null == oldIP) {
+                                    changeIp = true;
+                                } else {
+                                    IPCheckService ipCheckService = ServerServiceRegistry.getInstance().getService(IPCheckService.class);
+                                    if (SessionUtility.isWhitelistedFromIPCheck(oldIP,  ipCheckService.getConfigurationFor(session).getRanges())) {
+                                        changeIp = true;
+                                    }
                                 }
+
+                                if (changeIp) {
+                                    String newIP = req.getRemoteAddr();
+                                    if (!newIP.equals(oldIP)) {
+                                        LOG.info("Changing IP of session {} with authID: {} from {} to {}.", session.getSessionID(), session.getAuthId(), oldIP, newIP);
+                                        sessiondService.setLocalIp(session.getSessionID(), newIP);
+                                    }
+                                }
+                            } catch (OXException e) {
+                                LOG.error("", e);
+                                resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                                return;
                             }
                         }
                     }
@@ -629,13 +677,13 @@ public class LoginServlet extends AJAXServlet {
     @Override
     public void init(final ServletConfig config) throws ServletException {
         super.init(config);
-        final String uiWebPath = config.getInitParameter(ServerConfig.Property.UI_WEB_PATH.getPropertyName());
-        final boolean sessiondAutoLogin = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.SESSIOND_AUTOLOGIN.getPropertyName()));
-        final CookieHashSource hashSource = CookieHashSource.parse(config.getInitParameter(Property.COOKIE_HASH.getPropertyName()));
-        final String httpAuthAutoLogin = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_AUTOLOGIN.getPropertyName());
-        final String defaultClient = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_CLIENT.getPropertyName());
-        final String clientVersion = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_VERSION.getPropertyName());
-        final String templateFileLocation = config.getInitParameter(ConfigurationProperty.ERROR_PAGE_TEMPLATE.getPropertyName());
+        String uiWebPath = config.getInitParameter(ServerConfig.Property.UI_WEB_PATH.getPropertyName());
+        boolean sessiondAutoLogin = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.SESSIOND_AUTOLOGIN.getPropertyName()));
+        CookieHashSource hashSource = CookieHashSource.parse(config.getInitParameter(Property.COOKIE_HASH.getPropertyName()));
+        String httpAuthAutoLogin = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_AUTOLOGIN.getPropertyName());
+        String defaultClient = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_CLIENT.getPropertyName());
+         String clientVersion = config.getInitParameter(ConfigurationProperty.HTTP_AUTH_VERSION.getPropertyName());
+        String templateFileLocation = config.getInitParameter(ConfigurationProperty.ERROR_PAGE_TEMPLATE.getPropertyName());
         String errorPageTemplate;
         if (null == templateFileLocation) {
             errorPageTemplate = ERROR_PAGE_TEMPLATE;
@@ -649,28 +697,15 @@ public class LoginServlet extends AJAXServlet {
                 errorPageTemplate = ERROR_PAGE_TEMPLATE;
             }
         }
-        final int cookieExpiry = ConfigTools.parseTimespanSecs(config.getInitParameter(ServerConfig.Property.COOKIE_TTL.getPropertyName()));
-        final boolean cookieForceHTTPS = Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.COOKIE_FORCE_HTTPS.getPropertyName())) || Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.FORCE_HTTPS.getPropertyName()));
-        final boolean insecure = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.INSECURE.getPropertyName()));
-        final boolean ipCheck = Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.IP_CHECK.getPropertyName()));
-        final ClientWhitelist ipCheckWhitelist = new ClientWhitelist().add(config.getInitParameter(Property.IP_CHECK_WHITELIST.getPropertyName()));
-        final boolean redirectIPChangeAllowed = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.REDIRECT_IP_CHANGE_ALLOWED.getPropertyName()));
-        final List<IPRange> ranges = new LinkedList<IPRange>();
-        final String tmp = config.getInitParameter(ConfigurationProperty.NO_IP_CHECK_RANGE.getPropertyName());
-        if (tmp != null) {
-            final String[] lines = Strings.splitByCRLF(tmp);
-            for (String line : lines) {
-                line = line.replaceAll("\\s", "");
-                if (!line.equals("") && (line.length() == 0 || line.charAt(0) != '#')) {
-                    ranges.add(IPRange.parseRange(line));
-                }
-            }
-        }
-        final boolean disableTrimLogin = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.DISABLE_TRIM_LOGIN.getPropertyName()));
-        final boolean formLoginWithoutAuthId = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.FORM_LOGIN_WITHOUT_AUTHID.getPropertyName()));
-        final boolean isRandomTokenEnabled = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.RANDOM_TOKEN.getPropertyName()));
-        final boolean checkPunyCodeLoginString = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.CHECK_PUNY_CODE_LOGIN.getPropertyName()));
-        LoginConfiguration conf = new LoginConfiguration(uiWebPath, sessiondAutoLogin, hashSource, httpAuthAutoLogin, defaultClient, clientVersion, errorPageTemplate, cookieExpiry, cookieForceHTTPS, insecure, ipCheck, ipCheckWhitelist, redirectIPChangeAllowed, ranges, disableTrimLogin, formLoginWithoutAuthId, isRandomTokenEnabled, checkPunyCodeLoginString);
+        int cookieExpiry = ConfigTools.parseTimespanSecs(config.getInitParameter(ServerConfig.Property.COOKIE_TTL.getPropertyName()));
+        boolean cookieForceHTTPS = Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.COOKIE_FORCE_HTTPS.getPropertyName())) || Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.FORCE_HTTPS.getPropertyName()));
+        boolean insecure = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.INSECURE.getPropertyName()));
+        boolean redirectIPChangeAllowed = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.REDIRECT_IP_CHANGE_ALLOWED.getPropertyName()));
+        boolean disableTrimLogin = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.DISABLE_TRIM_LOGIN.getPropertyName()));
+        boolean formLoginWithoutAuthId = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.FORM_LOGIN_WITHOUT_AUTHID.getPropertyName()));
+        boolean isRandomTokenEnabled = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.RANDOM_TOKEN.getPropertyName()));
+        boolean checkPunyCodeLoginString = Boolean.parseBoolean(config.getInitParameter(ConfigurationProperty.CHECK_PUNY_CODE_LOGIN.getPropertyName()));
+        LoginConfiguration conf = new LoginConfiguration(uiWebPath, sessiondAutoLogin, hashSource, httpAuthAutoLogin, defaultClient, clientVersion, errorPageTemplate, cookieExpiry, cookieForceHTTPS, insecure, redirectIPChangeAllowed, disableTrimLogin, formLoginWithoutAuthId, isRandomTokenEnabled, checkPunyCodeLoginString);
         confReference.set(conf);
         ShareLoginConfiguration shareConf = initShareLoginConfig(config);
         shareConfReference.set(shareConf);
@@ -689,7 +724,8 @@ public class LoginServlet extends AJAXServlet {
     }
 
     public LoginRequestHandler addRequestHandler(String action, LoginRequestHandler handler) {
-        return handlerMap.put(action, handler);
+        LoginRequestHandler prev = handlerMap.putIfAbsent(action, handler);
+        return null == prev ? handler : prev;
     }
 
     public LoginRequestHandler removeRequestHandler(String action) {
@@ -713,14 +749,12 @@ public class LoginServlet extends AJAXServlet {
         try {
             final String action = req.getParameter(PARAMETER_ACTION);
             final String subPath = getServletSpecificURI(req);
+
             if (null != subPath && subPath.startsWith("/httpAuth")) {
                 handlerMap.get("/httpAuth").handleRequest(req, resp);
-            } else if (null != action) {
+            } else {
                 // Regular login handling
                 doJSONAuth(req, resp, action);
-            } else {
-                logAndSendException(resp, AjaxExceptionCodes.MISSING_PARAMETER.create(PARAMETER_ACTION));
-                return;
             }
         } catch (RateLimitedException e) {
             e.send(resp);
@@ -729,8 +763,28 @@ public class LoginServlet extends AJAXServlet {
         }
     }
 
+    private static final Capability CAPABILITY_AUTOLOGIN = new Capability("autologin");
+
+    /**
+     * Checks if auto-login is enabled for specified host name.
+     *
+     * @param hostName The host name to check for
+     * @return <code>true</code> if auto-login is enabled; otherwise <code>false</code>
+     * @throws OXException If server configuration cannot be obtained
+     */
+    public static boolean isAutologinActivated(String hostName) throws OXException {
+        ServerConfigService serverConfigService = ServerServiceRegistry.getInstance().getService(ServerConfigService.class);
+        com.openexchange.serverconfig.ServerConfig serverConfig = serverConfigService.getServerConfig(hostName, -1, -1);
+        return serverConfig.getCapabilities().contains(CAPABILITY_AUTOLOGIN);
+    }
+
     private void doJSONAuth(final HttpServletRequest req, final HttpServletResponse resp, final String action) throws IOException {
-        final LoginRequestHandler handler = handlerMap.get(action);
+        if (null == action) {
+            logAndSendException(resp, AjaxExceptionCodes.MISSING_PARAMETER.create(PARAMETER_ACTION));
+            return;
+        }
+
+        LoginRequestHandler handler = handlerMap.get(action);
         if (null == handler) {
             logAndSendException(resp, AjaxExceptionCodes.UNKNOWN_ACTION.create(action));
             return;
@@ -760,11 +814,11 @@ public class LoginServlet extends AJAXServlet {
             throw SessionExceptionCodes.SESSION_EXPIRED.create(sessionId);
         }
         final LoginConfiguration conf = getLoginConfiguration(session);
-        if (!conf.isSessiondAutoLogin() && CookieType.SESSION == type) {
+        if (!conf.isSessiondAutoLogin(req.getServerName(), session) && CookieType.SESSION == type) {
             throw AjaxExceptionCodes.DISABLED_ACTION.create("store");
         }
         try {
-            SessionUtility.checkIP(conf.isIpCheck(), conf.getRanges(), session, req.getRemoteAddr(), conf.getIpCheckWhitelist());
+            SessionUtility.checkIP(session, req.getRemoteAddr());
             if (type == CookieType.SESSION) {
                 writeSessionCookie(resp, session, session.getHash(), req.isSecure(), req.getServerName());
             } else {
@@ -973,7 +1027,7 @@ public class LoginServlet extends AJAXServlet {
         if (secure || (conf.isCookieForceHTTPS() && !Cookies.isLocalLan(serverName))) {
             cookie.setSecure(true);
         }
-        if (conf.isSessiondAutoLogin() || conf.getCookieExpiry() < 0) {
+        if (conf.isSessiondAutoLogin(serverName) || conf.getCookieExpiry() < 0) {
             /*
              * A negative value means that the cookie is not stored persistently and will be deleted when the Web browser exits. A zero
              * value causes the cookie to be deleted.
