@@ -54,11 +54,9 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
-import java.io.FilterInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.nio.channels.FileChannel;
 import java.security.DigestInputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
@@ -73,8 +71,10 @@ import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.fileholder.InputStreamReadable;
 import com.openexchange.ajax.fileholder.Readable;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.SizeKnowingInputStream;
 import com.openexchange.java.Streams;
 import com.openexchange.java.UnsynchronizedByteArrayOutputStream;
+import com.openexchange.log.LogProperties;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
 /**
@@ -205,6 +205,25 @@ public final class ThresholdFileHolder implements IFileHolder {
         }
     }
 
+    /**
+     * Lets this file holder be auto-managed by calling thread.
+     *
+     * @return <code>true</code> if this file holder could be made auto-managed by calling thread; otherwise <code>false</code>
+     */
+    public boolean automanaged() {
+        if (autoManaged) {
+            return false;
+        }
+
+        File tempFile = this.tempFile;
+        if (null == tempFile) {
+            return false;
+        }
+
+        LogProperties.addTempFile(tempFile);
+        return true;
+    }
+
     /**
      * Gets the internal buffer.
      *
@@ -583,22 +602,39 @@ public final class ThresholdFileHolder implements IFileHolder {
 
     @Override
     public InputStream getStream() throws OXException {
+        return new ThresholdFileHolderInputStream(this);
+    }
+
+    /**
+     * Gets the effective input stream from this file holder; either array- or file-backed.
+     *
+     * @param sizeKnowing <code>true</code> to return a size-knowing input stream; otherwise <code>false</code>
+     * @return The effective input stream
+     * @throws OXException If input stream cannot be returned due to an I/O error
+     */
+    InputStream getInnerStream(boolean sizeKnowing) throws OXException {
         if (count <= 0) {
             return Streams.EMPTY_INPUT_STREAM;
         }
         ByteArrayOutputStream buf = this.buf;
         if (null != buf) {
-            return Streams.asInputStream(buf);
+            return sizeKnowing ? new SizeKnowingInputStream(Streams.asInputStream(buf), buf.size()) : Streams.asInputStream(buf);
         }
         File tempFile = this.tempFile;
         if (null == tempFile) {
             IOException e = new IOException("Already closed.");
             throw AjaxExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
+        FileInputStream fis = null;
         try {
-            return new FileInputStream(tempFile);
+            fis = new FileInputStream(tempFile);
+            InputStream retval = sizeKnowing ? new SizeKnowingInputStream(fis, tempFile.length()) : fis;
+            fis = null; // Avoid premature closing
+            return retval;
         } catch (IOException e) {
             throw AjaxExceptionCodes.IO_ERROR.create(e, e.getMessage());
+        } finally {
+            Streams.close(fis);
         }
     }
 
@@ -798,16 +834,13 @@ public final class ThresholdFileHolder implements IFileHolder {
         }
     } // End of class TransferringOutStream
 
-    private static final class ClosingInputStream extends FilterInputStream {
-
-        private final ThresholdFileHolder fileHolder;
+    private static final class ClosingInputStream extends ThresholdFileHolderInputStream {
 
         /**
          * Initializes a new {@link ClosingInputStream}.
          */
         protected ClosingInputStream(final ThresholdFileHolder fileHolder) throws OXException {
-            super(fileHolder.getStream());
-            this.fileHolder = fileHolder;
+            super(fileHolder);
         }
 
         @Override
@@ -820,6 +853,32 @@ public final class ThresholdFileHolder implements IFileHolder {
         }
     }
 
+    /**
+     * The input stream backed by <code>ThresholdFileHolder</code> instance.
+     */
+    public static class ThresholdFileHolderInputStream extends SizeKnowingInputStream {
+
+        /** The <code>ThresholdFileHolder</code> instance */
+        protected final ThresholdFileHolder fileHolder;
+
+        /**
+         * Initializes a new {@link ClosingInputStream}.
+         */
+        ThresholdFileHolderInputStream(final ThresholdFileHolder fileHolder) throws OXException {
+            super(fileHolder.getInnerStream(false), fileHolder.getLength());
+            this.fileHolder = fileHolder;
+        }
+
+        /**
+         * Gets the file holder
+         *
+         * @return The file holder
+         */
+        public ThresholdFileHolder getFileHolder() {
+            return fileHolder;
+        }
+    }
+
     private static final class ClosingRandomAccess implements RandomAccess {
 
         private final ThresholdFileHolder fileHolder;
@@ -865,16 +924,20 @@ public final class ThresholdFileHolder implements IFileHolder {
     }
 
     private static void copyFile(final File in, final File out) throws IOException {
-        FileChannel inChannel = null;
-        FileChannel outChannel = null;
+        FileInputStream inStream = null;
+        FileOutputStream outStream  = null;
         try {
-            inChannel = new FileInputStream(in).getChannel();
-            outChannel = new FileOutputStream(out).getChannel();
-            inChannel.transferTo(0, inChannel.size(), outChannel);
-        } catch (final IOException e) {
-            throw e;
+            inStream = new FileInputStream(in);
+            outStream = new FileOutputStream(out);
+
+            int buflen = 0xFFFF;
+            byte[] buf = new byte[buflen];
+            for (int read; (read = inStream.read(buf, 0, buflen)) > 0;) {
+                outStream.write(buf, 0, read);
+            }
+            outStream.flush();
         } finally {
-            Streams.close(inChannel, outChannel);
+            Streams.close(inStream, outStream);
         }
     }
 
