@@ -103,6 +103,16 @@ public class AdditionalFolderFieldList {
         return null == additionalFolderField ? new NullField(col) : additionalFolderField;
     }
 
+    /**
+     * Optionally gets the additional folder field associated with specified column number.
+     *
+     * @param col The column number
+     * @return The additional folder field associated with specified column number or <code>null</code>
+     */
+    public AdditionalFolderField opt(final int col) {
+        return byColId.get(col);
+    }
+
     /**
      * Gets known fields.
      *
