@@ -234,8 +234,11 @@ public final class DownloadUtility {
                         in = new ByteArrayRandomAccess(tmp);
                     }
                 }
-            } else if (Strings.startsWithAny(toLowerCase(contentType.getSubType()), "javascript") || fileNameImpliesJavascript(fileName)) {
-                // Treat all JavaScript content as harmful
+            } else if (Strings.containsAny(toLowerCase(contentType.getSubType()), "script") || fileNameImpliesJavascript(fileName)) {
+                // Treat all script content as harmful
+                harmful = true;
+                sContentDisposition = "attachment";
+            } else if (Strings.containsAny(toLowerCase(contentType.getSubType()), "rdf") || fileNameImpliesRdf(fileName)) {
                 harmful = true;
                 sContentDisposition = "attachment";
             } else if (Strings.containsAny(toLowerCase(contentType.getSubType()), "svg") || fileNameImpliesSvg(fileName)) {
@@ -430,7 +433,7 @@ public final class DownloadUtility {
                             /*
                              * File extension does not fit to MIME type. Reset file name.
                              */
-                            fn = addFileExtension(fileExtension, extensions.iterator().next());
+                            fn = addFileExtension(fn, extensions.iterator().next());
                             preparedFileName = getSaveAsFileName(fn, msieOnWindows, contentType.getBaseType());
                         }
                         final String detectedCT = ImageTypeDetector.getMimeType(sink.getStream());
@@ -508,17 +511,17 @@ public final class DownloadUtility {
             if (sContentDisposition == null) {
                 // Assume "inline" as default disposition to trigger client's (Browser) internal viewer.
                 final StringBuilder builder = new StringBuilder(32).append("inline");
-                appendFilenameParameter(fileName, contentType.isBaseType("application", "octet-stream") ? null : contentType.toString(), userAgent, builder);
+                appendFilenameParameter(fn, contentType.isBaseType("application", "octet-stream") ? null : contentType.toString(), userAgent, builder);
                 contentType.removeParameter("name");
-                retval = new CheckedDownload(contentType.toString(), builder.toString(), in, sz, harmful);
+                retval = new CheckedDownload(contentType.toString(), builder.toString(), fn, in, sz, harmful);
             } else if (sContentDisposition.indexOf(';') < 0) {
                 final StringBuilder builder = new StringBuilder(32).append(sContentDisposition);
-                appendFilenameParameter(fileName, contentType.isBaseType("application", "octet-stream") ? null : contentType.toString(), userAgent, builder);
+                appendFilenameParameter(fn, contentType.isBaseType("application", "octet-stream") ? null : contentType.toString(), userAgent, builder);
                 contentType.removeParameter("name");
-                retval = new CheckedDownload(contentType.toString(), builder.toString(), in, sz, harmful);
+                retval = new CheckedDownload(contentType.toString(), builder.toString(), fn, in, sz, harmful);
             } else {
                 contentType.removeParameter("name");
-                retval = new CheckedDownload(contentType.toString(), sContentDisposition, in, sz, harmful);
+                retval = new CheckedDownload(contentType.toString(), sContentDisposition, fn, in, sz, harmful);
             }
             return retval;
         } catch (final UnsupportedEncodingException e) {
@@ -551,13 +554,17 @@ public final class DownloadUtility {
     }
 
     private static boolean fileNameImpliesJavascript(final String fileName) {
-        return null != fileName && MimeType2ExtMap.getContentType(fileName).indexOf("javascript") >= 0;
+        return null != fileName && MimeType2ExtMap.getContentType(fileName).indexOf("script") >= 0;
     }
 
     private static boolean fileNameImpliesXml(final String fileName) {
         return null != fileName && MimeType2ExtMap.getContentType(fileName).indexOf("xml") >= 0;
     }
 
+    private static boolean fileNameImpliesRdf(final String fileName) {
+        return null != fileName && MimeType2ExtMap.getContentType(fileName).indexOf("rdf") >= 0;
+    }
+
     private static boolean checkFileNameFor(String fileName, ContentTypeTest contentTypeTest, String... fileNameTests) {
         if (contentTypeTest.matches(fileName)) {
             return true;
@@ -657,7 +664,7 @@ public final class DownloadUtility {
         /*
          * We are supposed to offer attachment for download. Therefore enforce application/octet-stream and attachment disposition.
          */
-        return new CheckedDownload(MIME_APPL_OCTET, new StringBuilder(64).append("attachment; filename=\"").append(preparedFileName).append('"').toString(), randomAccess, size, harmful);
+        return new CheckedDownload(MIME_APPL_OCTET, new StringBuilder(64).append("attachment; filename=\"").append(preparedFileName).append('"').toString(), preparedFileName, randomAccess, size, harmful);
     }
 
     // private static final Pattern P = Pattern.compile("^[\\w\\d\\:\\/\\.]+(\\.\\w{3,4})$");
@@ -740,14 +747,16 @@ public final class DownloadUtility {
 
         private final String contentType;
         private final String contentDisposition;
+        private final String fileName;
         private final Readable inputStream;
         private final long size;
         private final boolean consideredHarmful;
 
-        CheckedDownload(String contentType, String contentDisposition, Readable inputStream, long size, boolean consideredHarmful) {
+        CheckedDownload(String contentType, String contentDisposition, String fileName, Readable inputStream, long size, boolean consideredHarmful) {
             super();
             this.contentType = contentType;
             this.contentDisposition = contentDisposition;
+            this.fileName = fileName;
             this.inputStream = inputStream;
             this.size = size;
             this.consideredHarmful = consideredHarmful;
@@ -762,6 +771,15 @@ public final class DownloadUtility {
             return consideredHarmful;
         }
 
+        /**
+         * Gets the file name
+         *
+         * @return The file name
+         */
+        public String getFileName() {
+            return fileName;
+        }
+
         /**
          * Gets the size
          *
