@@ -56,6 +56,8 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -85,6 +87,7 @@ import com.openexchange.login.LoginRampUpService;
 import com.openexchange.login.LoginResult;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -201,6 +204,7 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
         // Perform the login
         final Response response = new Response();
         LoginResult result = null;
+        ServerSession serverSession = null;
         try {
             // Do the login...
             {
@@ -272,7 +276,7 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
 
             // Remember User-Agent
             session.setParameter(USER_AGENT, req.getHeader(USER_AGENT));
-            ServerSession serverSession = ServerSessionAdapter.valueOf(session);
+            serverSession = ServerSessionAdapter.valueOf(session);
 
             // Trigger client-specific ramp-up
             Future<JSONObject> optRampUp = rampUpAsync(serverSession, req);
@@ -300,15 +304,24 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
 
             // Await client-specific ramp-up and add to JSON object
             if (null != optRampUp) {
+                int timeoutSecs = 30;
                 try {
-                    JSONObject jsonObject = optRampUp.get();
+                    JSONObject jsonObject = optRampUp.get(timeoutSecs, TimeUnit.SECONDS);
                     for (Map.Entry<String, Object> entry : jsonObject.entrySet()) {
                         json.put(entry.getKey(), entry.getValue());
                     }
                 } catch (InterruptedException e) {
                     // Keep interrupted state
+                    optRampUp.cancel(true);
                     Thread.currentThread().interrupt();
                     throw LoginExceptionCodes.UNKNOWN.create(e, "Thread interrupted.");
+                } catch (TimeoutException e) {
+                    optRampUp.cancel(true);
+                    if (LOG.isDebugEnabled()) {
+                        LOG.warn("Ramp-up information could not be added to login JSON response within {} seconds. Skipping...", Integer.valueOf(timeoutSecs));
+                    } else {
+                        LOG.warn("Ramp-up information could not be added to login JSON response within {} seconds. Skipping...", Integer.valueOf(timeoutSecs), e);
+                    }
                 } catch (ExecutionException e) {
                     // Cannot occur
                     final Throwable cause = e.getCause();
@@ -357,6 +370,7 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
             LOG.error("", oje);
             response.setException(oje);
         }
+
         try {
             if (response.hasError() || null == result) {
                 final Locale locale;
@@ -375,12 +389,16 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
 
             Session session = result.getSession();
             // Store associated session
-            SessionUtility.rememberSession(req, new ServerSessionAdapter(session));
+            if (null == serverSession) {
+                serverSession = new ServerSessionAdapter(session);
+            }
+            SessionUtility.rememberSession(req, serverSession);
+            ThreadLocalSessionHolder.getInstance().setSession(serverSession);
 
             // Set cookies
             if (null == cookiesSetter) {
                 // Check for existent secret cookie if auto-login is disabled
-                if (false == conf.isSessiondAutoLogin()) {
+                if (false == conf.isSessiondAutoLogin(req.getServerName(), session)) {
                     Map<String, Cookie> cookies = Cookies.cookieMapFor(req);
                     String expectedSecretCookieName = LoginServlet.SECRET_PREFIX + session.getHash();
                     Cookie cookie = cookies.get(expectedSecretCookieName);
@@ -411,6 +429,8 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
             LOG.error(LoginServlet.RESPONSE_ERROR, e);
             LoginServlet.sendError(resp);
             return false;
+        } finally {
+            ThreadLocalSessionHolder.getInstance().clear();
         }
         return false;
     }
@@ -525,7 +545,7 @@ public abstract class AbstractLoginRequestHandler implements LoginRequestHandler
 
             @Override
             public JSONObject call() throws OXException, IOException {
-                JSONObject json = new JSONObject(8);
+                JSONObject json = new JSONObject(2);
                 performRampUp(req, json, serverSession);
                 return json;
             }
