@@ -418,7 +418,7 @@ public abstract class AbstractShareBasedLoginRequestHandler extends AbstractLogi
                  */
                 String expectedSecretCookieName = SECRET_PREFIX + session.getHash();
                 Map<String, Cookie> cookies = Cookies.cookieMapFor(request);
-                if (false == conf.isSessiondAutoLogin()) {
+                if (false == conf.isSessiondAutoLogin(request.getServerName(), session)) {
                     Cookie cookie = cookies.get(expectedSecretCookieName);
                     if (null != cookie && !session.getSecret().equals(cookie.getValue())) {
                         // The same client already initiated a session, but performed another login. Drop the old session.
@@ -429,7 +429,7 @@ public abstract class AbstractShareBasedLoginRequestHandler extends AbstractLogi
                  * set secret & share cookies
                  */
                 response.addCookie(configureCookie(new Cookie(expectedSecretCookieName, session.getSecret()), request, loginConfig));
-                if (loginConfig.isSessiondAutoLogin()) {
+                if (loginConfig.isSessiondAutoLogin(httpRequest.getServerName(), session)) {
                     response.addCookie(configureCookie(new Cookie(getShareCookieName(request), guest.getBaseToken()), request, loginConfig));
                 }
                 /*
