@@ -49,10 +49,15 @@
 
 package com.openexchange.ajax.login;
 
-import java.util.List;
-import com.openexchange.configuration.ClientWhitelist;
+import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.configuration.CookieHashSource;
-import com.openexchange.sessiond.impl.IPRange;
+import com.openexchange.exception.OXException;
+import com.openexchange.java.util.Tools;
+import com.openexchange.log.LogProperties;
+import com.openexchange.login.ConfigurationProperty;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.session.Session;
+import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 
 /**
  * Object to store the configuration parameters for the different login process mechanisms.
@@ -61,6 +66,8 @@ import com.openexchange.sessiond.impl.IPRange;
  */
 public final class LoginConfiguration {
 
+    private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(LoginConfiguration.class);
+
     private final String uiWebPath;
     private final boolean sessiondAutoLogin;
     private final CookieHashSource hashSource;
@@ -71,16 +78,13 @@ public final class LoginConfiguration {
     private final int cookieExpiry;
     private final boolean insecure;
     private final boolean cookieForceHTTPS;
-    private final boolean ipCheck;
-    private final ClientWhitelist ipCheckWhitelist;
     private final boolean redirectIPChangeAllowed;
-    private final List<IPRange> ranges;
     private final boolean disableTrimLogin;
     private final boolean formLoginWithoutAuthId;
     private final boolean isRandomTokenEnabled;
     private final boolean checkPunyCodeLoginString;
 
-    public LoginConfiguration(String uiWebPath, boolean sessiondAutoLogin, CookieHashSource hashSource, String httpAuthAutoLogin, String defaultClient, String clientVersion, String errorPageTemplate, int cookieExpiry, boolean cookieForceHTTPS, boolean insecure, boolean ipCheck, ClientWhitelist ipCheckWhitelist, boolean redirectIPChangeAllowed, List<IPRange> ranges, boolean disableTrimLogin, boolean formLoginWithoutAuthId, boolean isRandomTokenEnabled, boolean checkPunyCodeLoginString) {
+    public LoginConfiguration(String uiWebPath, boolean sessiondAutoLogin, CookieHashSource hashSource, String httpAuthAutoLogin, String defaultClient, String clientVersion, String errorPageTemplate, int cookieExpiry, boolean cookieForceHTTPS, boolean insecure, boolean redirectIPChangeAllowed, boolean disableTrimLogin, boolean formLoginWithoutAuthId, boolean isRandomTokenEnabled, boolean checkPunyCodeLoginString) {
         super();
         this.uiWebPath = uiWebPath;
         this.sessiondAutoLogin = sessiondAutoLogin;
@@ -92,10 +96,7 @@ public final class LoginConfiguration {
         this.cookieExpiry = cookieExpiry;
         this.cookieForceHTTPS = cookieForceHTTPS;
         this.insecure = insecure;
-        this.ipCheck = ipCheck;
-        this.ipCheckWhitelist = ipCheckWhitelist;
         this.redirectIPChangeAllowed = redirectIPChangeAllowed;
-        this.ranges = ranges;
         this.disableTrimLogin = disableTrimLogin;
         this.formLoginWithoutAuthId = formLoginWithoutAuthId;
         this.isRandomTokenEnabled = isRandomTokenEnabled;
@@ -106,7 +107,66 @@ public final class LoginConfiguration {
         return uiWebPath;
     }
 
+    /**
+     * Checks if auto-login is enabled.
+     * <p>
+     * This routine tries to determine the host name associated with calling thread in order to check reliably using {@link #isSessiondAutoLogin(String)} method.
+     * If host name cannot be determined, global auto-login property is considered.
+     *
+     * @return <code>true</code> if auto-login is enabled; otherwise <code>false</code>
+     */
     public boolean isSessiondAutoLogin() {
+        String hostName = LogProperties.getHostName();
+        if (hostName != null) {
+            return isSessiondAutoLogin0(hostName, null);
+        }
+        return sessiondAutoLogin;
+    }
+
+    /**
+     * Checks if auto-login is enabled for given host name
+     *
+     * @param hostName The host name to check for
+     * @return <code>true</code> if auto-login is enabled; otherwise <code>false</code>
+     */
+    public boolean isSessiondAutoLogin(String hostName) {
+        return isSessiondAutoLogin(hostName, null);
+    }
+
+    /**
+     * Checks if auto-login is enabled for given host name
+     *
+     * @param hostName The host name to check for
+     * @param optSession The optional session to use
+     * @return <code>true</code> if auto-login is enabled; otherwise <code>false</code>
+     */
+    public boolean isSessiondAutoLogin(String hostName, Session optSession) {
+        if (null == hostName) {
+            return sessiondAutoLogin;
+        }
+
+        LogProperties.put(LogProperties.Name.HOSTNAME, hostName);
+        return isSessiondAutoLogin0(hostName, optSession);
+    }
+
+    private static final String CAPABILITY_AUTOLOGIN = "autologin";
+
+    private boolean isSessiondAutoLogin0(String hostName, Session optSession) {
+        try {
+            CapabilityService capabilityService = ServerServiceRegistry.getInstance().getService(CapabilityService.class);
+            if (null == capabilityService) {
+                LOGGER.warn("Missing capability service. Unable to reliably check auto-login capability for host {}. Using default '{}' as fall-back for auto-login (as configured through \"{}\" property", hostName, sessiondAutoLogin, ConfigurationProperty.SESSIOND_AUTOLOGIN.getPropertyName());
+            } else {
+                Session ses = null == optSession ? ThreadLocalSessionHolder.getInstance().getSessionObject() : optSession;
+                if (null == ses) {
+                    return capabilityService.getCapabilities(getUserId(), getContextId(), false, true).contains(CAPABILITY_AUTOLOGIN);
+                }
+                return capabilityService.getCapabilities(ses).contains(CAPABILITY_AUTOLOGIN);
+            }
+        } catch (OXException e) {
+            // fallback to default
+            LOGGER.warn("Failed to retrieve server configuration for host {}. Using default '{}' as fall-back (as configured through \"{}\" property", hostName, sessiondAutoLogin, ConfigurationProperty.SESSIOND_AUTOLOGIN.getPropertyName(), e);
+        }
         return sessiondAutoLogin;
     }
 
@@ -142,22 +202,10 @@ public final class LoginConfiguration {
         return cookieForceHTTPS;
     }
 
-    public boolean isIpCheck() {
-        return ipCheck;
-    }
-
-    public ClientWhitelist getIpCheckWhitelist() {
-        return ipCheckWhitelist;
-    }
-
     public boolean isRedirectIPChangeAllowed() {
         return redirectIPChangeAllowed;
     }
 
-    public List<IPRange> getRanges() {
-        return ranges;
-    }
-
     public boolean isDisableTrimLogin() {
         return disableTrimLogin;
     }
@@ -174,4 +222,35 @@ public final class LoginConfiguration {
         return checkPunyCodeLoginString;
     }
 
+
+    // ----------------------------------------------------------------------------------------------------------------------------------------------------------
+
+    /**
+     * Retrieves the context identifier from the {@link LogProperties}
+     *
+     * @return the context identifier from the LogProperties
+     */
+    private int getContextId() {
+        return getLogPropertyValue(LogProperties.Name.SESSION_CONTEXT_ID);
+    }
+
+    /**
+     * Retrieves the user identifier from the {@link LogProperties}
+     *
+     * @return the user identifier from the {@link LogProperties}
+     */
+    private int getUserId() {
+        return getLogPropertyValue(LogProperties.Name.SESSION_USER_ID);
+    }
+
+    /**
+     * Retrieves value of the specified property from the {@link LogProperties}
+     *
+     * @param name The log property's name
+     * @return the property's value
+     */
+    private int getLogPropertyValue(LogProperties.Name name) {
+        return Tools.getUnsignedInteger(LogProperties.get(name));
+    }
+
 }
\ No newline at end of file
