@@ -200,10 +200,7 @@ public class ShareLoginConfiguration {
             null != shareCookieTTL ? shareCookieTTL.intValue() : defaultConfig.getCookieExpiry(),
             defaultConfig.isCookieForceHTTPS(),
             defaultConfig.isInsecure(),
-            defaultConfig.isIpCheck(),
-            defaultConfig.getIpCheckWhitelist(),
             defaultConfig.isRedirectIPChangeAllowed(),
-            defaultConfig.getRanges(),
             defaultConfig.isDisableTrimLogin(),
             defaultConfig.isFormLoginWithoutAuthId(),
             defaultConfig.isRandomTokenEnabled(),
@@ -291,10 +288,7 @@ public class ShareLoginConfiguration {
                     shareExpiry,
                     loginConfig.isCookieForceHTTPS(),
                     loginConfig.isInsecure(),
-                    loginConfig.isIpCheck(),
-                    loginConfig.getIpCheckWhitelist(),
                     loginConfig.isRedirectIPChangeAllowed(),
-                    loginConfig.getRanges(),
                     loginConfig.isDisableTrimLogin(),
                     loginConfig.isFormLoginWithoutAuthId(),
                     loginConfig.isRandomTokenEnabled(),
