@@ -49,13 +49,18 @@
 
 package com.openexchange.ajax.login.osgi;
 
+import java.util.Dictionary;
+import java.util.Hashtable;
 import org.osgi.framework.BundleContext;
+import org.osgi.framework.Constants;
 import org.osgi.framework.Filter;
 import org.osgi.framework.ServiceReference;
 import org.osgi.service.http.HttpService;
 import org.osgi.util.tracker.ServiceTracker;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import org.slf4j.Logger;
 import com.openexchange.ajax.LoginServlet;
+import com.openexchange.ajax.login.RateLimiterByLogin;
 import com.openexchange.ajax.login.LoginRequestHandler;
 import com.openexchange.ajax.login.RedeemReservationLogin;
 import com.openexchange.config.ConfigurationService;
@@ -63,6 +68,7 @@ import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.login.LoginRampUpService;
 import com.openexchange.login.internal.LoginPerformer;
 import com.openexchange.login.internal.format.CompositeLoginFormatter;
+import com.openexchange.login.listener.LoginListener;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.osgi.SimpleRegistryListener;
@@ -82,6 +88,11 @@ import com.openexchange.tokenlogin.TokenLoginService;
  */
 public class LoginActivator extends HousekeepingActivator {
 
+    /** Simple class to delay initialization until needed */
+    private static class LoggerHolder {
+        static final Logger LOG = org.slf4j.LoggerFactory.getLogger(LoginActivator.class);
+    }
+
     public LoginActivator() {
         super();
     }
@@ -160,5 +171,22 @@ public class LoginActivator extends HousekeepingActivator {
         LoginPerformer.setLoginFormatter(new CompositeLoginFormatter(loginFormat, logoutFormat));
 
         com.openexchange.tools.servlet.http.Tools.setConfigurationService(configurationService);
+
+        // Login name rate limiter
+        boolean rateLimitByLogin = configurationService.getBoolProperty("com.openexchange.ajax.login.rateLimitByLogin.enabled", false);
+        if (rateLimitByLogin) {
+            String propPermits = "com.openexchange.ajax.login.rateLimitByLogin.permits";
+            String propTimeFrame = "com.openexchange.ajax.login.rateLimitByLogin.timeFrameInSeconds";
+            int permits = configurationService.getIntProperty(propPermits, 3);
+            long timeFrameInSeconds = configurationService.getIntProperty(propTimeFrame, 30);
+            if (permits > 0 && timeFrameInSeconds > 0) {
+                Dictionary<String, Object> properties = new Hashtable<String, Object>(2);
+                properties.put(Constants.SERVICE_RANKING, Integer.valueOf(999));
+                registerService(LoginListener.class, new RateLimiterByLogin(permits, timeFrameInSeconds), properties);
+            } else {
+                LoggerHolder.LOG.warn("Value configured for \"{}\" and/or \"{}\" property must be positive. Rate limiting by login name is effectively disabled!", propPermits, propTimeFrame);
+            }
+        }
     }
+
 }
