@@ -83,7 +83,8 @@ public class CookieRefresher implements SessionServletInterceptor {
 
     @Override
     public void intercept(Session session, HttpServletRequest req, HttpServletResponse resp) throws OXException {
-        if (needsCookieRefresh(session)) {
+        String host = req.getServerName();
+        if (needsCookieRefresh(session, host)) {
             String hash = session.getHash();
 
             // Write secret+public cookie
@@ -91,14 +92,12 @@ public class CookieRefresher implements SessionServletInterceptor {
 
             // Refresh HTTP session, too
             req.getSession();
-        } else if (conf.isSessiondAutoLogin()) {
-            if (needsSessionCookieRefresh(session)) {
-                String hash = session.getHash();
+        } else if (needsSessionCookieRefresh(session) && conf.isSessiondAutoLogin(host, session)) {
+            String hash = session.getHash();
 
-                // Check whether to write session cookie as well
-                if (refreshSessionCookie(session.getSessionID(), LoginServlet.SESSION_PREFIX + hash, req)) {
-                    LoginServlet.writeSessionCookie(resp, session, hash, req.isSecure(), req.getServerName());
-                }
+            // Check whether to write session cookie as well
+            if (refreshSessionCookie(session.getSessionID(), LoginServlet.SESSION_PREFIX + hash, req)) {
+                LoginServlet.writeSessionCookie(resp, session, hash, req.isSecure(), req.getServerName());
             }
         }
     }
@@ -118,7 +117,7 @@ public class CookieRefresher implements SessionServletInterceptor {
         return false;
     }
 
-    private boolean needsCookieRefresh(Session session) {
+    private boolean needsCookieRefresh(Session session, String host) {
         Long stamp = (Long) session.getParameter(PARAM_COOKIE_REFRESH_TIMESTAMP);
         if (null == stamp) {
             // No time stamp available, yet
@@ -142,7 +141,7 @@ public class CookieRefresher implements SessionServletInterceptor {
                 }
 
                 session.setParameter(PARAM_COOKIE_REFRESH_TIMESTAMP, createNewStamp());
-                if (conf.isSessiondAutoLogin()) {
+                if (conf.isSessiondAutoLogin(host, session)) {
                     session.setParameter(PARAM_REFRESH_SESSION_COOKIE_FLAG, Boolean.TRUE);
                 }
                 return true;
