@@ -52,6 +52,7 @@ package com.openexchange.ajax.parser;
 import java.util.Date;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.groupware.attach.AttachmentBatch;
 import com.openexchange.groupware.attach.AttachmentField;
 import com.openexchange.groupware.attach.AttachmentMetadata;
 
@@ -61,6 +62,8 @@ public class JSONAttachmentMetadata implements AttachmentMetadata {
 
     private final JSONObject json;
 
+    private AttachmentBatch batch;
+
     public JSONAttachmentMetadata(JSONObject json) {
         super();
         this.json = new JSONObject(json);
@@ -309,4 +312,14 @@ public class JSONAttachmentMetadata implements AttachmentMetadata {
         }
     }
 
+    @Override
+    public void setAttachmentBatch(AttachmentBatch batch) {
+        this.batch = batch;
+    }
+
+    @Override
+    public AttachmentBatch getAttachmentBatch() {
+        return batch;
+    }
+
 }
