@@ -224,7 +224,13 @@ public class DispatcherServlet extends SessionServlet {
      * Clears all registered renderer.
      */
     public static void clearRenderer() {
-        RESPONSE_RENDERERS.set(Collections.<ResponseRenderer> emptyList());
+        List<ResponseRenderer> expect;
+        do {
+            expect = RESPONSE_RENDERERS.get();
+            if (expect.isEmpty()) {
+                return;
+            }
+        } while (!RESPONSE_RENDERERS.compareAndSet(expect, Collections.<ResponseRenderer> emptyList()));
     }
 
     // -------------------------------------------------------------------------------------------------
@@ -390,14 +396,16 @@ public class DispatcherServlet extends SessionServlet {
             MailExceptionCode.REFERENCED_MAIL_NOT_FOUND,
             MailExceptionCode.FOLDER_NOT_FOUND,
             SessionExceptionCodes.SESSION_EXPIRED,
+            SessionExceptionCodes.WRONG_SESSION_SECRET,
             UploadException.UploadCode.MAX_UPLOAD_FILE_SIZE_EXCEEDED,
-            UploadException.UploadCode.MAX_UPLOAD_SIZE_EXCEEDED
+            UploadException.UploadCode.MAX_UPLOAD_SIZE_EXCEEDED,
+            AjaxExceptionCodes.CONNECTION_RESET
         );
 
     /**
      * A set of those {@link Category categories} that should not be logged as <tt>ERROR</tt>, but as <tt>DEBUG</tt> only.
      */
-    private static final Set<Category> CAT_IGNOREES = ImmutableSet.of(Category.CATEGORY_PERMISSION_DENIED);
+    private static final Set<Category> CAT_IGNOREES = ImmutableSet.of(Category.CATEGORY_PERMISSION_DENIED, Category.CATEGORY_USER_INPUT);
 
     /**
      * Checks if passed {@code OXException} instance should not be logged as <tt>ERROR</tt>, but as <tt>DEBUG</tt> only.
@@ -452,6 +460,7 @@ public class DispatcherServlet extends SessionServlet {
         AJAXRequestResult result = null;
         Exception exc = null;
         Dispatcher dispatcher = DISPATCHER.get();
+        boolean enqueued = false;
         try {
             AJAXRequestData requestData = initializeRequestData(httpRequest, httpResp, preferStream);
 
@@ -460,6 +469,10 @@ public class DispatcherServlet extends SessionServlet {
             if (null != session && false == session.isAnonymous()) {
                 // A non-anonymous session
                 enableRateLimitCheckFor(httpRequest);
+                String hostname = requestData.getHostname();
+                if (null != hostname) {
+                    session.setParameter(Session.PARAM_HOST_NAME, hostname);
+                }
             }
 
             // Start dispatcher processing
@@ -479,6 +492,10 @@ public class DispatcherServlet extends SessionServlet {
                 /*
                  * ... and send response
                  */
+                ResultType resultType = result.getType();
+                if (ResultType.ENQUEUED == resultType) {
+                    enqueued = true;
+                }
                 sendResponse(requestData, result, httpRequest, httpResp);
             }
         } catch (UploadException e) {
@@ -521,9 +538,11 @@ public class DispatcherServlet extends SessionServlet {
             }
             super.handleOXException(oxe, httpRequest, httpResp, false, false);
         } finally {
-            Dispatchers.signalDone(result, exc);
-            if (null != state) {
-                dispatcher.end(state);
+            if (false == enqueued) {
+                Dispatchers.signalDone(result, exc);
+                if (null != state) {
+                    dispatcher.end(state);
+                }
             }
         }
     }
@@ -734,7 +753,7 @@ public class DispatcherServlet extends SessionServlet {
 
     private ServerSession fakeSession() {
         UserImpl user = new UserImpl();
-        user.setAttributes(new HashMap<String, Set<String>>(1));
+        user.setAttributes(new HashMap<String, String>(1));
         return new ServerSessionAdapter(NO_SESSION, new ContextImpl(-1), user);
     }
 
