@@ -116,8 +116,10 @@ public class DownloadPreviewResultConverter extends AbstractPreviewResultConvert
             final File tempFile = fileManagement.newTempFile();
             final FileOutputStream fos = new FileOutputStream(tempFile);
             try {
-                fos.write(previewDocument.getContent().get(0).getBytes(com.openexchange.java.Charsets.UTF_8));
-                fos.flush();
+                if (previewDocument.hasContent()) {
+                    fos.write(previewDocument.getContent().get(0).getBytes(com.openexchange.java.Charsets.UTF_8));
+                    fos.flush();
+                }
             } finally {
                 Streams.close(fos);
             }
