@@ -75,11 +75,13 @@ import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.java.Streams;
 import com.openexchange.preview.PreviewExceptionCodes;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.timer.TimerService;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link FileStoreResourceCacheImpl} - The filestore-backed preview cache implementation for documents.
@@ -95,7 +97,7 @@ public class FileStoreResourceCacheImpl extends AbstractResourceCache {
     private static FileStorage getFileStorage(int contextId, boolean quotaAware) throws OXException {
         QuotaFileStorageService qfss = FileStorages.getQuotaFileStorageService();
         if (quotaAware) {
-            return qfss.getQuotaFileStorage(contextId);
+            return qfss.getQuotaFileStorage(contextId, Info.general());
         }
 
         URI uri = qfss.getFileStorageUriFor(0, contextId);
@@ -286,7 +288,7 @@ public class FileStoreResourceCacheImpl extends AbstractResourceCache {
                     }
 
                     // Storing the resource exceeded the quota. We schedule an alignment task if this wasn't already done.
-                    if (triggerAlignment && alignmentRequests.putIfAbsent(contextId, SCHEDULED) == null && scheduleAlignmentTask(globalQuota, contextId)) {
+                    if (triggerAlignment && alignmentRequests.putIfAbsent(contextId, SCHEDULED) == null && scheduleAlignmentTask(globalQuota, userId, contextId)) {
                         LOG.debug("Scheduling alignment task for context {}.", contextId);
                     } else {
                         LOG.debug("Skipping scheduling of alignment task for context {}.", contextId);
@@ -316,14 +318,14 @@ public class FileStoreResourceCacheImpl extends AbstractResourceCache {
         return false;
     }
 
-    protected boolean scheduleAlignmentTask(final long globalQuota, final int contextId) {
+    protected boolean scheduleAlignmentTask(final long globalQuota, final int userId, final int contextId) {
         try {
             TimerService timerService = optTimerService();
             if (timerService != null) {
                 timerService.schedule(new Runnable() {
                     @Override
                     public void run() {
-                        alignToQuota(globalQuota, contextId);
+                        alignToQuota(globalQuota, userId, contextId);
                     }
                 }, ALIGNMENT_DELAY);
 
@@ -338,7 +340,7 @@ public class FileStoreResourceCacheImpl extends AbstractResourceCache {
         return false;
     }
 
-    protected void alignToQuota(long globalQuota, int contextId) {
+    protected void alignToQuota(long globalQuota, int userId, int contextId) {
         Integer iContextId = Integer.valueOf(contextId);
         if (!alignmentRequests.replace(iContextId, SCHEDULED, RUNNING)) {
             return;
@@ -347,62 +349,77 @@ public class FileStoreResourceCacheImpl extends AbstractResourceCache {
         try {
             final ResourceCacheMetadataStore metadataStore = getMetadataStore();
             final DatabaseService dbService = getDBService();
-            final Connection con = dbService.getWritable(contextId);
-            final Set<String> refIds = new HashSet<String>();
-            boolean transactionStarted = false;
-            boolean rollback = false;
+            Set<String> refIds = new HashSet<String>();
             try {
-                long usedContextQuota = metadataStore.getUsedSize(con, contextId);
-                if (globalQuota > 0 && usedContextQuota > globalQuota) {
-                    long neededSpace = usedContextQuota - globalQuota;
-                    long collected = 0L;
+                final DBUtils.TransactionRollbackCondition condition = new DBUtils.TransactionRollbackCondition(3);
+                do {
+                    Connection con = dbService.getWritable(contextId);
+                    refIds.clear();
+                    condition.resetTransactionRollbackException();
+                    boolean transactionStarted = false;
+                    boolean rollback = false;
+                    try {
+                        long usedContextQuota = metadataStore.getUsedSize(con, contextId);
+                        if (globalQuota > 0 && usedContextQuota > globalQuota) {
+                            long neededSpace = usedContextQuota - globalQuota;
+                            long collected = 0L;
 
-                    Databases.startTransaction(con);
-                    transactionStarted = true;
-                    rollback = true;
-                    List<ResourceCacheMetadata> entries = metadataStore.loadForCleanUp(con, contextId);
-                    Iterator<ResourceCacheMetadata> it = entries.iterator();
-                    while (collected < neededSpace && it.hasNext()) {
-                        ResourceCacheMetadata metadata = it.next();
-                        String refId = metadata.getRefId();
-                        if (refId != null) {
-                            refIds.add(refId);
+                            Databases.startTransaction(con);
+                            transactionStarted = true;
+                            rollback = true;
+
+                            List<ResourceCacheMetadata> entries = metadataStore.loadForCleanUp(con, contextId);
+                            Iterator<ResourceCacheMetadata> it = entries.iterator();
+                            while (collected < neededSpace && it.hasNext()) {
+                                ResourceCacheMetadata metadata = it.next();
+                                String refId = metadata.getRefId();
+                                if (refId != null) {
+                                    refIds.add(refId);
+                                }
+                                collected += (metadata.getSize() > 0 ? metadata.getSize() : 0);
+                            }
+
+                            if (!refIds.isEmpty()) {
+                                metadataStore.removeByRefIds(con, contextId, refIds);
+                            }
+
+                            con.commit();
+                            rollback = false;
+                        }
+                    } catch (SQLException s) {
+                        if (condition.isFailedTransactionRollback(s)) {
+                            refIds.clear();
+                        } else {
+                            LOG.error("Could not align preview cache for context {} to quota.", iContextId, s);
+                        }
+                    } finally {
+                        if (rollback) {
+                            Databases.rollback(con);
+                        }
+                        if (transactionStarted) {
+                            Databases.autocommit(con);
+                        }
+                        if (refIds.isEmpty()) {
+                            dbService.backWritableAfterReading(contextId, con);
+                        } else {
+                            dbService.backWritable(contextId, con);
                         }
-                        collected += (metadata.getSize() > 0 ? metadata.getSize() : 0);
                     }
+                } while (condition.checkRetry());
 
-                    if (!refIds.isEmpty()) {
-                        metadataStore.removeByRefIds(con, contextId, refIds);
-                    }
-                    con.commit();
-                    rollback = false;
+                if (refIds.isEmpty()) {
+                    LOG.debug("No need to align preview cache for context {} to quota.", iContextId);
+                } else {
+                    LOG.debug("Aligning preview cache for context {} to quota.", iContextId);
+                    batchDeleteFiles(refIds, getFileStorage(contextId, quotaAware));
                 }
             } catch (SQLException s) {
                 LOG.error("Could not align preview cache for context {} to quota.", iContextId, s);
-            } finally {
-                if (rollback) {
-                    Databases.rollback(con);
-                }
-                alignmentRequests.remove(iContextId);
-                if (transactionStarted) {
-                    Databases.autocommit(con);
-                }
-
-                if (refIds.isEmpty()) {
-                    dbService.backWritableAfterReading(contextId, con);
-                } else {
-                    dbService.backWritable(contextId, con);
-                }
-            }
-
-            if (refIds.isEmpty()) {
-                LOG.debug("No need to align preview cache for context {} to quota.", iContextId);
-            } else {
-                LOG.debug("Aligning preview cache for context {} to quota.", iContextId);
-                batchDeleteFiles(refIds, getFileStorage(contextId, quotaAware));
             }
         } catch (Exception e) {
             LOG.error("Could not align preview cache for context {} to quota.", iContextId, e);
+        } finally {
+            alignmentRequests.remove(iContextId);
         }
     }
 
