@@ -88,6 +88,10 @@ public class PreviewResponseRenderer implements ResponseRenderer {
         //httpResp.setContentType(AJAXServlet.CONTENTTYPE_HTML);
         try {
             final PreviewDocument previewDocument = (PreviewDocument) result.getResultObject();
+            if(previewDocument==null){
+                LOG.error("The AJAXRequestResult doesn't contain a result object!");
+                return;
+            }
 
             final JSONArray jsonArray = new JSONArray();
             for (final String previewPage : previewDocument.getContent()) {
