@@ -680,7 +680,7 @@ public final class FolderWriter extends DataWriter {
                                 }
                                 jsonwriter.key(folderField.getColumnName());
                             }
-                            jsonwriter.value(folderField.renderJSON(folderField.getValue(fo, session)));
+                            jsonwriter.value(folderField.renderJSON(null, folderField.getValue(fo, session)));
                         }
                     };
                 }
