@@ -55,6 +55,7 @@ import java.util.regex.Pattern;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorage;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.server.ServiceExceptionCode;
@@ -108,7 +109,7 @@ public final class ConfigAJAXRequest {
         if (null == storageService) {
             throw ServiceExceptionCode.absentService(QuotaFileStorageService.class);
         }
-        return storageService.getQuotaFileStorage(userId, contextId);
+        return storageService.getQuotaFileStorage(userId, contextId, Info.drive());
     }
 
     /**
