@@ -54,8 +54,8 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -81,6 +81,7 @@ import com.openexchange.consistency.solver.ProblemSolver;
 import com.openexchange.consistency.solver.RecordSolver;
 import com.openexchange.consistency.solver.RemoveFileSolver;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorageCodes;
@@ -91,7 +92,7 @@ import com.openexchange.groupware.infostore.database.impl.DatabaseImpl;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.report.internal.Tools;
 import com.openexchange.server.services.ServerServiceRegistry;
-import com.openexchange.tools.sql.DBUtils;
+import com.openexchange.snippet.QuotaAwareSnippetService;
 
 /**
  * Provides the Business Logic for the consistency tool. Concrete subclasses must provide integration to the environment by implementing the
@@ -271,7 +272,7 @@ public abstract class Consistency implements ConsistencyMBean {
     private void deleteContextFromConfigDB(final Connection configCon, final int contextId) throws SQLException {
         PreparedStatement stmt = null;
         try {
-            LOG.debug("Deleting context_server2dbpool mapping for context {}", contextId);
+            LOG.debug("Deleting context_server2db_pool mapping for context {}", contextId);
             // delete context from context_server2db_pool
             stmt = configCon.prepareStatement("DELETE FROM context_server2db_pool WHERE cid=?");
             stmt.setInt(1, contextId);
@@ -301,6 +302,29 @@ public abstract class Consistency implements ConsistencyMBean {
         }
     }
 
+    /**
+     * Deletes the specified schema mapping from the 'context_server2db_pool'
+     *
+     * @param configCon The configdb writeable {@link Connection}
+     * @param schema The schema name
+     * @throws SQLException if an SQL error is occurred
+     */
+    private void deleteSchemaFromConfigDB(final Connection configCon, final String schema) throws SQLException {
+        PreparedStatement stmt = null;
+        try {
+            LOG.debug("Deleting context_server2db_pool mapping for schema {}", schema);
+            // delete schema from context_server2db_pool
+            stmt = configCon.prepareStatement("DELETE FROM context_server2db_pool WHERE db_schema=?");
+            stmt.setString(1, schema);
+            stmt.executeUpdate();
+            stmt.close();
+        } finally {
+            if (null != stmt) {
+                stmt.close();
+            }
+        }
+    }
+
     @Override
     public List<String> checkOrRepairConfigDB(final boolean repair) throws MBeanException {
         if (repair) {
@@ -324,26 +348,44 @@ public abstract class Consistency implements ConsistencyMBean {
 
             final Map<String, Integer> schemaPoolMap = Tools.getAllSchemata(LOG);
             confCon = databaseService.getReadOnly();
-            stmt = confCon.prepareStatement("SELECT db_schema,cid FROM context_server2db_pool");
-            rs = stmt.executeQuery();
-            while (rs.next()) {
-                final String schema = rs.getString(1);
-                final Integer ctx = Integer.valueOf(rs.getInt(2));
-                if (schemaMap.containsKey(schema)) {
-                    schemaMap.get(schema).add(ctx);
-                } else {
-                    List<Integer> ctxs = new ArrayList<Integer>();
-                    ctxs.add(ctx);
-                    schemaMap.put(schema, ctxs);
+
+            // Fetch all contexts for each db_schema
+            for (String schema : schemaPoolMap.keySet()) {
+                stmt = confCon.prepareStatement("SELECT cid FROM context_server2db_pool WHERE db_schema = ?");
+                stmt.setString(1, schema);
+                rs = stmt.executeQuery();
+                while (rs.next()) {
+                    final Integer ctx = Integer.valueOf(rs.getInt(1));
+                    if (schemaMap.containsKey(schema)) {
+                        schemaMap.get(schema).add(ctx);
+                    } else {
+                        List<Integer> ctxs = new ArrayList<Integer>();
+                        ctxs.add(ctx);
+                        schemaMap.put(schema, ctxs);
+                    }
                 }
+                Databases.closeSQLStuff(rs, stmt);
+                stmt = null;
             }
-            DBUtils.closeSQLStuff(rs, stmt);
-            stmt = null;
             for (final Entry<String, List<Integer>> schemaEntry : schemaMap.entrySet()) {
                 String schema = schemaEntry.getKey();
                 List<Integer> ctxs = schemaEntry.getValue();
                 Integer poolid = schemaPoolMap.get(schema);
-                poolCon = databaseService.get(poolid.intValue(), schema);
+                try {
+                    poolCon = databaseService.get(poolid.intValue(), schema);
+                } catch (OXException e) {
+                    Throwable cause = e.getCause();
+                    if (cause.getMessage() != null && cause.getMessage().contains("Unknown database")) {
+                        if (repair) {
+                            deleteSchemaFromConfigDB(confCon, schema);
+                            ret.add("Deleted inconsistent entry(ies) for schema " + schema + " from configdb.");
+                        } else {
+                            ret.add("The schema '" + schema + "' does not exist.'");
+                        }
+                        continue;
+                    }
+                    throw e;
+                }
                 String contextids = "";
                 for (final Integer c : ctxs) {
                     contextids += c + ",";
@@ -368,7 +410,7 @@ public abstract class Consistency implements ConsistencyMBean {
                         }
                     }
                 }
-                DBUtils.closeSQLStuff(rs, stmt);
+                Databases.closeSQLStuff(rs, stmt);
                 stmt = null;
                 databaseService.back(poolid.intValue(), poolCon);
                 poolCon = null;
@@ -376,7 +418,7 @@ public abstract class Consistency implements ConsistencyMBean {
             if (ret.size() == 0 && repair) {
                 ret.add("there was nothing to repair");
             }
-            DBUtils.closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             stmt = null;
             return ret;
         } catch (final SQLException e) {
@@ -388,7 +430,7 @@ public abstract class Consistency implements ConsistencyMBean {
             final Exception wrapMe = new Exception(e.getMessage());
             throw new MBeanException(wrapMe, e.getMessage());
         } finally {
-            DBUtils.closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             if (databaseService != null) {
                 if (null != confCon) {
                     databaseService.backReadOnly(confCon);
@@ -553,14 +595,25 @@ public abstract class Consistency implements ConsistencyMBean {
 
             Set<String> filesToIgnore;
             if (quotaAware) {
-                filesToIgnore = Collections.emptySet();
+                filesToIgnore = new HashSet<>();
             } else {
                 if (entity.getType().equals(EntityType.Context)) {
                     filesToIgnore = getPreviewCacheFileStoreLocationsPerContext(entity.getContext());
                 } else {
-                    filesToIgnore = Collections.emptySet();
+                    filesToIgnore = new HashSet<>();
                 }
             }
+
+            /*
+             * Depending on the configuration snippets doesn't count towards the usage too.
+             */
+            QuotaAwareSnippetService service = ServerServiceRegistry.getInstance().getService(QuotaAwareSnippetService.class);
+            if (service != null) {
+                if (service.ignoreQuota()) {
+                    filesToIgnore.addAll(service.getFilesToIgnore(entity.getContext().getContextId()));
+                }
+            }
+
             recalculateUsage(storage, filesToIgnore);
         }
     }
