@@ -2387,7 +2387,7 @@ public class ContactMapper extends DefaultMapper<Contact, ContactField> {
                              * Independent entries ('one-offs') must contain a valid e-mail address
                              */
                             if (null == member.getEmailaddress() || 0 == member.getEmailaddress().trim().length()) {
-                                throw ContactExceptionCodes.EMAIL_MANDATORY_FOR_EXTERNAL_MEMBERS.create();
+                                throw ContactExceptionCodes.EMAIL_MANDATORY_FOR_EXTERNAL_MEMBERS.create(member.getDisplayname());
                             }
                             try {
                                 new QuotedInternetAddress(member.getEmailaddress()).validate();
@@ -2985,30 +2985,6 @@ public class ContactMapper extends DefaultMapper<Contact, ContactField> {
             }
         });
 
-        mappings.put(ContactField.USE_COUNT, new ContactMapping<Integer>() {
-
-            @Override
-            public void set(Contact contact, Integer value) {
-                contact.setUseCount(value);
-            }
-
-            @Override
-            public boolean isSet(Contact contact) {
-                return contact.containsUseCount();
-            }
-
-            @Override
-            public Integer get(Contact contact) {
-                return contact.getUseCount();
-            }
-
-            @Override
-            public void remove(Contact contact) {
-                contact.removeUseCount();
-
-            }
-        });
-
         //        mappings.put(ContactField.IMAGE1_URL, new StringMapping() {
         //
         //            @Override
