@@ -51,7 +51,6 @@ package com.openexchange.data.conversion.ical;
 
 import com.openexchange.i18n.LocalizableStrings;
 
-
 /**
  * {@link ConversionWarningMessage}
  *
@@ -98,4 +97,12 @@ public class ConversionWarningMessage implements LocalizableStrings {
 
     public final static String TRUNCATION_WARNING_MSG = "Element truncated: %s";
 
+    public final static String INVALID_MAIL_ADDRESS_MSG = "Invalid mail address for external participant: %1$s";
+
+    public final static String NO_FOLDER_FOR_APPOINTMENTS = "The conversion yields some objects which could not be stored due to missing folder for appointments.";
+
+    public final static String NO_FOLDER_FOR_TASKS = "The conversion yields some objects which could not be stored due to missing folder for tasks.";
+
+    public static final String TRUNCATED_ITEMS = "The object could not be stored due to a configured limitation";
+
 }
