@@ -49,6 +49,8 @@
 
 package com.openexchange.data.conversion.ical;
 
+import com.openexchange.data.conversion.ical.itip.ITipMethod;
+
 /**
  * Defines the possible parameters of the iCal conversion.
  *
@@ -58,10 +60,16 @@ public interface Mode {
 
     /**
      * Determines which zone info should be used for time zones.
+     *
      * @return time zone information to use.
      */
     ZoneInfo getZoneInfo();
 
-    Object getParameter(String name);
+    /**
+     * Gets the desired method to use for the generated iCalendar data.
+     *
+     * @return The method, or <code>null</code> if no certain method should be declared
+     */
+    ITipMethod getMethod();
 
 }
