@@ -662,7 +662,9 @@ public final class CacheFolderStorage implements ReinitializableFolderStorage, F
      * @throws OXException If removal fails
      */
     public void removeFromCache(String id, String treeId, boolean singleOnly, Session session) throws OXException {
-        removeFromCache(id, treeId, singleOnly, null, null, session, null);
+        if (null != session) {
+            removeFromCache(id, treeId, singleOnly, null, null, session, null);
+        }
     }
 
     /**
@@ -1383,6 +1385,29 @@ public final class CacheFolderStorage implements ReinitializableFolderStorage, F
         }
     }
 
+    @Override
+    public SortableId[] getVisibleFolders(String rootFolderId, String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws OXException {
+        FolderStorage folderStorage = registry.getFolderStorageByContentType(treeId, contentType);
+        if (null == folderStorage) {
+            throw FolderExceptionErrorMessage.NO_STORAGE_FOR_CT.create(treeId, contentType);
+        }
+        boolean started = startTransaction(Mode.WRITE_AFTER_READ, storageParameters, folderStorage);
+        try {
+            SortableId[] ret = folderStorage.getVisibleFolders(rootFolderId, treeId, contentType, type, storageParameters);
+            if (started) {
+                folderStorage.commitTransaction(storageParameters);
+                started = false;
+            }
+            return ret;
+        } catch (RuntimeException e) {
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+        } finally {
+            if (started) {
+                folderStorage.rollback(storageParameters);
+            }
+        }
+    }
+
     @Override
     public SortableId[] getUserSharedFolders(String treeId, ContentType contentType, StorageParameters storageParameters) throws OXException {
         FolderStorage folderStorage = registry.getFolderStorageByContentType(treeId, contentType);
@@ -1483,8 +1508,8 @@ public final class CacheFolderStorage implements ReinitializableFolderStorage, F
                 allSubfolderIds = new LinkedList<SortableId>();
 
                 // Query storages (except first one) using dedicated threads
-                CompletionService<java.util.List<SortableId>> completionService = new ThreadPoolCompletionService<java.util.List<SortableId>>(
-                    ThreadPools.getThreadPool()).setTrackable(true);
+                ThreadPoolService tps = CacheServiceRegistry.getServiceRegistry().getService(ThreadPoolService.class);
+                CompletionService<java.util.List<SortableId>> completionService = new ThreadPoolCompletionService<java.util.List<SortableId>>(tps).setTrackable(true);
                 int submittedTasks = 0;
                 for (int i = 1; i < neededStorages.length; i++) {
                     final FolderStorage neededStorage = neededStorages[i];
