@@ -111,6 +111,7 @@ public class DatabaseFolder extends AbstractFolder {
     private static final String CAPABILITY_ZIPPABLE_FOLDER = Strings.asciiLowerCase(FileStorageCapability.ZIPPABLE_FOLDER.name());
     private static final String CAPABILITY_FILE_VERSIONS = Strings.asciiLowerCase(FileStorageCapability.FILE_VERSIONS.name());
     private static final String CAPABILITY_EXTENDED_METADATA = Strings.asciiLowerCase(FileStorageCapability.EXTENDED_METADATA.name());
+    private static final String CAPABILITY_LOCKS = Strings.asciiLowerCase(FileStorageCapability.LOCKS.name());
     private static final String CAPABILITY_COUNT_TOTAL = Strings.asciiLowerCase(FileStorageCapability.COUNT_TOTAL.name());
     private static final String CAPABILITY_CASE_INSENSITIVE = Strings.asciiLowerCase(FileStorageCapability.CASE_INSENSITIVE.name());
 
@@ -158,6 +159,7 @@ public class DatabaseFolder extends AbstractFolder {
             addSupportedCapabilities(CAPABILITY_ZIPPABLE_FOLDER);
             addSupportedCapabilities(CAPABILITY_FILE_VERSIONS);
             addSupportedCapabilities(CAPABILITY_EXTENDED_METADATA);
+            addSupportedCapabilities(CAPABILITY_LOCKS);
             addSupportedCapabilities(CAPABILITY_CASE_INSENSITIVE);
         }
         int module = contentType.getModule();
