@@ -99,6 +99,7 @@ public final class FileStorageFolderImpl extends AbstractFolder {
     private static final String CAPABILITY_ZIPPABLE_FOLDER = Strings.asciiLowerCase(FileStorageCapability.ZIPPABLE_FOLDER.name());
     private static final String CAPABILITY_FILE_VERSIONS = Strings.asciiLowerCase(FileStorageCapability.FILE_VERSIONS.name());
     private static final String CAPABILITY_EXTENDED_METADATA = Strings.asciiLowerCase(FileStorageCapability.EXTENDED_METADATA.name());
+    private static final String CAPABILITY_LOCKS = Strings.asciiLowerCase(FileStorageCapability.LOCKS.name());
     private static final String CAPABILITY_COUNT_TOTAL = Strings.asciiLowerCase(FileStorageCapability.COUNT_TOTAL.name());
     private static final String CAPABILITY_CASE_INSENSITIVE = Strings.asciiLowerCase(FileStorageCapability.CASE_INSENSITIVE.name());
     private static final String CAPABILITY_AUTO_RENAME_FOLDERS = Strings.asciiLowerCase(FileStorageCapability.AUTO_RENAME_FOLDERS.name());
@@ -285,7 +286,7 @@ public final class FileStorageFolderImpl extends AbstractFolder {
         Set<String> supportedCapabilities = fsFolder.getCapabilities();
         if (optCheckCapability(fsFolder.getId(), FileStorageCapability.ZIPPABLE_FOLDER, folderAccess)) {
             if (null == supportedCapabilities) {
-                supportedCapabilities = new LinkedHashSet<>(2);
+                supportedCapabilities = new LinkedHashSet<>(4);
             } else {
                 supportedCapabilities = new LinkedHashSet<>(supportedCapabilities);
             }
@@ -293,7 +294,7 @@ public final class FileStorageFolderImpl extends AbstractFolder {
         }
         if (optCheckCapability(fsFolder.getId(), FileStorageCapability.FILE_VERSIONS, folderAccess)) {
             if (null == supportedCapabilities) {
-                supportedCapabilities = new LinkedHashSet<>(2);
+                supportedCapabilities = new LinkedHashSet<>(4);
             } else {
                 supportedCapabilities = new LinkedHashSet<>(supportedCapabilities);
             }
@@ -301,12 +302,20 @@ public final class FileStorageFolderImpl extends AbstractFolder {
         }
         if (optCheckCapability(fsFolder.getId(), FileStorageCapability.EXTENDED_METADATA, folderAccess)) {
             if (null == supportedCapabilities) {
-                supportedCapabilities = new LinkedHashSet<>(2);
+                supportedCapabilities = new LinkedHashSet<>(4);
             } else {
                 supportedCapabilities = new LinkedHashSet<>(supportedCapabilities);
             }
             supportedCapabilities.add(CAPABILITY_EXTENDED_METADATA);
         }
+        if (optCheckCapability(fsFolder.getId(), FileStorageCapability.LOCKS, folderAccess)) {
+            if (null == supportedCapabilities) {
+                supportedCapabilities = new LinkedHashSet<>(4);
+            } else {
+                supportedCapabilities = new LinkedHashSet<>(supportedCapabilities);
+            }
+            supportedCapabilities.add(CAPABILITY_LOCKS);
+        }
         if (optCheckCapability(fsFolder.getId(), FileStorageCapability.COUNT_TOTAL, folderAccess)) {
             if (null == supportedCapabilities) {
                 supportedCapabilities = new LinkedHashSet<>(4);
