@@ -53,6 +53,7 @@ import static com.openexchange.folderstorage.mail.MailFolderStorage.closeMailAcc
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareMailFolderParam;
 import gnu.trove.map.hash.TIntIntHashMap;
+import java.io.Serializable;
 import java.util.EnumSet;
 import java.util.Locale;
 import java.util.Set;
@@ -63,6 +64,7 @@ import com.openexchange.file.storage.FileStorageCapability;
 import com.openexchange.folderstorage.AbstractFolder;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.FolderExtension;
+import com.openexchange.folderstorage.FolderServiceDecorator;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.StorageParameters;
@@ -171,10 +173,10 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
     private final int mailAccountId;
     private final int userId;
     private final int contextId;
-    private String localizedName;
+    private final LocalizedNameProvider localizedNameProvider;
 
-    private int m_total = -1;
-    private int m_unread = -1;
+    private final int m_total;
+    private final int m_unread;
 
     /** The special bit for user flag support */
     public static final int BIT_USER_FLAG = (1 << 29);
@@ -199,7 +201,12 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
      * @throws OXException If creation fails
      */
     public MailFolderImpl(MailFolder mailFolder, int accountId, MailConfig mailConfig, StorageParameters params, DefaultFolderFullnameProvider fullnameProvider, MailAccess<?, ?> mailAccess, MailAccount mailAccount, boolean translatePrimaryAccountDefaultFolders) throws OXException {
-        this(mailFolder, accountId, mailConfig, params.getUser(), params.getContextId(), fullnameProvider, mailAccess, mailAccount, translatePrimaryAccountDefaultFolders);
+        this(mailFolder, accountId, mailConfig, params.getUser(), optLocaleFrom(params), params.getContextId(), fullnameProvider, mailAccess, mailAccount, translatePrimaryAccountDefaultFolders);
+    }
+
+    private static Locale optLocaleFrom(StorageParameters params) {
+        FolderServiceDecorator decorator = params.getDecorator();
+        return null == decorator ? null : decorator.getLocale();
     }
 
     /**
@@ -211,6 +218,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
      * @param accountId The account identifier
      * @param mailConfig The mail configuration
      * @param user The user
+     * @param locale The optional locale to use; if <code>null</code> user's locale is used
      * @param contextId The context identifier
      * @param fullnameProvider The (optional) full name provider
      * @param mailAccess The associated {@link MailAccess} instance
@@ -218,7 +226,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
      * @param translatePrimaryAccountDefaultFolders Whether to translate names of default folders from the primary account
      * @throws OXException If creation fails
      */
-    public MailFolderImpl(MailFolder mailFolder, int accountId, MailConfig mailConfig, User user, int contextId, DefaultFolderFullnameProvider fullnameProvider, MailAccess<?, ?> mailAccess, MailAccount mailAccount, boolean translatePrimaryAccountDefaultFolders) throws OXException {
+    public MailFolderImpl(MailFolder mailFolder, int accountId, MailConfig mailConfig, User user, Locale locale, int contextId, DefaultFolderFullnameProvider fullnameProvider, MailAccess<?, ?> mailAccess, MailAccount mailAccount, boolean translatePrimaryAccountDefaultFolders) throws OXException {
         super();
         this.mailAccountId = accountId;
         this.accountId = MailFolderUtility.prepareFullname(accountId, MailFolder.DEFAULT_FOLDER_ID);
@@ -228,12 +236,14 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
         id = MailFolderUtility.prepareFullname(accountId, fullName);
         String folderName = mailFolder.getName();
         name = folderName;
+        Locale effectiveLocale = null == locale ? (null == user.getLocale() ? Locale.US : user.getLocale()) : locale;
+        LocalizedNameProvider localizedNameProvider;
         if ("INBOX".equals(fullName)) {
-            localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.INBOX);
+            localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.INBOX);
         } else if (mailFolder.isRootFolder() && isUnifiedMail(mailFolder)) {
-            localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.UNIFIED_MAIL);
+            localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.UNIFIED_MAIL);
         } else {
-            localizedName = folderName;
+            localizedNameProvider = new StaticLocalizedNameProvider(folderName);
         }
         // Determine the parent...
         if (mailFolder.isRootFolder()) {
@@ -283,9 +293,14 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
             }
 
             // Determine the mail folder type (None, Trash, Sent, ...) and set localized name
-            mailFolderType = determineMailFolderType(folderName, mailFolder, mailAccess, mailAccount, user, fullnameProvider, translatePrimaryAccountDefaultFolders);
+            MailFolderTypeRetval retval = determineMailFolderType(folderName, mailFolder, mailAccess, mailAccount, effectiveLocale, fullnameProvider, translatePrimaryAccountDefaultFolders);
+            mailFolderType = retval.mailFolderType;
+            if (null != retval.localizedNameProvider) {
+                localizedNameProvider = retval.localizedNameProvider;
+            }
         }
         this.mailFolderTypeRef = new AtomicReference<MailFolderType>(mailFolderType);
+        this.localizedNameProvider = localizedNameProvider;
 
         {
             String client = Strings.asciiLowerCase(mailAccess.getSession().getClient());
@@ -350,23 +365,30 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
             // Already cached in MAL API layer
             cache = false;
         }
-        // Since not cached we can obtain total/unread counter here
+        // If not cached, we can obtain total/unread counter here
+        int m_total = -1;
+        int m_unread = -1;
         if (!cache) {
-            final IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
-            if (folderStorage instanceof IMailFolderStorageEnhanced2) {
-                final IMailFolderStorageEnhanced2 storageEnhanced2 = (IMailFolderStorageEnhanced2) folderStorage;
-                final int[] tu = storageEnhanced2.getTotalAndUnreadCounter(ensureFullName(fullName));
+            IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
+
+            IMailFolderStorageEnhanced2 storageEnhanced2 = folderStorage.supports(IMailFolderStorageEnhanced2.class);
+            if (null != storageEnhanced2) {
+                int[] tu = storageEnhanced2.getTotalAndUnreadCounter(ensureFullName(fullName));
                 m_total = null == tu ? -1 : tu[0];
                 m_unread = null == tu ? -1 : tu[1];
-            } else if (folderStorage instanceof IMailFolderStorageEnhanced) {
-                final IMailFolderStorageEnhanced storageEnhanced = (IMailFolderStorageEnhanced) folderStorage;
-                m_total = storageEnhanced.getTotalCounter(ensureFullName(fullName));
-                m_unread = storageEnhanced.getUnreadCounter(ensureFullName(fullName));
             } else {
-                m_total = mailAccess.getMessageStorage().searchMessages(ensureFullName(fullName), IndexRange.NULL, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS_ID).length;
-                m_unread = mailAccess.getMessageStorage().getUnreadMessages(ensureFullName(fullName), MailSortField.RECEIVED_DATE, OrderDirection.DESC, FIELDS_ID, -1).length;
+                IMailFolderStorageEnhanced storageEnhanced = folderStorage.supports(IMailFolderStorageEnhanced.class);
+                if (null != storageEnhanced) {
+                    m_total = storageEnhanced.getTotalCounter(ensureFullName(fullName));
+                    m_unread = storageEnhanced.getUnreadCounter(ensureFullName(fullName));
+                } else {
+                    m_total = mailAccess.getMessageStorage().searchMessages(ensureFullName(fullName), IndexRange.NULL, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS_ID).length;
+                    m_unread = mailAccess.getMessageStorage().getUnreadMessages(ensureFullName(fullName), MailSortField.RECEIVED_DATE, OrderDirection.DESC, FIELDS_ID, -1).length;
+                }
             }
         }
+        this.m_total = m_total;
+        this.m_unread = m_unread;
         cacheable = cache;
     }
 
@@ -387,8 +409,13 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
         return MailFolder.DEFAULT_FOLDER_ID.equals(fullName) ? FolderStorage.PRIVATE_ID : MailFolderUtility.prepareFullname(accountId, MailFolder.DEFAULT_FOLDER_ID);
     }
 
-    private MailFolderType determineMailFolderType(String folderName, MailFolder mailFolder, MailAccess<?, ?> mailAccess, MailAccount mailAccount, User user, DefaultFolderFullnameProvider fullnameProvider, boolean translatePrimaryAccountDefaultFolders) throws OXException {
+    private LocalizedNameProvider getLocalizedNameProviderForPrimaryStandard(String key, boolean translatePrimaryAccountDefaultFolders, String folderName) {
+        return translatePrimaryAccountDefaultFolders ? new CommonLocalizedNameProvider(key) : new StaticLocalizedNameProvider(folderName);
+    }
+
+    private MailFolderTypeRetval determineMailFolderType(String folderName, MailFolder mailFolder, MailAccess<?, ?> mailAccess, MailAccount mailAccount, Locale effectiveLocale, DefaultFolderFullnameProvider fullnameProvider, boolean translatePrimaryAccountDefaultFolders) throws OXException {
         MailFolderType mailFolderType = MailFolderType.NONE;
+        LocalizedNameProvider localizedNameProvider = null;
         boolean isPrimaryAccount = MailAccount.DEFAULT_ID == mailAccount.getId();
         if (mailFolder.containsDefaultFolderType()) {
             switch (mailFolder.getDefaultFolderType()) {
@@ -397,41 +424,41 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
                 break;
             case TRASH:
                 if (isPrimaryAccount) {
-                    localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH)) : (MailStrings.TRASH.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH) : folderName);
+                    localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.TRASH, translatePrimaryAccountDefaultFolders, folderName);
                 }
                 mailFolderType = MailFolderType.TRASH;
                 break;
             case SENT:
                 if (isPrimaryAccount) {
-                    localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT)) : (MailStrings.SENT.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT) : folderName);
+                    localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.SENT, translatePrimaryAccountDefaultFolders, folderName);
                 }
                 mailFolderType = MailFolderType.SENT;
                 break;
             case SPAM:
                 if (isPrimaryAccount) {
-                    localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM)) : (MailStrings.SPAM.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM) : folderName);
+                    localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.SPAM, translatePrimaryAccountDefaultFolders, folderName);
                 }
                 mailFolderType = MailFolderType.SPAM;
                 break;
             case DRAFTS:
                 if (isPrimaryAccount) {
-                    localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS)) : (MailStrings.DRAFTS.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS) : folderName);
+                    localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.DRAFTS, translatePrimaryAccountDefaultFolders, folderName);
                 }
                 mailFolderType = MailFolderType.DRAFTS;
                 break;
             case CONFIRMED_SPAM:
                 if (isPrimaryAccount) {
-                    localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.CONFIRMED_SPAM);
+                    localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.CONFIRMED_SPAM);
                 }
                 break;
             case CONFIRMED_HAM:
                 if (isPrimaryAccount) {
-                    localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.CONFIRMED_HAM);
+                    localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.CONFIRMED_HAM);
                 }
                 break;
             default:
                 if (isPrimaryAccount && translatePrimaryAccountDefaultFolders && MailFolderStorage.isArchiveFolder(fullName, mailAccess, mailAccount)) {
-                    localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.ARCHIVE);
+                    localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.ARCHIVE);
                 }
                 // Nope
             }
@@ -442,34 +469,34 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
                 try {
                     if (fullName.equals(fullnameProvider.getDraftsFolder())) {
                         if (isPrimaryAccount) {
-                            localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS)) : (MailStrings.DRAFTS.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.DRAFTS) : folderName);
+                            localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.DRAFTS, translatePrimaryAccountDefaultFolders, folderName);
                         }
                         mailFolderType = MailFolderType.DRAFTS;
                     } else if (fullName.equals(fullnameProvider.getINBOXFolder())) {
                         mailFolderType = MailFolderType.INBOX;
                     } else if (fullName.equals(fullnameProvider.getSentFolder())) {
                         if (isPrimaryAccount) {
-                            localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT)) : (MailStrings.SENT.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.SENT) : folderName);
+                            localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.SENT, translatePrimaryAccountDefaultFolders, folderName);
                         }
                         mailFolderType = MailFolderType.SENT;
                     } else if (fullName.equals(fullnameProvider.getSpamFolder())) {
                         if (isPrimaryAccount) {
-                            localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM)) : (MailStrings.SPAM.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.SPAM) : folderName);
+                            localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.SPAM, translatePrimaryAccountDefaultFolders, folderName);
                         }
                         mailFolderType = MailFolderType.SPAM;
                     } else if (fullName.equals(fullnameProvider.getTrashFolder())) {
                         if (isPrimaryAccount) {
-                            localizedName = translatePrimaryAccountDefaultFolders ? (StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH)) : (MailStrings.TRASH.equals(folderName) ? StringHelper.valueOf(user.getLocale()).getString(MailStrings.TRASH) : folderName);
+                            localizedNameProvider = getLocalizedNameProviderForPrimaryStandard(MailStrings.TRASH, translatePrimaryAccountDefaultFolders, folderName);
                         }
                         mailFolderType = MailFolderType.TRASH;
                     } else {
                         if (isPrimaryAccount && translatePrimaryAccountDefaultFolders) {
                             if (fullName.equals(fullnameProvider.getConfirmedSpamFolder())) {
-                                localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.CONFIRMED_SPAM);
+                                localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.CONFIRMED_SPAM);
                             } else if (fullName.equals(fullnameProvider.getConfirmedHamFolder())) {
-                                localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.CONFIRMED_HAM);
+                                localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.CONFIRMED_HAM);
                             } else if (MailFolderStorage.isArchiveFolder(fullName, mailAccess, mailAccount)) {
-                                localizedName = StringHelper.valueOf(user.getLocale()).getString(MailStrings.ARCHIVE);
+                                localizedNameProvider = new CommonLocalizedNameProvider(MailStrings.ARCHIVE);
                             }
                         }
                     }
@@ -481,7 +508,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
         } else {
             mailFolderType = MailFolderType.NONE;
         }
-        return mailFolderType;
+        return new MailFolderTypeRetval(mailFolderType, localizedNameProvider);
     }
 
     private boolean isUnifiedMail(final MailFolder mailFolder) {
@@ -537,10 +564,13 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
         try {
             mailAccess = MailAccess.getInstance(userId, contextId, mailAccountId);
             mailAccess.connect(false);
-            final IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
-            if (folderStorage instanceof IMailFolderStorageEnhanced) {
-                return ((IMailFolderStorageEnhanced) folderStorage).getUnreadCounter(ensureFullName(fullName));
+            IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
+
+            IMailFolderStorageEnhanced storageEnhanced = folderStorage.supports(IMailFolderStorageEnhanced.class);
+            if (null != storageEnhanced) {
+                return storageEnhanced.getUnreadCounter(ensureFullName(fullName));
             }
+
             return mailAccess.getMessageStorage().getUnreadMessages(ensureFullName(fullName), MailSortField.RECEIVED_DATE, OrderDirection.DESC, FIELDS_ID, -1).length;
         } catch (final OXException e) {
             LOG.debug("Cannot return up-to-date unread counter.", e);
@@ -564,10 +594,13 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
         try {
             mailAccess = MailAccess.getInstance(userId, contextId, mailAccountId);
             mailAccess.connect(false);
-            final IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
-            if (folderStorage instanceof IMailFolderStorageEnhanced) {
-                return ((IMailFolderStorageEnhanced) folderStorage).getTotalCounter(ensureFullName(fullName));
+            IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
+
+            IMailFolderStorageEnhanced storageEnhanced = folderStorage.supports(IMailFolderStorageEnhanced.class);
+            if (null != storageEnhanced) {
+                return storageEnhanced.getTotalCounter(ensureFullName(fullName));
             }
+
             return mailAccess.getMessageStorage().searchMessages(ensureFullName(fullName), IndexRange.NULL, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS_ID).length;
         } catch (final OXException e) {
             LOG.debug("Cannot return up-to-date total counter.", e);
@@ -588,6 +621,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
             return new int[] { total, unread };
         }
 
+        // Live look-up of total/unread count
         if (null == optParams) {
             MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = null;
             try {
@@ -604,6 +638,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
                 closeMailAccess(mailAccess);
             }
         }
+
         // Look-up provided parameters
         try {
             final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = mailAccess(optParams);
@@ -618,25 +653,26 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
     }
 
     private int[] totalAndUnread(MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess) throws OXException {
-        final IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
-        if (folderStorage instanceof IMailFolderStorageEnhanced2) {
-            return ((IMailFolderStorageEnhanced2) folderStorage).getTotalAndUnreadCounter(ensureFullName(fullName));
+        IMailFolderStorage folderStorage = mailAccess.getFolderStorage();
+        String ensuredFullName = ensureFullName(fullName);
+
+        IMailFolderStorageEnhanced2 storageEnhanced2 = folderStorage.supports(IMailFolderStorageEnhanced2.class);
+        if (null != storageEnhanced2) {
+            return storageEnhanced2.getTotalAndUnreadCounter(ensuredFullName);
         }
-        final String ensuredFullName = ensureFullName(fullName);
+
         int unread, total;
-        if (folderStorage instanceof IMailFolderStorageEnhanced2) {
-            final IMailFolderStorageEnhanced2 storageEnhanced2 = (IMailFolderStorageEnhanced2) folderStorage;
-            final int[] tu = storageEnhanced2.getTotalAndUnreadCounter(ensureFullName(fullName));
-            total = null == tu ? -1 : tu[0];
-            unread = null == tu ? -1 : tu[1];
-        } else if (folderStorage instanceof IMailFolderStorageEnhanced) {
-            final IMailFolderStorageEnhanced storageEnhanced = (IMailFolderStorageEnhanced) folderStorage;
-            unread = storageEnhanced.getUnreadCounter(ensuredFullName);
-            total = storageEnhanced.getTotalCounter(ensuredFullName);
-        } else {
-            unread = mailAccess.getMessageStorage().getUnreadMessages(ensuredFullName, MailSortField.RECEIVED_DATE, OrderDirection.DESC, FIELDS_ID, -1).length;
-            total = mailAccess.getMessageStorage().searchMessages(ensuredFullName, IndexRange.NULL, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS_ID).length;
+        {
+            IMailFolderStorageEnhanced storageEnhanced = folderStorage.supports(IMailFolderStorageEnhanced.class);
+            if (null != storageEnhanced) {
+                unread = storageEnhanced.getUnreadCounter(ensuredFullName);
+                total = storageEnhanced.getTotalCounter(ensuredFullName);
+            } else {
+                unread = mailAccess.getMessageStorage().getUnreadMessages(ensuredFullName, MailSortField.RECEIVED_DATE, OrderDirection.DESC, FIELDS_ID, -1).length;
+                total = mailAccess.getMessageStorage().searchMessages(ensuredFullName, IndexRange.NULL, MailSortField.RECEIVED_DATE, OrderDirection.ASC, null, FIELDS_ID).length;
+            }
         }
+
         return new int[] { total, unread };
     }
 
@@ -685,7 +721,7 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
     public void setDefaultType(final int defaultType) {
         // Nothing to do
     }
-    
+
     /**
      * Sets the mail folder type
      *
@@ -712,8 +748,61 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
 
     @Override
     public String getLocalizedName(final Locale locale) {
-        final String localizedName = this.localizedName;
-        return null == localizedName ? name : localizedName;
+        LocalizedNameProvider localizedNameProvider = this.localizedNameProvider;
+        return null == localizedNameProvider ? name : localizedNameProvider.getLocalizedName(locale);
+    }
+
+    // --------------------------------------------------- i18n stuff ------------------------------------------------------------------------
+
+    private static final class MailFolderTypeRetval {
+
+        final MailFolderType mailFolderType;
+        final LocalizedNameProvider localizedNameProvider;
+
+        MailFolderTypeRetval(MailFolderType mailFolderType, LocalizedNameProvider localizedNameProvider) {
+            super();
+            this.mailFolderType = mailFolderType;
+            this.localizedNameProvider = localizedNameProvider;
+        }
+    }
+
+    private static interface LocalizedNameProvider extends Serializable {
+
+        String getLocalizedName(Locale locale);
+    }
+
+    private static final class StaticLocalizedNameProvider implements LocalizedNameProvider {
+
+        private static final long serialVersionUID = 7258965483623767051L;
+
+        private final String name;
+
+        StaticLocalizedNameProvider(String name) {
+            super();
+            this.name = name;
+        }
+
+        @Override
+        public String getLocalizedName(Locale locale) {
+            return name;
+        }
+    }
+
+    private static final class CommonLocalizedNameProvider implements LocalizedNameProvider {
+
+        private static final long serialVersionUID = -2733154469307477060L;
+
+        private final String key;
+
+        CommonLocalizedNameProvider(String key) {
+            super();
+            this.key = key;
+        }
+
+        @Override
+        public String getLocalizedName(Locale locale) {
+            return StringHelper.valueOf(locale).getString(key);
+        }
     }
 
 }
