@@ -63,9 +63,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.Permission;
-import com.openexchange.folderstorage.internal.Tools;
 import com.openexchange.folderstorage.mail.MailFolderType;
 import com.openexchange.folderstorage.virtual.osgi.Services;
+import com.openexchange.java.util.Tools;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.event.EventPool;
 import com.openexchange.mail.event.PooledEvent;
