@@ -49,15 +49,13 @@
 
 package com.openexchange.groupware.attach.json.actions;
 
+import org.json.JSONException;
 import org.json.JSONValue;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.parser.AttachmentParser.UnknownColumnException;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.writer.AttachmentWriter;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.attach.AttachmentBase;
 import com.openexchange.groupware.attach.AttachmentField;
@@ -79,15 +77,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(method = RequestMethod.GET, name = "all", description = "Get all Attachments for an Object.", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "attached", description = "The Object ID of the Object."),
-    @Parameter(name = "folder", description = "The Folder ID of the Object."),
-    @Parameter(name = "module", description = "The Module type of the Object."),
-    @Parameter(name = "columns", description = "A comma-separated list of columns to return. Each column is specified by a numeric column identifier. Column identifiers for attachment's are defined in Common object data (with only id, created_by and creation_date available) and Attachment object."),
-    @Parameter(name = "sort", optional=true, description = "The identifier of a column which determines the sort order of the response. If this parameter is specified, then the parameter order must be also specified."),
-    @Parameter(name = "order", optional=true, description = "\"asc\" if the response entires should be sorted in the ascending order, \"desc\" if the response entries should be sorted in the descending order. If this parameter is specified, then the parameter sort must be also specified.")
-}, responseDescription = "An array with attachment data. Each array element describes one attachment and is itself an array. The elements of each array contain the information specified by the corresponding identifiers in the columns parameter.")
 public final class AllAction extends AbstractAttachmentAction {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AllAction.class);
@@ -128,11 +117,11 @@ public final class AllAction extends AbstractAttachmentAction {
     }
 
     private JSONValue all(final ServerSession session, final int folderId, final int attachedId, final int moduleId, final AttachmentField[] fields, final AttachmentField sort, final int order) throws OXException {
-
         SearchIterator<AttachmentMetadata> iter = null;
-
+        boolean rollback = false;
         try {
             ATTACHMENT_BASE.startTransaction();
+            rollback = true;
 
             final Context ctx = session.getContext();
             final User user = session.getUser();
@@ -152,14 +141,14 @@ public final class AllAction extends AbstractAttachmentAction {
             aWriter.endTimedResult();
             // w.flush();
             ATTACHMENT_BASE.commit();
+            rollback = false;
             return w.getObject();
-        } catch (final Throwable t) {
-            rollback();
-            if (t instanceof OXException) {
-                throw (OXException) t;
-            }
-            throw new OXException(t);
+        } catch (JSONException e) {
+            throw new OXException(e);
         } finally {
+            if (rollback) {
+                rollback();
+            }
             try {
                 ATTACHMENT_BASE.finish();
             } catch (final OXException e) {
