@@ -54,15 +54,15 @@ import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.groupware.attach.AttachmentFilestoreLocationUpdater;
 import com.openexchange.groupware.attach.impl.AttachmentBaseImpl;
 import com.openexchange.groupware.attach.impl.AttachmentQuotaProvider;
 import com.openexchange.groupware.attach.json.AttachmentActionFactory;
-import com.openexchange.groupware.filestore.FilestoreLocationUpdater;
+import com.openexchange.groupware.filestore.FileLocationHandler;
 import com.openexchange.osgi.DependentServiceRegisterer;
 import com.openexchange.quota.QuotaProvider;
 import com.openexchange.server.ExceptionOnAbsenceServiceLookup;
-import com.openexchange.tools.file.external.QuotaFileStorageFactory;
 
 /**
  * {@link AttachmentActivator}
@@ -85,7 +85,7 @@ public final class AttachmentActivator extends AJAXModuleActivator {
         /*
          * register attachment filestore location updater for move context filestore
          */
-        registerService(FilestoreLocationUpdater.class, new AttachmentFilestoreLocationUpdater());
+        registerService(FileLocationHandler.class, new AttachmentFilestoreLocationUpdater());
         registerModule(new AttachmentActionFactory(new ExceptionOnAbsenceServiceLookup(this)), "attachment");
         DependentServiceRegisterer<QuotaProvider> quotaProviderRegisterer = new DependentServiceRegisterer<QuotaProvider>(
             context,
@@ -95,7 +95,7 @@ public final class AttachmentActivator extends AJAXModuleActivator {
             DatabaseService.class,
             ContextService.class,
             ConfigViewFactory.class,
-            QuotaFileStorageFactory.class) {
+            QuotaFileStorageService.class) {
 
             @Override
             protected void register() {
