@@ -49,6 +49,7 @@
 
 package com.openexchange.groupware.container.mail;
 
+import static com.openexchange.mail.mime.filler.MimeMessageFiller.getMailerInfo;
 import static com.openexchange.mail.mime.utils.MimeMessageUtility.parseAddressList;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -97,7 +98,6 @@ import com.openexchange.mail.transport.MailTransport;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
-import com.openexchange.version.Version;
 
 /**
  * MailObject
@@ -403,7 +403,7 @@ public class MailObject {
 
     private final static String HEADER_XOXREMINDER = "X-OX-Reminder";
 
-    private final static String VALUE_PRIORITYNROM = "3 (normal)";
+    private final static String VALUE_PRIORITYNORM = "3 (normal)";
 
     private final static String HEADER_ORGANIZATION = "Organization";
 
@@ -541,11 +541,11 @@ public class MailObject {
             /*
              * Set priority
              */
-            msg.setHeader(HEADER_XPRIORITY, VALUE_PRIORITYNROM);
+            msg.setHeader(HEADER_XPRIORITY, VALUE_PRIORITYNORM);
             /*
-             * Set mailer TODO: Read in mailer from file
+             * Set mailer
              */
-            msg.setHeader(HEADER_X_MAILER, "Open-Xchange Mailer v" + Version.getInstance().getVersionString());
+            msg.setHeader(HEADER_X_MAILER, getMailerInfo());
             /*
              * Set organization
              */
