@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,6 +64,10 @@ public class ContextExceptionMessage implements LocalizableStrings {
     public final static String NO_CONNECTION_TO_CONTEXT_MSG = "Could not connect to the context storage.";
     public final static String NO_MAPPING_MSG = "The account \"%1$s\" was not found.";
 
+    // This exception is triggered by concurrent requests of clients trying to modify the same user attributes in the same moment.
+    // This should happen in very rare conditions and is not visible to the client.
+    public static final String CONCURRENT_ATTRIBUTES_UPDATE_DISPLAY = "Denied concurrent update of user attributes.";
+
     /**
      * Initializes a new {@link ContextExceptionMessage}.
      */
