@@ -84,6 +84,7 @@ import com.openexchange.groupware.infostore.webdav.PropertyStoreImpl;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskV2;
 import com.openexchange.jslob.shared.SharedJSlobService;
+import com.openexchange.management.ManagementService;
 import com.openexchange.server.services.SharedInfostoreJSlob;
 
 /**
@@ -104,6 +105,7 @@ public class InfostoreActivator implements BundleActivator {
     private volatile ServiceTracker<FileStorageServiceRegistry, FileStorageServiceRegistry> tracker;
     private volatile ServiceTracker<ConfigurationService, ConfigurationService> configTracker;
     private volatile ServiceTracker<QuotaFileStorageService, QuotaFileStorageService> qfsTracker;
+    private volatile ServiceTracker<ManagementService, ManagementService> mgmtTracker;
 
     @Override
     public void start(final BundleContext context) throws Exception {
@@ -217,6 +219,10 @@ public class InfostoreActivator implements BundleActivator {
             this.qfsTracker = qfsTracker;
             qfsTracker.open();
 
+            ServiceTracker<ManagementService, ManagementService> mgmtTracker = new ServiceTracker<ManagementService, ManagementService>(context, ManagementService.class, new ManagementTracker(context));
+            this.mgmtTracker = mgmtTracker;
+            mgmtTracker.open();
+
         } catch (final Exception e) {
             final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(InfostoreActivator.class);
             logger.error("Starting InfostoreActivator failed.", e);
@@ -227,6 +233,12 @@ public class InfostoreActivator implements BundleActivator {
     @Override
     public void stop(final BundleContext context) throws Exception {
         try {
+            ServiceTracker<ManagementService, ManagementService> mgmtTracker = this.mgmtTracker;
+            if (null != mgmtTracker) {
+                mgmtTracker.close();
+                this.mgmtTracker = null;
+            }
+
             ServiceTracker<FileStorageServiceRegistry, FileStorageServiceRegistry> tracker = this.tracker;
             if (null != tracker) {
                 tracker.close();
