@@ -68,6 +68,7 @@ import com.openexchange.database.DatabaseService;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorage;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
@@ -139,7 +140,7 @@ public class FileMD5SumHelper {
         Collection<Integer> databaseIds;
         Connection connection = dbSerivce.getReadOnly();
         try {
-            databaseIds = getDatabaseIds(connection);
+            databaseIds = dbSerivce.getAllSchemata(connection).values();
         } finally {
             dbSerivce.backReadOnly(connection);
         }
@@ -232,7 +233,7 @@ public class FileMD5SumHelper {
         Collection<Integer> databaseIds;
         Connection connection = dbSerivce.getReadOnly();
         try {
-            databaseIds = getDatabaseIds(connection);
+            databaseIds = dbSerivce.getAllSchemata(connection).values();
         } finally {
             dbSerivce.backReadOnly(connection);
         }
@@ -296,7 +297,7 @@ public class FileMD5SumHelper {
     }
 
     private FileStorage getFileStorage(int contextId, int userId) throws OXException {
-        return fsService.getQuotaFileStorage(userId, contextId);
+        return fsService.getQuotaFileStorage(userId, contextId, Info.drive());
     }
 
     private static Map<Integer, List<DocumentMetadata>> getDocumentsPerOwner(Connection connection, int contextId, List<DocumentMetadata> documents) throws SQLException {
@@ -391,19 +392,6 @@ public class FileMD5SumHelper {
         }
     }
 
-    private static Collection<Integer> getDatabaseIds(Connection connection) throws OXException {
-        List<Integer> databaseIds = new ArrayList<>();
-        try (PreparedStatement stmt = connection.prepareStatement("SELECT DISTINCT read_db_pool_id FROM context_server2db_pool GROUP BY db_schema;");
-            ResultSet result = stmt.executeQuery()) {
-            while (result.next()) {
-                databaseIds.add(Integer.valueOf(result.getInt(1)));
-            }
-        } catch (SQLException e) {
-            throw new OXException(e);
-        }
-        return databaseIds;
-    }
-
     private static <K, V> boolean put(Map<K, List<V>> multiMap, K key, V value) {
         List<V> values = multiMap.get(key);
         if (null == values) {
