@@ -184,4 +184,14 @@ public class GetSwitch implements MetadataSwitcher {
         return metadata.getNumberOfVersions();
     }
 
+    @Override
+    public Object objectPermissions() {
+        return metadata.getObjectPermissions();
+    }
+
+    @Override
+    public Object shareable() {
+        return metadata.isShareable();
+    }
+
 }
