@@ -365,6 +365,7 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.mail.Colorquoted.class,
             com.openexchange.groupware.settings.tree.modules.mail.DefaultAddress.class,
             com.openexchange.groupware.settings.tree.modules.mail.DefaultSeparator.class,
+            com.openexchange.groupware.settings.tree.modules.mail.DeleteDraftOnTransport.class,
             com.openexchange.groupware.settings.tree.modules.mail.DeleteMail.class,
             com.openexchange.groupware.settings.tree.modules.mail.SaveNoCopy.class,
             com.openexchange.groupware.settings.tree.modules.mail.DisplayReceiptNotification.class,
@@ -376,15 +377,23 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.mail.folder.Sent.class,
             com.openexchange.groupware.settings.tree.modules.mail.folder.Spam.class,
             com.openexchange.groupware.settings.tree.modules.mail.folder.Trash.class,
+            com.openexchange.groupware.settings.tree.modules.mail.folder.Archive.class,
             com.openexchange.groupware.settings.tree.modules.mail.ForwardMessage.class,
             com.openexchange.groupware.settings.tree.modules.mail.GUI.class,
             com.openexchange.groupware.settings.tree.modules.mail.InlineAttachments.class,
             com.openexchange.groupware.settings.tree.modules.mail.LineWrap.class,
+            com.openexchange.groupware.settings.tree.modules.mail.UploadQuotaPerFile.class,
+            com.openexchange.groupware.settings.tree.modules.mail.UploadQuotaTotal.class,
+            com.openexchange.groupware.settings.tree.modules.mail.MailColorModePreferenceItem.class,
+            com.openexchange.groupware.settings.tree.modules.mail.MailFlaggedModePreferenceItem.class,
+            com.openexchange.groupware.settings.tree.modules.mail.MaliciousCheck.class,
+            com.openexchange.groupware.settings.tree.modules.mail.MaliciousListing.class,
+            com.openexchange.groupware.settings.tree.modules.mail.AllMessagesFolder.class,
+            com.openexchange.groupware.settings.tree.modules.mail.Whitelist.class,
             com.openexchange.groupware.settings.tree.modules.mail.Module.class,
             com.openexchange.groupware.settings.tree.modules.mail.MsgFormat.class,
             com.openexchange.groupware.settings.tree.modules.mail.Namespace.class,
             com.openexchange.groupware.settings.tree.modules.mail.DefaultArchiveDays.class,
-            com.openexchange.groupware.settings.tree.modules.mail.EnforceSecureConnection.class,
             com.openexchange.groupware.settings.tree.modules.mail.PhishingHeaders.class,
             com.openexchange.groupware.settings.tree.modules.mail.MailProtocols.class,
             com.openexchange.groupware.settings.tree.modules.mail.ReplyAllCc.class,
