@@ -631,9 +631,16 @@ public final class InternalList {
         // Extends the "password" column for "user_mail_account" and "user_transport_account" tables
         list.add(new com.openexchange.groupware.update.tasks.MailAccountExtendPasswordTask());
 
+        // +++++++++++++++++++++++++++++++++ Version 7.8.4 starts here. +++++++++++++++++++++++++++++++++
+
+        list.add(new com.openexchange.groupware.update.tasks.ChangePrimaryKeyForUserAttribute());
+
         // Drops rather needless foreign keys from tables.
         list.add(new com.openexchange.groupware.update.tasks.DropFKTaskv3());
 
+        // Adds several columns to "user_mail_account" and "user_transport_account" tables for tracking/managing failed authentication attempts.
+        list.add(new com.openexchange.groupware.update.tasks.AddFailedAuthColumnsToMailAccountTablesTask());
+
         // +++++++++++++++++++++++++++++++++ Version 7.10.0 starts here. +++++++++++++++++++++++++++++++++
 
         // Extends uidl column of the pop3_storage_ids and pop3_storage_deleted tables
