@@ -50,6 +50,7 @@
 package com.openexchange.groupware.update.internal;
 
 import java.util.Collection;
+import java.util.Date;
 import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.SchemaStore;
@@ -68,10 +69,23 @@ import com.openexchange.timer.TimerService;
  */
 public class UpdaterImpl extends Updater {
 
+    private static final UpdaterImpl INSTANCE = new UpdaterImpl();
+
+    /**
+     * Gets the instance
+     *
+     * @return The instance
+     */
+    public static UpdaterImpl getInstance() {
+        return INSTANCE;
+    }
+
+    // ------------------------------------------------------------------------------------------------------------------------ //
+
     /**
      * Default constructor.
      */
-    public UpdaterImpl() {
+    private UpdaterImpl() {
         super();
     }
 
@@ -105,12 +119,26 @@ public class UpdaterImpl extends Updater {
                 return schema.backgroundUpdatesRunning();
             }
             @Override
+            public Date blockingUpdatesRunningSince() {
+                return schema.blockingUpdatesRunningSince();
+            }
+            @Override
+            public Date backgroundUpdatesRunningSince() {
+                return schema.backgroundUpdatesRunningSince();
+            }
+            @Override
             public boolean isExecutedSuccessfully(String taskName) {
                 return schema.isExecutedSuccessfully(taskName);
             }
         };
     }
 
+    @Override
+    public void unblock(String schemaName, int poolId, int contextId) throws OXException {
+        SchemaUpdateState schema = SchemaStore.getInstance().getSchema(poolId, schemaName);
+        SchemaStore.getInstance().unlockSchema(schema, contextId, false);
+    }
+
     @Override
     public void startUpdate(final int contextId) throws OXException {
         final TimerService timerService = ServerServiceRegistry.getInstance().getService(TimerService.class, true);
