@@ -65,6 +65,7 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.http.HttpServletRequest;
+import org.apache.commons.fileupload.FileItemHeaders;
 import org.apache.commons.fileupload.FileItemIterator;
 import org.apache.commons.fileupload.FileItemStream;
 import org.apache.commons.fileupload.FileUploadBase;
@@ -85,6 +86,7 @@ import com.openexchange.groupware.upload.UploadFile;
 import com.openexchange.groupware.upload.UploadFileListener;
 import com.openexchange.java.Streams;
 import com.openexchange.java.util.UUIDs;
+import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MimeType2ExtMap;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -171,12 +173,21 @@ public final class UploadUtility {
         int pos = 0;
         double decSize = size;
         final int base = realSize ? 1024 : 1000;
-        while (decSize > base) {
+        while (decSize >= base) {
             decSize /= base;
             pos++;
         }
-        final int num = (int) Math.pow(10, precision);
-        final StringBuilder sb = new StringBuilder(8).append(((Math.round(decSize * num)) / (double) num)).append(' ');
+
+        StringBuilder sb = new StringBuilder(8);
+        int num = (int) Math.pow(10, precision);
+        double value = (Math.round(decSize * num)) / (double) num;
+        if (precision <= 0) {
+            sb.append((int) value);
+        } else {
+            sb.append(value);
+        }
+        sb.append(' ');
+
         if (longName) {
             sb.append(getSizePrefix(pos)).append("bytes");
         } else {
@@ -309,7 +320,8 @@ public final class UploadUtility {
                 upload.setHeaderEncoding(defaultEnc);
             }
             // Parse multipart request
-            iter = upload.getItemIterator(req);
+            ServletRequestContext requestContext = new ServletRequestContext(req);
+            iter = upload.getItemIterator(requestContext);
         } catch (FileSizeLimitExceededException e) {
             throw UploadFileSizeExceededException.create(e.getActualSize(), e.getPermittedSize(), true);
         } catch (SizeLimitExceededException e) {
@@ -459,15 +471,30 @@ public final class UploadUtility {
         retval.setFieldName(item.getFieldName());
         retval.setFileName(fileName);
 
+        FileItemHeaders headers = item.getHeaders();
+        String contentId = headers.getHeader("Content-Id");
+        retval.setContentId(contentId);
+
         // Deduce MIME type from passed file name
         String mimeType = MimeType2ExtMap.getContentType(fileName, null);
 
         // Set associated MIME type
         {
             // Check if we are forced to select the MIME type as signaled by file item
-            String forcedMimeType = item.getHeaders().getHeader("X-Forced-MIME-Type");
+            String forcedMimeType = headers.getHeader("X-Forced-MIME-Type");
             if (null == forcedMimeType) {
-                retval.setContentType(null == mimeType ? item.getContentType() : mimeType);
+                String itemContentType = item.getContentType();
+                ContentType contentType = getContentTypeSafe(itemContentType);
+                if (null == contentId && contentType != null) {
+                    contentId = contentType.getParameter("cid");
+                    retval.setContentId(contentId);
+                }
+
+                if (null == contentType) {
+                    retval.setContentType(null == mimeType ? itemContentType : mimeType);
+                } else {
+                    retval.setContentType(contentType.getBaseType());
+                }
             } else if (AJAXRequestDataTools.parseBoolParameter(forcedMimeType)) {
                 retval.setContentType(item.getContentType());
             } else {
@@ -566,6 +593,19 @@ public final class UploadUtility {
         return retval;
     }
 
+    private static ContentType getContentTypeSafe(String contentType) {
+        if (null == contentType) {
+            return null;
+        }
+
+        try {
+            return new ContentType(contentType);
+        } catch (Exception e) {
+            LOG.debug("MIME type could not be parsed", e);
+            return null;
+        }
+    }
+
     private static void startUploadEvicterIfNotYetDone() {
         ScheduledTimerTask timerTask = TIMER_TASK_REFERENCE.get();
         if (null == timerTask) {
