@@ -57,7 +57,6 @@ import java.util.HashSet;
 import java.util.Set;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.java.Strings;
 
 /**
  * {@link UserConfiguration} - Represents a user configuration.
@@ -485,7 +484,7 @@ public class UserConfiguration implements Serializable, Cloneable {
      * @return <code>true</code> if conflict handling is allowed; otherwise <code>false</code>
      */
     public boolean hasConflictHandling() {
-        return hasCalendar() && hasFullSharedFolderAccess() && hasFullPublicFolderAccess();
+        return hasCalendar();
     }
 
     /**
@@ -494,7 +493,7 @@ public class UserConfiguration implements Serializable, Cloneable {
      * @return <code>true</code> if the user configuration allows the participant dialog.
      */
     public boolean hasParticipantsDialog() {
-        return hasConflictHandling();
+        return hasCalendar() && hasFullSharedFolderAccess() && hasFullPublicFolderAccess();
     }
 
     /**
@@ -771,7 +770,10 @@ public class UserConfiguration implements Serializable, Cloneable {
      * Gets the extended permissions.
      *
      * @return The extended permissions
+     * @deprecated Might return incomplete capabilities as capabilities are loaded by user/context identifier pair not providing further
+     * session attributes
      */
+    @Deprecated
     public Set<String> getExtendedPermissions() {
         return capabilities;
     }
