@@ -52,6 +52,8 @@ package com.openexchange.image;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.atomic.AtomicReference;
+import com.openexchange.java.Strings;
 
 /**
  * {@link ImageLocation} - An image location description.
@@ -75,6 +77,7 @@ public final class ImageLocation {
         protected String timestamp;
         protected String optImageHost;
         protected String registrationName;
+        protected String auth;
 
         public Builder() {
             super();
@@ -111,9 +114,13 @@ public final class ImageLocation {
         public Builder registrationName(final String registrationName) {
             this.registrationName = registrationName; return this;
         }
+        public Builder auth(final String auth) {
+            this.auth = auth; return this;
+        }
         public String getRegistrationName() {
             return registrationName;
         }
+
         public ImageLocation build() {
             return new ImageLocation(this);
         }
@@ -125,6 +132,7 @@ public final class ImageLocation {
     private final String imageId;
     private final String timestamp;
     private final String optImageHost;
+    private final AtomicReference<String> authRef;
     private final ConcurrentMap<String, Object> properties;
 
     /**
@@ -141,6 +149,7 @@ public final class ImageLocation {
         this.imageId = builder.imageId;
         this.timestamp = builder.timestamp;
         this.optImageHost = builder.optImageHost;
+        this.authRef = new AtomicReference<String>(builder.auth);
     }
 
     /**
@@ -263,6 +272,25 @@ public final class ImageLocation {
         return imageId;
     }
 
+    /**
+     * Gets any authentication token for an encrypted image
+     *
+     * @return The authentication token or <code>null</code>
+     */
+    public String getAuth() {
+        String auth = authRef.get();
+        return Strings.isEmpty(auth) ? null : auth;
+    }
+
+    /**
+     * Sets the authentication token for an encrypted image
+     *
+     * @param auth The authentication token
+     */
+    public void setAuth (String auth) {
+        this.authRef.set(auth);
+    }
+
     /**
      * Gets the registration name
      *
@@ -303,6 +331,10 @@ public final class ImageLocation {
         if (properties != null && !properties.isEmpty()) {
             builder.append("properties=").append(properties);
         }
+        String auth = authRef.get();
+        if (false == Strings.isEmpty(auth)) {
+            builder.append("auth=").append(auth);
+        }
         builder.append(']');
         return builder.toString();
     }
