@@ -60,13 +60,19 @@ import org.slf4j.Logger;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.AJAXUtility;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
+import com.openexchange.ajax.requesthandler.oauth.OAuthConstants;
 import com.openexchange.dispatcher.DispatcherPrefixService;
+import com.openexchange.exception.OXException;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.groupware.notify.hostname.HostnameService;
+import com.openexchange.image.osgi.Services;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
+import com.openexchange.session.Sessions;
 import jonelo.jacksum.JacksumAPI;
 import jonelo.jacksum.algorithm.AbstractChecksum;
 import jonelo.jacksum.algorithm.MD;
@@ -217,9 +223,22 @@ public final class ImageUtility {
         final String id = requestData.getParameter(AJAXServlet.PARAMETER_ID);
         final String imageId = requestData.getParameter(AJAXServlet.PARAMETER_UID);
         final String timestamp = requestData.getParameter(AJAXServlet.PARAMETER_TIMESTAMP);
+
+        String auth = null;
+        {
+            ServiceLookup services = Services.getServiceLookup();
+            CryptographicServiceAuthenticationFactory cryptoService = null == services ? null : services.getOptionalService(CryptographicServiceAuthenticationFactory.class);
+            if (cryptoService != null) {
+                try {
+                    auth = cryptoService.createAuthenticationFrom(requestData);
+                } catch (OXException e) {
+                    LOGGER.error("Problem creating authentication token ", e);
+                }
+            }
+        }
         String registrationName = requestData.getParameter("source");
 
-        final ImageLocation il = new ImageLocation.Builder(imageId).accountId(accountId).folder(folder).id(id).timestamp(timestamp).build();
+        final ImageLocation il = new ImageLocation.Builder(imageId).accountId(accountId).folder(folder).id(id).timestamp(timestamp).auth(auth).build();
         if (null == registrationName) {
             registrationName = ImageActionFactory.getRegistrationNameFor(requestData.getSerlvetRequestURI());
             if (null == registrationName) {
@@ -335,20 +354,19 @@ public final class ImageUtility {
          */
         sb.append(prefix.endsWith("/") ? prefix.substring(0, prefix.length() - 1) : prefix);
         sb.append(getDispatcherPrefix());
+        boolean isOAuthSession = Sessions.isOAuthSession(session);
+        if (isOAuthSession) {
+            sb.append(OAuthConstants.OAUTH_SERVLET_SUBPREFIX);
+        }
         sb.append(ImageDataSource.ALIAS_APPENDIX);
         final String alias = imageDataSource.getAlias();
         if (null != alias) {
             sb.append(alias);
         }
-        if (optImageHostSet) {
+        if (optImageHostSet || isOAuthSession || addRoute(addRoute, imageLocation)) {
             if (null != httpSessionID) {
                 sb.append(";jsessionid=").append(httpSessionID);
             }
-        } else if (addRoute ) {
-            final Boolean noRoute = (Boolean) imageLocation.getProperty(ImageLocation.PROPERTY_NO_ROUTE);
-            if ((null == noRoute || !noRoute.booleanValue()) && null != httpSessionID) {
-                sb.append(";jsessionid=").append(httpSessionID);
-            }
         }
         boolean first = true;
         if (null != publicSessionId) {
@@ -389,6 +407,22 @@ public final class ImageUtility {
         }
     }
 
+    /**
+     * Checks whether JVM route is supposed to be added to image URL
+     *
+     * @param addRoute The flag signaling whether JVM route is supposed to be added
+     * @param imageLocation The image location providing additional properties to consider
+     * @return <code>true</code> if JVM route is supposed to be added; otherwise <code>false</code>
+     */
+    private static boolean addRoute(boolean addRoute, ImageLocation imageLocation) {
+        if (addRoute) {
+            Boolean noRoute = (Boolean) imageLocation.getProperty(ImageLocation.PROPERTY_NO_ROUTE);
+            return (null == noRoute || false == noRoute.booleanValue());
+        }
+
+        return false;
+    }
+
     /**
      * Translates specified string into application/x-www-form-urlencoded format using a specific encoding scheme. This method uses the
      * supplied encoding scheme to obtain the bytes for unsafe characters.
