@@ -51,6 +51,7 @@ package com.openexchange.image.osgi;
 
 import java.util.Dictionary;
 import java.util.Hashtable;
+import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.conversion.DataSource;
 import com.openexchange.dispatcher.DispatcherPrefixService;
@@ -61,7 +62,12 @@ import com.openexchange.groupware.contact.datasource.UserImageDataSource;
 import com.openexchange.image.ImageActionFactory;
 import com.openexchange.image.ImageUtility;
 import com.openexchange.image.Mp3ImageDataSource;
+import com.openexchange.mail.api.crypto.CryptographicAwareMailAccessFactory;
 import com.openexchange.mail.conversion.InlineImageDataSource;
+import com.openexchange.mail.mime.crypto.PGPMailRecognizer;
+import com.openexchange.mail.service.EncryptedMailService;
+import com.openexchange.server.ExceptionOnAbsenceServiceLookup;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link ImageActivator}
@@ -70,6 +76,9 @@ import com.openexchange.mail.conversion.InlineImageDataSource;
  */
 public class ImageActivator extends AJAXModuleActivator {
 
+    /**
+     * Initializes a new {@link ImageActivator}.
+     */
     public ImageActivator() {
         super();
     }
@@ -79,11 +88,20 @@ public class ImageActivator extends AJAXModuleActivator {
         return new Class<?>[] { ManagedFileManagement.class, DispatcherPrefixService.class };
     }
 
+    @Override
+    protected Class<?>[] getOptionalServices() {
+        return new Class<?>[] { CryptographicServiceAuthenticationFactory.class, CryptographicAwareMailAccessFactory.class, EncryptedMailService.class, PGPMailRecognizer.class };
+    }
+
     @Override
     protected void startBundle() throws Exception {
+        final ServiceLookup serviceLookup = new ExceptionOnAbsenceServiceLookup(this);
+        Services.setServiceLookup(serviceLookup);
+
         ImageUtility.setDispatcherPrefixService(getService(DispatcherPrefixService.class));
         {
             InlineImageDataSource inlineDataSource = InlineImageDataSource.getInstance();
+            inlineDataSource.setServiceLookup(this);
             Dictionary<String, Object> inlineProps = new Hashtable<String, Object>(1);
             inlineProps.put("identifier", inlineDataSource.getRegistrationName());
             registerService(DataSource.class, inlineDataSource, inlineProps);
@@ -121,4 +139,10 @@ public class ImageActivator extends AJAXModuleActivator {
         registerModule(new ImageActionFactory(this), "image");
     }
 
+    @Override
+    protected void stopBundle() throws Exception {
+        Services.setServiceLookup(null);
+        super.stopBundle();
+    }
+
 }
