@@ -54,14 +54,10 @@ import static com.openexchange.ajax.requesthandler.AJAXRequestDataBuilder.reques
 import static com.openexchange.login.LoginRampUpConfig.getConfig;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
 import java.util.Iterator;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
-import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
@@ -70,7 +66,6 @@ import org.json.JSONArray;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import com.google.common.collect.ImmutableList;
-import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.Dispatcher;
@@ -80,7 +75,6 @@ import com.openexchange.ajax.writer.ResponseWriter;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXExceptions;
-import com.openexchange.java.Strings;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.osgi.ExceptionUtils;
@@ -128,84 +122,6 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
         }
     }
 
-    public static interface Contribution {
-
-        /**
-         * Gets the key of this contribution.
-         * <p>
-         * Must not be one of {@link RampUpKey reserved keys}.
-         *
-         * @return The key
-         */
-        String getKey();
-
-        /**
-         * Gets the result object.
-         *
-         * @param session The session providing user information
-         * @param loginRequest The login request
-         * @return The result object
-         * @throws OXException If result object cannot be returned
-         */
-        Object getResult(ServerSession session, AJAXRequestData loginRequest) throws OXException;
-    }
-
-    public static abstract class AbstractDispatcherContribution implements Contribution {
-
-        private final Dispatcher ox;
-
-        /**
-         * Initializes a new {@link DefaultAppSuiteLoginRampUp.AbstractDispatcherContribution}.
-         */
-        protected AbstractDispatcherContribution(Dispatcher ox) {
-            super();
-            this.ox = ox;
-        }
-
-        @Override
-        public Object getResult(ServerSession session, AJAXRequestData loginRequest) throws OXException {
-            AJAXRequestResult requestResult = null;
-            Exception exc = null;
-            try {
-                AJAXRequestData requestData = request().session(session).module(getModule()).action(getAction()).params(getParams()).format("json").build(loginRequest);
-                requestResult = ox.perform(requestData, null, session);
-                return requestResult.getResultObject();
-            } catch (OXException x) {
-                // Omit result on error. Let the UI deal with this
-                exc = x;
-                throw x;
-            } catch (RuntimeException x) {
-                // Omit result on error. Let the UI deal with this
-                exc = x;
-                throw x;
-            } finally {
-                Dispatchers.signalDone(requestResult, exc);
-            }
-        }
-
-        /**
-         * Gets the parameters to pass to dispatcher action
-         *
-         * @return The parameters
-         */
-        protected abstract String[] getParams();
-
-        /**
-         * Gets the action to call
-         *
-         * @return The action
-         */
-        protected abstract String getAction();
-
-        /**
-         * Gets the dispatcher module
-         *
-         * @return The module
-         */
-        protected abstract String getModule();
-
-    }
-
     // ------------------------------------------------------------------------------------------------------------------------------------------------------ //
 
     /** The service look-up */
@@ -235,8 +151,6 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
     static void handleException(OXException e, String key, ConcurrentMap<String, OXException> errors) {
         if (OXExceptions.isCategory(Category.CATEGORY_PERMISSION_DENIED, e)) {
             LOG.debug("Permission error during {} ramp-up", key, e);
-        } else if (OXExceptions.isCategory(Category.CATEGORY_USER_INPUT, e)) {
-            LOG.debug("Error during {} ramp-up", key, e);
         } else {
             LOG.error("Error during {} ramp-up", key, e);
         }
@@ -253,28 +167,16 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
 
     /** The ramp-up keys. Keep order! */
     private static final List<RampUpKey> KEYS;
-    private static final Set<String> RESERVED;
     static {
         RampUpKey[] values = RampUpKey.values();
-        ImmutableList.Builder<RampUpKey> keys = ImmutableList.builder();
-        ImmutableSet.Builder<String> reserved = ImmutableSet.builder();
+        int len = values.length;
+        List<RampUpKey> keys = new ArrayList<>(len);
         for (RampUpKey rampUpKey : values) {
             if (RampUpKey.ERRORS != rampUpKey) {
                 keys.add(rampUpKey);
             }
-            reserved.add(Strings.asciiLowerCase(rampUpKey.key));
         }
-        KEYS = keys.build();
-        RESERVED = reserved.build();
-    }
-
-    /**
-     * Gets extended contributions
-     *
-     * @return The extended contributions
-     */
-    protected Collection<Contribution> getExtendedContributions() {
-        return Collections.emptyList();
+        KEYS = ImmutableList.copyOf(keys);
     }
 
     /**
@@ -594,41 +496,9 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
 
         }));
 
-        // Check for extended contributions
-        List<String> extendedKeys = null;
-        {
-            Collection<Contribution> contributions = getExtendedContributions();
-            if (null != contributions && false == contributions.isEmpty()) {
-                extendedKeys = new ArrayList<>(contributions.size());
-                for (final Contribution contribution : contributions) {
-                    if (RESERVED.contains(Strings.asciiLowerCase(contribution.getKey()))) {
-                        // Illegal key... Ignore
-                    } else {
-                        rampUps.put(contribution.getKey(), threads.submit(new AbstractTrackableTask<Object>() {
-
-                            @Override
-                            public Object call() throws Exception {
-                                try {
-                                    return contribution.getResult(session, loginRequest);
-                                } catch (OXException x) {
-                                    // Omit result on error. Let the UI deal with this
-                                    handleException(x, contribution.getKey(), errors);
-                                } catch (RuntimeException x) {
-                                    // Omit result on error. Let the UI deal with this
-                                    handleException(x, contribution.getKey());
-                                }
-                                return null;
-                            }
-                        }));
-                        extendedKeys.add(contribution.getKey());
-                    }
-                }
-            }
-        }
-
         try {
             // Grab tasks to complete in preserved order
-            List<RampUpFuture> taskCompletions = new LinkedList<>();
+            List<RampUpFuture> taskCompletions = new ArrayList<>(numberOfKeys);
             for (RampUpKey rampUpKey : KEYS) {
                 Future<Object> taskCompletion = rampUps.get(rampUpKey.key);
                 if (null != taskCompletion) {
@@ -636,15 +506,6 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
                 }
             }
 
-            if (null != extendedKeys) {
-                for (String extendedKey : extendedKeys) {
-                    Future<Object> taskCompletion = rampUps.get(extendedKey);
-                    if (null != taskCompletion) {
-                        taskCompletions.add(new RampUpFuture(extendedKey, taskCompletion));
-                    }
-                }
-            }
-
             // Let tasks contribute to JSON object
             JSONObject jo = new JSONObject(numberOfKeys);
             Iterator<RampUpFuture> tasksToWaitFor = taskCompletions.iterator();
@@ -693,23 +554,17 @@ public abstract class DefaultAppSuiteLoginRampUp implements LoginRampUpService {
 
     private static final class RampUpFuture {
 
-        private final String key;
+        private final RampUpKey rampUpKey;
         private final Future<Object> rampUpTask;
 
         RampUpFuture(RampUpKey rampUpKey, Future<Object> rampUpTask) {
             super();
-            this.key = rampUpKey.key;
-            this.rampUpTask = rampUpTask;
-        }
-
-        RampUpFuture(String key, Future<Object> rampUpTask) {
-            super();
-            this.key = key;
+            this.rampUpKey = rampUpKey;
             this.rampUpTask = rampUpTask;
         }
 
         String getKey() {
-            return key;
+            return rampUpKey.key;
         }
 
         boolean cancel(boolean mayInterruptIfRunning) {
