@@ -68,6 +68,7 @@ import com.openexchange.authentication.ResultCode;
 import com.openexchange.authentication.SessionEnhancement;
 import com.openexchange.authorization.Authorization;
 import com.openexchange.authorization.AuthorizationService;
+import com.openexchange.configuration.ServerProperty;
 import com.openexchange.database.DBPoolingExceptionCodes;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
@@ -102,6 +103,7 @@ import com.openexchange.threadpool.ThreadPoolCompletionService;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.threadpool.behavior.CallerRunsBehavior;
+import com.openexchange.user.UserService;
 
 /**
  * {@link LoginPerformer} - Performs a login for specified credentials.
@@ -114,13 +116,6 @@ public final class LoginPerformer {
 
     private static final LoginPerformer SINGLETON = new LoginPerformer();
 
-    /**
-     * Initializes a new {@link LoginPerformer}.
-     */
-    private LoginPerformer() {
-        super();
-    }
-
     /**
      * Gets the {@link LoginPerformer} instance.
      *
@@ -130,6 +125,15 @@ public final class LoginPerformer {
         return SINGLETON;
     }
 
+    // -----------------------------------------------------------------------------------------------------------------
+
+    /**
+     * Initializes a new {@link LoginPerformer}.
+     */
+    private LoginPerformer() {
+        super();
+    }
+
     /**
      * Performs the login for specified login request.
      *
@@ -261,10 +265,15 @@ public final class LoginPerformer {
                 authService.authorizeUser(ctx, user);
             }
             if (storeLanguage && !Strings.isEmpty(userLoginLanguage) && !userLoginLanguage.equals(user.getPreferredLanguage())) {
-                UserStorage us = UserStorage.getInstance();
                 UserImpl impl = new UserImpl(user);
                 impl.setPreferredLanguage(userLoginLanguage);
-                us.updateUser(impl, ctx);
+                UserService userService = ServerServiceRegistry.getInstance().getService(UserService.class);
+                if (null != userService) {
+                    userService.updateUser(impl, ctx);
+                } else {
+                    LOG.warn("Unable to access user service, updating directly via storage.", ServiceExceptionCode.absentService(UserService.class));
+                    UserStorage.getInstance().updateUser(impl, ctx);
+                }
                 user = impl;
             }
             retval.setContext(ctx);
@@ -470,28 +479,38 @@ public final class LoginPerformer {
                 throw ServiceExceptionCode.absentService(SessiondService.class);
             }
         }
-        final Session session = sessiondService.getSession(sessionId);
+
+        // Obtain session
+        Session session = sessiondService.getSession(sessionId);
         if (null == session) {
             LOG.debug("No session found for ID: {}", sessionId);
             return null;
         }
+
         // Get context
-        final ContextStorage contextStor = ContextStorage.getInstance();
-        final Context context;
-        context = contextStor.getContext(session.getContextId());
-        if (null == context) {
-            throw ContextExceptionCodes.NOT_FOUND.create(Integer.valueOf(session.getContextId()));
+        Context context;
+        {
+            ContextStorage contextStor = ContextStorage.getInstance();
+            context = contextStor.getContext(session.getContextId());
+            if (null == context) {
+                throw ContextExceptionCodes.NOT_FOUND.create(Integer.valueOf(session.getContextId()));
+            }
         }
+
         // Get user
-        final User u;
+        User user;
         {
             final UserStorage us = UserStorage.getInstance();
-            u = us.getUser(session.getUserId(), context);
+            user = us.getUser(session.getUserId(), context);
         }
-        final LoginResultImpl logout = new LoginResultImpl(session, context, u);
+
         // Remove session
         sessiondService.removeSession(sessionId);
+
+        // Log logout performed
+        LoginResultImpl logout = new LoginResultImpl(session, context, user);
         logLogout(logout);
+
         // Trigger registered logout handlers
         triggerLogoutHandlers(logout);
         return session;
@@ -677,7 +696,8 @@ public final class LoginPerformer {
             String login = null == session ? request.getLogin() : session.getLoginName();
             if (null != login) {
                 String client = request.getClient();
-                auditLogService.log("ox.login", DefaultAttribute.valueFor(Name.LOGIN, login, 256), DefaultAttribute.valueFor(Name.IP_ADDRESS, request.getClientIP()), DefaultAttribute.timestampFor(new Date()), DefaultAttribute.valueFor(Name.CLIENT, null == client ? "<none>" : client));
+                String sessionId = null == session ? null : session.getSessionID();
+                auditLogService.log("ox.login", DefaultAttribute.valueFor(Name.LOGIN, login, 256), DefaultAttribute.valueFor(Name.IP_ADDRESS, request.getClientIP()), DefaultAttribute.timestampFor(new Date()), DefaultAttribute.valueFor(Name.CLIENT, null == client ? "<none>" : client), DefaultAttribute.valueFor(Name.SESSION_ID, null == sessionId ? "<none>" : sessionId));
             }
         }
     }
