@@ -49,11 +49,11 @@
 
 package com.openexchange.mail.api;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.Closeable;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Properties;
@@ -77,8 +77,8 @@ import com.openexchange.mail.MailInitialization;
 import com.openexchange.mail.MailProviderRegistry;
 import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.MailSessionParameterNames;
-import com.openexchange.mail.api.permittance.Permittance;
-import com.openexchange.mail.api.permittance.Permitter;
+import com.openexchange.mail.api.AuthenticationFailedHandler.Service;
+import com.openexchange.mail.api.AuthenticationFailureHandlerResult.Type;
 import com.openexchange.mail.cache.EnqueueingMailAccessCache;
 import com.openexchange.mail.cache.IMailAccessCache;
 import com.openexchange.mail.cache.SingletonMailAccessCache;
@@ -87,7 +87,9 @@ import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.mime.MimeCleanUp;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
+import com.openexchange.mailaccount.Account;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
@@ -107,7 +109,7 @@ import com.openexchange.version.Version;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMessageStorage> implements Serializable, Closeable {
+public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMessageStorage> implements Serializable, Closeable, IMailStorage {
 
     /**
      * Serial version UID
@@ -244,6 +246,11 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         trackable = true;
     }
 
+    @Override
+    public <T> T supports(Class<T> iface) throws OXException {
+        return iface.isInstance(this) ? (T) this : null;
+    }
+
     /**
      * Gets the session associated with this <tt>MailAccess</tt> instance.
      *
@@ -288,7 +295,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @return Possible warnings.
      */
     public Collection<OXException> getWarnings() {
-        return Collections.unmodifiableCollection(warnings);
+        return new ArrayList<>(warnings);
     }
 
     /**
@@ -406,22 +413,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         checkLogin(session, accountId);
 
         // Return instance
-        Permitter permitter = Permittance.acquireFor(accountId, session);
-        if (null == permitter) {
-            // Non-restricted
-            return doGetInstance(session, accountId);
-        }
-
-        // Acquire permit, then return instance
-        permitter.acquire();
-        try {
-            return doGetInstance(session, accountId);
-        } finally {
-            boolean lastOne = permitter.release();
-            if (lastOne) {
-                Permittance.release(permitter);
-            }
-        }
+        return doGetInstance(session, accountId);
     }
 
     private static MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> doGetInstance(Session session, int accountId) throws OXException {
@@ -665,10 +657,8 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
     public boolean ping() throws OXException {
         try {
             final MailConfig mailConfig = getMailConfig();
-            if (mailConfig.isRequireTls() || mailConfig.getMailProperties().isEnforceSecureConnection()) {
-                if (!mailConfig.isSecure()) {
-                    throw MailExceptionCode.NON_SECURE_DENIED.create(mailConfig.getServer());
-                }
+            if (mailConfig.isRequireTls() && false == mailConfig.isSecure()) {
+                throw MailExceptionCode.NON_SECURE_DENIED.create(mailConfig.getServer());
             }
             connect0(false);
             close(false);
@@ -765,10 +755,41 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
             if (!supports(mailConfig.getAuthType())) {
                 throw MailExceptionCode.AUTH_TYPE_NOT_SUPPORTED.create(mailConfig.getAuthType().getName(), mailConfig.getServer());
             }
+            {
+                MailAccount mailAccount = getMailAccount(mailConfig);
+                if (null != mailAccount && mailAccount.isMailDisabled()) {
+                    if (mailAccount.isMailOAuthAble() && mailAccount.getMailOAuthId() >= 0) {
+                        OAuthService oauthService = ServerServiceRegistry.getInstance().getService(OAuthService.class);
+                        if (null != oauthService) {
+                            OAuthAccount oAuthAccount;
+                            try {
+                                oAuthAccount = oauthService.getAccount(mailAccount.getMailOAuthId(), session, session.getUserId(), session.getContextId());
+                            } catch (Exception x) {
+                                LOG.warn("Failed to load mail-associated OAuth account", x);
+                                oAuthAccount = null;
+                            }
+                            if (null != oAuthAccount) {
+                                throw MailExceptionCode.MAIL_ACCESS_DISABLED_OAUTH.create(mailConfig.getServer(), mailConfig.getLogin(), I(session.getUserId()), I(session.getContextId()), oAuthAccount.getDisplayName());
+                            }
+                        }
+                    }
+                    throw MailExceptionCode.MAIL_ACCESS_DISABLED.create(mailConfig.getServer(), mailConfig.getLogin(), I(session.getUserId()), I(session.getContextId()));
+                }
+            }
             try {
                 connectInternal();
             } catch (OXException e) {
-                throw handleConnectFailure(e, mailConfig);
+                AuthenticationFailureHandlerResult result = handleConnectFailure(e, mailConfig);
+                Type type = result.getType();
+                switch (type) {
+                    case RETRY:
+                        connectInternal();
+                        break;
+                    case EXCEPTION:
+                        throw result.getError();
+                    default:
+                        throw e;
+                }
             }
             if (checkDefaultFolder) {
                 checkDefaultFolderOnConnect();
@@ -783,17 +804,42 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
         }
     }
 
-    private OXException handleConnectFailure(OXException e, MailConfig mailConfig) {
+    private MailAccount getMailAccount(MailConfig mailConfig) throws OXException {
+        Account account = mailConfig.getAccount();
+        if (account instanceof MailAccount) {
+            return (MailAccount) account;
+        }
+
+        MailAccountStorageService service = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class);
+        if (null == service) {
+            return null;
+        }
+
+        return service.getMailAccount(accountId, session.getUserId(), session.getContextId());
+    }
+
+    private AuthenticationFailureHandlerResult handleConnectFailure(OXException e, MailConfig mailConfig) {
         if (!MimeMailExceptionCode.LOGIN_FAILED.equals(e) && !MimeMailExceptionCode.INVALID_CREDENTIALS.equals(e) && !OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.equals(e)) {
-            return e;
+            return AuthenticationFailureHandlerResult.createErrorResult(e);
+        }
+
+        if (mailConfig.getAccountId() == MailAccount.DEFAULT_ID) {
+            AuthenticationFailedHandlerService handlerService = ServerServiceRegistry.getInstance().getService(AuthenticationFailedHandlerService.class);
+            if (null != handlerService) {
+                try {
+                    return handlerService.handleAuthenticationFailed(e, Service.MAIL, mailConfig, session);
+                } catch (OXException x) {
+                    return AuthenticationFailureHandlerResult.createErrorResult(x);
+                }
+            }
         }
 
         if (OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.equals(e)) {
-            return e;
+            return AuthenticationFailureHandlerResult.createErrorResult(e);
         }
 
         // Authentication failed... Check for OAuth-based authentication
-        if (AuthType.OAUTH.equals(mailConfig.getAuthType())) {
+        if (AuthType.isOAuthType(mailConfig.getAuthType())) {
             // Determine identifier of the associated OAuth account
             int oauthAccountId = mailConfig.getOAuthAccountId();
             if (oauthAccountId >= 0) {
@@ -805,7 +851,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
                         OAuthAccount oAuthAccount = oauthService.getAccount(oauthAccountId, session, session.getUserId(), session.getContextId());
                         API api = oAuthAccount.getAPI();
                         Throwable cause = e.getCause();
-                        return OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(cause, api.getName(), oAuthAccount.getId(), session.getUserId(), session.getContextId());
+                        return AuthenticationFailureHandlerResult.createErrorResult(OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(cause, api.getName(), I(oAuthAccount.getId()), I(session.getUserId()), I(session.getContextId())));
                     } catch (Exception x) {
                         LOG.warn("Failed to handle failed OAuth authentication", x);
                     }
@@ -813,7 +859,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
             }
         }
 
-        return e;
+        return AuthenticationFailureHandlerResult.createErrorResult(e);
     }
 
     private void checkDefaultFolderOnConnect() throws OXException {
