@@ -55,6 +55,10 @@ import java.util.Map.Entry;
 import java.util.Queue;
 import java.util.concurrent.ConcurrentMap;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Interests;
+import com.openexchange.config.Reloadable;
+import com.openexchange.config.Reloadables;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.MailProviderRegistry;
 import com.openexchange.mail.api.IMailFolderStorage;
@@ -64,11 +68,11 @@ import com.openexchange.mail.cache.queue.MailAccessQueue;
 import com.openexchange.mail.cache.queue.MailAccessQueueImpl;
 import com.openexchange.mail.cache.queue.SingletonMailAccessQueue;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.config.MailReloadable;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
-import com.openexchange.sessiond.SessiondService;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 
@@ -91,16 +95,6 @@ public final class EnqueueingMailAccessCache implements IMailAccessCache {
      */
     private static final boolean DROP_TIMED_OUT_QUEUES = false;
 
-    /**
-     * Creates a new {@link EnqueueingMailAccessCache}
-     *
-     * @return A new {@link EnqueueingMailAccessCache}
-     * @throws OXException If initialization fails
-     */
-    public static EnqueueingMailAccessCache newInstance(final int queueCapacity) throws OXException {
-        return new EnqueueingMailAccessCache(queueCapacity);
-    }
-
     private static volatile EnqueueingMailAccessCache singleton;
 
     /**
@@ -146,11 +140,36 @@ public final class EnqueueingMailAccessCache implements IMailAccessCache {
         }
     }
 
+    static {
+        MailReloadable.getInstance().addReloadable(new Reloadable() {
+
+            @Override
+            public void reloadConfiguration(ConfigurationService configService) {
+                EnqueueingMailAccessCache tmp = singleton;
+                if (null != tmp) {
+                    try {
+                        int shrinkerSeconds = configService.getIntProperty("com.openexchange.mail.mailAccessCacheShrinkerSeconds", 3);
+                        int idleSeconds = configService.getIntProperty("com.openexchange.mail.mailAccessCacheIdleSeconds", 4);
+
+                        tmp.setIdleAndShrinkerSeconds(idleSeconds, shrinkerSeconds, false);
+                    } catch (OXException e) {
+                        LOG.error("Failed to re-initialize singleton mail-access cache", e);
+                    }
+                }
+            }
+
+            @Override
+            public Interests getInterests() {
+                return Reloadables.interestsForProperties("com.openexchange.mail.mailAccessCacheShrinkerSeconds", "com.openexchange.mail.mailAccessCacheIdleSeconds");
+            }
+        });
+    }
+
     // ------------------------------------------------------------------------------------------------------------------------------
 
     private final ConcurrentMap<Key, MailAccessQueue> map;
-    private final int defaultIdleSeconds;
-    private final ScheduledTimerTask timerTask;
+    private volatile int defaultIdleSeconds;
+    private volatile ScheduledTimerTask timerTask;
 
     /**
      * The number of {@link MailAccess} instances which may be concurrently active/opened per account for a user.
@@ -167,17 +186,25 @@ public final class EnqueueingMailAccessCache implements IMailAccessCache {
         super();
         this.fallbackQueueCapacity = fallbackQueueCapacity;
         map = new NonBlockingHashMap<Key, MailAccessQueue>();
-        final int configuredIdleSeconds = MailProperties.getInstance().getMailAccessCacheIdleSeconds();
-        defaultIdleSeconds = configuredIdleSeconds <= 0 ? 7 : configuredIdleSeconds;
-        /*
-         * Add timer task
-         */
-        final TimerService service = ServerServiceRegistry.getInstance().getService(TimerService.class, true);
-        final int configuredShrinkerSeconds = MailProperties.getInstance().getMailAccessCacheShrinkerSeconds();
-        final int shrinkerMillis = (configuredShrinkerSeconds <= 0 ? 3 : configuredShrinkerSeconds) * 1000;
-        timerTask = service.scheduleWithFixedDelay(new PurgeExpiredRunnable(map), shrinkerMillis, shrinkerMillis);
+        setIdleAndShrinkerSeconds(MailProperties.getInstance().getMailAccessCacheIdleSeconds(), MailProperties.getInstance().getMailAccessCacheShrinkerSeconds(), true);
     }
 
+    private void setIdleAndShrinkerSeconds(int idleSeconds, int shrinkerSeconds, boolean withInitialDelay) throws OXException {
+        TimerService service = ServerServiceRegistry.getInstance().getService(TimerService.class, true);
+
+        ScheduledTimerTask timerTask = this.timerTask;
+        if (null != timerTask) {
+            this.timerTask = null;
+            timerTask.cancel();
+            service.purge();
+        }
+
+        defaultIdleSeconds = idleSeconds <= 0 ? 7 : idleSeconds;
+        int shrinkerMillis = (shrinkerSeconds <= 0 ? 3 : shrinkerSeconds) * 1000;
+        this.timerTask = service.scheduleWithFixedDelay(new PurgeExpiredRunnable(map), withInitialDelay ? shrinkerMillis : 0L, shrinkerMillis);
+    }
+
+
     @Override
     public int numberOfMailAccesses(Session session, int accountId) throws OXException {
         final Key key = keyFor(accountId, session);
@@ -320,32 +347,21 @@ public final class EnqueueingMailAccessCache implements IMailAccessCache {
         }
     }
 
-    /**
-     * Clears the cache entries kept for specified user.
-     *
-     * @param session The session
-     * @throws OXException If clearing user entries fails
-     */
     @Override
-    public void clearUserEntries(final Session session) throws OXException {
-        /*
-         * Check if last...
-         */
-        final SessiondService service = ServerServiceRegistry.getInstance().getService(SessiondService.class);
-        final int user = session.getUserId();
-        final int cid = session.getContextId();
-        if (null == service || null == service.getAnyActiveSessionForUser(user, cid)) {
-            final MailAccountStorageService storageService =
-                ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
-            final MailAccount[] accounts = storageService.getUserMailAccounts(user, cid);
-            for (final MailAccount mailAccount : accounts) {
-                orderlyClearQueue(keyFor(mailAccount.getId(), session));
-            }
+    public void clearUserEntries(int userId, int contextId) throws OXException {
+        MailAccountStorageService storageService = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class, true);
+        MailAccount[] accounts = storageService.getUserMailAccounts(userId, contextId);
+        for (MailAccount mailAccount : accounts) {
+            orderlyClearQueue(keyFor(mailAccount.getId(), userId, contextId));
         }
     }
 
-    private static Key keyFor(final int accountId, final Session session) {
-        return new Key(accountId, session.getUserId(), session.getContextId());
+    private static Key keyFor(int accountId, Session session) {
+        return keyFor(accountId, session.getUserId(), session.getContextId());
+    }
+
+    private static Key keyFor(int accountId, int userId, int contextId) {
+        return new Key(accountId, userId, contextId);
     }
 
     private static final class PurgeExpiredRunnable implements Runnable {
