@@ -701,6 +701,11 @@ public class ContentAwareMailMessage extends MailMessage {
         message.setSubject(subject);
     }
 
+    @Override
+    public void setSubject(String subject, boolean decoded) {
+        message.setSubject(subject, decoded);
+    }
+
     @Override
     public void prepareForCaching() {
         message.prepareForCaching();
