@@ -673,6 +673,11 @@ public class DraftMailMessage extends MailMessage {
         message.setSubject(subject);
     }
 
+    @Override
+    public void setSubject(String subject, boolean decoded) {
+        message.setSubject(subject, decoded);
+    }
+
     @Override
     public Date getSentDate() {
         final Date sentDate = message.getSentDate();
