@@ -66,9 +66,11 @@ import org.json.JSONObject;
 import com.openexchange.ajax.Mail;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.AJAXRequestResultPostProcessor;
 import com.openexchange.ajax.requesthandler.AJAXState;
+import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
 import com.openexchange.ajax.requesthandler.oauth.OAuthConstants;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.contactcollector.ContactCollectorService;
@@ -93,6 +95,8 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountExceptionCodes;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.TransportAccount;
+import com.openexchange.objectusecount.IncrementArguments;
+import com.openexchange.objectusecount.ObjectUseCountService;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -165,14 +169,29 @@ public abstract class AbstractMailAction implements AJAXActionService, MailActio
      * @return The mail interface
      * @throws OXException If mail interface cannot be initialized
      */
-    protected MailServletInterface getMailInterface(final MailRequest mailRequest) throws OXException {
+    protected MailServletInterface getMailInterface(MailRequest mailRequest) throws OXException {
+        // Requests can control whether or not to decrypt messages or verify signatures
+        boolean decrypt = AJAXRequestDataTools.parseBoolParameter(mailRequest.getParameter("decrypt"));
+        boolean verify = AJAXRequestDataTools.parseBoolParameter(mailRequest.getParameter("verify"));
+
+        // Parsing crypto authentication from the request if decrypting
+        String cryptoAuthentication = null;
+        if (decrypt) {
+            CryptographicServiceAuthenticationFactory encryptionAuthenticationFactory = services.getOptionalService(CryptographicServiceAuthenticationFactory.class);
+            if (encryptionAuthenticationFactory != null) {
+                cryptoAuthentication = encryptionAuthenticationFactory.createAuthenticationFrom(mailRequest.getRequest());
+            }
+        }
+
         // Get mail interface
         AJAXState state = mailRequest.getRequest().getState();
         if (state == null) {
             // No AJAX state
             MailServletInterface mailInterface = mailRequest.getMailServletInterface();
             if (mailInterface == null) {
-                MailServletInterface newMailInterface = MailServletInterface.getInstance(mailRequest.getSession());
+                MailServletInterface newMailInterface = decrypt || verify ? // If decrypting or verifying, get Crypto Aware MailServlet
+                    MailServletInterface.getInstanceWithDecryptionSupport(mailRequest.getSession(), cryptoAuthentication) :
+                    MailServletInterface.getInstance(mailRequest.getSession());
                 mailRequest.setMailServletInterface(newMailInterface);
                 mailInterface = newMailInterface;
             }
@@ -181,7 +200,9 @@ public abstract class AbstractMailAction implements AJAXActionService, MailActio
 
         MailServletInterface mailInterface = state.optProperty(PROPERTY_MAIL_IFACE);
         if (mailInterface == null) {
-            MailServletInterface newMailInterface = MailServletInterface.getInstance(mailRequest.getSession());
+            MailServletInterface newMailInterface = decrypt || verify ?
+                MailServletInterface.getInstanceWithDecryptionSupport(mailRequest.getSession(), cryptoAuthentication) :
+                MailServletInterface.getInstance(mailRequest.getSession());
             mailInterface = state.putProperty(PROPERTY_MAIL_IFACE, newMailInterface);
             if (null == mailInterface) {
                 mailInterface = newMailInterface;
@@ -290,37 +311,90 @@ public abstract class AbstractMailAction implements AJAXActionService, MailActio
      *
      * @param session The session
      * @param mail The mail
+     * @param memorizeAddresses Whether contact-collector is supposed to be triggered
      * @param incrementUseCount Whether the associated contacts' use-count is supposed to be incremented
      * @throws OXException
      */
-    public static void triggerContactCollector(ServerSession session, MailMessage mail, boolean incrementUseCount) throws OXException {
-        triggerContactCollector(session, Collections.singletonList(mail), incrementUseCount);
+    public static void triggerContactCollector(ServerSession session, MailMessage mail, boolean memorizeAddresses, boolean incrementUseCount) throws OXException {
+        if (null != mail) {
+            triggerContactCollector(session, Collections.singletonList(mail), memorizeAddresses, incrementUseCount);
+        }
     }
 
+    /** The prefix for puny-code encoded mail addresses */
+    private final static String ACE_PREFIX = "xn--";
+
     /**
      * Triggers the contact collector for specified mail's addresses.
      *
      * @param session The session
      * @param mails The mails
+     * @param memorizeAddresses Whether contact-collector is supposed to be triggered
      * @param incrementUseCount Whether the associated contacts' use-count is supposed to be incremented
      * @throws OXException
      */
-    public static void triggerContactCollector(ServerSession session, Collection<? extends MailMessage> mails, boolean incrementUseCount) throws OXException {
-        final ContactCollectorService ccs = ServerServiceRegistry.getInstance().getService(ContactCollectorService.class);
-        if (null != ccs) {
-            Set<InternetAddress> addrs = null;
-            for (MailMessage mail : mails) {
-                if (null != mail) {
-                    if (null == addrs) {
-                        addrs = AddressUtility.getAddresses(mail, session);
-                    } else {
-                        addrs.addAll(AddressUtility.getAddresses(mail, session));
+    public static void triggerContactCollector(ServerSession session, Collection<? extends MailMessage> mails, boolean memorizeAddresses, boolean incrementUseCount) throws OXException {
+        // Sets to store user's alias addresses (which should not be considered) and cumulative addresses of specified mail collection
+        Set<InternetAddress> addrs = null;
+        Set<InternetAddress> aliases = null;
+
+        // Check whether contact-collector is supposed to be triggered
+        if (memorizeAddresses) {
+            ContactCollectorService ccs = ServerServiceRegistry.getInstance().getService(ContactCollectorService.class);
+            if (null != ccs) {
+                for (MailMessage mail : mails) {
+                    if (null != mail) {
+                        if (null == aliases) {
+                            aliases = AddressUtility.getAliases(session);
+                        }
+
+                        if (null == addrs) {
+                            addrs = AddressUtility.getFilteredAddresses(mail, aliases);
+                        } else {
+                            addrs.addAll(AddressUtility.getFilteredAddresses(mail, aliases));
+                        }
                     }
                 }
-            }
 
-            if (null != addrs && !addrs.isEmpty()) {
-                ccs.memorizeAddresses(new ArrayList<InternetAddress>(addrs), incrementUseCount, session);
+                if (null != addrs && !addrs.isEmpty()) {
+                    ccs.memorizeAddresses(new ArrayList<InternetAddress>(addrs), false, session);
+                }
+            }
+        }
+
+        // Check whether to increment use-count
+        if (incrementUseCount) {
+            ObjectUseCountService useCountService = ServerServiceRegistry.getInstance().getService(ObjectUseCountService.class);
+            if (null != useCountService) {
+                if (null == addrs) {
+                    for (MailMessage mail : mails) {
+                        if (null != mail) {
+                            if (null == aliases) {
+                                aliases = AddressUtility.getAliases(session);
+                            }
+
+                            if (null == addrs) {
+                                addrs = AddressUtility.getFilteredAddresses(mail, aliases);
+                            } else {
+                                addrs.addAll(AddressUtility.getFilteredAddresses(mail, aliases));
+                            }
+                        }
+                    }
+                }
+
+                if (null != addrs && !addrs.isEmpty()) {
+                    Set<String> addressesToIncrementBy = new HashSet<>(addrs.size());
+                    for (InternetAddress addr : addrs) {
+                        String address = addr.getAddress();
+                        addressesToIncrementBy.add(address);
+                        if (address.indexOf(ACE_PREFIX) >= 0) {
+                            addressesToIncrementBy.add(QuotedInternetAddress.toIDN(address));
+                        }
+                    }
+
+                    IncrementArguments.Builder builder = new IncrementArguments.Builder(addressesToIncrementBy);
+                    useCountService.incrementObjectUseCount(session, builder.build());
+                }
             }
         }
     }
