@@ -102,7 +102,7 @@ public final class AutosaveAction extends AbstractMailAction {
                 /*
                  * Parse with default account's transport provider
                  */
-                ComposedMailMessage composedMail = MessageParser.parse4Draft(jsonMailObj, (UploadEvent) null, session, MailAccount.DEFAULT_ID, csid, warnings);
+                ComposedMailMessage composedMail = MessageParser.parse4Draft(jsonMailObj, (UploadEvent) null, session, MailAccount.DEFAULT_ID, warnings);
                 if ((composedMail.getFlags() & MailMessage.FLAG_DRAFT) == 0) {
                     LOG.debug("Missing \\Draft flag on action=autosave in JSON message object");
                     composedMail.setFlag(MailMessage.FLAG_DRAFT, true);
@@ -151,6 +151,11 @@ public final class AutosaveAction extends AbstractMailAction {
             return result;
         } catch (final RuntimeException e) {
             throw MailExceptionCode.UNEXPECTED_ERROR.create(e, e.getMessage());
+        } catch (final OXException e){
+            if (MailExceptionCode.COPY_TO_SENT_FOLDER_FAILED_QUOTA.equals(e)) {
+                throw MailExceptionCode.UNABLE_TO_SAVE_DRAFT_QUOTA.create();
+            }
+            throw e;
         }
     }
 
