@@ -156,7 +156,7 @@ public final class EditAction extends AbstractMailAction {
                 /*
                  * Parse with default account's transport provider
                  */
-                ComposedMailMessage composedMail = MessageParser.parse4Draft(jsonMailObj, uploadEvent, session, MailAccount.DEFAULT_ID, csid, warnings);
+                ComposedMailMessage composedMail = MessageParser.parse4Draft(jsonMailObj, uploadEvent, session, MailAccount.DEFAULT_ID, warnings);
                 MailPath msgref = composedMail.getMsgref();
                 /*
                  * ... and edit draft
@@ -178,8 +178,7 @@ public final class EditAction extends AbstractMailAction {
             result.addWarnings(warnings);
             return result;
         } catch (final OXException e) {
-            final Object[] args = e.getDisplayArgs();
-            final String uid = null == args || 0 == args.length ? null : args[0].toString();
+            final String uid = getUidFromException(e);
             if (MailExceptionCode.MAIL_NOT_FOUND.equals(e) && "undefined".equalsIgnoreCase(uid)) {
                 throw MailExceptionCode.PROCESSING_ERROR.create(e, new Object[0]);
             }
