@@ -290,13 +290,11 @@ public final class GetAction extends AbstractMailAction {
                          * Trigger contact collector
                          */
                         try {
-                            final ServerUserSetting setting = ServerUserSetting.getInstance();
-                            final int contextId = session.getContextId();
-                            final int userId = session.getUserId();
-                            if (setting.isContactCollectOnMailAccess(contextId, userId).booleanValue()) {
-                                triggerContactCollector(session, mail, false);
+                            boolean memorizeAddresses = ServerUserSetting.getInstance().isContactCollectOnMailAccess(session.getContextId(), session.getUserId()).booleanValue();
+                            if (memorizeAddresses) {
+                                triggerContactCollector(session, mail, true, false);
                             }
-                        } catch (final OXException e) {
+                        } catch (final Exception e) {
                             LOG.warn("Contact collector could not be triggered.", e);
                         }
                     }
@@ -376,13 +374,11 @@ public final class GetAction extends AbstractMailAction {
                     mailInterface.updateMessageFlags(folderPath, new String[] { uid }, MailMessage.FLAG_SEEN, false);
                 } else if (wasUnseen) {
                     try {
-                        final ServerUserSetting setting = ServerUserSetting.getInstance();
-                        final int contextId = session.getContextId();
-                        final int userId = session.getUserId();
-                        if (setting.isContactCollectOnMailAccess(contextId, userId).booleanValue()) {
-                            triggerContactCollector(session, mail, false);
+                        boolean memorizeAddresses = ServerUserSetting.getInstance().isContactCollectOnMailAccess(session.getContextId(), session.getUserId()).booleanValue();
+                        if (memorizeAddresses) {
+                            triggerContactCollector(session, mail, true, false);
                         }
-                    } catch (final OXException e) {
+                    } catch (final Exception e) {
                         LOG.warn("Contact collector could not be triggered.", e);
                     }
                 }
@@ -421,13 +417,11 @@ public final class GetAction extends AbstractMailAction {
                      */
                     if (!unseen && (mail.containsPrevSeen() && !mail.isPrevSeen())) {
                         try {
-                            final ServerUserSetting setting = ServerUserSetting.getInstance();
-                            final int contextId = session.getContextId();
-                            final int userId = session.getUserId();
-                            if (setting.isContactCollectOnMailAccess(contextId, userId).booleanValue()) {
-                                triggerContactCollector(session, mail, false);
+                            boolean memorizeAddresses = ServerUserSetting.getInstance().isContactCollectOnMailAccess(session.getContextId(), session.getUserId()).booleanValue();
+                            if (memorizeAddresses) {
+                                triggerContactCollector(session, mail, true, false);
                             }
-                        } catch (final OXException e) {
+                        } catch (final Exception e) {
                             LOG.warn("Contact collector could not be triggered.", e);
                         }
                     }
