@@ -49,7 +49,8 @@
 
 package com.openexchange.mail.json.actions;
 
-import java.util.Iterator;
+import static com.openexchange.ajax.requesthandler.AJAXRequestDataBuilder.request;
+import java.util.Map;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -58,10 +59,13 @@ import com.openexchange.ajax.Mail;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
+import com.openexchange.ajax.requesthandler.Dispatcher;
+import com.openexchange.ajax.requesthandler.Dispatchers;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailPath;
 import com.openexchange.mail.MailServletInterface;
+import com.openexchange.mail.api.FromAddressProvider;
 import com.openexchange.mail.compose.CompositionSpace;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.json.MailRequest;
@@ -96,25 +100,29 @@ public final class GetReplyAllAction extends AbstractMailAction {
 
     private AJAXRequestResult performPut(final MailRequest req, final JSONArray paths) throws OXException {
         try {
-            final int length = paths.length();
+            int length = paths.length();
             if (length != 1) {
                 throw new IllegalArgumentException("JSON array's length is not 1");
             }
-            final AJAXRequestData requestData = new AJAXRequestData();
-            final AJAXRequestData request = req.getRequest();
-            for (final Iterator<String> it = request.getParameterNames(); it.hasNext();) {
-                final String name = it.next();
-                requestData.putParameter(name, request.getParameter(name));
+
+            // Compile a new request instance...
+            AJAXRequestData request = req.getRequest();
+            AJAXRequestData requestData = new AJAXRequestData();
+            requestData.setHostname(request.getHostname());
+            requestData.setPrefix(request.getPrefix());
+            requestData.setRoute(request.getRoute());
+            requestData.setServerPort(request.getServerPort());
+            for (Map.Entry<String, String> entry : request.getParameters().entrySet()) {
+                requestData.putParameter(entry.getKey(), entry.getValue());
             }
             for (int i = 0; i < length; i++) {
-                final JSONObject folderAndID = paths.getJSONObject(i);
+                JSONObject folderAndID = paths.getJSONObject(i);
                 requestData.putParameter(AJAXServlet.PARAMETER_FOLDERID, folderAndID.getString(AJAXServlet.PARAMETER_FOLDERID));
                 requestData.putParameter(AJAXServlet.PARAMETER_ID, folderAndID.get(AJAXServlet.PARAMETER_ID).toString());
             }
             requestData.setState(request.getState());
-            /*
-             * ... and fake a GET request
-             */
+
+            // ... and fake a GET request
             return performGet(new MailRequest(requestData, req.getSession()));
         } catch (final JSONException e) {
             throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
@@ -146,12 +154,27 @@ public final class GetReplyAllAction extends AbstractMailAction {
             if (AJAXRequestDataTools.parseBoolParameter(req.getParameter("attachOriginalMessage"))) {
                 usmNoSave.setAttachOriginalMessage(true);
             }
-            boolean setFrom = AJAXRequestDataTools.parseBoolParameter(req.getParameter("setFrom"));
+            FromAddressProvider fromAddressProvider = FromAddressProvider.none();
+            {
+                boolean setFrom = AJAXRequestDataTools.parseBoolParameter(req.getParameter("setFrom"));
+                if (setFrom) {
+                    Dispatcher ox = getService(Dispatcher.class);
+                    AJAXRequestData requestData = request().session(session).module(com.openexchange.mailaccount.Constants.getModule()).action(com.openexchange.mailaccount.json.actions.ResolveFolderAction.ACTION).params(AJAXServlet.PARAMETER_FOLDERID, folderPath).format("json").build(req.getRequest());
+                    AJAXRequestResult requestResult = perform(requestData, ox, session);
+                    JSONObject jResult = ((JSONObject) requestResult.getResultObject());
+                    if (null != jResult && jResult.hasAndNotNull("from")) {
+                        String address = jResult.optString("from");
+                        fromAddressProvider = FromAddressProvider.providerFor(address);
+                    } else {
+                        fromAddressProvider = FromAddressProvider.byAccountId();
+                    }
+                }
+            }
             /*
              * Get mail interface
              */
             MailServletInterface mailInterface = getMailInterface(req);
-            MailMessage mail = mailInterface.getReplyMessageForDisplay(folderPath, uid, true, usmNoSave, setFrom);
+            MailMessage mail = mailInterface.getReplyMessageForDisplay(folderPath, uid, true, usmNoSave, fromAddressProvider);
             if (!mail.containsAccountId()) {
                 mail.setAccountId(mailInterface.getAccountID());
             }
@@ -178,4 +201,21 @@ public final class GetReplyAllAction extends AbstractMailAction {
         }
     }
 
+    private AJAXRequestResult perform(AJAXRequestData requestData, Dispatcher ox, ServerSession session) throws OXException {
+        AJAXRequestResult requestResult = null;
+        Exception exc = null;
+        try {
+            requestResult = ox.perform(requestData, null, session);
+            return requestResult;
+        } catch (OXException x) {
+            exc = x;
+            throw x;
+        } catch (RuntimeException x) {
+            exc = x;
+            throw MailExceptionCode.UNEXPECTED_ERROR.create(x, x.getMessage());
+        } finally {
+            Dispatchers.signalDone(requestResult, exc);
+        }
+    }
+
 }
