@@ -55,9 +55,6 @@ import org.json.JSONException;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.Mail;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.mail.MailExceptionCode;
@@ -77,9 +74,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(method = RequestMethod.GET, name = "updates", description = "Get updated mails", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module.")
-}, responseDescription = "Just an empty JSON array is going to be returned since this action cannot be applied to IMAP.")
 public final class GetUpdatesAction extends AbstractMailAction {
 
     /**
