@@ -125,7 +125,9 @@ public final class ListAction extends AbstractMailAction {
                     }
                 }
             }
-            return new AJAXRequestResult(list, "mail");
+            AJAXRequestResult result = new AJAXRequestResult(list, "mail");
+            result.addWarnings(mailInterface.getWarnings());
+            return result;
         } catch (final JSONException e) {
             throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
         } catch (final RuntimeException e) {
