@@ -116,6 +116,8 @@ import com.openexchange.mail.transport.MtaStatusInfo;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.mailaccount.MailAccounts;
 import com.openexchange.preferences.ServerUserSetting;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -136,6 +138,7 @@ public final class NewAction extends AbstractMailAction {
     private static final String FLAGS = MailJSONField.FLAGS.getKey();
     private static final String FROM = MailJSONField.FROM.getKey();
     private static final String UPLOAD_FORMFIELD_MAIL = AJAXServlet.UPLOAD_FORMFIELD_MAIL;
+    private static final String PLAIN_JSON = AJAXServlet.PARAM_PLAIN_JSON;
 
     private final EnumSet<ComposeType> draftTypes;
 
@@ -268,7 +271,9 @@ public final class NewAction extends AbstractMailAction {
                     composedMail.removeHeader("Message-ID");
                     composedMail.removeMessageId();
                 }
+
                 MailServletInterface mailInterface = getMailInterface(req);
+
                 msgIdentifier = mailInterface.saveDraft(composedMail, false, accountId).toString();
                 if (msgIdentifier == null) {
                     throw MailExceptionCode.DRAFT_FAILED_UNKNOWN.create();
@@ -288,7 +293,8 @@ public final class NewAction extends AbstractMailAction {
 
                 warnings.addAll(mailInterface.getWarnings());
 
-                AJAXRequestResult result = new AJAXRequestResult(msgIdentifier, "string");
+                boolean plainJson = AJAXRequestDataTools.parseBoolParameter(PLAIN_JSON, request);
+                AJAXRequestResult result = resultFor(msgIdentifier, plainJson);
                 result.addWarnings(warnings);
                 return result;
             }
@@ -345,7 +351,7 @@ public final class NewAction extends AbstractMailAction {
                 String[] ids = mailInterface.appendMessages(folder, new MailMessage[] { mm }, false);
                 msgIdentifier = ids[0];
                 mailInterface.updateMessageFlags(folder, ids, MailMessage.FLAG_SEEN, true);
-                return new AJAXRequestResult(new JSONObject(2).put(FolderChildFields.FOLDER_ID, folder).put(DataFields.ID, ids[0]), "json");
+                return resultFor(new JSONObject(2).put(FolderChildFields.FOLDER_ID, folder).put(DataFields.ID, ids[0]));
             }
 
             // Normal transport
@@ -414,6 +420,12 @@ public final class NewAction extends AbstractMailAction {
                             usm.setNoCopyIntoStandardSentFolder(true);
                         }
                     }
+                } else {
+                    MailAccountStorageService mass = ServerServiceRegistry.getInstance().getService(MailAccountStorageService.class);
+                    if (mass != null && MailAccounts.isGmailTransport(mass.getTransportAccount(accountId, session.getUserId(), session.getContextId()))) {
+                        // Deny copy to sent folder for Gmail
+                        usm.setNoCopyIntoStandardSentFolder(true);
+                    }
                 }
             }
             checkAndApplyLineWrapAfter(request, usm);
@@ -445,25 +457,23 @@ public final class NewAction extends AbstractMailAction {
 
             // Trigger contact collector
             try {
-                ServerUserSetting setting = ServerUserSetting.getInstance();
-                if (setting.isContactCollectOnMailTransport(session.getContextId(), session.getUserId()).booleanValue()) {
-                    triggerContactCollector(session, composedMails, true);
-                }
-            } catch (final Exception e) {
+                boolean memorizeAddresses = ServerUserSetting.getInstance().isContactCollectOnMailTransport(session.getContextId(), session.getUserId()).booleanValue();
+                triggerContactCollector(session, composedMails, memorizeAddresses, true);
+            } catch (Exception e) {
                 LOG.warn("Contact collector could not be triggered.", e);
             }
         }
 
         if (msgIdentifier == null) {
             if (null != userSettingMail && userSettingMail.isNoCopyIntoStandardSentFolder()) {
-                final AJAXRequestResult result = new AJAXRequestResult(JSONObject.NULL, "json");
+                final AJAXRequestResult result = resultFor(null, false);
                 result.addWarnings(warnings);
                 return result;
             }
             if (warnings.isEmpty()) {
                 throw MailExceptionCode.SEND_FAILED_UNKNOWN.create();
             }
-            final AJAXRequestResult result = new AJAXRequestResult(JSONObject.NULL, "json");
+            final AJAXRequestResult result = resultFor(null, false);
             result.addWarnings(warnings);
             return result;
         }
@@ -471,11 +481,34 @@ public final class NewAction extends AbstractMailAction {
         /*
          * Create JSON response object
          */
-        final AJAXRequestResult result = new AJAXRequestResult(msgIdentifier, "string");
+        boolean plainJson = AJAXRequestDataTools.parseBoolParameter(PLAIN_JSON, request);
+        AJAXRequestResult result = resultFor(msgIdentifier, plainJson);
         result.addWarnings(warnings);
         return result;
     }
 
+    private AJAXRequestResult resultFor(String msgIdentifier, boolean asJsonObject) {
+        if (null == msgIdentifier) {
+            return new AJAXRequestResult(JSONObject.NULL, "json");
+        }
+
+        if (false == asJsonObject) {
+            return new AJAXRequestResult(msgIdentifier, "string");
+        }
+
+        try {
+            MailPath mp = new MailPath(msgIdentifier);
+            return new AJAXRequestResult(new JSONObject(2).put(FolderChildFields.FOLDER_ID, prepareFullname(mp.getAccountId(), mp.getFolder())).put(DataFields.ID, mp.getMailID()), "json");
+        } catch (Exception e) {
+            // Invalid mail path
+            return new AJAXRequestResult(msgIdentifier, "string");
+        }
+    }
+
+    private AJAXRequestResult resultFor(JSONObject jObject) {
+        return new AJAXRequestResult(null == jObject ? JSONObject.NULL : jObject, "json");
+    }
+
     private void checkAndApplyLineWrapAfter(AJAXRequestData request, UserSettingMail usm) throws OXException {
         String paramName = "lineWrapAfter";
         if (request.containsParameter(paramName)) { // Provided as URL parameter
@@ -532,6 +565,7 @@ public final class NewAction extends AbstractMailAction {
             if (newMessageId) {
                 message.removeHeader("Message-ID");
             }
+            message.foldAllHeaderLines();
             String fromAddr = message.getHeader(MessageHeaders.HDR_FROM, null);
             if (isEmpty(fromAddr)) {
                 // Add from address
@@ -648,11 +682,11 @@ public final class NewAction extends AbstractMailAction {
          */
         if (isOAuthRequest(request)) {
             if (MailAccount.DEFAULT_ID == accountId) {
-                PasswordSource passwordSource = MailProperties.getInstance().getPasswordSource();
+                PasswordSource passwordSource = MailProperties.getInstance().getPasswordSource(session.getUserId(), session.getContextId());
                 switch (passwordSource) {
                     case GLOBAL: {
                         // Just for convenience
-                        String masterPassword = MailProperties.getInstance().getMasterPassword();
+                        String masterPassword = MailProperties.getInstance().getMasterPassword(session.getUserId(), session.getContextId());
                         if (masterPassword == null) {
                             throw MailConfigException.create("Property \"com.openexchange.mail.masterPassword\" not set");
                         }
