@@ -52,7 +52,6 @@ package com.openexchange.mail.json.compose;
 import static com.openexchange.java.Strings.toLowerCase;
 import static com.openexchange.mail.json.parser.MessageParser.parseAddressKey;
 import static com.openexchange.mail.mime.filler.MimeMessageFiller.isCustomOrReplyHeader;
-import static com.openexchange.mail.mime.utils.MimeMessageUtility.parseAddressList;
 import static com.openexchange.mail.mime.utils.MimeMessageUtility.shouldRetry;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
@@ -63,11 +62,13 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.TimeZone;
 import java.util.Map.Entry;
+import java.util.Queue;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.mail.internet.AddressException;
@@ -75,6 +76,10 @@ import javax.mail.internet.InternetAddress;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.ajax.AJAXServlet;
+import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
+import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
 import com.openexchange.conversion.ConversionService;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataArguments;
@@ -96,14 +101,19 @@ import com.openexchange.mail.MailPath;
 import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.MailAccess;
+import com.openexchange.mail.api.crypto.CryptographicAwareMailAccessFactory;
+import com.openexchange.mail.compose.CompositionSpace;
+import com.openexchange.mail.compose.CompositionSpaces;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
+import com.openexchange.mail.dataobjects.SecuritySettings;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.dataobjects.compose.DataMailPart;
 import com.openexchange.mail.dataobjects.compose.ReferencedMailPart;
 import com.openexchange.mail.dataobjects.compose.TextBodyMailPart;
+import com.openexchange.mail.json.osgi.MailJSONActivator;
 import com.openexchange.mail.mime.HeaderCollection;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeTypes;
@@ -114,6 +124,7 @@ import com.openexchange.mail.parser.handlers.MultipleMailPartHandler;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.UnifiedInboxManagement;
 import com.openexchange.server.ServiceExceptionCode;
+import com.openexchange.server.ServiceLookup;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.TimeZoneUtils;
@@ -285,7 +296,22 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
             if (attachmentArray.length() > 1) {
                 // Check for inline images (in case content is HTML)
                 Set<String> contentIds = extractContentIds(sContent);
-                parseAttachments(sourceMessage, attachmentArray, contentIds, context);
+
+                // Check composition space
+                CompositionSpace compositionSpace = null;
+                {
+                    String csid = request.getRequest().getParameter(AJAXServlet.PARAMETER_CSID);
+                    if (null == csid) {
+                        csid = request.getJsonMail().optString("csid", null);
+                    }
+                    if (null != csid) {
+                        compositionSpace = CompositionSpaces.get(csid, request.getSession());
+                    }
+                }
+
+                parseAttachments(sourceMessage, attachmentArray, contentIds, context, compositionSpace,
+                    // If forwarding a previously encrypted message, needs attachments decrypted with authentication
+                    (sourceMessage.getSecuritySettings() == null ? null : sourceMessage.getSecuritySettings().getAuthentication()));
             }
         } else {
             // There are no attachments at all; yield an empty text part
@@ -332,12 +358,13 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
         int length = jDriveIds.length();
         if (length > 0) {
             // Check max. allowed Drive attachments
-            int max = MailProperties.getInstance().getMaxDriveAttachments();
+            ServerSession session = context.getSession();
+            int max = MailProperties.getInstance().getMaxDriveAttachments(session.getUserId(), session.getContextId());
             if (max > 0 && length > max) {
                 throw MailExceptionCode.MAX_DRIVE_ATTACHMENTS_EXCEEDED.create(Integer.toString(max));
             }
             for (int i = 0; i < length; i++) {
-                context.addDrivePart(context.getProvider().getNewDocumentPart(jDriveIds.getString(i), context.getSession()));
+                context.addDrivePart(context.getProvider().getNewDocumentPart(jDriveIds.getString(i), session));
             }
         }
     }
@@ -354,7 +381,8 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
         int length = jDataSources.length();
         if (length > 0) {
             // Check max. allowed Drive attachments
-            int max = MailProperties.getInstance().getMaxDriveAttachments();
+            ServerSession session = context.getSession();
+            int max = MailProperties.getInstance().getMaxDriveAttachments(session.getUserId(), session.getContextId());
             if (max > 0 && length > max) {
                 throw MailExceptionCode.MAX_DRIVE_ATTACHMENTS_EXCEEDED.create(Integer.toString(max));
             }
@@ -382,14 +410,14 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
 
                 Data<?> data;
                 if (types.contains(InputStream.class)) {
-                    data = dataSource.getData(InputStream.class, parseDataSourceArguments(jDataSource), context.getSession());
+                    data = dataSource.getData(InputStream.class, parseDataSourceArguments(jDataSource), session);
                 } else if (types.contains(byte[].class)) {
-                    data = dataSource.getData(byte[].class, parseDataSourceArguments(jDataSource), context.getSession());
+                    data = dataSource.getData(byte[].class, parseDataSourceArguments(jDataSource), session);
                 } else {
                     throw MailExceptionCode.UNSUPPORTED_DATASOURCE.create();
                 }
 
-                DataMailPart dataMailPart = context.getProvider().getNewDataPart(data.getData(), data.getDataProperties().toMap(), context.getSession());
+                DataMailPart dataMailPart = context.getProvider().getNewDataPart(data.getData(), data.getDataProperties().toMap(), session);
                 context.addDataPart(dataMailPart);
             }
         }
@@ -442,15 +470,31 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
      * @param jAttachments The attachments to parse
      * @param contentIds The extracted content identifiers of inline images
      * @param context The compose context
+     * @param compositionSpace The optional composition space
      * @throws OXException If parsing fails
      * @throws JSONException If a JSON error occurred
      */
-    protected void parseAttachments(ComposedMailMessage composeMessage, JSONArray jAttachments, Set<String> contentIds, ComposeContext context) throws OXException, JSONException {
+    protected void parseAttachments(ComposedMailMessage composeMessage, JSONArray jAttachments, Set<String> contentIds, ComposeContext context, CompositionSpace compositionSpace, String cryptoAuth) throws OXException, JSONException {
         // Get the identifier of the referenced message
         MailPath parentMsgRef = composeMessage.getMsgref();
+        MailPath originalMsgRef = null;
+        if (null != parentMsgRef && null != compositionSpace) {
+            originalMsgRef = compositionSpace.getReplyFor();
+            if (null == originalMsgRef) {
+                Queue<MailPath> queue = compositionSpace.getForwardsFor();
+                originalMsgRef = queue.size() == 1 ? queue.peek() : null;
+            }
+            if (null == originalMsgRef) {
+                Queue<MailPath> queue = compositionSpace.getDraftEditsFor();
+                originalMsgRef = queue.size() == 1 ? queue.peek() : null;
+            }
+            if (null != originalMsgRef && (originalMsgRef.equals(parentMsgRef) || parentMsgRef.getAccountId() != originalMsgRef.getAccountId())) {
+                originalMsgRef = null;
+            }
+        }
 
         // Load & set referenced parts
-        Map<String, ReferencedMailPart> referencedParts = loadReferencedParts(jAttachments, contentIds, parentMsgRef, context);
+        Map<String, ReferencedMailPart> referencedParts = loadReferencedParts(jAttachments, contentIds, parentMsgRef, originalMsgRef, context, cryptoAuth);
 
         // Iterate attachments (once again)
         int len = jAttachments.length();
@@ -561,12 +605,13 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
      * @param jAttachments The attachments of the JSON representation of the message
      * @param contentIds The extracted content identifiers of inline images
      * @param parentMsgRef The message reference identifier
+     * @param originalMsgRef The optional original message reference identifier
      * @param context The compose context
      * @return The loaded parts
      * @throws OXException If loading the parts fails
      * @throws JSONException If a JSON error occurred
      */
-    protected Map<String, ReferencedMailPart> loadReferencedParts(JSONArray jAttachments, Set<String> contentIds, MailPath parentMsgRef, ComposeContext context) throws OXException, JSONException {
+    protected Map<String, ReferencedMailPart> loadReferencedParts(JSONArray jAttachments, Set<String> contentIds, MailPath parentMsgRef, MailPath originalMsgRef, ComposeContext context, String cryptoAuth) throws OXException, JSONException {
         if (null == parentMsgRef) {
             return Collections.emptyMap();
         }
@@ -575,7 +620,7 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
         Map<String, String> groupedSeqIDs = new HashMap<String, String>(len);
         for (int i = 1; i < len; i++) {
             JSONObject jAttachment = jAttachments.getJSONObject(i);
-            String seqId = jAttachment.hasAndNotNull(MailListField.ID.getKey()) ? jAttachment.getString(MailListField.ID.getKey()) : null;
+            String seqId = jAttachment.optString(MailListField.ID.getKey(), null);
             if (seqId != null) {
                 // If "msgref" is defined in attachment itself, the referenced mail itself is meant to be attached and not an attachment
                 if (!jAttachment.hasAndNotNull(MSGREF)) {
@@ -593,18 +638,25 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
         MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = null;
         try {
             mailAccess = context.getConnectedMailAccess(parentMsgRef.getAccountId());
-            return loadMultipleRefs(groupedSeqIDs, parentMsgRef, contentIds, mailAccess, context);
+            CryptographicAwareMailAccessFactory cryptoMailAccessFactory = MailJSONActivator.SERVICES.get().getOptionalService(CryptographicAwareMailAccessFactory.class);
+            if(cryptoMailAccessFactory != null) {
+                mailAccess = cryptoMailAccessFactory.createAccess(
+                    (MailAccess<IMailFolderStorage, IMailMessageStorage>) mailAccess,
+                    context.getSession(),
+                    cryptoAuth);
+            }
+            return loadMultipleRefs(groupedSeqIDs, parentMsgRef, originalMsgRef, contentIds, mailAccess, context);
         } catch (OXException oe) {
             if (null == mailAccess || !shouldRetry(oe)) {
                 throw oe;
             }
 
             mailAccess = context.reconnectMailAccess(mailAccess.getAccountId());
-            return loadMultipleRefs(groupedSeqIDs, parentMsgRef, contentIds, mailAccess, context);
+            return loadMultipleRefs(groupedSeqIDs, parentMsgRef, originalMsgRef, contentIds, mailAccess, context);
         }
     }
 
-    protected Map<String, ReferencedMailPart> loadMultipleRefs(Map<String, String> groupedSeqIDs, MailPath parentMsgRef, Set<String> contentIds, MailAccess<?, ?> access, ComposeContext context) throws OXException {
+    protected Map<String, ReferencedMailPart> loadMultipleRefs(Map<String, String> groupedSeqIDs, MailPath parentMsgRef, MailPath originalMsgRef, Set<String> contentIds, MailAccess<?, ?> access, ComposeContext context) throws OXException {
         MailMessage referencedMail = access.getMessageStorage().getMessage(parentMsgRef.getFolder(), parentMsgRef.getMailID(), false);
         if (null == referencedMail) {
             throw MailExceptionCode.REFERENCED_MAIL_NOT_FOUND.create(parentMsgRef.getMailID(), parentMsgRef.getFolder());
@@ -622,9 +674,43 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
         }
 
         if (!groupedSeqIDs.isEmpty()) {
-            for (String seqId : groupedSeqIDs.keySet()) {
-                if (!contentIds.contains(seqId)) {
-                    throw MailExceptionCode.ATTACHMENT_NOT_FOUND.create(seqId, Long.valueOf(referencedMail.getMailId()), referencedMail.getFolder());
+            if (null == originalMsgRef) {
+                // Throw an exception for parts that were not loaded
+                for (String seqId : groupedSeqIDs.keySet()) {
+                    if (!contentIds.contains(seqId)) {
+                        throw MailExceptionCode.ATTACHMENT_NOT_FOUND.create(seqId, Long.valueOf(referencedMail.getMailId()), referencedMail.getFolder());
+                    }
+                }
+            } else {
+                // Retry loading referenced parts using original msgref
+                Set<String> retries = new LinkedHashSet<>(groupedSeqIDs.size());
+                for (String seqId : groupedSeqIDs.keySet()) {
+                    if (!contentIds.contains(seqId)) {
+                        retries.add(seqId);
+                    }
+                }
+
+                if (!retries.isEmpty()) {
+                    MailMessage originalMessage = access.getMessageStorage().getMessage(originalMsgRef.getFolder(), originalMsgRef.getMailID(), false);
+                    if (null != originalMessage) {
+                        originalMessage.setAccountId(access.getAccountId());
+                        MultipleMailPartHandler handler2 = new MultipleMailPartHandler(retries, false);
+                        new MailMessageParser().parseMailMessage(originalMessage, handler2);
+                        for (Map.Entry<String, MailPart> e : handler2.getMailParts().entrySet()) {
+                            String seqId = e.getKey();
+                            loadedParts.put(seqId, context.getProvider().getNewReferencedPart(e.getValue(), context.getSession()));
+                            retries.remove(seqId);
+                        }
+                    }
+
+                    if (!retries.isEmpty()) {
+                        // Throw an exception for parts that were not loaded
+                        for (String seqId : retries) {
+                            if (!contentIds.contains(seqId)) {
+                                throw MailExceptionCode.ATTACHMENT_NOT_FOUND.create(seqId, Long.valueOf(referencedMail.getMailId()), referencedMail.getFolder());
+                            }
+                        }
+                    }
                 }
             }
         }
@@ -705,20 +791,13 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
             /*
              * From Only mandatory if non-draft message
              */
-            String fromKey = MailJSONField.FROM.getKey();
-            if (jMail.hasAndNotNull(fromKey)) {
-                try {
-                    String value = jMail.getString(fromKey);
-                    int endPos;
-                    if ('[' == value.charAt(0) && (endPos = value.indexOf(']', 1)) < value.length()) {
-                        value = new StringBuilder(32).append("\"[").append(value.substring(1, endPos)).append("]\"").append(value.substring(endPos+1)).toString();
-                    }
-                    composedMail.addFrom(parseAddressList(value, true, true));
-                } catch (AddressException e) {
-                    composedMail.addFrom(parseAddressKey(fromKey, jMail, forTransport));
+            {
+                InternetAddress[] fromAddresses = parseAddressKey(MailJSONField.FROM.getKey(), jMail, forTransport);
+                if (null != fromAddresses && fromAddresses.length > 0) {
+                    composedMail.addFrom(fromAddresses);
+                } else if (forTransport) {
+                    throw MailExceptionCode.MISSING_FIELD.create(MailJSONField.FROM.getKey());
                 }
-            } else if (forTransport) {
-                throw MailExceptionCode.MISSING_FIELD.create(fromKey);
             }
             /*
              * To Only mandatory if non-draft message
@@ -786,7 +865,7 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
              * VCard
              */
             if (jMail.hasAndNotNull(MailJSONField.VCARD.getKey())) {
-                composedMail.setAppendVCard((jMail.getInt(MailJSONField.VCARD.getKey()) > 0));
+                composedMail.setAppendVCard(AJAXRequestDataTools.parseBoolParameter(jMail.getString(MailJSONField.VCARD.getKey())));
             }
             /*
              * Msg Ref
@@ -822,6 +901,35 @@ public abstract class AbstractComposeHandler<T extends ComposeContext, D extends
                 int offset = timeZone.getOffset(date.getTime());
                 composedMail.setReceivedDate(new Date(jMail.getLong(MailJSONField.RECEIVED_DATE.getKey()) - offset));
             }
+            /*
+             * Security settings
+             */
+            {
+                ServiceLookup services = MailJSONActivator.SERVICES.get();
+                CryptographicServiceAuthenticationFactory authenticationFactory = null == services ? null : services.getOptionalService(CryptographicServiceAuthenticationFactory.class);
+                String authentication = null;
+                if (authenticationFactory != null) {
+                    AJAXRequestData request = composeRequest.getRequest();
+                    if (request != null) {
+                        authentication = authenticationFactory.createAuthenticationFrom(request);
+                    }
+                }
+                JSONObject jSecuritySettings = jMail.optJSONObject("security");
+                if (null != jSecuritySettings) {
+                    SecuritySettings settings = SecuritySettings.builder()
+                        .encrypt(jSecuritySettings.optBoolean("encrypt", false))
+                        .pgpInline(jSecuritySettings.optBoolean("pgpInline", false))
+                        .sign(jSecuritySettings.optBoolean("sign", false))
+                        .authentication(authentication)
+                        .guestLanguage(jSecuritySettings.optString("language", null))
+                        .guestMessage(jSecuritySettings.optString("message", null))
+                        .pin(jSecuritySettings.optString("pin", null))
+                        .build();
+                    if (settings.anythingSet()) {
+                        composedMail.setSecuritySettings(settings);
+                    }
+                }
+            }
             /*
              * Drop special "x-original-headers" header
              */
