@@ -60,6 +60,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
+import com.openexchange.cluster.timer.ClusterTimerService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.DefaultFile;
@@ -104,7 +105,6 @@ import com.openexchange.share.ShareTarget;
 import com.openexchange.share.recipient.AnonymousRecipient;
 import com.openexchange.share.recipient.ShareRecipient;
 import com.openexchange.timer.ScheduledTimerTask;
-import com.openexchange.timer.TimerService;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tx.TransactionAware;
 import com.openexchange.tx.TransactionAwares;
@@ -132,28 +132,52 @@ public class DefaultAttachmentStorage implements AttachmentStorage {
     /**
      * Initializes this attachment storage.
      *
-     * @param configService The config service
-     * @param timerService The timer service
      * @return The initialized instance
-     * @throws OXException If instance cannot be returned
      */
-    public static synchronized void startInstance(ConfigurationService configService, TimerService timerService) throws OXException {
+    public static synchronized void startInstance() {
         DefaultAttachmentStorage tmp = instance;
         if (null == tmp) {
             tmp = new DefaultAttachmentStorage("default");
-
-            long cleanerInterval = Utilities.parseTimespanProperty("com.openexchange.mail.compose.share.periodicCleanerInterval", DAYS.toMillis(1), HOURS.toMillis(1), true, configService);
-            if (0 < cleanerInterval) {
-                DefaultAttachmentStoragePeriodicCleaner cleaner = new DefaultAttachmentStoragePeriodicCleaner(tmp.id);
-                long shiftMillis = TimeUnit.MILLISECONDS.convert((long)(Math.random() * 100), TimeUnit.MINUTES);
-                ScheduledTimerTask timerTask = timerService.scheduleWithFixedDelay(cleaner, cleanerInterval + shiftMillis, cleanerInterval);
-                tmp.setCleanerInfo(cleaner, timerTask);
-            }
-
             instance = tmp;
         }
     }
 
+    /**
+     * Initializes the periodic cleaner.
+     *
+     * @param configService The config service
+     * @param timerService The timer service
+     * @throws OXException If cleaner cannot be initialized
+     */
+    public static synchronized void initiateCleaner(ConfigurationService configService, ClusterTimerService timerService) throws OXException {
+        DefaultAttachmentStorage tmp = instance;
+        if (null == tmp) {
+            throw new IllegalStateException("DefaultAttachmentStorage not yet started");
+        }
+
+        long cleanerInterval = Utilities.parseTimespanProperty("com.openexchange.mail.compose.share.periodicCleanerInterval", DAYS.toMillis(1), HOURS.toMillis(1), true, configService);
+        if (0 < cleanerInterval) {
+            DefaultAttachmentStoragePeriodicCleaner cleaner = new DefaultAttachmentStoragePeriodicCleaner(tmp.id);
+            long shiftMillis = TimeUnit.MILLISECONDS.convert((long)(Math.random() * 100), TimeUnit.MINUTES);
+            ScheduledTimerTask timerTask = timerService.scheduleWithFixedDelay(DefaultAttachmentStoragePeriodicCleaner.class.getName(), cleaner, cleanerInterval + shiftMillis, cleanerInterval);
+            tmp.setCleanerInfo(cleaner, timerTask);
+        }
+    }
+
+    /**
+     * Drops the periodic cleaner.
+     *
+     * @throws OXException If cleaner cannot be dropped
+     */
+    public static synchronized void dropCleaner() {
+        DefaultAttachmentStorage tmp = instance;
+        if (null == tmp) {
+            return;
+        }
+
+        tmp.halt();
+    }
+
     /**
      * Shuts down this attachment storage.
      */
@@ -361,10 +385,9 @@ public class DefaultAttachmentStorage implements AttachmentStorage {
         if (Strings.isEmpty(toSanitize)) {
             toSanitize = defaultName;
         } else {
-            toSanitize = toSanitize.trim();
-
             boolean sanitize = true;
             while (sanitize) {
+                toSanitize = toSanitize.trim();
                 sanitize = false;
 
                 String illegalCharacters = FilenameValidationUtils.getIllegalCharacters(toSanitize);
@@ -376,9 +399,21 @@ public class DefaultAttachmentStorage implements AttachmentStorage {
                     }
                 } else {
                     ValidityResult validity = FilenameValidationUtils.getValidityFor(toSanitize);
-                    if (!validity.isValid()) {
-                        sanitize = true;
-                        toSanitize = defaultName;
+                    switch (validity.getViolation()) {
+                        case ONLY_DOTS:
+                            sanitize = true;
+                            toSanitize = defaultName;
+                            break;
+                        case OTHER_ILLEGAL:
+                            sanitize = true;
+                            toSanitize = toSanitize.length() > 1 ? toSanitize.substring(0, toSanitize.length() - 1) : defaultName;
+                            break;
+                        case RESERVED_NAME:
+                            sanitize = true;
+                            toSanitize = defaultName;
+                            break;
+                        default:
+                            break;
                     }
                 }
             }
