@@ -69,6 +69,7 @@ import org.json.JSONObject;
 import org.json.JSONValue;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.Mail;
+import com.openexchange.ajax.SessionServlet;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.helper.ParamContainer;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -81,6 +82,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.json.cache.JsonCacheService;
 import com.openexchange.json.cache.JsonCaches;
+import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.MailFields;
@@ -89,6 +91,7 @@ import com.openexchange.mail.MailListField;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.MailSortField;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.config.MaliciousFolders;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailThread;
 import com.openexchange.mail.dataobjects.MailThreads;
@@ -99,13 +102,15 @@ import com.openexchange.mail.json.MailRequestSha1Calculator;
 import com.openexchange.mail.json.actions.AbstractMailAction;
 import com.openexchange.mail.json.utils.Column;
 import com.openexchange.mail.json.writer.MessageWriter;
-import com.openexchange.mail.json.writer.MessageWriterParams;
 import com.openexchange.mail.json.writer.MessageWriter.MailFieldWriter;
+import com.openexchange.mail.json.writer.MessageWriterParams;
 import com.openexchange.mail.mime.MimeFilter;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.DisplayMode;
+import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mail.utils.MailMessageComparator;
+import com.openexchange.mail.utils.SizePolicy;
 import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
@@ -282,9 +287,9 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             if (null != originalId) {
                 jMailThread.put("rootOriginalMailId", originalId);
             }
-            String originalFolder = rootMessage.getOriginalFolder();
+            FullnameArgument originalFolder = rootMessage.getOriginalFolder();
             if (null != originalFolder) {
-                jMailThread.put("rootOriginalFolderId", originalFolder);
+                jMailThread.put("rootOriginalFolderId", originalFolder.getFullName());
             }
         }
 
@@ -294,9 +299,9 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             if (null != originalId) {
                 jMailThread.put("latestOriginalMailId", originalId);
             }
-            String originalFolder = latestMessage.getOriginalFolder();
+            FullnameArgument originalFolder = latestMessage.getOriginalFolder();
             if (null != originalFolder) {
-                jMailThread.put("latestOriginalFolderId", originalFolder);
+                jMailThread.put("latestOriginalFolderId", originalFolder.getFullName());
             }
         }
         jMailThread.put("latestReceivedDate", MessageWriter.addUserTimezone(latestMessage.getReceivedDate().getTime(), timeZone));
@@ -660,20 +665,20 @@ public final class MailConverter implements ResultConverter, MailActionConstants
         }
         tmp = paramContainer.getStringParam("embedded");
         final boolean embedded = (tmp != null && ("1".equals(tmp) || Boolean.parseBoolean(tmp)));
+        tmp = paramContainer.getStringParam("process_plain_text");
+        boolean asMarkup = (tmp == null || (!"0".equals(tmp) && Boolean.parseBoolean(tmp)));
         tmp = paramContainer.getStringParam("includePlainText");
         final boolean includePlainText = (tmp != null && ("1".equals(tmp) || Boolean.parseBoolean(tmp)));
         tmp = paramContainer.getStringParam("ignorable");
-        final MimeFilter mimeFilter;
-        if (com.openexchange.java.Strings.isEmpty(tmp)) {
-            mimeFilter = null;
-        } else {
-            final String[] strings = SPLIT.split(tmp, 0);
-            final int length = strings.length;
+        MimeFilter mimeFilter = null;
+        if (false == com.openexchange.java.Strings.isEmpty(tmp)) {
+            String[] strings = SPLIT.split(tmp, 0);
+            int length = strings.length;
             MimeFilter mf;
             if (1 == length && (mf = MimeFilter.filterFor(strings[0])) != null) {
                 mimeFilter = mf;
             } else {
-                final List<String> ignorableContentTypes = new ArrayList<String>(length);
+                List<String> ignorableContentTypes = new ArrayList<String>(length);
                 for (int i = 0; i < length; i++) {
                     final String cts = strings[i];
                     if ("ics".equalsIgnoreCase(cts)) {
@@ -700,6 +705,15 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             usmNoSave.setAllowHTMLImages(true);
         }
         final String folderPath = paramContainer.checkStringParam(AJAXServlet.PARAMETER_FOLDERID);
+        /*
+         * Check for malicious folder
+         */
+        {
+            FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(folderPath);
+            if (MaliciousFolders.instanceFor(session).isMalicious(fa.getFullName(), fa.getAccountId(), mailInterface)) {
+                usmNoSave.setSuppressLinks(true);
+            }
+        }
         /*
          * Check for possible unseen action
          */
@@ -716,13 +730,25 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             String str = paramContainer.getStringParam(Mail.PARAMETER_ALLOW_NESTED_MESSAGES);
             allowNestedMessages = null == str ? true : AJAXRequestDataTools.parseBoolParameter(str);
         }
-        boolean exactLength = AJAXRequestDataTools.parseBoolParameter(paramContainer.getStringParam("exact_length"));
+        SizePolicy sizePolicy;
+        {
+            boolean b = AJAXRequestDataTools.parseBoolParameter(paramContainer.getStringParam("exact_length"));
+            if (b) {
+                sizePolicy = SizePolicy.EXACT;
+            } else {
+                b = AJAXRequestDataTools.parseBoolParameter(paramContainer.getStringParam("estimate_length"));
+                sizePolicy = b ? SizePolicy.ESTIMATE : SizePolicy.NONE;
+            }
+        }
+        boolean handleNestedMessageAsAttachment = AJAXRequestDataTools.parseBoolParameter(paramContainer.getStringParam("no_nested_message"));
+
         JSONObject jMail;
         try {
             MessageWriterParams params = MessageWriterParams.builder(mail.getAccountId(), mail, session)
                                                             .setDisplayMode(displayMode)
                                                             .setEmbedded(embedded)
-                                                            .setExactLength(exactLength)
+                                                            .setAsMarkup(asMarkup)
+                                                            .setSizePolicy(sizePolicy)
                                                             .setIncludePlainText(includePlainText)
                                                             .setMaxContentSize(maxContentSize)
                                                             .setMaxNestedMessageLevels(allowNestedMessages ? -1 : 1)
@@ -732,9 +758,21 @@ public final class MailConverter implements ResultConverter, MailActionConstants
                                                             .setToken(token)
                                                             .setTokenTimeout(ttlMillis)
                                                             .setWarnings(warnings)
+                                                            .setHandleNestedMessageAsAttachment(handleNestedMessageAsAttachment)
                                                             .build();
             jMail = MessageWriter.writeMailMessage(params);
         } catch (final OXException e) {
+            if (DisplayMode.DOCUMENT.isIncluded(displayMode)) {
+                HttpServletResponse resp = paramContainer.getHttpServletResponse();
+                if (resp != null) {
+                    try {
+                        SessionServlet.writeErrorPage(HttpServletResponse.SC_NOT_FOUND, e.getDisplayMessage(session.getUser().getLocale()), resp);
+                    } catch (IOException e1) {
+                        LOG.warn("Unable to write error page.", e1);
+                    }
+                    return null;
+                }
+            }
             if (MailExceptionCode.MESSAGING_ERROR.equals(e)) {
                 final Throwable cause = e.getCause();
                 if (cause instanceof javax.mail.MessageRemovedException) {
@@ -806,7 +844,9 @@ public final class MailConverter implements ResultConverter, MailActionConstants
         String view = requestData.getParameter(Mail.PARAMETER_VIEW);
         view = null == view ? null : view.toLowerCase(Locale.US);
         String tmp = requestData.getParameter("embedded");
-        final boolean embedded = (tmp != null && ("1".equals(tmp) || Boolean.parseBoolean(tmp)));
+        boolean embedded = (tmp != null && ("1".equals(tmp) || Boolean.parseBoolean(tmp)));
+        tmp = requestData.getParameter("process_plain_text");
+        boolean asMarkup = (tmp == null || (!"0".equals(tmp) && Boolean.parseBoolean(tmp)));
         tmp = null;
         final UserSettingMail usmNoSave = session.getUserSettingMail().clone();
         /*
@@ -821,9 +861,21 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             usmNoSave.setAllowHTMLImages(true);
         }
         int maxContentSize = AJAXRequestDataTools.parseIntParameter(requestData.getParameter(Mail.PARAMETER_MAX_SIZE), -1);
+        /*
+         * Check for malicious folder
+         */
+        {
+            String folderPath = requestData.getParameter(AJAXServlet.PARAMETER_FOLDERID);
+            if (null != folderPath) {
+                FullnameArgument fa = MailFolderUtility.prepareMailFolderParam(folderPath);
+                if (MaliciousFolders.instanceFor(session).isMalicious(fa.getFullName(), fa.getAccountId(), getMailInterface(requestData, session))) {
+                    usmNoSave.setSuppressLinks(true);
+                }
+            }
+        }
         boolean allowNestedMessages = AJAXRequestDataTools.parseBoolParameter(Mail.PARAMETER_ALLOW_NESTED_MESSAGES, requestData, true);
         List<OXException> warnings = new ArrayList<OXException>(2);
-        JSONObject jsonObject = MessageWriter.writeMailMessage(mail.getAccountId(), mail, displayMode, embedded, session, usmNoSave, warnings, false, -1, null, null, false, maxContentSize, allowNestedMessages ? -1 : 1);
+        JSONObject jsonObject = MessageWriter.writeMailMessage(mail.getAccountId(), mail, displayMode, embedded, asMarkup, session, usmNoSave, warnings, false, -1, null, null, SizePolicy.NONE, maxContentSize, allowNestedMessages ? -1 : 1);
 
         {
             String csid = (String) result.getParameter("csid");
