@@ -50,6 +50,7 @@
 package com.openexchange.mail.mime;
 
 import static com.openexchange.exception.ExceptionUtils.isEitherOf;
+import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.io.IOException;
 import java.net.SocketException;
@@ -66,12 +67,20 @@ import javax.mail.Store;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
 import com.openexchange.log.LogProperties.Name;
 import com.openexchange.mail.MailExceptionCode;
+import com.openexchange.mail.api.AuthType;
 import com.openexchange.mail.api.MailConfig;
+import com.openexchange.mailaccount.Account;
 import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.oauth.API;
+import com.openexchange.oauth.OAuthAccount;
+import com.openexchange.oauth.OAuthExceptionCodes;
+import com.openexchange.oauth.OAuthService;
 import com.openexchange.osgi.ServiceListing;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.exceptions.ExceptionUtils;
 import com.sun.mail.iap.CommandFailedException;
@@ -241,6 +250,14 @@ public class MimeMailException extends OXException {
             if ((e instanceof javax.mail.AuthenticationFailedException) || ((toLowerCase(e.getMessage(), "").indexOf(ERR_AUTH_FAILED) != -1))) {
                 // Authentication failed
                 return handleAuthenticationFailedException(e, mailConfig, session);
+            } else if (e instanceof javax.mail.AuthorizationFailedException) {
+                return MimeMailExceptionCode.AUTHORIZATION_FAILED.create(e, mailConfig == null ? STR_EMPTY : mailConfig.getServer(), mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
+            } else if (e instanceof javax.mail.TemporaryAuthenticationFailureException) {
+                return MimeMailExceptionCode.TEMPORARY_AUTH_FAILURE.create(e, mailConfig == null ? STR_EMPTY : mailConfig.getServer(), mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
+            } else if (e instanceof javax.mail.PasswordExpiredException) {
+                return MimeMailExceptionCode.PASSWORD_EXPIRED.create(e, mailConfig == null ? STR_EMPTY : mailConfig.getServer(), mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
+            } else if (e instanceof javax.mail.PrivacyRequiredException) {
+                return MimeMailExceptionCode.PRIVACY_REQUIRED.create(e, mailConfig == null ? STR_EMPTY : mailConfig.getServer(), mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
             } else if (e instanceof javax.mail.FolderClosedException) {
                 if (isTimeoutException(e)) {
                     // javax.mail.FolderClosedException through a read timeout
@@ -479,7 +496,8 @@ public class MimeMailException extends OXException {
                         mailConfig.getLogin(),
                         Integer.valueOf(session.getUserId()),
                         Integer.valueOf(session.getContextId()),
-                        appendInfo(getInfo(skipTag(nextException.getMessage())), folder));
+                        appendInfo(getInfo(skipTag(nextException.getMessage())), folder),
+                        getDisplayName(mailConfig));
                 }
                 return MimeMailExceptionCode.QUOTA_EXCEEDED.create(nextException, appendInfo(getInfo(skipTag(nextException.getMessage())), folder));
             } else if (nextException instanceof com.sun.mail.iap.CommandFailedException) {
@@ -499,7 +517,8 @@ public class MimeMailException extends OXException {
                             mailConfig.getLogin(),
                             Integer.valueOf(session.getUserId()),
                             Integer.valueOf(session.getContextId()),
-                            appendInfo(getInfo(skipTag(nextException.getMessage())), folder));
+                            appendInfo(getInfo(skipTag(nextException.getMessage())), folder),
+                            getDisplayName(mailConfig));
                     }
                     return MimeMailExceptionCode.QUOTA_EXCEEDED.create(nextException, appendInfo(getInfo(skipTag(nextException.getMessage())), folder));
                 }
@@ -571,7 +590,7 @@ public class MimeMailException extends OXException {
             return MimeMailExceptionCode.MESSAGING_ERROR.create(e, appendInfo(e.getMessage(), folder));
         }
     }
-
+    
     /**
      * Handles specified IMAP protocol exception by its possibly available <a href="https://tools.ietf.org/html/rfc5530">response code</a>.<br>
      * If no such response code is present, <code>null</code> is returned.
@@ -648,7 +667,8 @@ public class MimeMailException extends OXException {
                             mailConfig.getLogin(),
                             Integer.valueOf(session.getUserId()),
                             Integer.valueOf(session.getContextId()),
-                            appendInfo(getInfo(skipTag(pe.getMessage())), folder));
+                            appendInfo(getInfo(skipTag(pe.getMessage())), folder),
+                            getDisplayName(mailConfig));
                     }
                     return MimeMailExceptionCode.QUOTA_EXCEEDED.create(pe, appendInfo(getInfo(skipTag(pe.getMessage())), folder));
                 }
@@ -658,6 +678,8 @@ public class MimeMailException extends OXException {
                 break;
             case UNAVAILABLE:
                 return MailExceptionCode.SUBSYSTEM_DOWN.create(pe, new Object[0]);
+            case TRYCREATE:
+                return MimeMailExceptionCode.TRYCREATE.create(pe, new Object[0]);
             default:
                 break;
         }
@@ -680,40 +702,69 @@ public class MimeMailException extends OXException {
     }
 
     private static OXException handleAuthenticationFailedException(Exception authenticationFailedException, MailConfig mailConfig, Session session) {
-        // Authentication failed
+        // Authentication failed...
+
+        // OAuth token expired?
+        if (null != mailConfig && AuthType.isOAuthType(mailConfig.getAuthType())) {
+            if (MailAccount.DEFAULT_ID == mailConfig.getAccountId()) {
+                // OAuth token expired for primary account
+                return createInvalidCredentialsException(authenticationFailedException, mailConfig, session);
+            }
+
+            Account account = mailConfig.getAccount();
+            if (account instanceof MailAccount) {
+                MailAccount mailAccount = (MailAccount) account;
+                if (mailAccount.isMailOAuthAble() && mailAccount.getMailOAuthId() >= 0) {
+                    OAuthService oauthService = ServerServiceRegistry.getInstance().getService(OAuthService.class);
+                    if (null != oauthService) {
+                        OAuthAccount oAuthAccount;
+                        try {
+                            oAuthAccount = oauthService.getAccount(mailAccount.getMailOAuthId(), session, session.getUserId(), session.getContextId());
+                        } catch (Exception x) {
+                            LOG.warn("Failed to load mail-associated OAuth account", x);
+                            oAuthAccount = null;
+                        }
+                        if (null != oAuthAccount) {
+                            API api = oAuthAccount.getAPI();
+                            return OAuthExceptionCodes.OAUTH_ACCESS_TOKEN_INVALID.create(api.getName(), I(oAuthAccount.getId()), I(session.getUserId()), I(session.getContextId()));
+                        }
+                    }
+                }
+            }
+        }
+
+        // Primary account?
         if (null != mailConfig && MailAccount.DEFAULT_ID == mailConfig.getAccountId()) {
             return MimeMailExceptionCode.LOGIN_FAILED.create(authenticationFailedException, mailConfig.getServer(), mailConfig.getLogin());
         }
+
+        // Temporary nature?
         if ((authenticationFailedException.getMessage() != null) && ERR_TMP.equals(com.openexchange.java.Strings.toLowerCase(authenticationFailedException.getMessage()))) {
-            return MimeMailExceptionCode.LOGIN_FAILED.create(
-                authenticationFailedException,
-                mailConfig == null ? STR_EMPTY : mailConfig.getServer(),
-                    mailConfig == null ? STR_EMPTY : mailConfig.getLogin());
+            String server = mailConfig == null ? STR_EMPTY : mailConfig.getServer();
+            String login = mailConfig == null ? STR_EMPTY : mailConfig.getLogin();
+            return MimeMailExceptionCode.LOGIN_FAILED.create(authenticationFailedException, server, login);
         }
+
+        // Advertise invalid credential w/ or w/o additional info
+        return createInvalidCredentialsException(authenticationFailedException, mailConfig, session);
+    }
+
+    private static OXException createInvalidCredentialsException(Exception authenticationFailedException, MailConfig mailConfig, Session session) {
         if (null != mailConfig && null != session) {
-            return MimeMailExceptionCode.INVALID_CREDENTIALS_EXT.create(
-                authenticationFailedException,
-                mailConfig.getServer(),
-                mailConfig.getLogin(),
-                Integer.valueOf(session.getUserId()),
-                Integer.valueOf(session.getContextId()),
-                authenticationFailedException.getMessage());
+            String server = mailConfig.getServer();
+            String login = mailConfig.getLogin();
+            return MimeMailExceptionCode.INVALID_CREDENTIALS_EXT.create(authenticationFailedException, server, login, I(session.getUserId()), I(session.getContextId()), authenticationFailedException.getMessage());
         }
-        return MimeMailExceptionCode.INVALID_CREDENTIALS.create(
-            authenticationFailedException,
-            mailConfig == null ? STR_EMPTY : mailConfig.getServer(),
-                authenticationFailedException.getMessage());
+
+        String server = mailConfig == null ? STR_EMPTY : mailConfig.getServer();
+        return MimeMailExceptionCode.INVALID_CREDENTIALS.create(authenticationFailedException, server, authenticationFailedException.getMessage());
     }
 
     private static OXException handleIOException(IOException ioException, MailConfig mailConfig, Session session, Folder folder) {
         if (null != mailConfig && null != session) {
-            return MimeMailExceptionCode.IO_ERROR_EXT.create(
-                ioException,
-                appendInfo(ioException.getMessage(), folder),
-                mailConfig.getServer(),
-                mailConfig.getLogin(),
-                Integer.valueOf(session.getUserId()),
-                Integer.valueOf(session.getContextId()));
+            String server = mailConfig.getServer();
+            String login = mailConfig.getLogin();
+            return MimeMailExceptionCode.IO_ERROR_EXT.create(ioException, appendInfo(ioException.getMessage(), folder), server, login, I(session.getUserId()), I(session.getContextId()));
         }
         return MimeMailExceptionCode.IO_ERROR.create(ioException, appendInfo(ioException.getMessage(), folder));
     }
@@ -1094,5 +1145,23 @@ public class MimeMailException extends OXException {
         }
         return builder.toString();
     }
-
+    
+    /**
+     * Retrieves the display name from the specified {@link MailConfig}.
+     * If no {@link Account} is attached to the {@link MailConfig} or
+     * no display name is present, then the login name is returned.
+     * 
+     * @param mailConfig The {@link MailConfig}
+     * @return The display name
+     */
+    private static String getDisplayName(MailConfig mailConfig) {
+        if (null == mailConfig.getAccount()) {
+            return mailConfig.getLogin();
+        }
+        Account account = mailConfig.getAccount();
+        if (Strings.isEmpty(account.getName())) {
+            return mailConfig.getLogin();
+        }
+        return mailConfig.getAccount().getName();
+    }
 }
