@@ -120,6 +120,7 @@ import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.config.MailReloadable;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
+import com.openexchange.mail.dataobjects.SecuritySettings;
 import com.openexchange.mail.dataobjects.compose.ComposeType;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.dataobjects.compose.ComposedMailPart;
@@ -142,6 +143,7 @@ import com.openexchange.mail.mime.utils.sourcedimage.SourcedImage;
 import com.openexchange.mail.mime.utils.sourcedimage.SourcedImageUtility;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
+import com.openexchange.mail.utils.IpAddressRenderer;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
@@ -297,17 +299,18 @@ public class MimeMessageFiller {
         /*
          * Set mailer
          */
-        mimeMessage.setHeader(HDR_X_MAILER, "Open-Xchange Mailer v" + Version.getInstance().getVersionString());
+        mimeMessage.setHeader(HDR_X_MAILER, getMailerInfo());
         /*
          * Set organization to context-admin's company field setting
          */
+        MailProperties mailProperties = MailProperties.getInstance();
         if (accountId <= 0) {
             try {
                 final String organization = compositionParameters.getOrganization();
                 if (null != organization && 0 < organization.length()) {
                     final String encoded = MimeUtility.fold(
                         14,
-                        MimeUtility.encodeText(organization, MailProperties.getInstance().getDefaultMimeCharset(), null));
+                        MimeUtility.encodeText(organization, mailProperties.getDefaultMimeCharset(), null));
                     mimeMessage.setHeader(HDR_ORGANIZATION, encoded);
                 }
             } catch (final Exception e) {
@@ -317,14 +320,14 @@ public class MimeMessageFiller {
         /*
          * Add header X-Originating-IP containing the IP address of the client
          */
-        if (MailProperties.getInstance().isAddClientIPAddress()) {
-            addClientIPAddress(mimeMessage);
+        if (mailProperties.isAddClientIPAddress()) {
+            addClientIPAddress(mimeMessage, mailProperties.getIpAddressRenderer());
         }
         {
             String client = compositionParameters.getClient();
             if (!Strings.isEmpty(client)) {
                 try {
-                    final String encoded = MimeUtility.fold(20, MimeUtility.encodeText(client, MailProperties.getInstance().getDefaultMimeCharset(), null));
+                    final String encoded = MimeUtility.fold(20, MimeUtility.encodeText(client, mailProperties.getDefaultMimeCharset(), null));
                     mimeMessage.setHeader(HDR_X_ORIGINATING_CLIENT, encoded);
                 } catch (final Exception e) {
                     LOG.warn("Header \"X-Originating-Client\" could not be set", e);
@@ -333,16 +336,29 @@ public class MimeMessageFiller {
         }
     }
 
+    /**
+     * Gets the value for the <code>X-Mailer</code> header.
+     *
+     * @return The value for the <code>X-Mailer</code> header
+     */
+    public static String getMailerInfo() {
+        if (MailProperties.getInstance().isAppendVersionToMailerHeader()) {
+            return new StringBuilder("Open-Xchange Mailer v").append(Version.getInstance().getVersionString()).toString();
+        }
+        return "Open-Xchange Mailer";
+    }
+
     /**
      * Add "X-Originating-IP" header.
      *
      * @param mimeMessage The MIME message
+     * @param renderer The renderer to use
      * @throws MessagingException If an error occurs
      */
-    private void addClientIPAddress(final MimeMessage mimeMessage) throws OXException, MessagingException {
+    private void addClientIPAddress(MimeMessage mimeMessage, IpAddressRenderer renderer) throws OXException, MessagingException {
         String originatingIP = compositionParameters.getOriginatingIP();
         if (originatingIP != null) {
-            mimeMessage.setHeader("X-Originating-IP", originatingIP);
+            mimeMessage.setHeader("X-Originating-IP", null == renderer ? originatingIP : renderer.render(originatingIP));
         }
     }
 
@@ -354,17 +370,19 @@ public class MimeMessageFiller {
      * @throws MessagingException If an error occurs
      */
     public static void addClientIPAddress(final MimeMessage mimeMessage, final Session session) throws MessagingException {
+        IpAddressRenderer renderer = MailProperties.getInstance().getIpAddressRenderer();
         /*
          * Get IP from session
          */
-        final String localIp = session.getLocalIp();
+        String localIp = session.getLocalIp();
         if (isLocalhost(localIp)) {
             LOG.debug("Session provides localhost as client IP address: {}", localIp);
             // Prefer request's remote address if local IP seems to denote local host
             String clientIp = LogProperties.getLogProperty(LogProperties.Name.GRIZZLY_REMOTE_ADDRESS);
-            mimeMessage.setHeader("X-Originating-IP", clientIp == null ? localIp : clientIp);
+            clientIp = clientIp == null ? localIp : clientIp;
+            mimeMessage.setHeader("X-Originating-IP", null == renderer ? clientIp : renderer.render(clientIp));
         } else {
-            mimeMessage.setHeader("X-Originating-IP", localIp);
+            mimeMessage.setHeader("X-Originating-IP", null == renderer ? localIp : renderer.render(localIp));
         }
     }
 
@@ -1056,50 +1074,56 @@ public class MimeMessageFiller {
     }
 
     private Multipart appendVCard(ComposedMailMessage mail, Multipart primaryMultipart, MimeMessage mimeMessage) throws OXException, MessagingException, UnsupportedEncodingException {
-        final String charset = MailProperties.getInstance().getDefaultMimeCharset();
-        final String fileName = compositionParameters.getUserVCardFileName();
-        AppendVCard: if (mail.isAppendVCard() && fileName != null) {
-            final String encodedFileName = MimeUtility.encodeText(fileName, charset, "Q");
-            for (int i = 0; i < mail.getEnclosedCount(); i++) {
-                final MailPart part = mail.getEnclosedMailPart(i);
-                if (encodedFileName.equalsIgnoreCase(part.getFileName())) {
-                    /*
-                     * VCard already attached in (former draft) message
-                     */
-                    break AppendVCard;
-                }
+        if (!mail.isAppendVCard()) {
+            // vCard is not supposed to be added
+            return primaryMultipart;
+        }
+
+        String fileName = compositionParameters.getUserVCardFileName();
+        if (fileName == null) {
+            // No vCard file name
+            return primaryMultipart;
+        }
+
+        String charset = MailProperties.getInstance().getDefaultMimeCharset();
+        String encodedFileName = MimeUtility.encodeText(fileName, charset, "Q");
+        int numberOfParts = mail.getEnclosedCount();
+        for (int i = numberOfParts; i-- > 0;) {
+            MailPart part = mail.getEnclosedMailPart(i);
+            String partFileName = part.getFileName();
+            if (null != partFileName && encodedFileName.equalsIgnoreCase(MimeUtility.encodeText(partFileName, charset, "Q"))) {
+                // vCard already attached in (former draft) message
+                return primaryMultipart;
             }
-            try {
-                /*
-                 * Create a body part for vcard
-                 */
-                final MimeBodyPart vcardPart = new MimeBodyPart();
-                /*
-                 * Define content
-                 */
-                final ContentType ct = new ContentType(MimeTypes.MIME_TEXT_VCARD);
-                ct.setCharsetParameter(charset);
-                vcardPart.setDataHandler(new DataHandler(new MessageDataSource(compositionParameters.getUserVCard(), ct.toString())));
-                if (!ct.containsNameParameter()) {
-                    ct.setNameParameter(encodedFileName);
-                }
-                vcardPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MimeMessageUtility.foldContentType(ct.toString()));
-                vcardPart.setHeader(HDR_MIME_VERSION, VERSION_1_0);
-                final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
-                cd.setFilenameParameter(encodedFileName);
-                vcardPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MimeMessageUtility.foldContentDisposition(cd.toString()));
-                /*
-                 * Append body part
-                 */
-                Multipart mp = null == primaryMultipart ? new MimeMultipart() : primaryMultipart;
-                mp.addBodyPart(vcardPart);
-                if (mail.isDraft()) {
-                    mimeMessage.setHeader(MessageHeaders.HDR_X_OX_VCARD, "true");
-                }
-                return mp;
-            } catch (final OXException e) {
-                LOG.error(VCARD_ERROR, e);
+        }
+
+        // No vCard attached so far...
+        try {
+            // Create a body part for vCard
+            MimeBodyPart vcardPart = new MimeBodyPart();
+
+            // Define content
+            ContentType ct = new ContentType(MimeTypes.MIME_TEXT_VCARD);
+            ct.setCharsetParameter(charset);
+            vcardPart.setDataHandler(new DataHandler(new MessageDataSource(compositionParameters.getUserVCard(), ct.toString())));
+            if (!ct.containsNameParameter()) {
+                ct.setNameParameter(encodedFileName);
             }
+            vcardPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MimeMessageUtility.foldContentType(ct.toString()));
+            vcardPart.setHeader(HDR_MIME_VERSION, VERSION_1_0);
+            final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
+            cd.setFilenameParameter(encodedFileName);
+            vcardPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MimeMessageUtility.foldContentDisposition(cd.toString()));
+
+            // Append body part
+            Multipart mp = null == primaryMultipart ? new MimeMultipart() : primaryMultipart;
+            mp.addBodyPart(vcardPart);
+            if (mail.isDraft()) {
+                mimeMessage.setHeader(MessageHeaders.HDR_X_OX_VCARD, "true");
+            }
+            return mp;
+        } catch (final OXException e) {
+            LOG.error(VCARD_ERROR, e);
         }
         return primaryMultipart;
     }
@@ -1231,7 +1255,7 @@ public class MimeMessageFiller {
         final List<String> cidList = MimeMessageUtility.getContentIDs(wellFormedHTMLContent);
         final StringBuilder tmp = new StringBuilder(32);
         NextImg: for (final String cid : cidList) {
-            final BodyPart relatedImageBodyPart;
+            final MimeBodyPart relatedImageBodyPart;
             final SourcedImage image = images.get(cid);
             if (null == image) {
                 /*
@@ -1246,9 +1270,13 @@ public class MimeMessageFiller {
                  */
                 relatedImageBodyPart = new MimeBodyPart();
                 relatedImageBodyPart.setDataHandler(imgPart.getDataHandler());
-                for (final Iterator<Map.Entry<String, String>> iter = imgPart.getHeadersIterator(); iter.hasNext();) {
-                    final Map.Entry<String, String> e = iter.next();
-                    relatedImageBodyPart.setHeader(e.getKey(), e.getValue());
+                tmp.setLength(0);
+                relatedImageBodyPart.setContentID(tmp.append('<').append(cid).append('>').toString());
+                for (Iterator<Map.Entry<String, String>> iter = imgPart.getHeadersIterator(); iter.hasNext();) {
+                    Map.Entry<String, String> e = iter.next();
+                    if (false == MessageHeaders.HDR_CONTENT_ID.equalsIgnoreCase(e.getKey())) {
+                        relatedImageBodyPart.setHeader(e.getKey(), e.getValue());
+                    }
                 }
             } else {
                 final DataSource dataSource;
@@ -1707,7 +1735,14 @@ public class MimeMessageFiller {
                                 continue;
                             }
                             ImageProvider tmp = null;
-                            String prefix = "<" + UUIDs.getUnformattedString(UUID.fromString(id));
+                            String prefix = null;
+                            try {
+                                prefix = "<" + UUIDs.getUnformattedString(UUID.fromString(id));
+                            } catch (IllegalArgumentException e) {
+                                // looks like the id is invalid. Skip image.
+                                m.appendLiteralReplacement(sb, blankSrc(imageTag));
+                                continue;
+                            }
                             for (int i = size; null == tmp && i-- > 0;) {
                                 MailPart part = mail.getEnclosedMailPart(i);
                                 if (ComposedPartType.REFERENCE.equals(((ComposedMailPart) part).getType())) {
@@ -1735,6 +1770,10 @@ public class MimeMessageFiller {
                                 ImageLocation il;
                                 try {
                                     il = ImageUtility.parseImageLocationFrom(PATTERN_AMP.matcher(srcMatcher.group(1)).replaceAll("&"));
+                                    SecuritySettings securitySettings = mail.getSecuritySettings();
+                                    if (null != securitySettings) {
+                                        il.setAuth(securitySettings.getAuthentication());
+                                    }
                                 } catch (final IllegalArgumentException e) {
                                     final StringBuffer bblankImageTag = new StringBuffer(imageTag.length());
                                     srcMatcher.appendReplacement(bblankImageTag, "");
