@@ -55,6 +55,7 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Date;
@@ -77,6 +78,7 @@ import net.freeutils.tnef.Attr;
 import net.freeutils.tnef.CompressedRTFInputStream;
 import net.freeutils.tnef.MAPIProp;
 import net.freeutils.tnef.MAPIProps;
+import net.freeutils.tnef.MAPIValue;
 import net.freeutils.tnef.RawInputStream;
 import net.freeutils.tnef.TNEFInputStream;
 import net.freeutils.tnef.TNEFUtils;
@@ -90,11 +92,11 @@ import org.bouncycastle.mail.smime.SMIMESigned;
 import com.openexchange.ajax.container.ThresholdFileHolder;
 import com.openexchange.exception.OXException;
 import com.openexchange.i18n.LocaleTools;
-import com.openexchange.java.CountingOutputStream;
+import com.openexchange.java.CharsetDetector;
+import com.openexchange.java.Charsets;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.mail.MailExceptionCode;
-import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
@@ -130,8 +132,6 @@ public final class MailMessageParser {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailMessageParser.class);
 
-    private static final String APPL_OCTET = MimeTypes.MIME_APPL_OCTET;
-
     private static final String HDR_CONTENT_DISPOSITION = MessageHeaders.HDR_CONTENT_DISPOSITION;
 
     private static final String HDR_CONTENT_TYPE = MessageHeaders.HDR_CONTENT_TYPE;
@@ -392,26 +392,22 @@ public final class MailMessageParser {
         handler.handleMessageEnd(mail);
     }
 
-    private void parseMailContent(final MailPart mailPartArg, final MailMessageHandler handler, final String prefix, final int partCountArg) throws OXException, IOException {
+    private void parseMailContent(final MailPart mailPart, final MailMessageHandler handler, final String prefix, final int partCountArg) throws OXException, IOException {
         if (stop) {
             return;
         }
-        /*
-         * Part modifier
-         */
-        final MailPart mailPart = MailConfig.usePartModifier() ? MailConfig.getPartModifier().modifyPart(mailPartArg) : mailPartArg;
         /*
          * Set part information
          */
         int partCount = partCountArg;
         final String disposition = mailPart.containsContentDisposition() ? mailPart.getContentDisposition().getDisposition() : null;
         final long size = mailPart.getSize();
-        final ContentType contentType = mailPart.containsContentType() ? mailPart.getContentType() : new ContentType(APPL_OCTET);
+        final ContentType contentType = mailPart.containsContentType() ? mailPart.getContentType() : ContentType.APPLICATION_OCTETSTREAM_CONTENT_TYPE;
         final String lcct = LocaleTools.toLowerCase(contentType.getBaseType());
         if (null != mimeFilter && mimeFilter.ignorable(lcct, mailPart)) {
             return;
         }
-        final String fileName = getFileName(mailPart.getFileName(), getSequenceId(prefix, partCount), lcct);
+        final String fileName = getFileName(mailPart.getFileName(), contentType, getSequenceId(prefix, partCount), lcct);
         /*
          * Parse part dependent on its MIME type
          */
@@ -490,13 +486,18 @@ public final class MailMessageParser {
                 }
             } else {
                 if (isInline) {
-                    if (null != mailPart.getFileName()) {
-                        contentType.setParameter("realfilename", mailPart.getFileName());
+                    boolean dropTmpParameter = false;
+                    {
+                        String fn = mailPart.getFileName();
+                        if (null != fn) {
+                            contentType.setParameter("realfilename", fn);
+                            dropTmpParameter = true;
+                        }
                     }
                     try {
                         String content = readContent(mailPart, contentType, mailId, folder);
-                        UUEncodedMultiPart uuencodedMP = new UUEncodedMultiPart(content);
-                        if (uuencodedMP.isUUEncoded()) {
+                        UUEncodedMultiPart uuencodedMP = UUEncodedMultiPart.valueFor(content);
+                        if (null != uuencodedMP && uuencodedMP.isUUEncoded()) {
                             /*
                              * UUEncoded content detected. Handle normal text.
                              */
@@ -542,7 +543,9 @@ public final class MailMessageParser {
                             }
                         }
                     } finally {
-                        contentType.removeParameter("realfilename");
+                        if (dropTmpParameter) {
+                            contentType.removeParameter("realfilename");
+                        }
                     }
                 } else {
                     /*
@@ -612,7 +615,7 @@ public final class MailMessageParser {
                 stop = true;
                 return;
             }
-            
+
         } else if (TNEFUtils.isTNEFMimeType(lcct)) {
             try {
                 /*
@@ -712,9 +715,11 @@ public final class MailMessageParser {
                         part.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
                         {
                             final net.fortuna.ical4j.model.Component vEvent = calendar.getComponents().getComponent(net.fortuna.ical4j.model.Component.VEVENT);
-                            final Property summary = vEvent.getProperties().getProperty(net.fortuna.ical4j.model.Property.SUMMARY);
-                            if (summary != null) {
-                                part.setFileName(new StringBuilder(MimeUtility.encodeText(summary.getValue().replaceAll("\\s", "_"), MailProperties.getInstance().getDefaultMimeCharset(), "Q")).append(".ics").toString());
+                            if(vEvent != null) {
+                                final Property summary = vEvent.getProperties().getProperty(net.fortuna.ical4j.model.Property.SUMMARY);
+                                if (summary != null) {
+                                    part.setFileName(new StringBuilder(MimeUtility.encodeText(summary.getValue().replaceAll("\\s", "_"), MailProperties.getInstance().getDefaultMimeCharset(), "Q")).append(".ics").toString());
+                                }
                             }
                         }
                         /*
@@ -791,7 +796,7 @@ public final class MailMessageParser {
                             /*
                              * Translate TNEF attributes to MIME
                              */
-                            final String attachFilename = attachment.getFilename();
+                            final String attachFilename = getFileNameFromTnefAttachment(attachment);
                             String contentTypeStr = null;
                             if (attachment.getMAPIProps() != null) {
                                 contentTypeStr = (String) attachment.getMAPIProps().getPropValue(MAPIProp.PR_ATTACH_MIME_TAG);
@@ -799,7 +804,7 @@ public final class MailMessageParser {
                             if (null != contentTypeStr) {
                                 final String tmp = contentTypeStr.toLowerCase(Locale.US);
                                 if (tmp.startsWith("multipart/") && tmp.indexOf("boundary=") < 0) {
-                                    final MimeMessage nested = new MimeMessage(MimeDefaultSession.getDefaultSession(), attachment.getRawData());
+                                    MimeMessage nested = new MimeMessage(MimeDefaultSession.getDefaultSession(), attachment.getRawData());
                                     parseMailContent(MimeMessageConverter.convertMessage(nested, false), handler, prefix, partCount++);
                                     // Proceed with next attachment in list
                                     continue Next;
@@ -811,33 +816,22 @@ public final class MailMessageParser {
                             if (contentTypeStr == null) {
                                 contentTypeStr = MimeTypes.MIME_APPL_OCTET;
                             }
-                            final DataSource ds = new RawDataSource(attachment.getRawData(), contentTypeStr);
-                            bodyPart.setDataHandler(new DataHandler(ds));
-                            bodyPart.setHeader(
-                                HDR_CONTENT_TYPE,
-                                ContentType.prepareContentTypeString(contentTypeStr, attachFilename));
+
+                            RawInputStream ris = attachment.getRawData();
+                            bodyPart.setSize((int) ris.getLength());
+                            bodyPart.setDataHandler(new DataHandler(new RawDataSource(ris, contentTypeStr)));
+                            bodyPart.setHeader(HDR_CONTENT_TYPE, ContentType.prepareContentTypeString(contentTypeStr, attachFilename));
                             if (attachFilename != null) {
-                                final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
+                                ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
                                 cd.setFilenameParameter(attachFilename);
-                                bodyPart.setHeader(
-                                    HDR_CONTENT_DISPOSITION,
-                                    MimeMessageUtility.foldContentDisposition(cd.toString()));
-                            }
-                            CountingOutputStream counter = null;
-                            try {
-                                counter = new CountingOutputStream();
-                                attachment.writeTo(counter);
-                                bodyPart.setSize((int) counter.getCount());
-                            } finally {
-                                Streams.close(counter);
+                                bodyPart.setHeader(HDR_CONTENT_DISPOSITION, MimeMessageUtility.foldContentDisposition(cd.toString()));
                             }
                             parseMailContent(MimeMessageConverter.convertPart(bodyPart), handler, prefix, partCount++);
                         } else {
                             /*
                              * Nested message
                              */
-                            final MimeMessage nestedMessage =
-                                TNEFMime.convert(MimeDefaultSession.getDefaultSession(), attachment.getNestedMessage());
+                            MimeMessage nestedMessage = TNEFMime.convert(MimeDefaultSession.getDefaultSession(), attachment.getNestedMessage());
                             os.reset();
                             nestedMessage.writeTo(os);
                             bodyPart.setDataHandler(new DataHandler(new MessageDataSource(os.toByteArray(), MimeTypes.MIME_MESSAGE_RFC822)));
@@ -862,7 +856,7 @@ public final class MailMessageParser {
                             return;
                         }
                     } else {
-                        final TNEFBodyPart bodyPart = new TNEFBodyPart();
+                        TNEFBodyPart bodyPart = new TNEFBodyPart();
                         /*
                          * Add TNEF attributes
                          */
@@ -870,18 +864,14 @@ public final class MailMessageParser {
                         /*
                          * Translate TNEF attributes to MIME
                          */
-                        final String attachFilename = fileName;
-                        final DataSource ds = new RawDataSource(messageClass.getRawData(), MimeTypes.MIME_APPL_OCTET);
+                        String attachFilename = fileName;
+                        DataSource ds = new RawDataSource(messageClass.getRawData(), MimeTypes.MIME_APPL_OCTET);
                         bodyPart.setDataHandler(new DataHandler(ds));
-                        bodyPart.setHeader(
-                            HDR_CONTENT_TYPE,
-                            ContentType.prepareContentTypeString(MimeTypes.MIME_APPL_OCTET, attachFilename));
+                        bodyPart.setHeader(HDR_CONTENT_TYPE, ContentType.prepareContentTypeString(MimeTypes.MIME_APPL_OCTET, attachFilename));
                         if (attachFilename != null) {
-                            final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
+                            ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
                             cd.setFilenameParameter(attachFilename);
-                            bodyPart.setHeader(
-                                HDR_CONTENT_DISPOSITION,
-                                MimeMessageUtility.foldContentDisposition(cd.toString()));
+                            bodyPart.setHeader(HDR_CONTENT_DISPOSITION, MimeMessageUtility.foldContentDisposition(cd.toString()));
                         }
                         bodyPart.setSize(messageClass.getLength());
                         parseMailContent(MimeMessageConverter.convertPart(bodyPart), handler, prefix, partCount++);
@@ -932,6 +922,98 @@ public final class MailMessageParser {
         }
     }
 
+    private String getFileNameFromTnefAttachment(final Attachment attachment) {
+        String filename = null;
+        try {
+            int codePage = 0;
+            {
+                Attr oemCodePage = attachment.getAttribute(Attr.attOemCodepage);
+                if (null != oemCodePage) {
+                    Object value = oemCodePage.getValue();
+                    if (value instanceof Number) {
+                        codePage = ((Number) value).intValue();
+                    }
+                }
+            }
+
+            MAPIProps mapiProps = attachment.getMAPIProps();
+            if (mapiProps != null) {
+                // long filename
+                filename = readPropStringValue(MAPIProp.PR_ATTACH_LONG_FILENAME, mapiProps, codePage);
+                // or short filename
+                if (filename == null) {
+                    filename = readPropStringValue(MAPIProp.PR_ATTACH_FILENAME, mapiProps, codePage);
+                }
+            }
+
+            // or transport filename
+            if (filename == null) {
+                Attr attr = attachment.getAttribute(Attr.attAttachTransportFilename);
+                if (attr != null) {
+                    filename = (String)attr.getValue();
+                }
+            }
+
+            // or title (filename)
+            if (filename == null) {
+                Attr attr = attachment.getAttribute(Attr.attAttachTitle);
+                if (attr != null) {
+                    filename = (String)attr.getValue();
+                }
+            }
+        } catch (IOException ioe) {
+            filename = null;
+        }
+        return filename;
+    }
+
+    private String readPropStringValue(int id, MAPIProps mapiProps, int codePage) throws IOException {
+        MAPIProp prop = mapiProps.getProp(id);
+        if (null == prop) {
+            return null;
+        }
+
+        MAPIValue[] values = prop.getValues();
+        if (null == values || values.length == 0) {
+            return null;
+        }
+
+        MAPIValue value = values[0];
+        if (value.getType() != MAPIProp.PT_STRING) {
+            // Not a string
+            return null;
+        }
+
+        RawInputStream ris = new RawInputStream(value.getRawData()); // a copy
+        try {
+            int length = (int) ris.getLength();
+            byte[] bytes = ris.readBytes(length);
+
+            Charset charset;
+            if (codePage > 0) {
+                charset = Charsets.forCodePage(codePage);
+            } else {
+                String charsetName = CharsetDetector.detectCharset(bytes);
+                if (null == charsetName) {
+                    // Don't know better...
+                    return TNEFUtils.createString(bytes, 0, length);
+                }
+                charset = Charsets.forName(charsetName);
+            }
+
+            String nullTerminatedString;
+            if (MessageUtility.isSpecialCharset(charset.displayName())) {
+                nullTerminatedString = MessageUtility.readBytes(bytes, charset.displayName());
+            } else {
+                nullTerminatedString = new String(bytes, 0, length, charset);
+            }
+
+            return TNEFUtils.removeTerminatingNulls(nullTerminatedString);
+        } finally {
+            Streams.close(ris);
+        }
+    }
+
     private MailPart checkSMIME(MailPart mailPart, String lcct, ContentType contentType) throws IOException, OXException {
         if (!(mailPart instanceof MimeRawSource)) {
             return null;
@@ -1032,8 +1114,6 @@ public final class MailMessageParser {
         handler.handleHeaders(headersSize, headersSize > 0 ? mail.getHeadersIterator() : EMPTY_ITER);
     }
 
-    private static final String PREFIX = "Part_";
-
     /**
      * Generates an appropriate filename from either specified <code>rawFileName</code> if not <code>null</code> or generates a filename
      * composed with <code>"Part_" + sequenceId</code>
@@ -1044,10 +1124,26 @@ public final class MailMessageParser {
      * @return An appropriate filename
      */
     public static String getFileName(final String rawFileName, final String sequenceId, final String baseMimeType) {
+        return getFileName(rawFileName, null, sequenceId, baseMimeType);
+    }
+
+    private static final String PREFIX = "Part_";
+
+    /**
+     * Generates an appropriate filename from either specified <code>rawFileName</code> if not <code>null</code> or generates a filename
+     * composed with <code>"Part_" + sequenceId</code>
+     *
+     * @param rawFileName The raw filename obtained from mail part
+     * @param contentType The Content-Type obtained from mail part
+     * @param sequenceId The part's sequence ID
+     * @param baseMimeType The base MIME type to look up an appropriate file extension, if <code>rawFileName</code> is <code>null</code>
+     * @return An appropriate filename
+     */
+    public static String getFileName(String rawFileName, ContentType contentType, String sequenceId, String baseMimeType) {
         String filename = rawFileName;
-        if ((filename == null) || com.openexchange.java.Strings.isEmpty(filename)) {
-            final List<String> exts = MimeType2ExtMap.getFileExtensions(baseMimeType.toLowerCase(Locale.ENGLISH));
-            final StringBuilder sb = new StringBuilder(16).append(PREFIX).append(sequenceId).append('.');
+        if (Strings.isEmpty(filename)) {
+            List<String> exts = MimeType2ExtMap.getFileExtensions(baseMimeType.toLowerCase(Locale.ENGLISH));
+            StringBuilder sb = new StringBuilder(16).append(PREFIX).append(sequenceId).append('.');
             if (exts == null) {
                 sb.append("dat");
             } else {
@@ -1056,6 +1152,13 @@ public final class MailMessageParser {
             filename = sb.toString();
         } else {
             filename = MimeMessageUtility.decodeMultiEncodedHeader(filename);
+            if (filename.indexOf('.') < 0) {
+                // No file extension given. Check if "name" parameter from Content-Type provides a better "alternative" value
+                String name = null == contentType ? null : contentType.getNameParameter();
+                if (Strings.isNotEmpty(name) && name.indexOf('.') > 0) {
+                    filename = MimeMessageUtility.decodeMultiEncodedHeader(name);
+                }
+            }
         }
         return filename;
     }
