@@ -52,6 +52,7 @@ package com.openexchange.mail.parser.handlers;
 import static com.openexchange.java.Strings.isEmpty;
 import static com.openexchange.mail.mime.utils.MimeMessageUtility.decodeMultiEncodedHeader;
 import static com.openexchange.mail.parser.MailMessageParser.generateFilename;
+import static com.openexchange.mail.parser.MailMessageParser.getFileName;
 import static com.openexchange.mail.utils.MailFolderUtility.prepareFullname;
 import java.io.File;
 import java.util.ArrayList;
@@ -63,7 +64,6 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.regex.Pattern;
 import java.util.Set;
 import java.util.TimeZone;
 import javax.mail.Part;
@@ -74,7 +74,6 @@ import org.json.JSONObject;
 import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
-import com.openexchange.ajax.helper.DownloadUtility;
 import com.openexchange.data.conversion.ical.ICalParser;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
@@ -87,6 +86,8 @@ import com.openexchange.html.HtmlSanitizeResult;
 import com.openexchange.html.HtmlService;
 import com.openexchange.image.ImageLocation;
 import com.openexchange.java.Streams;
+import com.openexchange.java.Strings;
+import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailJSONField;
 import com.openexchange.mail.MailListField;
@@ -98,6 +99,9 @@ import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.conversion.InlineImageDataSource;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
+import com.openexchange.mail.dataobjects.SecurityInfo;
+import com.openexchange.mail.dataobjects.SecurityResult;
+import com.openexchange.mail.dataobjects.SignatureResult;
 import com.openexchange.mail.json.writer.MessageWriter;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.HeaderName;
@@ -114,6 +118,7 @@ import com.openexchange.mail.text.HtmlProcessing;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.DisplayMode;
 import com.openexchange.mail.utils.MaxBytesExceededIOException;
+import com.openexchange.mail.utils.SizePolicy;
 import com.openexchange.mail.uuencode.UUEncodedPart;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
@@ -139,6 +144,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
     private static final String NESTED_MESSAGES = MailJSONField.NESTED_MESSAGES.getKey();
     private static final String ATTACHMENTS = MailJSONField.ATTACHMENTS.getKey();
     private static final String ACCOUNT_ID = MailJSONField.ACCOUNT_ID.getKey();
+    private static final String MALICIOUS = "malicious";
     private static final String ACCOUNT_NAME = MailJSONField.ACCOUNT_NAME.getKey();
     private static final String HAS_ATTACHMENTS = MailJSONField.HAS_ATTACHMENTS.getKey();
     private static final String HAS_REAL_ATTACHMENTS = "real_attachment";
@@ -152,6 +158,8 @@ public final class JsonMessageHandler implements MailMessageHandler {
     private static final String HEADERS = MailJSONField.HEADERS.getKey();
     private static final String ORIGINAL_ID = MailJSONField.ORIGINAL_ID.getKey();
     private static final String ORIGINAL_FOLDER_ID = MailJSONField.ORIGINAL_FOLDER_ID.getKey();
+    private static final String SECURITY = MailJSONField.SECURITY.getKey();
+    private static final String SECURITY_INFO = MailJSONField.SECURITY_INFO.getKey();
 
     private static final String TRUNCATED = MailJSONField.TRUNCATED.getKey();
     private static final String SANITIZED = "sanitized";
@@ -161,7 +169,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
 
     private static final String HTML_PREFIX = HtmlExceptionCodes.PREFIX;
 
-//    private static final int DEFAULT_MAX_NESTED_MESSAGES_LEVELS = 10;
+    //    private static final int DEFAULT_MAX_NESTED_MESSAGES_LEVELS = 10;
 
     private static final class PlainTextContent {
 
@@ -249,13 +257,15 @@ public final class JsonMessageHandler implements MailMessageHandler {
     private final boolean token;
     private final int ttlMillis;
     private final boolean embedded;
+    private final boolean asMarkup;
     private boolean attachHTMLAlternativePart;
     private boolean includePlainText;
-    private boolean exactLength;
+    private SizePolicy sizePolicy;
     private final int maxContentSize;
     private int currentNestingLevel = 0;
     private final int maxNestedMessageLevels;
     private String initialiserSequenceId;
+    private boolean handleNestedMessageAsAttachment;
 
     /**
      * Initializes a new {@link JsonMessageHandler}
@@ -263,13 +273,14 @@ public final class JsonMessageHandler implements MailMessageHandler {
      * @param accountId The account ID
      * @param mailPath The unique mail path
      * @param displayMode The display mode
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param session The session providing needed user data
-     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise
-     *            it is ignored.
+     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise it is ignored.
      * @throws OXException If JSON message handler cannot be initialized
      */
-    public JsonMessageHandler(final int accountId, final String mailPath, final DisplayMode displayMode, final boolean embedded, final Session session, final UserSettingMail usm, final boolean token, final int ttlMillis) throws OXException {
-        this(accountId, new MailPath(mailPath), null, displayMode, embedded, session, usm, getContext(session), token, ttlMillis, -1, -1);
+    public JsonMessageHandler(int accountId, String mailPath, DisplayMode displayMode, boolean embedded, boolean asMarkup, Session session, UserSettingMail usm, boolean token, int ttlMillis) throws OXException {
+        this(accountId, new MailPath(mailPath), null, displayMode, embedded, asMarkup, session, usm, getContext(session), token, ttlMillis, -1, -1);
     }
 
     /**
@@ -279,15 +290,16 @@ public final class JsonMessageHandler implements MailMessageHandler {
      * @param mailPath The unique mail path
      * @param mail The mail message to add JSON fields not set by message parser traversal
      * @param displayMode The display mode
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param session The session providing needed user data
-     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise
-     *            it is ignored.
+     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise it is ignored.
      * @param token <code>true</code> to add attachment tokens
      * @param ttlMillis The tokens' timeout
      * @throws OXException If JSON message handler cannot be initialized
      */
-    public JsonMessageHandler(final int accountId, final MailPath mailPath, final MailMessage mail, final DisplayMode displayMode, final boolean embedded, final Session session, final UserSettingMail usm, final boolean token, final int ttlMillis) throws OXException {
-        this(accountId, mailPath, mail, displayMode, embedded, session, usm, getContext(session), token, ttlMillis, -1, -1);
+    public JsonMessageHandler(int accountId, MailPath mailPath, MailMessage mail, DisplayMode displayMode, boolean embedded, boolean asMarkup, Session session, UserSettingMail usm, boolean token, int ttlMillis) throws OXException {
+        this(accountId, mailPath, mail, displayMode, embedded, asMarkup, session, usm, getContext(session), token, ttlMillis, -1, -1);
     }
 
     /**
@@ -297,17 +309,18 @@ public final class JsonMessageHandler implements MailMessageHandler {
      * @param mailPath The unique mail path
      * @param mail The mail message to add JSON fields not set by message parser traversal
      * @param displayMode The display mode
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param session The session providing needed user data
-     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise
-     *            it is ignored.
+     * @param usm The mail settings used for preparing message content if <code>displayVersion</code> is set to <code>true</code>; otherwise it is ignored.
      * @param token <code>true</code> to add attachment tokens
      * @param ttlMillis The tokens' timeout
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @param maxNestedMessageLevels The number of levels in which deep-parsing of nested messages takes place; otherwise only ID information is set; '<=0' falls back to default value (10)
      * @throws OXException If JSON message handler cannot be initialized
      */
-    public JsonMessageHandler(int accountId, MailPath mailPath, MailMessage mail, DisplayMode displayMode, boolean embedded, Session session, UserSettingMail usm, boolean token, int ttlMillis, int maxContentSize, int maxNestedMessageLevels) throws OXException {
-        this(accountId, mailPath, mail, displayMode, embedded, session, usm, getContext(session), token, ttlMillis, maxContentSize, maxNestedMessageLevels);
+    public JsonMessageHandler(int accountId, MailPath mailPath, MailMessage mail, DisplayMode displayMode, boolean embedded, boolean asMarkup, Session session, UserSettingMail usm, boolean token, int ttlMillis, int maxContentSize, int maxNestedMessageLevels) throws OXException {
+        this(accountId, mailPath, mail, displayMode, embedded, asMarkup, session, usm, getContext(session), token, ttlMillis, maxContentSize, maxNestedMessageLevels);
     }
 
     private static Context getContext(final Session session) throws OXException {
@@ -320,11 +333,12 @@ public final class JsonMessageHandler implements MailMessageHandler {
     /**
      * Initializes a new {@link JsonMessageHandler} for internal usage
      */
-    private JsonMessageHandler(int accountId, MailPath mailPath, MailMessage mail, DisplayMode displayMode, boolean embedded, Session session, UserSettingMail usm, Context ctx, boolean token, int ttlMillis, int maxContentSize, int maxNestedMessageLevels) throws OXException {
+    private JsonMessageHandler(int accountId, MailPath mailPath, MailMessage mail, DisplayMode displayMode, boolean embedded, boolean asMarkup, Session session, UserSettingMail usm, Context ctx, boolean token, int ttlMillis, int maxContentSize, int maxNestedMessageLevels) throws OXException {
         super();
         this.warnings = new LinkedList<>();
         this.multiparts = new LinkedList<MultipartInfo>();
         this.embedded = DisplayMode.DOCUMENT.equals(displayMode) ? false : embedded;
+        this.asMarkup = asMarkup;
         this.attachHTMLAlternativePart = !usm.isSuppressHTMLAlternativePart();
         this.ttlMillis = ttlMillis;
         this.token = token;
@@ -338,6 +352,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
         this.maxContentSize = maxContentSize;
         this.jsonObject = new JSONObject(32);
         this.maxNestedMessageLevels = 1; //maxNestedMessageLevels <= 0 ? DEFAULT_MAX_NESTED_MESSAGES_LEVELS : maxNestedMessageLevels;
+        this.handleNestedMessageAsAttachment = false;
         try {
             if (DisplayMode.MODIFYABLE.equals(this.displayMode) && null != mailPath) {
                 jsonObject.put(MailJSONField.MSGREF.getKey(), mailPath.toString());
@@ -367,8 +382,16 @@ public final class JsonMessageHandler implements MailMessageHandler {
                 jsonObject.put(SIZE, mail.getSize());
                 jsonObject.put(ACCOUNT_NAME, mail.getAccountName());
                 jsonObject.put(ACCOUNT_ID, mail.getAccountId());
-                this.initialiserSequenceId = mail.getSequenceId();
+                jsonObject.put(MALICIOUS, usm.isSuppressLinks());
+                // Guard info
+                if (mail.containsSecurityInfo()) {
+                    jsonObject.put(SECURITY_INFO, securityInfoToJSON(mail.getSecurityInfo()));
+                }
+                if (mail.hasSecurityResult()) {
+                    jsonObject.put(SECURITY, securityResultToJSON(mail.getSecurityResult()));
+                }
 
+                this.initialiserSequenceId = mail.getSequenceId();
 
                 String originalId = null;
                 if (mail.containsOriginalId()) {
@@ -377,15 +400,15 @@ public final class JsonMessageHandler implements MailMessageHandler {
                         jsonObject.put(ORIGINAL_ID, originalId);
                     }
                 }
-                String originalFolder = null;
+                FullnameArgument originalFolder = null;
                 if (mail.containsOriginalFolder()) {
                     originalFolder = mail.getOriginalFolder();
                     if (null != originalFolder) {
-                        jsonObject.put(ORIGINAL_FOLDER_ID, prepareFullname(accountId, originalFolder));
+                        jsonObject.put(ORIGINAL_FOLDER_ID, originalFolder.getPreparedName());
                     }
                 }
                 if (null != originalId && null != originalFolder) {
-                    originalMailPath = new MailPath(null == mailPath ? mail.getAccountId() : mailPath.getAccountId(), originalFolder, originalId);
+                    originalMailPath = new MailPath(originalFolder.getAccountId(), originalFolder.getFullName(), originalId);
                 }
             }
             this.originalMailPath = originalMailPath;
@@ -394,14 +417,73 @@ public final class JsonMessageHandler implements MailMessageHandler {
         }
     }
 
+    /**
+     * Transforms given security result to JSON.
+     *
+     * @param result The security result associated with the mail
+     * @return The JSON representation of security result
+     * @throws JSONException If JSON cannot be returned
+     */
+    public JSONObject securityResultToJSON(SecurityResult result) throws JSONException {
+        JSONObject json = new JSONObject(10);
+        json.put("decrypted", result.getSuccess());
+        json.put("type", result.getType().toString());
+        if (result.hasError()) {
+            json.put("error", result.getError());
+        }
+        json.put("pgpInline", result.isPgpInline());
+        if (result.hasSignatureResults()) {
+            List<SignatureResult> signatureResults = result.getSignatureResults();
+            JSONArray signatures = new JSONArray(signatureResults.size());
+            for (SignatureResult res : signatureResults) {
+                JSONObject sig = new JSONObject(4);
+                sig.put("verified", res.isVerified());
+                sig.put("missing", res.isMissing());
+                sig.put("date", res.getDate());
+                sig.put("issuerKeyId", res.getIssuerKeyId());
+                sig.put("issuerKeyFingerprint",res.getIssuerKeyFingerprint());
+                sig.put("issuerUserIds", res.getIssuerUserIds());
+                if (res.getError() != null) {
+                    sig.put("error", res.getError());
+                }
+                signatures.put(sig);
+            }
+            json.put("signatures", signatures);
+        }
+        return json;
+    }
+
+    /**
+     * Create the JSON representation for this <code>SecurityInfo</code> object.
+     *
+     * @return The JSON representation
+     * @throws JSONException If JSON representation cannot be returned
+     */
+    public JSONObject securityInfoToJSON(SecurityInfo info) throws JSONException {
+        JSONObject security = new JSONObject(2);
+        security.put("encrypted", info.isEncrypted());
+        security.put("signed", info.isSigned());
+        return security;
+    }
+
     /**
      * Sets whether to set the exact length of mail parts.
      *
      * @param exactLength <code>true</code> to set the exact length of mail parts; otherwise use mail system's size estimation
      * @return This {@link JsonMessageHandler} with new behavior applied
      */
-    public JsonMessageHandler setExactLength(final boolean exactLength) {
-        this.exactLength = exactLength;
+    public JsonMessageHandler setSizePolicy(final SizePolicy sizePolicy) {
+        this.sizePolicy = sizePolicy;
+        return this;
+    }
+
+    /**
+     * Sets to handle nested messages as attachments
+     *
+     * @return This {@link JsonMessageHandler} with new behavior applied
+     */
+    public JsonMessageHandler setHandleNestedMessageAsAttachment() {
+        this.handleNestedMessageAsAttachment = true;
         return this;
     }
 
@@ -530,17 +612,28 @@ public final class JsonMessageHandler implements MailMessageHandler {
             /*
              * Size
              */
-            boolean checkSize = true;
-            if (exactLength) {
-                try {
-                    jsonObject.put(SIZE, Streams.countInputStream(part.getInputStream()));
-                    checkSize = false;
-                } catch (final Exception e) {
-                    // Failed counting part's content
+            {
+                boolean checkSize = true;
+                if (SizePolicy.EXACT == sizePolicy) {
+                    try {
+                        jsonObject.put(SIZE, Streams.countInputStream(part.getInputStream()));
+                        checkSize = false;
+                    } catch (final Exception e) {
+                        // Failed counting part's content
+                        LOG.debug("{}", e.getMessage(), e);
+                    }
+                } else if (SizePolicy.ESTIMATE == sizePolicy) {
+                    if (part.containsSize()) {
+                        String transferEncoding = Strings.asciiLowerCase(part.getFirstHeader(MessageHeaders.HDR_CONTENT_TRANSFER_ENC));
+                        if ("base64".equals(transferEncoding)) {
+                            jsonObject.put(SIZE, (int) (0.75 * part.getSize()));
+                            checkSize = false;
+                        }
+                    }
+                }
+                if (checkSize && part.containsSize()) {
+                    jsonObject.put(SIZE, part.getSize());
                 }
-            }
-            if (checkSize && part.containsSize()) {
-                jsonObject.put(SIZE, part.getSize());
             }
             /*
              * Disposition
@@ -639,10 +732,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
     /**
      * These headers are covered by fields of {@link MailMessage}
      */
-    private static final Set<HeaderName> COVERED_HEADER_NAMES = ImmutableSet.of(
-        MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC, MessageHeaders.CC,
-        MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY, MessageHeaders.SUBJECT,
-        MessageHeaders.TO);
+    private static final Set<HeaderName> COVERED_HEADER_NAMES = ImmutableSet.of(MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC, MessageHeaders.CC, MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY, MessageHeaders.SUBJECT, MessageHeaders.TO);
 
     @Override
     public boolean handleHeaders(final int size, final Iterator<Entry<String, String>> iter) throws OXException {
@@ -717,7 +807,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
         boolean considerAsInline = isInline || (!part.getContentDisposition().isAttachment() && part.containsHeader("Content-Id"));
 
         // Handle it...
-        if (considerAsInline && (DisplayMode.MODIFYABLE.getMode() < displayMode.getMode())) {
+        if (asMarkup && considerAsInline && (DisplayMode.MODIFYABLE.getMode() < displayMode.getMode())) {
             final MultipartInfo mpInfo = multiparts.peek();
             if (null != mpInfo && textAppended && id.startsWith(mpInfo.mpId) && mpInfo.isSubType("mixed")) {
                 try {
@@ -788,6 +878,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                 }
             }
         }
+
         return handleAttachment0(part, considerAsInline, considerAsInline ? Part.INLINE : Part.ATTACHMENT, baseContentType, fileName, id, considerAsInline);
     }
 
@@ -811,6 +902,13 @@ public final class JsonMessageHandler implements MailMessageHandler {
 
             throw x;
         }
+        String identifier = id;
+        /*
+         * Adjust DI if virtually inserted; e.g. MimeForward
+         */
+        if (isVirtual(contentType)) {
+            identifier = "0";
+        }
         if (textAppended) {
             /*
              * A text part has already been detected as message's body
@@ -823,7 +921,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                      */
                     if (textWasEmpty) {
                         if (usm.isDisplayHtmlInlineContent()) {
-                            JSONObject jsonObject = asDisplayHtml(id, contentType.getBaseType(), htmlContent, contentType.getCharsetParameter());
+                            JSONObject jsonObject = asDisplayHtml(identifier, contentType.getBaseType(), htmlContent, contentType.getCharsetParameter());
                             if (includePlainText) {
                                 try {
                                     String plainText = html2text(htmlContent);
@@ -834,7 +932,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                             }
                         } else {
                             try {
-                                asDisplayText(id, contentType.getBaseType(), htmlContent, fileName, false);
+                                asDisplayText(identifier, contentType.getBaseType(), htmlContent, fileName, false);
                                 getAttachmentListing().removeFirst();
                             } catch (RuntimeException e) {
                                 throw MailExceptionCode.UNEXPECTED_ERROR.create(e, e.getMessage());
@@ -855,7 +953,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                                 String content = jAttachment.optString(CONTENT, "null");
                                 if (!"null".equals(content) && null != mailPath) {
                                     // Append to first one
-                                    HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, contentType.getCharsetParameter(), session, mailPath, originalMailPath, usm, modified, displayMode, embedded, maxContentSize);
+                                    HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, contentType.getCharsetParameter(), session, mailPath, originalMailPath, usm, modified, displayMode, embedded, asMarkup, maxContentSize);
                                     content = new StringBuilder(content).append(sanitizeResult.getContent()).toString();
                                     jAttachment.put(CONTENT, content);
                                     return true;
@@ -870,7 +968,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                      */
                     if (attachHTMLAlternativePart) {
                         try {
-                            JSONObject attachment = asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName, null);
+                            JSONObject attachment = asAttachment(identifier, contentType.getBaseType(), htmlContent.length(), fileName, null);
                             attachment.put(VIRTUAL, true);
                         } catch (final JSONException e) {
                             throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
@@ -880,7 +978,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                     /*
                      * Return HTML content as-is
                      */
-                    asRawContent(id, contentType.getBaseType(), new HtmlSanitizeResult(htmlContent));
+                    asRawContent(identifier, contentType.getBaseType(), new HtmlSanitizeResult(htmlContent));
                 } else {
                     /*
                      * Discard
@@ -899,7 +997,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                             String content = jAttachment.optString(CONTENT, "null");
                             if (!"null".equals(content) && null != mailPath) {
                                 // Append to first one
-                                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, contentType.getCharsetParameter(), session, mailPath, originalMailPath, usm, modified, displayMode, embedded, maxContentSize);
+                                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, contentType.getCharsetParameter(), session, mailPath, originalMailPath, usm, modified, displayMode, embedded, asMarkup, maxContentSize);
                                 content = new StringBuilder(content).append(sanitizeResult.getContent()).toString();
                                 jAttachment.put(CONTENT, content);
                                 return true;
@@ -913,7 +1011,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                  * Add HTML part as attachment
                  */
                 try {
-                    JSONObject attachment = asAttachment(id, contentType.getBaseType(), htmlContent.length(), fileName, null);
+                    JSONObject attachment = asAttachment(identifier, contentType.getBaseType(), htmlContent.length(), fileName, null);
                     attachment.put(VIRTUAL, true);
                 } catch (final JSONException e) {
                     throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
@@ -934,7 +1032,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                          */
                         asRawContent(plainText.id, plainText.contentType, new HtmlSanitizeResult(plainText.content));
                     } else {
-                        JSONObject jsonObject = asDisplayHtml(id, contentType.getBaseType(), htmlContent, contentType.getCharsetParameter());
+                        JSONObject jsonObject = asDisplayHtml(identifier, contentType.getBaseType(), htmlContent, contentType.getCharsetParameter());
                         if (includePlainText) {
                             try {
                                 /*
@@ -948,17 +1046,17 @@ public final class JsonMessageHandler implements MailMessageHandler {
                         }
                     }
                 } else {
-                    asDisplayText(id, contentType.getBaseType(), htmlContent, fileName, DisplayMode.DISPLAY.isIncluded(displayMode));
+                    asDisplayText(identifier, contentType.getBaseType(), htmlContent, fileName, DisplayMode.DISPLAY.isIncluded(displayMode));
                 }
             } else if (DisplayMode.RAW.equals(displayMode)) {
                 /*
                  * Return HTML content as-is
                  */
-                asRawContent(id, contentType.getBaseType(), new HtmlSanitizeResult(htmlContent));
+                asRawContent(identifier, contentType.getBaseType(), new HtmlSanitizeResult(htmlContent));
             } else {
                 try {
                     JSONObject jsonObject = new JSONObject(6);
-                    jsonObject.put(ID, id);
+                    jsonObject.put(ID, identifier);
                     jsonObject.put(CONTENT_TYPE, contentType.getBaseType());
                     jsonObject.put(SIZE, htmlContent.length());
                     jsonObject.put(DISPOSITION, Part.INLINE);
@@ -986,7 +1084,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                 /*
                  * Remember plain-text content
                  */
-                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, maxContentSize);
+                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, asMarkup, maxContentSize);
                 plainText = new PlainTextContent(identifier, contentType.getBaseType(), sanitizeResult.getContent());
             }
             return true;
@@ -1060,7 +1158,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
              */
             if (textAppended) {
                 if (textWasEmpty) {
-                    final HtmlSanitizeResult content = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, maxContentSize);
+                    final HtmlSanitizeResult content = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, asMarkup, maxContentSize);
                     final JSONObject textObject = asPlainText(identifier, contentType.getBaseType(), content);
                     if (includePlainText) {
                         textObject.put("plain_text", plainTextContentArg);
@@ -1092,7 +1190,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                     }
 
                     // A plain text message body has already been detected
-                    final HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, maxContentSize);
+                    final HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, asMarkup, maxContentSize);
                     final MultipartInfo mpInfo = multiparts.peek();
                     if (null != mpInfo && (DisplayMode.RAW.getMode() < displayMode.getMode()) && identifier.startsWith(mpInfo.mpId) && mpInfo.isSubType("mixed")) {
                         List<JSONObject> attachments = getAttachmentListing().getAttachments();
@@ -1125,7 +1223,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                     }
                 }
             } else {
-                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, maxContentSize);
+                HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode, asMarkup, maxContentSize);
                 final JSONObject textObject = asPlainText(identifier, contentType.getBaseType(), sanitizeResult);
                 if (includePlainText) {
                     textObject.put("plain_text", plainTextContentArg);
@@ -1142,16 +1240,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
     private String getHtmlDisplayVersion(final ContentType contentType, final String src) throws OXException {
         final String baseType = contentType.getBaseType().toLowerCase(Locale.ENGLISH);
         if (baseType.startsWith(MimeTypes.MIME_TEXT_ENRICHED) || baseType.startsWith(MimeTypes.MIME_TEXT_RICHTEXT)) {
-            return HtmlProcessing.formatHTMLForDisplay(
-                ENRCONV.convert(src),
-                contentType.getCharsetParameter(),
-                session,
-                mailPath,
-                originalMailPath,
-                usm,
-                modified,
-                displayMode,
-                embedded);
+            return HtmlProcessing.formatHTMLForDisplay(ENRCONV.convert(src), contentType.getCharsetParameter(), session, mailPath, originalMailPath, usm, modified, displayMode, embedded, asMarkup);
         }
         return HtmlProcessing.formatTextForDisplay(src, usm, displayMode);
     }
@@ -1167,9 +1256,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                 final Locale locale = UserStorage.getInstance().getUser(session.getUserId(), ctx).getLocale();
                 contentType = MimeType2ExtMap.getContentType(new File(filename.toLowerCase(locale)).getName()).toLowerCase(locale);
             } catch (final Exception e) {
-                final Throwable t =
-                    new Throwable(
-                        new StringBuilder("Unable to fetch content/type for '").append(filename).append("': ").append(e).toString());
+                final Throwable t = new Throwable(new StringBuilder("Unable to fetch content/type for '").append(filename).append("': ").append(e).toString());
                 LOG.warn("", t);
             }
             jsonObject.put(CONTENT_TYPE, contentType);
@@ -1305,8 +1392,17 @@ public final class JsonMessageHandler implements MailMessageHandler {
         return true;
     }
 
+    private static final String PRIMARY_RFC822 = "message/rfc822";
+
     @Override
     public boolean handleNestedMessage(final MailPart mailPart, final String id) throws OXException {
+        if (handleNestedMessageAsAttachment) {
+            final String disposition = mailPart.containsContentDisposition() ? mailPart.getContentDisposition().getDisposition() : null;
+            boolean inline = Part.INLINE.equalsIgnoreCase(disposition) || ((disposition == null) && (mailPart.getFileName() == null));
+            ContentType contentType = mailPart.containsContentType() ? mailPart.getContentType() : ContentType.APPLICATION_OCTETSTREAM_CONTENT_TYPE;
+            String fileName = getFileName(mailPart.getFileName(), contentType, id, PRIMARY_RFC822);
+            return handleAttachment(mailPart, inline, PRIMARY_RFC822, fileName, id);
+        }
 
         String nestedMessageFullId = "";
         try {
@@ -1320,13 +1416,13 @@ public final class JsonMessageHandler implements MailMessageHandler {
                 }
 
                 // Generate a dedicated JsonMessageHandler instance to parse the nested message
-                JsonMessageHandler msgHandler = new JsonMessageHandler(accountId, null, null, displayMode, embedded, session, usm, ctx, token, ttlMillis, maxContentSize, maxNestedMessageLevels);
+                JsonMessageHandler msgHandler = new JsonMessageHandler(accountId, null, null, displayMode, embedded, asMarkup, session, usm, ctx, token, ttlMillis, maxContentSize, maxNestedMessageLevels);
                 msgHandler.setTimeZone(timeZone);
                 msgHandler.includePlainText = includePlainText;
                 msgHandler.attachHTMLAlternativePart = attachHTMLAlternativePart;
                 msgHandler.tokenFolder = tokenFolder;
                 msgHandler.tokenMailId = tokenMailId;
-                msgHandler.exactLength = exactLength;
+                msgHandler.sizePolicy = sizePolicy;
                 // msgHandler.originalMailPath = originalMailPath;
                 msgHandler.currentNestingLevel = currentNestingLevel + 1;
                 if (this.initialiserSequenceId != null) {
@@ -1405,7 +1501,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
         try {
             Object value = receivedDate == null ? JSONObject.NULL : Long.valueOf(MessageWriter.addUserTimezone(receivedDate.getTime(), getTimeZone()));
             jsonObject.put(MailJSONField.RECEIVED_DATE.getKey(), value);
-            if (false == MailProperties.getInstance().isPreferSentDate()) {
+            if (false == MailProperties.getInstance().isPreferSentDate(session.getUserId(), session.getContextId())) {
                 jsonObject.put(MailJSONField.DATE.getKey(), value);
             }
             return true;
@@ -1419,7 +1515,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
         try {
             Object value = sentDate == null ? JSONObject.NULL : Long.valueOf(MessageWriter.addUserTimezone(sentDate.getTime(), getTimeZone()));
             jsonObject.put(MailJSONField.SENT_DATE.getKey(), value);
-            if (MailProperties.getInstance().isPreferSentDate()) {
+            if (MailProperties.getInstance().isPreferSentDate(session.getUserId(), session.getContextId())) {
                 jsonObject.put(MailJSONField.DATE.getKey(), value);
             }
             return true;
@@ -1624,7 +1720,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
 
             HtmlSanitizeResult sanitizeResult;
             try {
-                sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, charset, session, mailPath, originalMailPath, usm, modified, displayMode, embedded, maxContentSize);
+                sanitizeResult = HtmlProcessing.formatHTMLForDisplay(htmlContent, charset, session, mailPath, originalMailPath, usm, modified, displayMode, embedded, asMarkup, maxContentSize);
                 jsonObject.put(CONTENT_TYPE, baseContentType);
             } catch (OXException e) {
                 if (!HTML_PREFIX.equals(e.getPrefix())) {
@@ -1638,7 +1734,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
                     jsonObject.put(CONTENT_TYPE, plainText.contentType);
                 } else {
                     String text = html2text(htmlContent);
-                    sanitizeResult = HtmlProcessing.formatTextForDisplay(text, usm, displayMode, maxContentSize);
+                    sanitizeResult = HtmlProcessing.formatTextForDisplay(text, usm, displayMode, asMarkup, maxContentSize);
                     jsonObject.put(CONTENT_TYPE, MimeTypes.MIME_TEXT_PLAIN);
                 }
             }
@@ -1670,7 +1766,7 @@ public final class JsonMessageHandler implements MailMessageHandler {
             if (includePlainText) {
                 jsonObject.put("plain_text", plainText);
             }
-            HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainText, usm, displayMode, maxContentSize);
+            HtmlSanitizeResult sanitizeResult = HtmlProcessing.formatTextForDisplay(plainText, usm, displayMode, asMarkup, maxContentSize);
             final String content = sanitizeResult.getContent();
             jsonObject.put(TRUNCATED, sanitizeResult.isTruncated());
             jsonObject.put(SANITIZED, true);
