@@ -705,6 +705,11 @@ final class ComposedMailWrapper extends ComposedMailMessage {
         mail.setSubject(subject);
     }
 
+    @Override
+    public void setSubject(String subject, boolean decoded) {
+        mail.setSubject(subject, decoded);
+    }
+
     @Override
     public void prepareForCaching() {
         mail.prepareForCaching();
