@@ -89,6 +89,7 @@ import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadable;
 import com.openexchange.config.Reloadables;
 import com.openexchange.exception.OXException;
+import com.openexchange.html.HtmlSanitizeOptions;
 import com.openexchange.html.HtmlSanitizeResult;
 import com.openexchange.html.HtmlService;
 import com.openexchange.html.HtmlServices;
@@ -123,12 +124,13 @@ public final class HtmlProcessing {
      * @param content The plain text content
      * @param usm The settings used for formatting content
      * @param mode The display mode
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static HtmlSanitizeResult formatTextForDisplay(final String content, final UserSettingMail usm, final DisplayMode mode, final int maxContentSize) throws OXException {
-        return formatContentForDisplay(content, null, false, null, null, usm, null, mode, false, maxContentSize);
+    public static HtmlSanitizeResult formatTextForDisplay(String content, UserSettingMail usm, DisplayMode mode, boolean asMarkup, int maxContentSize) throws OXException {
+        return formatContentForDisplay(content, null, false, null, null, usm, null, mode, false, asMarkup, maxContentSize);
     }
 
     /**
@@ -140,8 +142,8 @@ public final class HtmlProcessing {
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static String formatTextForDisplay(final String content, final UserSettingMail usm, final DisplayMode mode) throws OXException {
-        return formatTextForDisplay(content, usm, mode, -1).getContent();
+    public static String formatTextForDisplay(String content, UserSettingMail usm, DisplayMode mode) throws OXException {
+        return formatTextForDisplay(content, usm, mode, true, -1).getContent();
     }
 
     /**
@@ -155,11 +157,12 @@ public final class HtmlProcessing {
      * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter
      * @param mode The display mode
      * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static String formatHTMLForDisplay(final String content, final String charset, final Session session, final MailPath mailPath, final UserSettingMail usm, final boolean[] modified, final DisplayMode mode, final boolean embedded) throws OXException {
-        return formatHTMLForDisplay(content, charset, session, mailPath, usm, modified, mode, embedded, -1).getContent();
+    public static String formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup) throws OXException {
+        return formatHTMLForDisplay(content, charset, session, mailPath, usm, modified, mode, embedded, asMarkup, -1).getContent();
     }
 
     /**
@@ -173,11 +176,12 @@ public final class HtmlProcessing {
      * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter
      * @param mode The display mode
      * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static String formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded) throws OXException {
-        return formatHTMLForDisplay(content, charset, session, mailPath, originalMailPath, usm, modified, mode, embedded, -1).getContent();
+    public static String formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup) throws OXException {
+        return formatHTMLForDisplay(content, charset, session, mailPath, originalMailPath, usm, modified, mode, embedded, asMarkup, -1).getContent();
     }
 
     /**
@@ -190,14 +194,14 @@ public final class HtmlProcessing {
      * @param usm The settings used for formatting content
      * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter
      * @param mode The display mode
-     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise
-     *            <code>false</code>
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static HtmlSanitizeResult formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, int maxContentSize) throws OXException {
-        return formatHTMLForDisplay(content, charset, session, mailPath, null, usm, modified, mode, embedded, maxContentSize);
+    public static HtmlSanitizeResult formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup, int maxContentSize) throws OXException {
+        return formatHTMLForDisplay(content, charset, session, mailPath, null, usm, modified, mode, embedded, asMarkup, maxContentSize);
     }
 
     /**
@@ -211,14 +215,14 @@ public final class HtmlProcessing {
      * @param usm The settings used for formatting content
      * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter
      * @param mode The display mode
-     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise
-     *            <code>false</code>
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @see #formatContentForDisplay(String, String, boolean, Session, MailPath, UserSettingMail, boolean[], DisplayMode)
      * @return The formatted content
      */
-    public static HtmlSanitizeResult formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, int maxContentSize) throws OXException {
-        return formatContentForDisplay(content, charset, true, session, mailPath, originalMailPath, usm, modified, mode, embedded, maxContentSize);
+    public static HtmlSanitizeResult formatHTMLForDisplay(String content, String charset, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup, int maxContentSize) throws OXException {
+        return formatContentForDisplay(content, charset, true, session, mailPath, originalMailPath, usm, modified, mode, embedded, asMarkup, maxContentSize);
     }
 
     /**
@@ -242,16 +246,15 @@ public final class HtmlProcessing {
      * @param session The session
      * @param mailPath The message's unique path in mailbox
      * @param usm The settings used for formatting content
-     * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter (only
-     *            needed by HTML content; may be <code>null</code> on plain text)
+     * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter (only needed by HTML content; may be <code>null</code> on plain text)
      * @param mode The display mode
-     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise
-     *            <code>false</code>
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @return The formatted content
      */
-    public static HtmlSanitizeResult formatContentForDisplay(String content, String charset, boolean isHtml, Session session, MailPath mailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, int maxContentSize) throws OXException {
-        return formatContentForDisplay(content, charset, isHtml, session, mailPath, null, usm, modified, mode, embedded, maxContentSize);
+    public static HtmlSanitizeResult formatContentForDisplay(String content, String charset, boolean isHtml, Session session, MailPath mailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup, int maxContentSize) throws OXException {
+        return formatContentForDisplay(content, charset, isHtml, session, mailPath, null, usm, modified, mode, embedded, asMarkup, maxContentSize);
     }
 
     private static final String COMMENT_ID = "anchor-5fd15ca8-a027-4b14-93ea-35de1747419e:";
@@ -278,50 +281,39 @@ public final class HtmlProcessing {
      * @param mailPath The message's unique path in mailbox
      * @param originalMailPath The original mail path or <code>null</code>
      * @param usm The settings used for formatting content
-     * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter (only
-     *            needed by HTML content; may be <code>null</code> on plain text)
+     * @param modified A <code>boolean</code> array with length <code>1</code> to store modified status of external images filter (only needed by HTML content; may be <code>null</code> on plain text)
      * @param mode The display mode
-     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise
-     *            <code>false</code>
+     * @param embedded <code>true</code> for embedded display (CSS prefixed, &lt;body&gt; replaced with &lt;div&gt;); otherwise <code>false</code>
+     * @param asMarkup <code>true</code> if the content is supposed to be rendered as HTML (be it HTML or plain text); otherwise <code>false</code> to keep content as-is (plain text is left as such)
      * @param maxContentSize maximum number of bytes that is will be returned for content. '<=0' means unlimited.
      * @return The formatted content
      */
-    public static HtmlSanitizeResult formatContentForDisplay(String content, String charset, boolean isHtml, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, int maxContentSize) throws OXException {
+    public static HtmlSanitizeResult formatContentForDisplay(String content, String charset, boolean isHtml, Session session, MailPath mailPath, MailPath originalMailPath, UserSettingMail usm, boolean[] modified, DisplayMode mode, boolean embedded, boolean asMarkup, int maxContentSize) throws OXException {
         HtmlSanitizeResult retval = new HtmlSanitizeResult(content);
-        final HtmlService htmlService = ServerServiceRegistry.getInstance().getService(HtmlService.class);
         if (isHtml) {
             if (DisplayMode.RAW.equals(mode)) {
                 retval.setContent(content);
             } else {
+                HtmlService htmlService = ServerServiceRegistry.getInstance().getService(HtmlService.class);
                 retval.setContent(htmlService.dropScriptTagsInHeader(content));
 
                 if (DisplayMode.MODIFYABLE.isIncluded(mode) && usm.isDisplayHtmlInlineContent()) {
-                    final boolean externalImagesAllowed = usm.isAllowHTMLImages();
+                    boolean externalImagesAllowed = usm.isAllowHTMLImages();
+                    boolean suppressLinks = usm.isSuppressLinks();
                     // Resolve <base> tags
                     retval.setContent(htmlService.checkBaseTag(retval.getContent(), externalImagesAllowed));
                     // TODO: Use static string "o1p2e3n4-x5c6h7a8n9g0e" ?
-                    final String cssPrefix = null == mailPath ? null : (embedded ? "ox-" + getHash(mailPath.toString(), 10) : null);
-                    if (useSanitize()) {
+                    String cssPrefix = null == mailPath ? null : (embedded ? "ox-" + getHash(mailPath.toString(), 10) : null);
+                    {
                         // No need to generate well-formed HTML
+                        HtmlSanitizeOptions.Builder optionsBuilder = HtmlSanitizeOptions.builder().setSession(session);
                         if (externalImagesAllowed) {
-                            retval = htmlService.sanitize(retval.getContent(), null, false, null, cssPrefix, maxContentSize);
+                            optionsBuilder.setDropExternalImages(false);
                         } else {
-                            retval = htmlService.sanitize(retval.getContent(), null, true, modified, cssPrefix, maxContentSize);
-                        }
-                    } else {
-                        retval.setContent(htmlService.getConformHTML(retval.getContent(), charset == null ? CHARSET_US_ASCII : charset, false));
-                        /*
-                         * Filter according to white-list
-                         */
-                        retval.setContent(htmlService.filterWhitelist(retval.getContent()));
-                        if (externalImagesAllowed) {
-                            /*
-                             * TODO: Does not work reliably by now
-                             */
-                            // retval = htmlService.checkExternalImages(retval);
-                        } else {
-                            retval.setContent(htmlService.filterExternalImages(retval.getContent(), modified));
+                            optionsBuilder.setDropExternalImages(true).setModified(modified);
                         }
+                        optionsBuilder.setCssPrefix(cssPrefix).setMaxContentSize(maxContentSize).setSuppressLinks(suppressLinks).setReplaceBodyWithDiv(null != cssPrefix);
+                        retval = htmlService.sanitize(retval.getContent(), optionsBuilder.build());
                     }
                     /*
                      * Filter inlined images
@@ -333,7 +325,7 @@ public final class HtmlProcessing {
                             retval.setContent(filterInlineImages(retval.getContent(), session, mailPath));
                         }
                     }
-                    if (embedded) {
+                    if (embedded && !retval.isBodyReplacedWithDiv()) {
                         /*
                          * Replace <body> with <div>
                          */
@@ -342,47 +334,34 @@ public final class HtmlProcessing {
                 }
             }
         } else {
-            if (DisplayMode.MODIFYABLE.isIncluded(mode)) {
-                if (DisplayMode.DISPLAY.isIncluded(mode)) {
-                    retval.setContent(htmlService.formatURLs(retval.getContent(), COMMENT_ID));
-                    retval = htmlService.htmlFormat(retval.getContent(), true, COMMENT_ID, maxContentSize);
-                    if (usm.isUseColorQuote()) {
-                        retval.setContent(replaceHTMLSimpleQuotesForDisplay(retval.getContent()));
+            if (asMarkup) {
+                if (DisplayMode.MODIFYABLE.isIncluded(mode)) {
+                    HtmlService htmlService = ServerServiceRegistry.getInstance().getService(HtmlService.class);
+                    if (DisplayMode.DISPLAY.isIncluded(mode)) {
+                        if (false == usm.isSuppressLinks()) {
+                            retval.setContent(htmlService.formatURLs(retval.getContent(), COMMENT_ID));
+                        }
+                        retval = htmlService.htmlFormat(retval.getContent(), true, COMMENT_ID, maxContentSize);
+                        if (usm.isUseColorQuote()) {
+                            retval.setContent(replaceHTMLSimpleQuotesForDisplay(retval.getContent()));
+                        }
+                        if (DisplayMode.DOCUMENT.equals(mode)) {
+                            retval.setContent(htmlService.getConformHTML(retval.getContent(), "UTF-8"));
+                        }
+                    } else {
+                        retval = htmlService.htmlFormat(retval.getContent(), true, null, maxContentSize);
                     }
-                    if (DisplayMode.DOCUMENT.equals(mode)) {
-                        retval.setContent(htmlService.getConformHTML(retval.getContent(), "UTF-8"));
-                    }
-                } else {
-                    retval = htmlService.htmlFormat(retval.getContent(), true, null, maxContentSize);
                 }
             }
         }
         return retval;
     }
 
-    private static volatile Boolean useSanitize;
-
-    /**
-     * Whether to use sanitize.
-     */
-    public static boolean useSanitize() {
-        if (null == useSanitize) {
-            synchronized (HtmlProcessing.class) {
-                if (null == useSanitize) {
-                    final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
-                    useSanitize = Boolean.valueOf((null == service) || (service.getBoolProperty("com.openexchange.mail.text.useSanitize", true)));
-                }
-            }
-        }
-        return useSanitize.booleanValue();
-    }
-
     static {
         MailReloadable.getInstance().addReloadable(new Reloadable() {
 
             @Override
             public void reloadConfiguration(ConfigurationService configService) {
-                useSanitize = null;
                 imageHost = null;
             }
 
@@ -540,9 +519,11 @@ public final class HtmlProcessing {
 
         if (1 == numOfBodies) {
             Element bodyElement = bodyElements.get(0);
-            Segment content = bodyElement.getContent();
-            StringBuilder sb = new StringBuilder(content.length());
+            StringBuilder sb = new StringBuilder(32);
             getDivStartTagHTML(bodyElement.getStartTag(), cssPrefix, sb);
+            outputDocument.replace(bodyElement.getStartTag(), sb.toString());
+
+            sb.setLength(0);
             if (null != styleElements) {
                 for (Element styleElement : styleElements) {
                     sb.append(styleElement);
@@ -553,9 +534,16 @@ public final class HtmlProcessing {
                     sb.append(element);
                 }
             }
-            sb.append(content);
-            sb.append("</div>");
-            outputDocument.replace(bodyElement, sb);
+            if (sb.length() > 0) {
+                outputDocument.insert(bodyElement.getStartTag().getEnd(), sb.toString());
+            }
+
+            EndTag bodyEndTag = bodyElement.getEndTag();
+            if (null == bodyEndTag) {
+                outputDocument.insert(bodyElement.getEnd(), "</div>");
+            } else {
+                outputDocument.replace(bodyEndTag, "</div>");
+            }
             return;
         }
 
