@@ -133,8 +133,8 @@ public final class TextPartFinder {
                 if (ct.startsWith("text/plain")) {
                     // Check for possible uuencoded plain-text part
                     if (UUEncodedMultiPart.isUUEncoded(content)) {
-                        final UUEncodedMultiPart uuencodedMP = new UUEncodedMultiPart(content);
-                        if (uuencodedMP.isUUEncoded()) {
+                        UUEncodedMultiPart uuencodedMP = UUEncodedMultiPart.valueFor(content);
+                        if (null != uuencodedMP && uuencodedMP.isUUEncoded()) {
                             content = uuencodedMP.getCleanText();
                             textPart = createPartFromPlainText(content);
                         }
