@@ -87,8 +87,6 @@ public final class TransportProperties implements ITransportProperties {
 
     private boolean removeMimeVersionInSubParts;
 
-    private boolean enforceSecureConnection;
-
     /**
      * Initializes a new {@link TransportProperties}
      */
@@ -129,7 +127,6 @@ public final class TransportProperties implements ITransportProperties {
         referencedPartLimit = 0;
         publishingInfostoreFolder = null;
         removeMimeVersionInSubParts = false;
-        enforceSecureConnection = false;
     }
 
     private void loadProperties0() {
@@ -173,12 +170,6 @@ public final class TransportProperties implements ITransportProperties {
             logBuilder.append("\tRemove \"MIME-Version\" header in sub-parts: ").append(removeMimeVersionInSubParts).append('\n');
         }
 
-        {
-            final String tmp = configuration.getProperty("com.openexchange.mail.enforceSecureConnection", "false").trim();
-            enforceSecureConnection = Boolean.parseBoolean(tmp);
-            logBuilder.append("\tEnforced secure connections to external accounts: ").append(enforceSecureConnection).append('\n');
-        }
-
         logBuilder.append("Global transport properties successfully loaded!");
         LOG.info(logBuilder.toString());
     }
@@ -215,14 +206,4 @@ public final class TransportProperties implements ITransportProperties {
         return publishingInfostoreFolder;
     }
 
-    @Override
-    public boolean isEnforceSecureConnection() {
-        return enforceSecureConnection;
-    }
-
-    @Override
-    public void setEnforceSecureConnection(boolean enforceSecureConnection) {
-        throw new UnsupportedOperationException("setEnforceSecureConnection() not allowed for static MailProperties");
-    }
-
 }
