@@ -80,6 +80,6 @@ public class KnownStatusMessage implements LocalizableStrings {
     public static final String MESSAGE_DISABLED = "Account is disabled.";
 
     // The message advertising that affected account is currently in setup phase and does not yet reflect up-to-date information
-    public static final String MESSAGE_IN_SETUP = "Account is current being set-up.";
+    public static final String MESSAGE_IN_SETUP = "Account is currently being set-up.";
 
 }
