@@ -212,6 +212,27 @@ public interface MailAccountStorageService {
      */
     TransportAccount getTransportAccount(int accountId, int userId, int contextId) throws OXException;
 
+    /**
+     * Gets the mail accounts belonging to specified user in given context.
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @return The user's mail accounts
+     * @throws OXException If the mail accounts cannot be returned
+     */
+    TransportAccount[] getUserTransportAccounts(int userId, int contextId) throws OXException;
+
+    /**
+     * Gets the mail accounts belonging to specified user in given context.
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param con The connection to use
+     * @return The user's mail accounts
+     * @throws OXException If the mail accounts cannot be returned
+     */
+    TransportAccount[] getUserTransportAccounts(int userId, int cid, Connection con) throws OXException;
+
     /**
      * Gets the mail accounts belonging to specified user in given context.
      *
@@ -261,6 +282,27 @@ public interface MailAccountStorageService {
      */
     char getDefaultSeparator(Session session) throws OXException;
 
+    /**
+     * Enables the specified mail/transport account.
+     *
+     * @param accountId The account identifier
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @throws OXException If enabling the account fails
+     */
+    void enableMailAccount(int accountId, int userId, int contextId) throws OXException;
+
+    /**
+     * Enables the specified mail/transport account.
+     *
+     * @param accountId The account identifier
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param con The connection to use
+     * @throws OXException If enabling the account fails
+     */
+    void enableMailAccount(int accountId, int userId, int contextId, Connection con) throws OXException;
+
     /**
      * Updates mail account's value taken specified {@code MailAccountDescription} instance.
      *
@@ -513,6 +555,34 @@ public interface MailAccountStorageService {
      */
     TransportAccount getTransportByReference(String reference, int userId, int contextId) throws OXException;
 
+    // --------------------------------------------------------------------------------------------------------------------
+
+    /**
+     * Increments the count of failed authentications for specified account's mail access.
+     *
+     * @param accountId The account identifier
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param optReason The optional reason for failed authentication or <code>null</code>
+     * @return <code>true</code> if mail access has been disabled due to this call; otherwise <code>false</code>
+     * @throws OXException If incrementing the count fails
+     */
+    boolean incrementFailedMailAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException;
+
+    /**
+     * Increments the count of failed authentications for specified account's mail transport.
+     *
+     * @param accountId The account identifier
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param optReason The optional reason for failed authentication or <code>null</code>
+     * @return <code>true</code> if mail transport has been disabled due to this call; otherwise <code>false</code>
+     * @throws OXException If incrementing the count fails
+     */
+    boolean incrementFailedTransportAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException;
+
+    // --------------------------------------------------------------------------------------------------------------------
+
     /**
      * Gets those mail accounts of given user in given context whose host name occurs in specified collection of host names.
      *
