@@ -120,6 +120,8 @@ public abstract class AbstractMailAccount implements MailAccount {
     protected int mailOAuthId;
     protected int transportOAuthId;
     protected String rootFolder;
+    protected boolean mailDisabled;
+    protected boolean transportDisabled;
 
     /**
      * Initializes a new {@link AbstractMailAccount}.
@@ -137,6 +139,8 @@ public abstract class AbstractMailAccount implements MailAccount {
         mailProtocol = mailProvider == null ? "imap" : mailProvider;
         mailOAuthId = -1;
         transportOAuthId = -1;
+        mailDisabled = false;
+        transportDisabled = false;
     }
 
     @Override
@@ -144,11 +148,6 @@ public abstract class AbstractMailAccount implements MailAccount {
         return id;
     }
 
-    @Override
-    public boolean isMailAccount() {
-        return true;
-    }
-
     @Override
     public String getLogin() {
         return login;
@@ -202,6 +201,11 @@ public abstract class AbstractMailAccount implements MailAccount {
         return replyTo;
     }
 
+    @Override
+    public boolean isMailDisabled() {
+        return mailDisabled;
+    }
+
     @Override
     public TransportAuth getTransportAuth() {
         return transportAuth;
@@ -227,6 +231,11 @@ public abstract class AbstractMailAccount implements MailAccount {
         return transportSecure;
     }
 
+    @Override
+    public boolean isTransportDisabled() {
+        return transportDisabled;
+    }
+
     @Override
     public int getUserId() {
         return userId;
@@ -305,6 +314,24 @@ public abstract class AbstractMailAccount implements MailAccount {
         }
     }
 
+    /**
+     * Sets whether mail access is disabled
+     *
+     * @param mailDisabled <code>true</code> if disabled; otherwise <code>false</code>
+     */
+    public void setMailDisabled(boolean mailDisabled) {
+        this.mailDisabled = mailDisabled;
+    }
+
+    /**
+     * Sets whether mail transport is disabled
+     *
+     * @param transportDisabled <code>true</code> if disabled; otherwise <code>false</code>
+     */
+    public void setTransportDisabled(boolean transportDisabled) {
+        this.transportDisabled = transportDisabled;
+    }
+
     /**
      * Sets the user ID.
      *
@@ -720,7 +747,7 @@ public abstract class AbstractMailAccount implements MailAccount {
     /**
      * Sets the archive full name
      *
-     * @param trashFullname The archive full name to set
+     * @param archiveFullname The archive full name to set
      */
     public void setArchiveFullname(String archiveFullname) {
         this.archiveFullname = archiveFullname;
