@@ -329,6 +329,24 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return delegate.getDefaultSeparator(session);
     }
 
+    @Override
+    public boolean incrementFailedMailAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException {
+        boolean disabled = delegate.incrementFailedMailAuthCount(accountId, userId, contextId, optReason);
+        if (disabled) {
+            invalidateMailAccount(accountId, userId, contextId);
+        }
+        return disabled;
+    }
+
+    @Override
+    public boolean incrementFailedTransportAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException {
+        boolean disabled = delegate.incrementFailedTransportAuthCount(accountId, userId, contextId, optReason);
+        if (disabled) {
+            invalidateMailAccount(accountId, userId, contextId);
+        }
+        return disabled;
+    }
+
     @Override
     public MailAccount getDefaultMailAccount(int userId, int contextId) throws OXException {
         CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
@@ -449,6 +467,16 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return accounts;
     }
 
+    @Override
+    public TransportAccount[] getUserTransportAccounts(int userId, int contextId, Connection con) throws OXException {
+        int[] ids = delegate.getUserTransportAccountIDs(userId, contextId, con);
+        TransportAccount[] accounts = new TransportAccount[ids.length];
+        for (int i = 0; i < accounts.length; i++) {
+            accounts[i] = getTransportAccount(ids[i], userId, contextId, con);
+        }
+        return accounts;
+    }
+
     @Override
     public MailAccount getRawMailAccount(int id, int userId, int contextId) throws OXException {
         return delegate.getRawMailAccount(id, userId, contextId);
@@ -530,6 +558,17 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         return accounts;
     }
 
+    @Override
+    public TransportAccount[] getUserTransportAccounts(int userId, int contextId) throws OXException {
+        int[] ids = delegate.getUserTransportAccountIDs(userId, contextId);
+
+        TransportAccount[] accounts = new TransportAccount[ids.length];
+        for (int i = 0; i < accounts.length; i++) {
+            accounts[i] = getTransportAccount(ids[i], userId, contextId);
+        }
+        return accounts;
+    }
+
     @Override
     public MailAccount[] resolveLogin(String login, int contextId) throws OXException {
         int[][] idsAndUsers = resolveFromCache(login, contextId, new FromDelegate() {
@@ -640,6 +679,18 @@ final class CachingMailAccountStorage implements MailAccountStorageService {
         }
     }
 
+    @Override
+    public void enableMailAccount(int accountId, int userId, int contextId) throws OXException {
+        delegate.enableMailAccount(accountId, userId, contextId);
+        invalidateMailAccount(accountId, userId, contextId);
+    }
+
+    @Override
+    public void enableMailAccount(int accountId, int userId, int contextId, Connection con) throws OXException {
+        delegate.enableMailAccount(accountId, userId, contextId, con);
+        invalidateMailAccount(accountId, userId, contextId);
+    }
+
     @Override
     public int insertMailAccount(MailAccountDescription mailAccount, int userId, Context ctx, Session session) throws OXException {
         int id = delegate.insertMailAccount(mailAccount, userId, ctx, session);
