@@ -101,6 +101,16 @@ final class SanitizingStorageService implements MailAccountStorageService {
         storageService.invalidateMailAccounts(user, cid);
     }
 
+    @Override
+    public boolean incrementFailedMailAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException {
+        return storageService.incrementFailedMailAuthCount(accountId, userId, contextId, optReason);
+    }
+
+    @Override
+    public boolean incrementFailedTransportAuthCount(int accountId, int userId, int contextId, Exception optReason) throws OXException {
+        return storageService.incrementFailedTransportAuthCount(accountId, userId, contextId, optReason);
+    }
+
     @Override
     public MailAccount getRawMailAccount(int id, int userId, int cid) throws OXException {
         try {
@@ -160,6 +170,32 @@ final class SanitizingStorageService implements MailAccountStorageService {
         }
     }
 
+    @Override
+    public TransportAccount[] getUserTransportAccounts(final int user, final int cid) throws OXException {
+        try {
+            return storageService.getUserTransportAccounts(user, cid);
+        } catch (final OXException e) {
+            if (!isURIError(e)) {
+                throw e;
+            }
+            Sanitizer.sanitize(user, cid, storageService);
+            return storageService.getUserTransportAccounts(user, cid);
+        }
+    }
+
+    @Override
+    public TransportAccount[] getUserTransportAccounts(final int user, final int cid, final Connection con) throws OXException {
+        try {
+            return storageService.getUserTransportAccounts(user, cid, con);
+        } catch (final OXException e) {
+            if (!isURIError(e)) {
+                throw e;
+            }
+            Sanitizer.sanitize(user, cid, storageService);
+            return storageService.getUserTransportAccounts(user, cid, con);
+        }
+    }
+
     @Override
     public MailAccount[] getUserMailAccounts(final int user, final int cid) throws OXException {
         try {
@@ -191,6 +227,16 @@ final class SanitizingStorageService implements MailAccountStorageService {
         return storageService.getDefaultMailAccount(user, cid);
     }
 
+    @Override
+    public void enableMailAccount(int accountId, int userId, int contextId) throws OXException {
+        storageService.enableMailAccount(accountId, userId, contextId);
+    }
+
+    @Override
+    public void enableMailAccount(int accountId, int userId, int contextId, Connection con) throws OXException {
+        storageService.enableMailAccount(accountId, userId, contextId, con);
+    }
+
     @Override
     public void updateMailAccount(final MailAccountDescription mailAccount, final Set<Attribute> attributes, final int user, final int cid, final Session session) throws OXException {
         storageService.updateMailAccount(mailAccount, attributes, user, cid, session);
