@@ -57,6 +57,7 @@ import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.json.writer.FolderWriter;
+import com.openexchange.mailaccount.json.ActiveProviderDetector;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -64,15 +65,15 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public abstract class AbstractMailAccountTreeAction extends AbstractMailAccountAction {
+public abstract class AbstractMailAccountTreeAction extends AbstractValidateMailAccountAction {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AbstractMailAccountTreeAction.class);
 
     /**
      * Initializes a new {@link AbstractMailAccountTreeAction}.
      */
-    protected AbstractMailAccountTreeAction() {
-        super();
+    protected AbstractMailAccountTreeAction(ActiveProviderDetector activeProviderDetector) {
+        super(activeProviderDetector);
     }
 
     protected static JSONObject actionValidateTree0(final MailAccess<?, ?> mailAccess, final ServerSession session) throws JSONException {
