@@ -227,8 +227,9 @@ public final class NewAction extends AbstractMailAccountAction implements MailAc
                     mailAccess = getMailAccess(accountDescription, session, warnings);
                     mailAccess.connect(false);
                     IMailFolderStorage storage = mailAccess.getFolderStorage();
-                    if (storage instanceof IMailFolderStorageDefaultFolderAware) {
-                        defaultFolderNames = ((IMailFolderStorageDefaultFolderAware) storage).getSpecialUseFolder();
+                    IMailFolderStorageDefaultFolderAware defaultFolderAware = storage.supports(IMailFolderStorageDefaultFolderAware.class);
+                    if (null != defaultFolderAware) {
+                        defaultFolderNames = defaultFolderAware.getSpecialUseFolder();
                     }
                     mailAccess.close(false);
                     mailAccess = null;
@@ -294,8 +295,11 @@ public final class NewAction extends AbstractMailAccountAction implements MailAc
             if (null == loadedMailAccount) {
                 throw MailAccountExceptionCodes.NOT_FOUND.create(id, session.getUserId(), session.getContextId());
             }
-            jsonAccount = DefaultMailAccountWriter.write(checkFullNames(loadedMailAccount, storageService, session));
+            MailAccount mailAccount = checkFullNames(loadedMailAccount, storageService, session);
+            mailAccount = checkSpamInfo(mailAccount, session);
+            jsonAccount = DefaultMailAccountWriter.write(mailAccount);
         } else {
+            newAccount = checkSpamInfo(newAccount, session);
             jsonAccount = DefaultMailAccountWriter.write(newAccount);
         }
 
