@@ -72,9 +72,6 @@ import com.openexchange.java.Strings;
 import com.openexchange.jslob.DefaultJSlob;
 import com.openexchange.jslob.JSlobId;
 import com.openexchange.mail.MailSessionCache;
-import com.openexchange.mail.api.IMailFolderStorage;
-import com.openexchange.mail.api.IMailMessageStorage;
-import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.utils.MailPasswordUtil;
 import com.openexchange.mailaccount.Attribute;
@@ -82,7 +79,6 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountDescription;
 import com.openexchange.mailaccount.MailAccountExceptionCodes;
 import com.openexchange.mailaccount.MailAccountStorageService;
-import com.openexchange.mailaccount.Tools;
 import com.openexchange.mailaccount.TransportAuth;
 import com.openexchange.mailaccount.json.ActiveProviderDetector;
 import com.openexchange.mailaccount.json.MailAccountFields;
@@ -197,7 +193,7 @@ public final class UpdateAction extends AbstractMailAccountAction implements Mai
             // Don't check for POP3 account due to access restrictions (login only allowed every n minutes)
             boolean pop3 = Strings.toLowerCase(accountDescription.getMailProtocol()).startsWith("pop3");
 
-            if (fieldsToUpdate.contains(Attribute.MAIL_URL_LITERAL) && !toUpdate.generateMailServerURL().equals(accountDescription.generateMailServerURL())) {
+            if ((fieldsToUpdate.contains(Attribute.MAIL_SERVER_LITERAL) || fieldsToUpdate.contains(Attribute.MAIL_URL_LITERAL)) && !toUpdate.generateMailServerURL().equals(accountDescription.generateMailServerURL())) {
                 if (!pop3 && !ValidateAction.checkMailServerURL(accountDescription, session, warnings, true)) {
                     final OXException warning = MimeMailExceptionCode.CONNECT_ERROR.create(accountDescription.getMailServer(), accountDescription.getLogin());
                     warning.setCategory(Category.CATEGORY_WARNING);
@@ -205,7 +201,7 @@ public final class UpdateAction extends AbstractMailAccountAction implements Mai
                 }
                 clearStamp |= (pop3 && !toUpdate.getMailServer().equals(accountDescription.getMailServer()));
             }
-            if (fieldsToUpdate.contains(Attribute.TRANSPORT_URL_LITERAL) && !toUpdate.generateTransportServerURL().equals(accountDescription.generateTransportServerURL())) {
+            if ((fieldsToUpdate.contains(Attribute.TRANSPORT_SERVER_LITERAL) || fieldsToUpdate.contains(Attribute.TRANSPORT_URL_LITERAL)) && !toUpdate.generateTransportServerURL().equals(accountDescription.generateTransportServerURL())) {
                 if (!pop3 && !ValidateAction.checkTransportServerURL(accountDescription, session, warnings, true)) {
                     final String transportLogin = accountDescription.getTransportLogin();
                     final OXException warning = MimeMailExceptionCode.CONNECT_ERROR.create(accountDescription.getTransportServer(), transportLogin == null ? accountDescription.getLogin() : transportLogin);
@@ -216,12 +212,15 @@ public final class UpdateAction extends AbstractMailAccountAction implements Mai
             }
 
         }
-        // Check standard folder names against full names
-        if (false == isPop3(toUpdate)) {
+        /*-
+         * Check standard folder names against full names
+         *
+        if (false == isPop3(toUpdate) && false == toUpdate.isMailDisabled()) {
             fillMailConfig(accountDescription, fieldsToUpdate, toUpdate, session);
             MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = getMailAccess(accountDescription, session, warnings);
             Tools.checkNames(accountDescription, fieldsToUpdate, Tools.getSeparator(mailAccess));
         }
+         */
 
         // Update
         MailAccount updatedAccount = null;
@@ -302,8 +301,11 @@ public final class UpdateAction extends AbstractMailAccountAction implements Mai
         // Write to JSON structure
         final JSONObject jsonAccount;
         if (null == updatedAccount) {
-            jsonAccount = DefaultMailAccountWriter.write(storageService.getMailAccount(id, session.getUserId(), contextId));
+            MailAccount mailAccount = storageService.getMailAccount(id, session.getUserId(), contextId);
+            mailAccount = checkSpamInfo(mailAccount, session);
+            jsonAccount = DefaultMailAccountWriter.write(mailAccount);
         } else {
+            updatedAccount = checkSpamInfo(updatedAccount, session);
             jsonAccount = DefaultMailAccountWriter.write(updatedAccount);
         }
 
