@@ -229,7 +229,7 @@ public class DefaultMailAccountParser extends DataParser {
         } else {
             final SetSwitch setSwitch = new SetSwitch(account);
             for (final Attribute attribute : Attribute.MAIL_URL_ATTRIBUTES) {
-                if (json.has(attribute.getName())) {
+                if (json.hasAndNotNull(attribute.getName())) {
                     setSwitch.setValue(json.get(attribute.getName()));
                     attribute.doSwitch(setSwitch);
                     attributes.add(attribute);
@@ -292,7 +292,7 @@ public class DefaultMailAccountParser extends DataParser {
         } else {
             final SetSwitch setSwitch = new SetSwitch(account);
             for (final Attribute attribute : Attribute.TRANSPORT_URL_ATTRIBUTES) {
-                if (json.has(attribute.getName())) {
+                if (json.hasAndNotNull(attribute.getName())) {
                     setSwitch.setValue(json.get(attribute.getName()));
                     attribute.doSwitch(setSwitch);
                     attributes.add(attribute);
@@ -321,101 +321,101 @@ public class DefaultMailAccountParser extends DataParser {
         }
 
         // Other fields
-        if (json.has(MailAccountFields.NAME)) {
+        if (json.hasAndNotNull(MailAccountFields.NAME)) {
             account.setName(parseString(json, MailAccountFields.NAME));
             attributes.add(Attribute.NAME_LITERAL);
         }
-        if (json.has(MailAccountFields.PRIMARY_ADDRESS)) {
+        if (json.hasAndNotNull(MailAccountFields.PRIMARY_ADDRESS)) {
             final String string = parseString(json, MailAccountFields.PRIMARY_ADDRESS);
             account.setPrimaryAddress(null == string ? string : string.trim());
             attributes.add(Attribute.PRIMARY_ADDRESS_LITERAL);
         }
-        if (json.has(MailAccountFields.PERSONAL)) {
+        if (json.hasAndNotNull(MailAccountFields.PERSONAL)) {
             account.setPersonal(parseString(json, MailAccountFields.PERSONAL));
             attributes.add(Attribute.PERSONAL_LITERAL);
         }
         final Map<String, String> props = new HashMap<String, String>(8);
-        if (json.has(MailAccountFields.REPLY_TO)) {
+        if (json.hasAndNotNull(MailAccountFields.REPLY_TO)) {
             account.setReplyTo(parseString(json, MailAccountFields.REPLY_TO));
             props.put("replyto", json.getString(MailAccountFields.REPLY_TO).trim());
             attributes.add(Attribute.REPLY_TO_LITERAL);
         }
-        if (json.has(MailAccountFields.SPAM_HANDLER)) {
+        if (json.hasAndNotNull(MailAccountFields.SPAM_HANDLER)) {
             final String string = parseString(json, MailAccountFields.SPAM_HANDLER);
             account.setSpamHandler(null == string ? string : string.trim());
             attributes.add(Attribute.SPAM_HANDLER_LITERAL);
         }
         // Folder names
-        if (json.has(MailAccountFields.TRASH)) {
+        if (json.hasAndNotNull(MailAccountFields.TRASH)) {
             final String string = parseString(json, MailAccountFields.TRASH);
             account.setTrash(null == string ? string : string.trim());
             attributes.add(Attribute.TRASH_LITERAL);
         }
-        if (json.has(MailAccountFields.ARCHIVE)) {
+        if (json.hasAndNotNull(MailAccountFields.ARCHIVE)) {
             final String string = parseString(json, MailAccountFields.ARCHIVE);
             account.setArchive(null == string ? string : string.trim());
             attributes.add(Attribute.ARCHIVE_LITERAL);
         }
-        if (json.has(MailAccountFields.SENT)) {
+        if (json.hasAndNotNull(MailAccountFields.SENT)) {
             final String string = parseString(json, MailAccountFields.SENT);
             account.setSent(null == string ? string : string.trim());
             attributes.add(Attribute.SENT_LITERAL);
         }
-        if (json.has(MailAccountFields.DRAFTS)) {
+        if (json.hasAndNotNull(MailAccountFields.DRAFTS)) {
             final String string = parseString(json, MailAccountFields.DRAFTS);
             account.setDrafts(null == string ? string : string.trim());
             attributes.add(Attribute.DRAFTS_LITERAL);
         }
-        if (json.has(MailAccountFields.SPAM)) {
+        if (json.hasAndNotNull(MailAccountFields.SPAM)) {
             final String string = parseString(json, MailAccountFields.SPAM);
             account.setSpam(null == string ? string : string.trim());
             attributes.add(Attribute.SPAM_LITERAL);
         }
-        if (json.has(MailAccountFields.CONFIRMED_SPAM)) {
+        if (json.hasAndNotNull(MailAccountFields.CONFIRMED_SPAM)) {
             final String string = parseString(json, MailAccountFields.CONFIRMED_SPAM);
             account.setConfirmedSpam(null == string ? string : string.trim());
             attributes.add(Attribute.CONFIRMED_SPAM_LITERAL);
         }
-        if (json.has(MailAccountFields.CONFIRMED_HAM)) {
+        if (json.hasAndNotNull(MailAccountFields.CONFIRMED_HAM)) {
             final String string = parseString(json, MailAccountFields.CONFIRMED_HAM);
             account.setConfirmedHam(null == string ? string : string.trim());
             attributes.add(Attribute.CONFIRMED_HAM_LITERAL);
         }
-        if (json.has(MailAccountFields.UNIFIED_INBOX_ENABLED)) {
+        if (json.hasAndNotNull(MailAccountFields.UNIFIED_INBOX_ENABLED)) {
             account.setUnifiedINBOXEnabled(parseBoolean(json, MailAccountFields.UNIFIED_INBOX_ENABLED));
             attributes.add(Attribute.UNIFIED_INBOX_ENABLED_LITERAL);
         }
-        if (json.has(MailAccountFields.TRASH_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.TRASH_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.TRASH_FULLNAME);
             account.setTrashFullname(null == string ? string : string.trim());
             attributes.add(Attribute.TRASH_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.ARCHIVE_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.ARCHIVE_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.ARCHIVE_FULLNAME);
             account.setArchiveFullname(null == string ? string : string.trim());
             attributes.add(Attribute.ARCHIVE_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.SENT_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.SENT_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.SENT_FULLNAME);
             account.setSentFullname(null == string ? string : string.trim());
             attributes.add(Attribute.SENT_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.DRAFTS_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.DRAFTS_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.DRAFTS_FULLNAME);
             account.setDraftsFullname(null == string ? string : string.trim());
             attributes.add(Attribute.DRAFTS_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.SPAM_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.SPAM_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.SPAM_FULLNAME);
             account.setSpamFullname(null == string ? string : string.trim());
             attributes.add(Attribute.SPAM_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.CONFIRMED_SPAM_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.CONFIRMED_SPAM_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.CONFIRMED_SPAM_FULLNAME);
             account.setConfirmedSpamFullname(null == string ? string : string.trim());
             attributes.add(Attribute.CONFIRMED_SPAM_FULLNAME_LITERAL);
         }
-        if (json.has(MailAccountFields.CONFIRMED_HAM_FULLNAME)) {
+        if (json.hasAndNotNull(MailAccountFields.CONFIRMED_HAM_FULLNAME)) {
             final String string = parseString(json, MailAccountFields.CONFIRMED_HAM_FULLNAME);
             account.setConfirmedHamFullname(null == string ? string : string.trim());
             attributes.add(Attribute.CONFIRMED_HAM_FULLNAME_LITERAL);
