@@ -51,11 +51,10 @@ package com.openexchange.quota.json;
 
 import java.util.Collection;
 import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
 import org.osgi.framework.BundleContext;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.quota.json.actions.GetAction;
 import com.openexchange.server.ServiceLookup;
@@ -65,7 +64,6 @@ import com.openexchange.server.ServiceLookup;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Module(name = "quota", description = "The quota module allows accesssing information about the use and quota of the filestore/mailstorage.")
 public class QuotaActionFactory implements AJAXActionServiceFactory {
 
     private final Map<String, AJAXActionService> actions;
@@ -77,12 +75,13 @@ public class QuotaActionFactory implements AJAXActionServiceFactory {
      */
     public QuotaActionFactory(final ServiceLookup services, final BundleContext context) {
         super();
-        actions = new ConcurrentHashMap<String, AJAXActionService>(5, 0.9f, 1);
-        GetAction getAction = new com.openexchange.quota.json.actions.GetAction(context);
+        ImmutableMap.Builder<String, AJAXActionService> actions = ImmutableMap.builder();
+        GetAction getAction = new com.openexchange.quota.json.actions.GetAction(services);
         actions.put("get", getAction);
         actions.put("GET", getAction);
         actions.put("filestore", new com.openexchange.quota.json.actions.FilestoreAction(services));
         actions.put("mail", new com.openexchange.quota.json.actions.MailAction(services));
+        this.actions = actions.build();
     }
 
     @Override
