@@ -52,9 +52,6 @@ package com.openexchange.quota.json.actions;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.Quota;
 import com.openexchange.quota.json.QuotaAJAXRequest;
@@ -66,9 +63,6 @@ import com.openexchange.server.ServiceLookup;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(method = RequestMethod.GET, name = "filestore", description = "Get the filestore usage data", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module.")
-}, responseDescription = "A JSON Object containing the fields \"use\" and \"quota\". \"use\" represents the uploaded files sizes sum and the field \"quota\" represents the maximum.")
 public final class FilestoreAction extends AbstractQuotaAction {
 
     /**
