@@ -46,6 +46,7 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.report.internal;
 
 import java.sql.Connection;
@@ -63,6 +64,7 @@ import com.openexchange.database.DatabaseService;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.filestore.Info;
 import com.openexchange.filestore.QuotaFileStorage;
 import com.openexchange.filestore.QuotaFileStorageService;
 import com.openexchange.groupware.ldap.UserExceptionCode;
@@ -215,7 +217,7 @@ public class InfostoreInformationImpl implements InfostoreInformationService {
         HashMap<String, Integer> filestoreMap = new HashMap<>();
         for (Map.Entry<Integer, List<Integer>> contexts : usersInContext.entrySet()) {
             for (Integer userId : contexts.getValue()) {
-                QuotaFileStorage userStorage = storageService.getQuotaFileStorage(userId, contexts.getKey());
+                QuotaFileStorage userStorage = storageService.getQuotaFileStorage(userId, contexts.getKey(), Info.drive());
                 long quota = userStorage.getQuota();
                 Long percent = quota < 0 ? 0 : (quota == 0 ? 100 : userStorage.getUsage() * 100 / quota);
                 filestoreMap.put(userStorage.getUri().toString(), percent.intValue());
