@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,165 +63,83 @@ public enum ResourceExceptionCode implements DisplayableOXExceptionCode {
     /**
      * A database connection Cannot be obtained.
      */
-    NO_CONNECTION(ResourceExceptionCode.NO_CONNECTION_MSG, Category.CATEGORY_SERVICE_DOWN, 1, OXExceptionStrings.SQL_ERROR_MSG),
+    NO_CONNECTION("Cannot get database connection.", Category.CATEGORY_SERVICE_DOWN, 1, OXExceptionStrings.SQL_ERROR_MSG),
     /**
      * SQL Problem: "%1$s".
      */
-    SQL_ERROR(ResourceExceptionCode.SQL_ERROR_MSG, Category.CATEGORY_ERROR, 2, OXExceptionStrings.SQL_ERROR_MSG),
+    SQL_ERROR("SQL problem: \"%1$s\"", Category.CATEGORY_ERROR, 2, OXExceptionStrings.SQL_ERROR_MSG),
     /**
      * Cannot find resource group with identifier %1$d.
      */
-    RESOURCEGROUP_NOT_FOUND(ResourceExceptionCode.RESOURCEGROUP_NOT_FOUND_MSG, Category.CATEGORY_USER_INPUT, 3, ResourceExceptionMessage.RESOURCEGROUP_NOT_FOUND_MSG_DISPLAY),
+    RESOURCEGROUP_NOT_FOUND("Cannot find resource group with identifier %1$d.", Category.CATEGORY_USER_INPUT, 3, ResourceExceptionMessage.RESOURCEGROUP_NOT_FOUND_MSG_DISPLAY),
     /**
      * Found resource groups with same identifier %1$d.
      */
-    RESOURCEGROUP_CONFLICT(ResourceExceptionCode.RESOURCEGROUP_CONFLICT_MSG, Category.CATEGORY_USER_INPUT, 4, ResourceExceptionMessage.RESOURCEGROUP_CONFLICT_MSG_DISPLAY),
+    RESOURCEGROUP_CONFLICT("Found resource groups with same identifier %1$d.", Category.CATEGORY_USER_INPUT, 4, ResourceExceptionMessage.RESOURCEGROUP_CONFLICT_MSG_DISPLAY),
     /**
      * Cannot find resource with identifier %1$d.
      */
-    RESOURCE_NOT_FOUND(ResourceExceptionCode.RESOURCE_NOT_FOUND_MSG, Category.CATEGORY_USER_INPUT, 5, ResourceExceptionMessage.RESOURCE_NOT_FOUND_MSG_DISPLAY),
+    RESOURCE_NOT_FOUND("Cannot find resource with identifier %1$d.", Category.CATEGORY_USER_INPUT, 5, ResourceExceptionMessage.RESOURCE_NOT_FOUND_MSG_DISPLAY),
     /**
      * Found resource(s) with same identifier %1$s.
      */
-    RESOURCE_CONFLICT(ResourceExceptionCode.RESOURCE_CONFLICT_MSG, Category.CATEGORY_USER_INPUT, 6, ResourceExceptionMessage.RESOURCE_CONFLICT_MSG_DISPLAY),
+    RESOURCE_CONFLICT("Found resource(s) with same identifier %1$s.", Category.CATEGORY_USER_INPUT, 6, ResourceExceptionMessage.RESOURCE_CONFLICT_MSG_DISPLAY),
     /**
      * No resource given.
      */
-    NULL(ResourceExceptionCode.NULL_MSG, Category.CATEGORY_ERROR, 7),
+    NULL("No resource given.", Category.CATEGORY_ERROR, 7),
     /**
      * Missing mandatory field(s) in given resource.
      */
-    MANDATORY_FIELD(ResourceExceptionCode.MANDATORY_FIELD_MSG, Category.CATEGORY_ERROR, 8),
+    MANDATORY_FIELD("Missing mandatory field(s) in given resource.", Category.CATEGORY_USER_INPUT, 8, ResourceExceptionMessage.MANDATORY_FIELD_MSG_DISPLAY),
     /**
      * No permission to modify resources in context %1$s
      */
-    PERMISSION(ResourceExceptionCode.PERMISSION_MSG, Category.CATEGORY_PERMISSION_DENIED, 9, ResourceExceptionMessage.PERMISSION_MSG_DISPLAY),
+    PERMISSION("No permission to modify resources in context %1$s", Category.CATEGORY_PERMISSION_DENIED, 9, ResourceExceptionMessage.PERMISSION_MSG_DISPLAY),
     /**
      * Found resource(s) with same email address %1$s.
      */
-    RESOURCE_CONFLICT_MAIL(ResourceExceptionCode.RESOURCE_CONFLICT_MAIL_MSG, Category.CATEGORY_ERROR, 10),
+    RESOURCE_CONFLICT_MAIL("Found resource(s) with same email address %1$s.", Category.CATEGORY_USER_INPUT, 10, ResourceExceptionMessage.RESOURCE_CONFLICT_MAIL_MSG_DISPLAY),
     /**
      * Invalid resource identifier: %1$s
      */
-    INVALID_RESOURCE_IDENTIFIER(ResourceExceptionCode.INVALID_RESOURCE_IDENTIFIER_MSG, Category.CATEGORY_USER_INPUT, 11, ResourceExceptionMessage.INVALID_RESOURCE_IDENTIFIER_MSG_DISPLAY),
+    INVALID_RESOURCE_IDENTIFIER("Invalid resource identifier: %1$s", Category.CATEGORY_USER_INPUT, 11, ResourceExceptionMessage.INVALID_RESOURCE_IDENTIFIER_MSG_DISPLAY),
     /**
      * Invalid resource email address: %1$s
      */
-    INVALID_RESOURCE_MAIL(ResourceExceptionCode.INVALID_RESOURCE_MAIL_MSG, Category.CATEGORY_USER_INPUT, 12, ResourceExceptionMessage.INVALID_RESOURCE_MAIL_MSG_DISPLAY),
+    INVALID_RESOURCE_MAIL("Invalid resource E-Mail address: %1$s", Category.CATEGORY_USER_INPUT, 12, ResourceExceptionMessage.INVALID_RESOURCE_MAIL_MSG_DISPLAY),
     /**
      * The resource has been changed in the meantime
      */
-    CONCURRENT_MODIFICATION(ResourceExceptionCode.CONCURRENT_MODIFICATION_MSG, Category.CATEGORY_CONFLICT, 13, ResourceExceptionMessage.CONCURRENT_MODIFICATION_MSG_DISPLAY);
+    CONCURRENT_MODIFICATION("The resource has been changed in the meantime: %1$s", Category.CATEGORY_CONFLICT, 13, ResourceExceptionMessage.CONCURRENT_MODIFICATION_MSG_DISPLAY);
+
+    /** Message of the exception. */
+    private final String message;
+
+    /** Category of the exception. */
+    private final Category category;
+
+    /** Detail number of the exception. */
+    private final int detailNumber;
+
+    /** Message displayed to the user */
+    private final String displayMessage;
 
     /**
-     * A database connection Cannot be obtained.
-     */
-    private final static String NO_CONNECTION_MSG = "Cannot get database connection.";
-
-    /**
-     * SQL Problem: "%1$s".
-     */
-    private final static String SQL_ERROR_MSG = "SQL problem: \"%1$s\"";
-
-    /**
-     * Cannot find resource group with identifier %1$d.
-     */
-    private final static String RESOURCEGROUP_NOT_FOUND_MSG = "Cannot find resource group with identifier %1$d.";
-
-    /**
-     * Found resource groups with same identifier %1$d.
-     */
-    private final static String RESOURCEGROUP_CONFLICT_MSG = "Found resource groups with same identifier %1$d.";
-
-    /**
-     * Cannot find resource with identifier %1$d.
-     */
-    private final static String RESOURCE_NOT_FOUND_MSG = "Cannot find resource with identifier %1$d.";
-
-    /**
-     * Found resource(s) with same identifier %1$s.
-     */
-    private final static String RESOURCE_CONFLICT_MSG = "Found resource(s) with same identifier %1$s.";
-
-    /**
-     * No resource given.
-     */
-    private final static String NULL_MSG = "No resource given.";
-
-    /**
-     * Missing mandatory field(s) in given resource.
-     */
-    private final static String MANDATORY_FIELD_MSG = "Missing mandatory field(s) in given resource.";
-
-    /**
-     * No permission to modify resources in context %1$s
-     */
-    private final static String PERMISSION_MSG = "No permission to modify resources in context %1$s";
-
-    /**
-     * Found resource(s) with same email address %1$s.
-     */
-    private final static String RESOURCE_CONFLICT_MAIL_MSG = "Found resource(s) with same email address %1$s.";
-
-    /**
-     * Invalid resource identifier: %1$s
-     */
-    private final static String INVALID_RESOURCE_IDENTIFIER_MSG = "Invalid resource identifier: %1$s";
-
-    /**
-     * Invalid resource email address: %1$s
-     */
-    private final static String INVALID_RESOURCE_MAIL_MSG = "Invalid resource E-Mail address: %1$s";
-
-    /**
-     * The resource has been changed in the meantime: %1$s
-     */
-    private final static String CONCURRENT_MODIFICATION_MSG = "The resource has been changed in the meantime: %1$s";
-
-    /**
-     * Message of the exception.
-     */
-    final String message;
-
-    /**
-     * Category of the exception.
-     */
-    final Category category;
-
-    /**
-     * Detail number of the exception.
-     */
-    final int detailNumber;
-
-    /**
-     * Message displayed to the user
-     */
-    private String displayMessage;
-
-    /**
-     * Default constructor.
-     *
-     * @param message message.
-     * @param category category.
-     * @param detailNumber detail number.
+     * Initializes a new {@link ResourceExceptionCode}.
      */
     private ResourceExceptionCode(final String message, final Category category, final int detailNumber) {
         this(message, category, detailNumber, null);
     }
 
     /**
-     * Default constructor.
-     * 
-     * @param message
-     * @param category
-     * @param detailNumber
-     * @param displayMessage
+     * Initializes a new {@link ResourceExceptionCode}.
      */
     private ResourceExceptionCode(final String message, final Category category, final int detailNumber, final String displayMessage) {
         this.message = message;
         this.category = category;
         this.detailNumber = detailNumber;
-        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
+        this.displayMessage = displayMessage == null ? OXExceptionStrings.MESSAGE : displayMessage;
     }
 
     @Override
