@@ -79,6 +79,7 @@ import com.openexchange.ajax.customizer.file.AdditionalFileField;
 import com.openexchange.ajax.customizer.file.SanitizedFilename;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
 import com.openexchange.ajax.customizer.folder.osgi.FolderFieldCollector;
+import com.openexchange.ajax.ipcheck.IPCheckService;
 import com.openexchange.ajax.requesthandler.AJAXRequestHandler;
 import com.openexchange.auth.Authenticator;
 import com.openexchange.auth.mbean.AuthenticatorMBean;
@@ -93,6 +94,7 @@ import com.openexchange.charset.CustomCharsetProvider;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
+import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.configjump.ConfigJumpService;
 import com.openexchange.configjump.client.ConfigJump;
 import com.openexchange.configuration.ServerConfig;
@@ -162,6 +164,7 @@ import com.openexchange.groupware.infostore.facade.impl.InfostoreFacadeImpl;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.groupware.reminder.ReminderService;
 import com.openexchange.groupware.settings.PreferencesItemService;
+import com.openexchange.groupware.settings.tree.ShardingSubdomains;
 import com.openexchange.groupware.upgrade.SegmentedUpdateService;
 import com.openexchange.groupware.upload.impl.UploadUtility;
 import com.openexchange.groupware.userconfiguration.osgi.CapabilityRegistrationListener;
@@ -170,6 +173,7 @@ import com.openexchange.html.HtmlService;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.id.IDGeneratorService;
 import com.openexchange.imagetransformation.ImageTransformationService;
+import com.openexchange.jslob.ConfigTreeEquivalent;
 import com.openexchange.lock.LockService;
 import com.openexchange.lock.impl.LockServiceImpl;
 import com.openexchange.log.Slf4jLogger;
@@ -177,10 +181,12 @@ import com.openexchange.log.audit.AuditLogService;
 import com.openexchange.login.BlockingLoginHandlerService;
 import com.openexchange.login.LoginHandlerService;
 import com.openexchange.login.internal.LoginNameRecorder;
+import com.openexchange.login.listener.AutoLoginAwareLoginListener;
 import com.openexchange.login.listener.LoginListener;
 import com.openexchange.mail.MailCounterImpl;
 import com.openexchange.mail.MailIdleCounterImpl;
 import com.openexchange.mail.MailQuotaProvider;
+import com.openexchange.mail.api.AuthenticationFailedHandlerService;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.api.unified.UnifiedViewService;
 import com.openexchange.mail.attachment.AttachmentTokenService;
@@ -197,6 +203,7 @@ import com.openexchange.mail.json.compose.share.internal.ShareLinkGeneratorRegis
 import com.openexchange.mail.loginhandler.MailLoginHandler;
 import com.openexchange.mail.mime.MimeType2ExtMap;
 import com.openexchange.mail.oauth.MailOAuthService;
+import com.openexchange.mail.osgi.AuthenticationFailedHandlerServiceImpl;
 import com.openexchange.mail.osgi.MailCapabilityServiceTracker;
 import com.openexchange.mail.osgi.MailProviderServiceTracker;
 import com.openexchange.mail.osgi.MailSessionCacheInvalidator;
@@ -226,6 +233,7 @@ import com.openexchange.objectusecount.service.ObjectUseCountServiceTracker;
 import com.openexchange.osgi.BundleServiceTracker;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.SimpleRegistryListener;
+import com.openexchange.osgi.Tools;
 import com.openexchange.passwordchange.PasswordChangeService;
 import com.openexchange.passwordmechs.PasswordMechFactory;
 import com.openexchange.pns.PushNotificationService;
@@ -244,6 +252,7 @@ import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
+import com.openexchange.snippet.QuotaAwareSnippetService;
 import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.osgi.SpamHandlerServiceTracker;
 import com.openexchange.systemname.SystemNameService;
@@ -316,7 +325,7 @@ public final class ServerActivator extends HousekeepingActivator {
         IDBasedFolderAccessFactory.class, IDBasedFileAccessFactory.class, FileStorageServiceRegistry.class, FileStorageAccountManagerLookupService.class,
         CryptoService.class, HttpService.class, SystemNameService.class, ConfigViewFactory.class, StringParser.class, PreviewService.class,
         TextXtractService.class, SecretEncryptionFactoryService.class, SearchService.class, DispatcherPrefixService.class,
-        UserAgentParser.class, PasswordMechFactory.class, SegmentedUpdateService.class };
+        UserAgentParser.class, PasswordMechFactory.class, LeanConfigurationService.class, SegmentedUpdateService.class };
 
     private static volatile BundleContext CONTEXT;
 
@@ -438,6 +447,12 @@ public final class ServerActivator extends HousekeepingActivator {
         // Mail provider service tracker
         track(CacheEventService.class, new MailSessionCacheInvalidator(context));
         track(MailProvider.class, new MailProviderServiceTracker(context));
+        {
+            AuthenticationFailedHandlerServiceImpl authenticationFailedService = new AuthenticationFailedHandlerServiceImpl(context);
+            rememberTracker(authenticationFailedService);
+            registerService(AuthenticationFailedHandlerService.class, authenticationFailedService);
+            ServerServiceRegistry.getInstance().addService(AuthenticationFailedHandlerService.class, authenticationFailedService);
+        }
         track(MailcapCommandMap.class, new MailcapServiceTracker(context));
         track(CapabilityService.class, new MailCapabilityServiceTracker(context));
         track(AttachmentTokenService.class, new RegistryCustomizer<AttachmentTokenService>(context, AttachmentTokenService.class));
@@ -448,6 +463,9 @@ public final class ServerActivator extends HousekeepingActivator {
         track(AttachmentStorageRegistry.class, new RegistryCustomizer<AttachmentStorageRegistry>(context, AttachmentStorageRegistry.class));
         track(EnabledCheckerRegistry.class, new RegistryCustomizer<EnabledCheckerRegistry>(context, EnabledCheckerRegistry.class));
 
+        // IP checker
+        track(IPCheckService.class, new RegistryCustomizer<IPCheckService>(context, IPCheckService.class));
+
         // OAuth service
         track(OAuthService.class, new RegistryCustomizer<OAuthService>(context, OAuthService.class));
         track(MailOAuthService.class, new RegistryCustomizer<MailOAuthService>(context, MailOAuthService.class));
@@ -573,7 +591,7 @@ public final class ServerActivator extends HousekeepingActivator {
         track(LoginHandlerService.class, new LoginHandlerCustomizer(context));
         track(BlockingLoginHandlerService.class, new BlockingLoginHandlerCustomizer(context));
         // Login listener
-        track(LoginListener.class, new LoginListenerCustomizer(context));
+        track(Tools.generateServiceFilter(context, LoginListener.class, AutoLoginAwareLoginListener.class), new LoginListenerCustomizer(context));
         // Multiple handler factory services
         track(MultipleHandlerFactoryService.class, new MultipleHandlerServiceTracker(context));
 
@@ -615,6 +633,11 @@ public final class ServerActivator extends HousekeepingActivator {
          */
         track(QuotaFileStorageService.class, new RegistryCustomizer<QuotaFileStorageService>(context, QuotaFileStorageService.class));
 
+        /*
+         * Track QuotaAwareSnippetService
+         */
+        track(QuotaAwareSnippetService.class, new RankingAwareRegistryCustomizer<QuotaAwareSnippetService>(context, QuotaAwareSnippetService.class));
+
         /*
          * User Alias Service
          */
@@ -843,6 +866,10 @@ public final class ServerActivator extends HousekeepingActivator {
          * Register servlets
          */
         registerServlets(getService(HttpService.class));
+
+        ShardingSubdomains shardingSubdomains = new ShardingSubdomains();
+        registerService(PreferencesItemService.class, shardingSubdomains);
+        registerService(ConfigTreeEquivalent.class, shardingSubdomains);
     }
 
     @Override
