@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
+import com.openexchange.group.GroupStorage;
 import com.openexchange.tools.oxfolder.deletelistener.CorruptPermission;
 
 /**
@@ -125,9 +126,10 @@ public final class DetectCorruptPermissions {
 		}
 	}
 
-	private static final String SQL_SEL_INVALID_GROUP_PERM = "SELECT cid, fuid, permission_id FROM oxfolder_permissions AS op "
-			+ "WHERE op.cid = ? AND op.group_flag = 1 AND op.permission_id != 0 AND op.permission_id NOT IN ("
-			+ "SELECT id FROM groups AS g WHERE g.cid = op.cid)";
+    private static final String SQL_SEL_INVALID_GROUP_PERM = "SELECT cid, fuid, permission_id FROM oxfolder_permissions AS op "
+        + "WHERE op.cid = ? AND op.group_flag = 1 AND op.permission_id != " + GroupStorage.GROUP_ZERO_IDENTIFIER + " AND "
+        + "op.permission_id != " + GroupStorage.GUEST_GROUP_IDENTIFIER + " AND op.permission_id NOT IN ("
+        + "SELECT id FROM groups AS g WHERE g.cid = op.cid)";
 
 	/**
 	 * Detects corrupt group permissions existing in folders' permission table
