@@ -50,6 +50,9 @@
 package com.openexchange.tools.oxfolder.permissionLoader;
 
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
+import gnu.trove.iterator.TIntObjectIterator;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
 import gnu.trove.map.TIntObjectMap;
 import gnu.trove.map.hash.TIntObjectHashMap;
 import gnu.trove.procedure.TObjectProcedure;
@@ -59,43 +62,32 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Iterator;
-import java.util.LinkedList;
+import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.BlockingQueue;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.concurrent.atomic.AtomicInteger;
-import java.util.concurrent.atomic.AtomicReferenceArray;
-import java.util.concurrent.locks.Lock;
-import java.util.concurrent.locks.ReadWriteLock;
-import java.util.concurrent.locks.ReentrantReadWriteLock;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTracker;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.openexchange.concurrent.TimeoutConcurrentMap;
-import com.openexchange.config.ConfigurationService;
 import com.openexchange.databaseold.Database;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.server.osgi.ServerActivator;
-import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.threadpool.Task;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.threadpool.ThreadRenamer;
-import com.openexchange.timer.ScheduledTimerTask;
-import com.openexchange.timer.TimerService;
+import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.iterator.SearchIteratorExceptionCodes;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link PermissionLoaderService}
@@ -142,75 +134,22 @@ public final class PermissionLoaderService implements Runnable {
      */
     private static final Pair POISON = newPair(-1, -1);
 
-    /**
-     * The max. running time of 1 minute.
-     */
-    private static final long MAX_RUNNING_TIME = 60000;
-
-    /**
-     * The wait time in milliseconds.
-     */
-    private static final long WAIT_TIME = 3000;
-
-    private static volatile Integer maxConcurrentTasks;
-
-    /**
-     * Gets the max. number of concurrent tasks.
-     *
-     * @return The max. number of concurrent tasks
-     */
-    private static int maxConcurrentTasks() {
-        Integer tmp = maxConcurrentTasks;
-        if (null == tmp) {
-            synchronized (PermissionLoaderService.class) {
-                tmp = maxConcurrentTasks;
-                if (null == tmp) {
-                    int defaultValue = -1;
-                    ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
-                    tmp = Integer.valueOf(null == service ? defaultValue : service.getIntProperty("com.openexchange.tools.oxfolder.permissionLoader.maxConcurrentTasks", defaultValue));
-                    maxConcurrentTasks = tmp;
-                }
-            }
-        }
-        return tmp.intValue();
-    }
-
-    /**
-     * The container for currently running concurrent filler tasks.
-     */
-    protected final AtomicReferenceArray<StampedFuture> concurrentFutures;
-
     private final BlockingQueue<Pair> queue;
-
-    private volatile TimeoutConcurrentMap<Pair, OCLPermission[]> permsMap;
-
     private final AtomicBoolean keepgoing;
-
-    private volatile Future<Object> future;
-
     private final String simpleName;
-
     private final Gate gate;
 
-    private final StampedFuture placeHolder;
-
+    private volatile TimeoutConcurrentMap<Pair, OCLPermission[]> permsMap;
+    private volatile Future<Object> future;
     private volatile ServiceTracker<ThreadPoolService, ThreadPoolService> poolTracker;
-
     protected volatile ThreadPoolService threadPool;
 
-    protected volatile ConcurrentMap<Integer, ConWrapper> pooledCons;
-
-    private volatile ScheduledTimerTask timerTask;
-
     /**
      * Initializes a new {@link PermissionLoaderService}.
      */
     public PermissionLoaderService() {
         super();
-        int maxConcurrentTasks = maxConcurrentTasks();
-        placeHolder = maxConcurrentTasks > 0 ? new StampedFuture(null) : null;
         keepgoing = new AtomicBoolean(true);
-        concurrentFutures = maxConcurrentTasks > 0 ? new AtomicReferenceArray<StampedFuture>(maxConcurrentTasks) : null;
         queue = new LinkedBlockingQueue<Pair>();
         simpleName = getClass().getSimpleName();
         gate = new Gate(-1);
@@ -251,28 +190,6 @@ public final class PermissionLoaderService implements Runnable {
         }
         future = ThreadPools.getThreadPool().submit(ThreadPools.task(this, simpleName));
         permsMap = new TimeoutConcurrentMap<Pair, OCLPermission[]>(20, true);
-        pooledCons = new ConcurrentHashMap<Integer, ConWrapper>();
-        final Runnable task = new Runnable() {
-
-            @Override
-            public void run() {
-                try {
-                    final long stamp = System.currentTimeMillis() - 1000;
-                    for (final Iterator<ConWrapper> it = pooledCons.values().iterator(); it.hasNext();) {
-                        final ConWrapper vw = it.next();
-                        final Connection connection = vw.readyForRemoval(stamp);
-                        if (connection != null) {
-                            it.remove();
-                            Database.backNoTimeout(vw.contextId, false, connection);
-                            LOG.debug("Closed \"shared\" connection.");
-                        }
-                    }
-                } catch (final Exception e) {
-                    // Ignore
-                }
-            }
-        };
-        timerTask = ServerServiceRegistry.getInstance().getService(TimerService.class).scheduleWithFixedDelay(task, 1000, 1000);
         gate.open();
     }
 
@@ -292,18 +209,6 @@ public final class PermissionLoaderService implements Runnable {
         } catch (final TimeoutException e) {
             future.cancel(true);
         } finally {
-            if (null != timerTask) {
-                timerTask.cancel(false);
-                timerTask = null;
-                for (final Iterator<ConWrapper> it = pooledCons.values().iterator(); it.hasNext();) {
-                    final ConWrapper vw = it.next();
-                    final Connection connection = vw.con;
-                    if (connection != null) {
-                        Database.backNoTimeout(vw.contextId, false, connection);
-                    }
-                }
-                pooledCons.clear();
-            }
             if (null != poolTracker) {
                 poolTracker.close();
                 poolTracker = null;
@@ -313,6 +218,7 @@ public final class PermissionLoaderService implements Runnable {
 
     /**
      * Submits to load permission for specified folder in given context.
+     *
      * @param contextId The context identifier
      * @param folderId The folder identifier
      */
@@ -347,33 +253,33 @@ public final class PermissionLoaderService implements Runnable {
 
     private final class DelegaterTask implements Task<Object> {
 
-        private final List<Pair> list;
-        private final TObjectProcedure<List<Pair>> proc;
+        private final TIntObjectMap<GroupedPairs> groupByContext;
+        private final TObjectProcedure<GroupedPairs> proc;
 
-        protected DelegaterTask(final List<Pair> list, final TObjectProcedure<List<Pair>> proc) {
+        protected DelegaterTask(List<Pair> list, TObjectProcedure<GroupedPairs> proc) {
             super();
-            this.list = list;
+            this.groupByContext = groupByContext(list);
             this.proc = proc;
         }
 
         @Override
-        public void setThreadName(final ThreadRenamer threadRenamer) {
+        public void setThreadName(ThreadRenamer threadRenamer) {
             //
         }
 
         @Override
-        public void beforeExecute(final Thread t) {
+        public void beforeExecute(Thread t) {
             //
         }
 
         @Override
-        public void afterExecute(final Throwable t) {
+        public void afterExecute(Throwable t) {
             //
         }
 
         @Override
         public Object call() throws Exception {
-            groupByContext(list).forEachValue(proc);
+            groupByContext.forEachValue(proc);
             return null;
         }
 
@@ -384,16 +290,12 @@ public final class PermissionLoaderService implements Runnable {
         try {
             final Gate gate = this.gate;
             final List<Pair> list = new ArrayList<Pair>(128);
-            final TObjectProcedure<List<Pair>> proc = new TObjectProcedure<List<Pair>>() {
+            final TObjectProcedure<GroupedPairs> proc = new TObjectProcedure<GroupedPairs>() {
 
                 @Override
-                public boolean execute(final List<Pair> pairs) {
+                public boolean execute(GroupedPairs pairs) {
                     try {
                         handlePairs(pairs);
-                    } catch (final InterruptedException e) {
-                        // Restore the interrupted status; see http://www.ibm.com/developerworks/java/library/j-jtp05236/index.html
-                        Thread.currentThread().interrupt();
-                        LOG.error("Interrupted permission loader run.", e);
                     } catch (final Exception e) {
                         LOG.error("Failed permission loader run.", e);
                     }
@@ -427,7 +329,7 @@ public final class PermissionLoaderService implements Runnable {
                     queue.drainTo(list);
                     final boolean quit = list.remove(POISON);
                     if (!list.isEmpty()) {
-                        final DelegaterTask task = new DelegaterTask(new ArrayList<Pair>(list), proc);
+                        final DelegaterTask task = new DelegaterTask(list, proc);
                         final ThreadPoolService threadPool = this.threadPool;
                         if (null == threadPool) {
                             task.call();
@@ -458,81 +360,55 @@ public final class PermissionLoaderService implements Runnable {
      * Handles specified equally-grouped fillers
      *
      * @param groupedPairs The equally-grouped pairs
-     * @throws InterruptedException If thread is interrupted
      */
-    protected void handlePairs(final List<Pair> groupedPairs) throws InterruptedException {
-        final int size = groupedPairs.size();
-        final int configuredBlockSize = MAX_FILLER_CHUNK;
+    protected void handlePairs(GroupedPairs groupedPairs) {
+        int size = groupedPairs.size();
+        int configuredBlockSize = MAX_FILLER_CHUNK;
         if (size <= configuredBlockSize) {
-            handlePairsSublist(groupedPairs, simpleName);
-        } else {
-            int fromIndex = 0;
-            while (fromIndex < size) {
-                final int toIndex = fromIndex + configuredBlockSize;
-                if (toIndex > size) {
-                    schedulePairsSublist(groupedPairs.subList(fromIndex, size));
-                    fromIndex = size;
-                } else {
-                    schedulePairsSublist(groupedPairs.subList(fromIndex, toIndex));
-                    fromIndex = toIndex;
-                }
+            handlePairsSublist(groupedPairs);
+            return;
+        }
+
+        // Handle chunk-wise...
+        int fromIndex = 0;
+        while (fromIndex < size) {
+            boolean lastChunk;
+            int len;
+
+            int toIndex = fromIndex + configuredBlockSize;
+            if (toIndex > size) {
+                toIndex = size;
+                len = toIndex - fromIndex;
+                lastChunk = true;
+            } else {
+                len = configuredBlockSize;
+                lastChunk = false;
             }
+
+            GroupedPairs chunk = new GroupedPairs(groupedPairs.contextId, new TIntArrayList(groupedPairs.folderIds.toArray(fromIndex, len)));
+            if (lastChunk) {
+                // Handle last chunk with this thread
+                handlePairsSublist(chunk);
+            } else {
+                // Submit (if possible)
+                schedulePairsSublist(chunk);
+            }
+            fromIndex = toIndex;
         }
     }
 
-    private void schedulePairsSublist(final List<Pair> groupedPairsSublist) throws InterruptedException {
+    private void schedulePairsSublist(GroupedPairs groupedPairsSublist) {
         final ThreadPoolService threadPool = this.threadPool;
         if (null == threadPool) {
             /*
              * Caller runs because thread pool is absent
              */
-            handlePairsSublist(groupedPairsSublist, simpleName);
-        } else if (null == concurrentFutures) {
+            handlePairsSublist(groupedPairsSublist);
+        } else {
             /*
              * Submit without check for a free slot
              */
-            final PairHandlerTask task = new PairHandlerTask(groupedPairsSublist);
-            threadPool.submit(ThreadPools.task(task));
-            task.start(null);
-        } else {
-            /*
-             * Find a free or elapsed slot
-             */
-            int maxConcurrentTasks = maxConcurrentTasks();
-            if (maxConcurrentTasks > 0) {
-                int index = -1;
-                while (index < 0) {
-                    final long earliestStamp = System.currentTimeMillis() - MAX_RUNNING_TIME;
-                    for (int i = 0; (index < 0) && (i < maxConcurrentTasks); i++) {
-                        final StampedFuture sf = concurrentFutures.get(i);
-                        if (null == sf) {
-                            if (concurrentFutures.compareAndSet(i, null, placeHolder)) {
-                                index = i; // Found a free slot
-                            }
-                        } else if (sf.getStamp() < earliestStamp) { // Elapsed
-                            sf.getFuture().cancel(true);
-                            LOG.debug("Cancelled elapsed task running for {}msec.", (System.currentTimeMillis() - sf.getStamp()));
-                            if (concurrentFutures.compareAndSet(i, sf, placeHolder)) {
-                                index = i; // Found a slot with an elapsed task
-                            }
-                        }
-                    }
-                    LOG.debug(index < 0 ? "Awaiting a free/elapsed slot..." : "Found a free/elapsed slot...");
-                    if (index < 0) {
-                        synchronized (placeHolder) {
-                            placeHolder.wait(WAIT_TIME);
-                        }
-                    }
-                }
-                /*
-                 * Submit to a free worker thread
-                 */
-                final PairHandlerTask task = new IndexedPairHandlerTask(groupedPairsSublist, index);
-                final Future<Object> f = threadPool.submit(ThreadPools.task(task));
-                final StampedFuture sf = new StampedFuture(f);
-                concurrentFutures.set(index, sf);
-                task.start(sf);
-            }
+            threadPool.submit(ThreadPools.task(new PairHandlerTask(groupedPairsSublist)));
         }
     }
 
@@ -540,115 +416,77 @@ public final class PermissionLoaderService implements Runnable {
      * Handles specified chunk of equally-grouped pairs
      *
      * @param pairsChunk The chunk of equally-grouped pairs
-     * @param threadDesc The thread description
      */
-    protected void handlePairsSublist(final List<Pair> pairsChunk, final String threadDesc) {
+    protected void handlePairsSublist(GroupedPairs pairsChunk) {
         if (pairsChunk.isEmpty()) {
             return;
         }
         try {
-            /*
-             * Handle fillers in chunks
-             */
-            final int contextId = pairsChunk.get(0).contextId;
-            final Integer key = Integer.valueOf(contextId);
-            /*
-             * Get read-only connection
-             */
-            ConWrapper readConWrapper = pooledCons.get(key);
-            if (null == readConWrapper) {
-                final Connection newReadCon = Database.getNoTimeout(contextId, false);
-                final ConWrapper nw = new ConWrapper(newReadCon, contextId);
-                readConWrapper = pooledCons.putIfAbsent(key, nw);
-                if (null != readConWrapper) {
-                    // Wasn't able to put connection; work with newly fetched connection
-                    LOG.debug("Using \"un-shared\" connection.");
-                    try {
-                        for (final Pair pair : pairsChunk) {
-                            permsMap.put(pair, loadFolderPermissions(pair.folderId, contextId, newReadCon), 60);
-                        }
-                    } catch (SQLException e) {
-                        throw SearchIteratorExceptionCodes.SQL_ERROR.create(e, EnumComponent.FOLDER, e.getMessage());
-                    } finally {
-                        Database.backNoTimeout(contextId, false, newReadCon);
-                        LOG.debug("Released \"un-shared\" connection.");
+            int contextId = pairsChunk.contextId;
+
+            // Create partitions
+            TIntObjectMap<List<OCLPermission>> mapping = new TIntObjectHashMap<>(pairsChunk.size());
+            List<TIntList> fPartitions = createPartitions(pairsChunk);
+
+            {
+                Connection con = Database.get(contextId, false);
+                try {
+                    for (TIntList fPartition : fPartitions) {
+                        loadFolderPermissions(fPartition.toArray(), contextId, con, mapping);
                     }
-                    // Leave
-                    return;
+                } catch (SQLException e) {
+                    throw SearchIteratorExceptionCodes.SQL_ERROR.create(e, EnumComponent.FOLDER, e.getMessage());
+                } finally {
+                    Database.back(contextId, false, con);
                 }
-                // "Shared" connection
-                readConWrapper = nw;
-            } else {
-                LOG.debug("Using \"shared\" connection.");
             }
-            // Working with "shared" connection
-            final Lock rlock = readConWrapper.rlock;
-            rlock.lock();
-            boolean dec = false;
-            try {
-                if (readConWrapper.obtain()) {
-                    dec = true;
-                    synchronized (readConWrapper) {
-                        final Connection con = readConWrapper.con;
-                        for (final Pair pair : pairsChunk) {
-                            permsMap.put(pair, loadFolderPermissions(pair.folderId, contextId, con), 60);
-                        }
-                    }
-                } else {
-                    handlePairsSublist(pairsChunk, threadDesc);
-                    return;
-                }
-            } catch (SQLException e) {
-                // Fatal SQL error
-                pooledCons.remove(key);
-                throw SearchIteratorExceptionCodes.SQL_ERROR.create(e, EnumComponent.FOLDER, e.getMessage());
-            } finally {
-                if (dec) {
-                    readConWrapper.release();
-                }
-                rlock.unlock();
+
+            TIntObjectIterator<List<OCLPermission>> iterator = mapping.iterator();
+            for (int i = mapping.size(); i-- > 0;) {
+                iterator.advance();
+                int folderId = iterator.key();
+                List<OCLPermission> perms = iterator.value();
+                permsMap.put(new Pair(folderId, contextId), perms.toArray(new OCLPermission[perms.size()]), 60);
             }
         } catch (OXException e) {
             LOG.error("Failed loading permissions.", e);
         } catch (RuntimeException e) {
             LOG.error("Failed loading permissions.", e);
-        } finally {
-            if (null != placeHolder) {
-                synchronized (placeHolder) {
-                    placeHolder.notifyAll();
-                }
-            }
         }
     }
 
-    private static final String SQL_LOAD_P =
-        "SELECT permission_id, fp, orp, owp, odp, admin_flag, group_flag, system FROM oxfolder_permissions WHERE cid = ? AND fuid = ?";
+    private static final String SQL_LOAD_P = "SELECT permission_id, fp, orp, owp, odp, admin_flag, group_flag, system, fuid FROM oxfolder_permissions WHERE cid = ? AND fuid IN ";
 
-    protected static OCLPermission[] loadFolderPermissions(final int folderId, final int cid, final Connection con) throws OXException, SQLException {
+    protected static void loadFolderPermissions(int[] folderIds, int cid, Connection con, TIntObjectMap<List<OCLPermission>> mapping) throws OXException, SQLException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            stmt = con.prepareStatement(SQL_LOAD_P);
+            stmt = con.prepareStatement(SQL_LOAD_P + StringCollection.getSqlInString(folderIds));
             stmt.setInt(1, cid);
-            stmt.setInt(2, folderId);
             rs = stmt.executeQuery();
             if (!rs.next()) {
                 /*
                  * Empty result set
                  */
-                return new OCLPermission[0];
+                return;
             }
-            final ArrayList<OCLPermission> ret = new ArrayList<OCLPermission>(8);
+
             do {
-                final OCLPermission p = new OCLPermission();
+                int folderId = rs.getInt(9);
+                List<OCLPermission> permissions = mapping.get(folderId);
+                if (null == permissions) {
+                    permissions = new ArrayList<OCLPermission>(8);
+                    mapping.put(folderId, permissions);
+                }
+
+                OCLPermission p = new OCLPermission();
                 p.setEntity(rs.getInt(1)); // Entity
                 p.setAllPermission(rs.getInt(2), rs.getInt(3), rs.getInt(4), rs.getInt(5)); // fp, orp, owp, and odp
                 p.setFolderAdmin(rs.getInt(6) > 0 ? true : false); // admin_flag
                 p.setGroupPermission(rs.getInt(7) > 0 ? true : false); // group_flag
                 p.setSystem(rs.getInt(8)); // system
-                ret.add(p);
+                permissions.add(p);
             } while (rs.next());
-            return ret.toArray(new OCLPermission[ret.size()]);
         } catch (SQLException e) {
             if ("Connection was already closed.".equals(e.getMessage())) {
                 // Fatal...
@@ -660,16 +498,36 @@ public final class PermissionLoaderService implements Runnable {
         }
     }
 
-    protected static TIntObjectMap<List<Pair>> groupByContext(final Collection<Pair> pairs) {
-        final TIntObjectMap<List<Pair>> map = new TIntObjectHashMap<List<Pair>>(pairs.size());
-        for (final Pair pair : pairs) {
-            final int contextId = pair.contextId;
-            List<Pair> set = map.get(contextId);
+    private static List<TIntList> createPartitions(GroupedPairs pairsChunk) {
+        int size = pairsChunk.size();
+        if (size <= DBUtils.IN_LIMIT) {
+            return Collections.singletonList(pairsChunk.folderIds);
+        }
+
+        List<TIntList> fPartitions = new ArrayList<>(4);
+        int off = 0;
+        do {
+            int end = off + DBUtils.IN_LIMIT;
+            if (end > size) {
+                end = size;
+            }
+
+            fPartitions.add(new TIntArrayList(pairsChunk.folderIds.toArray(off, end - off)));
+            off = end;
+        } while (off < size);
+        return fPartitions;
+    }
+
+    protected static TIntObjectMap<GroupedPairs> groupByContext(final Collection<Pair> pairs) {
+        TIntObjectMap<GroupedPairs> map = new TIntObjectHashMap<GroupedPairs>(pairs.size());
+        for (Pair pair : pairs) {
+            int contextId = pair.contextId;
+            GroupedPairs set = map.get(contextId);
             if (null == set) {
-                set = new LinkedList<Pair>();
+                set = new GroupedPairs(contextId);
                 map.put(contextId, set);
             }
-            set.add(pair);
+            set.add(pair.folderId);
         }
         return map;
     }
@@ -735,24 +593,13 @@ public final class PermissionLoaderService implements Runnable {
 
     private class PairHandlerTask implements Task<Object> {
 
-        protected final List<Pair> pairs;
-        protected final CountDownLatch startSignal;
+        protected final GroupedPairs pairs;
 
-        protected PairHandlerTask(final List<Pair> pairs) {
+        protected PairHandlerTask(GroupedPairs pairs) {
             super();
-            this.startSignal = new CountDownLatch(1);
             this.pairs = pairs;
         }
 
-        /**
-         * Opens this task for processing.
-         *
-         * @param sf The stamped future object associated with this task
-         */
-        protected void start(final StampedFuture sf) {
-            startSignal.countDown();
-        }
-
         @Override
         public void setThreadName(final ThreadRenamer threadRenamer) {
             // Nope
@@ -770,102 +617,38 @@ public final class PermissionLoaderService implements Runnable {
 
         @Override
         public Object call() throws Exception {
-            startSignal.await();
-            handlePairsSublist(pairs, null);
+            handlePairsSublist(pairs);
             return null;
         }
 
     }
 
-    private final class IndexedPairHandlerTask extends PairHandlerTask {
+    /** A collection of folder identifiers associated with the same context */
+    private static final class GroupedPairs {
 
-        private final int indexPos;
+        final int contextId;
+        final TIntList folderIds;
 
-        private volatile StampedFuture sf;
-
-        protected IndexedPairHandlerTask(final List<Pair> pairs, final int indexPos) {
-            super(pairs);
-            this.indexPos = indexPos;
+        GroupedPairs(int contextId) {
+            this(contextId, new TIntArrayList(10));
         }
 
-        /**
-         * Opens this task for processing.
-         *
-         * @param sf The stamped future object associated with this task
-         */
-        @Override
-        protected void start(final StampedFuture sf) {
-            this.sf = sf;
-            startSignal.countDown();
-        }
-
-        @Override
-        public Object call() throws Exception {
-            try {
-                startSignal.await();
-                final StampedFuture sf = this.sf;
-                if (null != sf) {
-                    sf.setStamp(System.currentTimeMillis());
-                }
-                handlePairsSublist(pairs, String.valueOf(indexPos + 1));
-                return null;
-            } finally {
-                concurrentFutures.set(indexPos, null);
-            }
-        }
-
-    }
-
-    private static final class ConWrapper {
-        protected final int contextId;
-        protected volatile Connection con;
-        protected volatile long lastAccessed;
-        protected final AtomicInteger counter;
-        protected final Lock rlock;
-        protected final Lock wlock;
-
-        protected ConWrapper(final Connection con, final int contextId) {
+        GroupedPairs(int contextId, TIntList folderIds) {
             super();
             this.contextId = contextId;
-            final ReadWriteLock rwlock = new ReentrantReadWriteLock();
-            rlock = rwlock.readLock();
-            wlock = rwlock.writeLock();
-            this.con = con;
-            counter = new AtomicInteger();
-            lastAccessed = System.currentTimeMillis();
+            this.folderIds = folderIds;
         }
 
-        protected boolean obtain() {
-            // Holding read lock
-            if (null == con) {
-                return false;
-            }
-            counter.incrementAndGet();
-            return true;
+        boolean isEmpty() {
+            return folderIds.isEmpty();
         }
 
-        protected void release() {
-            // Holding read lock
-            counter.decrementAndGet();
-            lastAccessed = System.currentTimeMillis();
+        void add(int folderId) {
+            folderIds.add(folderId);
         }
 
-        protected Connection readyForRemoval(final long stamp) {
-            if (!wlock.tryLock()) {
-                // Occupied
-                return null;
-            }
-            try {
-                if ((lastAccessed < stamp) && ((null == con) || (0 == counter.get()))) {
-                    final Connection c = con;
-                    con = null;
-                    return c;
-                }
-                return null;
-            } finally {
-                wlock.unlock();
-            }
+        int size() {
+            return folderIds.size();
         }
     }
-
 }
