@@ -78,7 +78,8 @@ public final class DBUtils {
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DBUtils.class);
 
-    public static final int IN_LIMIT = 1000;
+    /** The default limit for SQL-IN expressions: <code>1000</code> */
+    public static final int IN_LIMIT = com.openexchange.database.Databases.IN_LIMIT;
 
     private DBUtils() {
         super();
@@ -103,7 +104,9 @@ public final class DBUtils {
      * Closes the ResultSet.
      *
      * @param result <code>null</code> or a ResultSet to close.
+     * @deprecated Prefer to use {@link Databases#closeSQLStuff(ResultSet)} instead
      */
+    @Deprecated
     public static void closeSQLStuff(final ResultSet result) {
         if (result != null) {
             try {
@@ -118,7 +121,9 @@ public final class DBUtils {
      * Closes the {@link Statement}.
      *
      * @param stmt <code>null</code> or a {@link Statement} to close.
+     * @deprecated Prefer to use {@link Databases#closeSQLStuff(Statement)} instead
      */
+    @Deprecated
     public static void closeSQLStuff(final Statement stmt) {
         if (null != stmt) {
             try {
@@ -134,7 +139,9 @@ public final class DBUtils {
      *
      * @param result <code>null</code> or a ResultSet to close.
      * @param stmt <code>null</code> or a Statement to close.
+     * @deprecated Prefer to use {@link Databases#closeSQLStuff(ResultSet, Statement)} instead
      */
+    @Deprecated
     public static void closeSQLStuff(final ResultSet result, final Statement stmt) {
         closeSQLStuff(result);
         closeSQLStuff(stmt);
@@ -216,7 +223,9 @@ public final class DBUtils {
      *
      * @param con connection to start the transaction on.
      * @throws SQLException if starting the transaction fails.
+     * @deprecated Prefer to use {@link Databases#startTransaction(Connection)} instead
      */
+    @Deprecated
     public static void startTransaction(final Connection con) throws SQLException {
         Statement stmt = null;
         try {
@@ -232,7 +241,9 @@ public final class DBUtils {
      * Performs a roll-back for a started transaction.
      *
      * @param con The connection to roll back.
+     * @deprecated Prefer to use {@link Databases#rollback(Connection)} instead
      */
+    @Deprecated
     public static void rollback(final Connection con) {
         if (null == con) {
             return;
@@ -250,7 +261,9 @@ public final class DBUtils {
      * Convenience method to set the autocommit of a connection to <code>true</code>.
      *
      * @param con connection that should go into autocommit mode.
+     * @deprecated Prefer to use {@link Databases#autocommit(Connection)} instead
      */
+    @Deprecated
     public static void autocommit(final Connection con) {
         if (null == con) {
             return;
