@@ -51,13 +51,17 @@ package com.openexchange.userconf.internal;
 
 import java.sql.Connection;
 import java.sql.SQLException;
+import com.openexchange.database.DatabaseService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.userconfiguration.RdbUserPermissionBitsStorage;
+import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationCodes;
 import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.groupware.userconfiguration.UserPermissionBitsStorage;
+import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.tools.oxfolder.OXFolderAdminHelper;
 import com.openexchange.userconf.UserPermissionService;
 
 
@@ -68,11 +72,18 @@ import com.openexchange.userconf.UserPermissionService;
  */
 public class UserPermissionServiceImpl implements UserPermissionService {
 
+    private AccessCombinationNameCache cache;
+
     /**
      * Initializes a new {@link UserPermissionServiceImpl}.
+     * 
+     * @throws OXException
+     * @throws ClassNotFoundException
      */
-    public UserPermissionServiceImpl() {
+    public UserPermissionServiceImpl() throws OXException {
         super();
+        cache = new AccessCombinationNameCache();
+        cache.initAccessCombinations();
     }
 
     @Override
@@ -138,4 +149,47 @@ public class UserPermissionServiceImpl implements UserPermissionService {
         UserPermissionBitsStorage.getInstance().removeUserPermissionBits(userId, ctx);
     }
 
+    @Override
+    public String getAccessCombinationName(Context context, int userId) throws OXException {
+        int contextId = context.getContextId();
+        DatabaseService dbService = ServerServiceRegistry.getServize(DatabaseService.class);
+        Connection read_ox_con = dbService.getReadOnly(context);
+        try {
+            UserPermissionBits user = getUserPermissionBits(userId, context);
+
+            UserModuleAccess acc = new UserModuleAccess();
+
+            acc.setCalendar(user.hasPermission(UserConfiguration.CALENDAR));
+            acc.setContacts(user.hasPermission(UserConfiguration.CONTACTS));
+            acc.setEditPublicFolders(user.hasPermission(UserConfiguration.EDIT_PUBLIC_FOLDERS));
+            acc.setReadCreateSharedFolders(user.hasPermission(UserConfiguration.READ_CREATE_SHARED_FOLDERS));
+            acc.setIcal(user.hasPermission(UserConfiguration.ICAL));
+            acc.setInfostore(user.hasPermission(UserConfiguration.INFOSTORE));
+            acc.setSyncml(user.hasPermission(UserConfiguration.MOBILITY));
+            acc.setTasks(user.hasPermission(UserConfiguration.TASKS));
+            acc.setVcard(user.hasPermission(UserConfiguration.VCARD));
+            acc.setWebdav(user.hasPermission(UserConfiguration.WEBDAV));
+            acc.setWebdavXml(user.hasPermission(UserConfiguration.WEBDAV_XML));
+            acc.setWebmail(user.hasPermission(UserConfiguration.WEBMAIL));
+            acc.setDelegateTask(user.hasPermission(UserConfiguration.DELEGATE_TASKS));
+            acc.setEditGroup(user.hasPermission(UserConfiguration.EDIT_GROUP));
+            acc.setEditResource(user.hasPermission(UserConfiguration.EDIT_RESOURCE));
+            acc.setEditPassword(user.hasPermission(UserConfiguration.EDIT_PASSWORD));
+            acc.setCollectEmailAddresses(user.hasPermission(UserConfiguration.COLLECT_EMAIL_ADDRESSES));
+            acc.setMultipleMailAccounts(user.hasPermission(UserConfiguration.MULTIPLE_MAIL_ACCOUNTS));
+            acc.setPublication(user.hasPermission(UserConfiguration.PUBLICATION));
+            acc.setSubscription(user.hasPermission(UserConfiguration.SUBSCRIPTION));
+            acc.setActiveSync(user.hasPermission(UserConfiguration.ACTIVE_SYNC));
+            acc.setUSM(user.hasPermission(UserConfiguration.USM));
+            acc.setOLOX20(user.hasPermission(UserConfiguration.OLOX20));
+            acc.setDeniedPortal(user.hasPermission(UserConfiguration.DENIED_PORTAL));
+            final OXFolderAdminHelper adminHelper = new OXFolderAdminHelper();
+            acc.setGlobalAddressBookDisabled(adminHelper.isGlobalAddressBookDisabled(contextId, userId, read_ox_con));
+            acc.setPublicFolderEditable(adminHelper.isPublicFolderEditable(contextId, userId, read_ox_con));
+            return cache.getNameForAccessCombination(acc);
+        } finally {
+            dbService.backReadOnly(context, read_ox_con);
+        }
+    }
+
 }
