@@ -81,6 +81,7 @@ import com.openexchange.serverconfig.ServerConfig;
 import com.openexchange.serverconfig.ServerConfigService;
 import com.openexchange.serverconfig.ServerConfigServicesLookup;
 import com.openexchange.session.Session;
+import com.openexchange.tools.session.SessionHolder;
 
 
 /**
@@ -92,12 +93,10 @@ import com.openexchange.session.Session;
 public class ServerConfigServiceImpl implements ServerConfigService {
 
     private static final Logger LOG = LoggerFactory.getLogger(ServerConfigService.class);
+
     private final static String SERVERCONFIG_PREFIX = "com.openexchange.appsuite.serverConfig.";
     private final static String SERVER_PREFIX = "com.openexchange.appsuite.server";
-    private final static String[] prefixes = {SERVERCONFIG_PREFIX, SERVER_PREFIX};
-
-    private final ServiceLookup serviceLookup;
-    private final ServerConfigServicesLookup serverConfigServicesLookup;
+    private final static String[] PREFIXES = {SERVERCONFIG_PREFIX, SERVER_PREFIX};
 
     private static final Cache<Key, List<Map<String, Object>>> CACHE_HOST_CONFIGS = CacheBuilder.newBuilder().maximumSize(65536).expireAfterAccess(30, TimeUnit.MINUTES).build();
 
@@ -108,6 +107,11 @@ public class ServerConfigServiceImpl implements ServerConfigService {
         CACHE_HOST_CONFIGS.invalidateAll();
     }
 
+    // --------------------------------------------------------------------------------------------------------------------------------
+
+    private final ServiceLookup serviceLookup;
+    private final ServerConfigServicesLookup serverConfigServicesLookup;
+
     /**
      * Initializes a new {@link ServerConfigServiceImpl}.
      */
@@ -157,7 +161,7 @@ public class ServerConfigServiceImpl implements ServerConfigService {
             Object value = configEntry.getValue();
             if (null == value) {
                 LOG.debug("Empty configuration \"{}\" is not applicable", configEntry.getKey());
-            } else {
+            } else {                
                 if (value instanceof Map) {
                     Map<String, Object> possibleConfiguration = (Map<String, Object>) value;
                     if (looksApplicable(possibleConfiguration, hostName)) {
@@ -185,11 +189,11 @@ public class ServerConfigServiceImpl implements ServerConfigService {
         Map<String, ComposedConfigProperty<String>> allProperties = configView.all();
         for (Map.Entry<String, ComposedConfigProperty<String>> entry : allProperties.entrySet()) {
             String propName = entry.getKey();
-            for (String prefix : prefixes) {
+            for (String prefix : PREFIXES) {
                 if (propName.startsWith(prefix)) {
                     String value = entry.getValue().get();
-                    // Allow to keep value from global config if specified as "<as-config>"
-                    if (null != value && !value.equals("<as-config>")) {
+                    //Allow to keep value from global config if specified as "<as-config>"
+                    if (!value.equals("<as-config>")) {
                         ccValues.put(propName.substring(prefix.length()), value);
                     }
                 }
@@ -200,133 +204,6 @@ public class ServerConfigServiceImpl implements ServerConfigService {
         return ImmutableList.copyOf(applicableConfigs);
     }
 
-    @Override
-    public ServerConfig getServerConfig(String hostName, int userID, int contextID) throws OXException {
-        return createNewServerConfig0(hostName, userID, contextID, null);
-    }
-
-    @Override
-    public ServerConfig getServerConfig(String hostName, Session session) throws OXException {
-        return createNewServerConfig0(hostName, session.getUserId(), session.getContextId(), session);
-    }
-
-    @SuppressWarnings("unchecked")
-    private ServerConfig createNewServerConfig0(String hostName, int userID, int contextID, Session session) throws OXException {
-        ConfigurationService configService = serviceLookup.getService(ConfigurationService.class);
-
-        // The resulting brand/server configuration
-        Map<String, Object> serverConfiguration = new HashMap<String, Object>(32, 0.9F);
-
-        // Get configured brands/server configurations
-        Map<String, Object> configurations = (Map<String, Object>)configService.getYaml("as-config.yml");
-        debugOut("as-config.yml", configurations);
-
-        Map<String, Object> defaults = (Map<String, Object>) configService.getYaml("as-config-defaults.yml");
-        if (defaults != null) {
-            serverConfiguration.putAll((Map<String, Object>) defaults.get("default"));
-            debugOut("as-config-defaults.yml", defaults);
-        }
-
-        // Find other applicable brands/server configurations
-        if (configurations != null) {
-            boolean empty = true;
-            LinkedList<Map<String, Object>> applicableConfigs = new LinkedList<Map<String,Object>>();
-            for (Map.Entry<String, Object> configEntry : configurations.entrySet()) {
-                Map<String, Object> possibleConfiguration = (Map<String, Object>) configEntry.getValue();
-                if (looksApplicable(possibleConfiguration, hostName)) {
-                    // ensure that "all"-host-wildcards are applied first
-                    if ("all".equals(possibleConfiguration.get("host"))) {
-                        applicableConfigs.addFirst(possibleConfiguration);
-                    } else {
-                        applicableConfigs.add(possibleConfiguration);
-                    }
-                    empty = false;
-                } else {
-                    final String configName = configEntry.getKey();
-                    if (null == possibleConfiguration) {
-                        LOG.debug("Empty configuration \"{}\" is not applicable", configName);
-                    } else {
-                        LOG.debug("Configuration \"{}\" is not applicable: {}", configName, prettyPrint(configName, possibleConfiguration));
-                    }
-                }
-            }
-
-
-            /*
-             * Add key/value pairs that start with SERVER_PREFIX or SERVERCONFIG_PREFIX to the serverconfig. The mentioned prefix is
-             * stripped from resulting name and entries are only added if the session is not anonymous.
-             */
-            Map<String, Object> ccValues = new HashMap<String, Object>();
-            ConfigView configView = null;
-            ConfigViewFactory configViewFactory = serviceLookup.getService(ConfigViewFactory.class);
-            configView = configViewFactory.getView(userID, contextID);
-
-            Map<String, ComposedConfigProperty<String>> allProperties = configView.all();
-            for(Map.Entry<String, ComposedConfigProperty<String>> entry: allProperties.entrySet()) {
-
-                String propName = entry.getKey();
-                for (String prefix : prefixes) {
-                    if(propName.startsWith(prefix)) {
-                        String value = entry.getValue().get();
-                        //Allow to keep value from global config if specified as "<as-config>"
-                        if (!value.equals("<as-config>")) {
-                            ccValues.put(propName.substring(prefix.length()), value);
-                        }
-                    }
-                }
-            }
-            applicableConfigs.add(ccValues);
-
-            if (!empty) {
-                for (Map<String, Object> config : applicableConfigs) {
-                    serverConfiguration.putAll(config);
-                }
-            }
-        }
-
-        /*
-         * Add computed values after configview values
-         */
-        for (ComputedServerConfigValueService computed : serverConfigServicesLookup.getComputed()) {
-            try {
-                computed.addValue(serverConfiguration, hostName, userID, contextID, session);
-            } catch (Throwable t) {
-                ExceptionUtils.handleThrowable(t);
-                LOG.error("Failed to add value from '{}' to server configuration", computed.getClass().getName(), t);
-            }
-        }
-
-        serverConfiguration = correctLanguageConfiguration(serverConfiguration);
-
-        return new ServerConfigImpl(serverConfiguration, serverConfigServicesLookup.getClientFilters());
-    }
-
-    /**
-     * The languages config item in the as-config.yml can be:
-     *  - A String "all" which then gets replaced with an ArrayList containing all installed languages
-     *  - A Hash as shown in Bug 24171, 41992 specifying a set of languages
-     *  - Missing which gets replaced with an ArrayList containing all installed languages
-     *
-     * What we have to deliver is an ArrayList of entries like [{de_DE=Deutsch},{en_US=English}]. As customers might be using this kind
-     * of configuration already we have to stay backwards compatible and thus rewrite the entry as workaround.
-     *
-     * @param serverConfiguration The configuration that might contain the languages entry.
-     * @return The configuration with the adjusted languages entry.
-     */
-    private Map<String, Object> correctLanguageConfiguration(Map<String, Object> serverConfiguration) {
-        Object languagesConfig = serverConfiguration.get("languages");
-
-        if (languagesConfig instanceof Map) {
-            ArrayList<SimpleEntry<String, String>> languageList = new ArrayList<SimpleEntry<String, String>>();
-            Map<String, String> languageMap = (Map<String, String>) languagesConfig;
-            for (Entry<String, String> entry : languageMap.entrySet()) {
-                languageList.add(new SimpleEntry<>(entry));
-            }
-            serverConfiguration.put("languages", languageList);
-        }
-        return serverConfiguration;
-    }
-
     /**
      * Every configuration object from the as-config.yml should have a host or hostRegex entry that specifies if a configuration object
      * should be used for an incoming request. If either of these matches the host given in the {@code AJAXRequestData} the configuration
@@ -344,7 +221,7 @@ public class ServerConfigServiceImpl implements ServerConfigService {
             return false;
         }
 
-        // We need a hostname for the host and hostRegex check
+        // We need a host name for the host and hostRegex check
         if ( !Strings.isEmpty(hostName) ) {
 
             // Check "host"
@@ -389,6 +266,104 @@ public class ServerConfigServiceImpl implements ServerConfigService {
         return false;
     }
 
+    private String prettyPrint(final String configName, Map<String, Object> configuration) {
+        if (null == configuration) {
+            return "<not-set>";
+        }
+
+        final StringBuilder sb = new StringBuilder(configuration.size() << 4);
+        final String indent = "    ";
+        final String sep = Strings.getLineSeparator();
+
+        sb.append(sep);
+        prettyPrint(configName, configuration, indent, sep, sb);
+        return sb.toString();
+    }
+
+    @Override
+    public ServerConfig getServerConfig(String hostName, int userID, int contextID) throws OXException {
+        Session session = null;
+        {
+            SessionHolder sessionHolder = serviceLookup.getOptionalService(SessionHolder.class);
+            if (null != sessionHolder) {
+                session = sessionHolder.getSessionObject();
+                if (null != session && (session.getContextId() != contextID || session.getUserId() != userID)) {
+                    session = null;
+                }
+            }
+        }
+
+        return createNewServerConfig0(hostName, userID, contextID, session);
+    }
+
+    @Override
+    public ServerConfig getServerConfig(String hostName, Session session) throws OXException {
+        return createNewServerConfig0(hostName, session.getUserId(), session.getContextId(), session);
+    }
+
+    @SuppressWarnings("unchecked")
+    private ServerConfig createNewServerConfig0(String hostName, int userID, int contextID, Session session) throws OXException {
+        ConfigurationService configService = serviceLookup.getService(ConfigurationService.class);
+
+        // The resulting brand/server configuration
+        Map<String, Object> serverConfiguration = new HashMap<String, Object>(32, 0.9F);
+
+        Map<String, Object> defaults = (Map<String, Object>) configService.getYaml("as-config-defaults.yml");
+        if (defaults != null) {
+            serverConfiguration.putAll((Map<String, Object>) defaults.get("default"));
+            debugOut("as-config-defaults.yml", defaults);
+        }
+
+        List<Map<String, Object>> applicableConfigs = getCustomHostConfigurations(hostName, userID, contextID);
+        for (Map<String, Object> config : applicableConfigs) {
+            serverConfiguration.putAll(config);
+        }
+
+        /*
+         * Add computed values after configview values
+         */
+        for (ComputedServerConfigValueService computed : serverConfigServicesLookup.getComputed()) {
+            try {
+                computed.addValue(serverConfiguration, hostName, userID, contextID, session);
+            } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
+                LOG.error("Failed to add value from '{}' to server configuration", computed.getClass().getName(), t);
+            }
+        }
+
+        serverConfiguration = correctLanguageConfiguration(serverConfiguration);
+
+        return new ServerConfigImpl(serverConfiguration, serverConfigServicesLookup.getClientFilters());
+    }
+
+
+    /**
+     * The languages config item in the as-config.yml can be:
+     *  - A String "all" which then gets replaced with an ArrayList containing all installed languages
+     *  - A Hash as shown in Bug 24171, 41992 specifying a set of languages
+     *  - Missing which gets replaced with an ArrayList containing all installed languages
+     *
+     * What we have to deliver is an ArrayList of entries like [{de_DE=Deutsch},{en_US=English}]. As customers might be using this kind
+     * of configuration already we have to stay backwards compatible and thus rewrite the entry as workaround.
+     *
+     * @param serverConfiguration The configuration that might contain the languages entry.
+     * @return The configuration with the adjusted languages entry.
+     */
+    private Map<String, Object> correctLanguageConfiguration(Map<String, Object> serverConfiguration) {
+        Object languagesConfig = serverConfiguration.get("languages");
+
+        if (languagesConfig instanceof Map) {
+            ArrayList<SimpleEntry<String, String>> languageList = new ArrayList<SimpleEntry<String, String>>();
+            Map<String, String> languageMap = (Map<String, String>) languagesConfig;
+            for (Entry<String, String> entry : languageMap.entrySet()) {
+                languageList.add(new SimpleEntry<>(entry));
+            }
+            serverConfiguration.put("languages", languageList);
+        }
+        return serverConfiguration;
+    }
+
+
     // ---------------------------------------------------- DEBUG STUFF --------------------------------------------------------------- //
 
     /**
@@ -440,20 +415,6 @@ public class ServerConfigServiceImpl implements ServerConfigService {
         return sb.toString();
     }
 
-    String prettyPrint(final String configName, Map<String, Object> configuration) {
-        if (null == configuration) {
-            return "<not-set>";
-        }
-
-        final StringBuilder sb = new StringBuilder(configuration.size() << 4);
-        final String indent = "    ";
-        final String sep = Strings.getLineSeparator();
-
-        sb.append(sep);
-        prettyPrint(configName, configuration, indent, sep, sb);
-        return sb.toString();
-    }
-
     void prettyPrint(final String configName, Map<String, Object> configuration, final String indent, final String sep, final StringBuilder sb) {
         if (null != configuration) {
             sb.append(indent).append(configName).append(':').append(sep);
