@@ -57,6 +57,7 @@ import com.openexchange.config.ForcedReloadable;
 import com.openexchange.config.Interests;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.conversion.simple.SimpleConverter;
+import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.NearRegistryServiceTracker;
 import com.openexchange.serverconfig.ClientServerConfigFilter;
@@ -68,7 +69,9 @@ import com.openexchange.serverconfig.impl.values.Capabilities;
 import com.openexchange.serverconfig.impl.values.ForcedHttpsValue;
 import com.openexchange.serverconfig.impl.values.Hosts;
 import com.openexchange.serverconfig.impl.values.Languages;
+import com.openexchange.serverconfig.impl.values.Prefix;
 import com.openexchange.serverconfig.impl.values.ServerVersion;
+import com.openexchange.tools.session.SessionHolder;
 
 /**
  * {@link ServerConfigActivator}
@@ -105,6 +108,8 @@ public class ServerConfigActivator extends HousekeepingActivator {
             ClientServerConfigFilter.class
         );
         rememberTracker(configFilterTracker);
+        trackService(DispatcherPrefixService.class);
+        trackService(SessionHolder.class);
         openTrackers();
 
         ServerConfigServicesLookup serverConfigServicesLookup = new ServerConfigServicesLookup() {
@@ -120,7 +125,7 @@ public class ServerConfigActivator extends HousekeepingActivator {
             }
 
         };
-        
+
         registerService(ForcedReloadable.class, new ForcedReloadable() {
 
             @Override
@@ -132,7 +137,6 @@ public class ServerConfigActivator extends HousekeepingActivator {
             public Interests getInterests() {
                 return null;
             }
-
         });
 
         // Register the services that add computed values during creation of the server config
@@ -141,6 +145,7 @@ public class ServerConfigActivator extends HousekeepingActivator {
         registerService(ComputedServerConfigValueService.class, new Languages(this));
         registerService(ComputedServerConfigValueService.class, new ServerVersion());
         registerService(ComputedServerConfigValueService.class, new Capabilities(this));
+        registerService(ComputedServerConfigValueService.class, new Prefix(this));
 
         // The actual config service
         ServerConfigServiceImpl serverConfigServiceImpl = new ServerConfigServiceImpl(this, serverConfigServicesLookup);
