@@ -58,6 +58,7 @@ import java.util.Dictionary;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Hashtable;
+import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
@@ -70,7 +71,6 @@ import java.util.concurrent.Future;
 import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventAdmin;
@@ -93,6 +93,7 @@ import com.openexchange.sessiond.serialization.PortableContextSessionsCleaner;
 import com.openexchange.sessiond.serialization.PortableSessionFilterApplier;
 import com.openexchange.sessiond.serialization.PortableSessionFilterApplier.Action;
 import com.openexchange.sessiond.serialization.PortableUserSessionsCleaner;
+import com.openexchange.sessionstorage.SessionStorageConfiguration;
 import com.openexchange.sessionstorage.SessionStorageExceptionCodes;
 import com.openexchange.sessionstorage.SessionStorageService;
 import com.openexchange.threadpool.AbstractTask;
@@ -136,9 +137,6 @@ public final class SessionHandler {
     /** The obfuscator */
     protected static volatile Obfuscator obfuscatr;
 
-    /** The initialized flag */
-    private static final AtomicBoolean initialized = new AtomicBoolean();
-
     /** Logger */
     protected static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SessionHandler.class);
 
@@ -158,9 +156,9 @@ public final class SessionHandler {
     /**
      * Initializes the {@link SessionHandler session handler}
      *
-     * @param newConfig The appropriate configuration
+     * @param config The appropriate configuration
      */
-    public static void init(SessiondConfigInterface config) {
+    public static synchronized void init(SessiondConfigInterface config) {
         SessionHandler.config = config;
         SessionData sessionData = new SessionData(
             config.getNumberOfSessionContainers(),
@@ -169,19 +167,37 @@ public final class SessionHandler {
             config.getNumberOfLongTermSessionContainers(),
             config.isAutoLogin());
         SESSION_DATA_REF.set(sessionData);
-        if (initialized.compareAndSet(false, true)) {
-            try {
-                sessionIdGenerator = SessionIdGenerator.getInstance();
-            } catch (OXException exc) {
-                LOG.error("create instance of SessionIdGenerator", exc);
-            }
-            noLimit = (config.getMaxSessions() == 0);
-            asyncPutToSessionStorage = config.isAsyncPutToSessionStorage();
-            synchronized (SessionHandler.class) {
-                // Make it visible to other threads, too
-                obfuscatr = new Obfuscator(config.getObfuscationKey().toCharArray());
-            }
+        try {
+            sessionIdGenerator = SessionIdGenerator.getInstance();
+        } catch (OXException exc) {
+            LOG.error("create instance of SessionIdGenerator", exc);
         }
+        noLimit = (config.getMaxSessions() == 0);
+        asyncPutToSessionStorage = config.isAsyncPutToSessionStorage();
+
+        obfuscatr = new Obfuscator(config.getObfuscationKey().toCharArray());
+    }
+
+    /**
+     * Shuts-down session handling.
+     */
+    public static synchronized void close() {
+        SessionData sd = SESSION_DATA_REF.get();
+        if (null != sd) {
+            postContainerRemoval(sd.getShortTermSessions(), false);
+            sd.clear();
+            SESSION_DATA_REF.set(null);
+        } else {
+            LOG.warn("\tSessionData instance is null.");
+        }
+        Obfuscator o = obfuscatr;
+        if (null != o) {
+            obfuscatr = null;
+            o.destroy();
+        }
+        sessionIdGenerator = null;
+        config = null;
+        noLimit = false;
     }
 
     /**
@@ -205,11 +221,13 @@ public final class SessionHandler {
     /**
      * Gets the names of such parameters that are supposed to be taken over from session to stored session representation.
      *
+     * @param userId The user identifier
+     * @param contextId The context identifier
      * @return The parameter names
      */
-    public static List<String> getRemoteParameterNames() {
-        SessiondConfigInterface conf = config;
-        return null == conf ? Collections.<String> emptyList() : conf.getRemoteParameterNames();
+    public static Collection<String> getRemoteParameterNames(int userId, int contextId) {
+        SessionStorageConfiguration configuration = SessionStorageConfiguration.getInstance();
+        return null == configuration ? Collections.<String>emptyList() : configuration.getRemoteParameterNames(userId, contextId);
     }
 
     /**
@@ -228,12 +246,16 @@ public final class SessionHandler {
         /*
          * remove from session data
          */
-        SessionControl[] control = sessionData.removeUserSessions(userId, contextId);
-        Session[] retval = new Session[control.length];
+        SessionControl[] controls = sessionData.removeUserSessions(userId, contextId);
+        List<SessionControl> removedSessions = new ArrayList<SessionControl>(controls.length);
+        Session[] retval = new Session[controls.length];
         for (int i = 0; i < retval.length; i++) {
-            SessionImpl removedSession = control[i].getSession();
+            SessionImpl removedSession = controls[i].getSession();
             retval[i] = removedSession;
-            postSessionRemoval(removedSession);
+            removedSessions.add(controls[i]);
+        }
+        if (!removedSessions.isEmpty()) {
+            postContainerRemoval(removedSessions, true);
         }
         /*
          * remove local sessions from storage (if available), too
@@ -427,8 +449,22 @@ public final class SessionHandler {
      */
     public static List<String> removeLocalSessions(SessionFilter filter) {
         List<String> sessionIds = findLocalSessions(filter);
-        for (String sessionId : sessionIds) {
-            clearSession(sessionId);
+        if (null == sessionIds || sessionIds.isEmpty()) {
+            return Collections.emptyList();
+        }
+
+        List<SessionControl> removedSessions = new ArrayList<SessionControl>(sessionIds.size());
+        for (Iterator<String> iterator = sessionIds.iterator(); iterator.hasNext();) {
+            String sessionId = iterator.next();
+            SessionControl removedSession = clearSession(sessionId, false);
+            if (null == removedSession) {
+                iterator.remove();
+            } else {
+                removedSessions.add(removedSession);
+            }
+        }
+        if (!removedSessions.isEmpty()) {
+            postContainerRemoval(removedSessions, true);
         }
 
         return sessionIds;
@@ -640,9 +676,8 @@ public final class SessionHandler {
 
                             // Unwrap
                             Session[] retval = new Session[length];
-                            List<String> remoteParameterNames = getRemoteParameterNames();
                             for (int i = length; i-- > 0;) {
-                                retval[i] = getObfuscator().unwrap(userSessions[i], remoteParameterNames);
+                                retval[i] = getObfuscator().unwrap(userSessions[i]);
                             }
                             return retval;
                         }
@@ -704,7 +739,7 @@ public final class SessionHandler {
                             return storageService.getAnyActiveSessionForUser(userId, contextId);
                         }
                     };
-                    SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null), getRemoteParameterNames());
+                    SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null));
                     if (null != unwrappedSession) {
                         retval = new SessionControl(unwrappedSession);
                     }
@@ -731,7 +766,7 @@ public final class SessionHandler {
 
                         @Override
                         public Session call() throws Exception {
-                            return getObfuscator().unwrap(storageService.findFirstSessionForUser(userId, contextId), getRemoteParameterNames());
+                            return getObfuscator().unwrap(storageService.findFirstSessionForUser(userId, contextId));
                         }
                     };
                     retval = getFrom(c, null);
@@ -747,9 +782,10 @@ public final class SessionHandler {
      * Stores the session (if available) into session storage.
      *
      * @param sessionId The session identifier
+     * @param addIfAbsent Adds the session to storage only if absent
      * @return <code>true</code> if stored; otherwise <code>false</code>
      */
-    protected static boolean storeSession(String sessionId) {
+    protected static boolean storeSession(String sessionId, boolean addIfAbsent) {
         if (null == sessionId) {
             return false;
         }
@@ -764,8 +800,7 @@ public final class SessionHandler {
             return false;
         }
 
-        List<String> remotes = getRemoteParameterNames();
-        return putIntoSessionStorage(sessionControl.getSession(), true, null == remotes || remotes.isEmpty());
+        return putIntoSessionStorage(sessionControl.getSession(), addIfAbsent, asyncPutToSessionStorage);
     }
 
 
@@ -806,8 +841,7 @@ public final class SessionHandler {
             addedSession = sessionData.addSession(newSession, noLimit).getSession();
 
             // Store session if not marked as transient and associated client is applicable
-            List<String> remotes = getRemoteParameterNames();
-            putIntoSessionStorage(addedSession, null == remotes || remotes.isEmpty());
+            putIntoSessionStorage(addedSession);
 
             // Post event for created session
             postSessionCreation(addedSession);
@@ -1084,21 +1118,24 @@ public final class SessionHandler {
      * Clears the session denoted by given session ID from session container(s)
      *
      * @param sessionid The session ID
+     * @param postEvent <code>true</code> to post an event about session removal; otherwise <code>false</code> for no such event
      * @return <code>true</code> if a session could be removed; otherwise <code>false</code>
      */
-    protected static boolean clearSession(String sessionid) {
+    protected static SessionControl clearSession(String sessionid, boolean postEvent) {
         SessionData sessionData = SESSION_DATA_REF.get();
         if (null == sessionData) {
             LOG.warn("\tSessionData instance is null.");
-            return false;
+            return null;
         }
         SessionControl sessionControl = sessionData.clearSession(sessionid);
         if (null == sessionControl) {
             LOG.debug("Cannot find session for given identifier to remove session <{}>", sessionid);
-            return false;
+            return null;
         }
-        postSessionRemoval(sessionControl.getSession());
-        return true;
+        if (postEvent) {
+            postSessionRemoval(sessionControl.getSession());
+        }
+        return sessionControl;
     }
 
     /**
@@ -1132,7 +1169,7 @@ public final class SessionHandler {
 
                 @Override
                 public Void call() throws Exception {
-                    Session wrappedSession = getObfuscator().wrap(currentSession, getRemoteParameterNames());
+                    Session wrappedSession = getObfuscator().wrap(currentSession);
                     sessionStorage.changePassword(sessionid, wrappedSession.getPassword());
                     return null;
                 }
@@ -1144,12 +1181,19 @@ public final class SessionHandler {
          */
         List<SessionControl> userSessionControls = sessionData.getUserSessions(currentSession.getUserId(), currentSession.getContextId());
         if (null != userSessionControls) {
+            List<SessionControl> removedSessions = new ArrayList<SessionControl>(userSessionControls.size());
             for (SessionControl userSessionControl : userSessionControls) {
                 String otherSessionID = userSessionControl.getSession().getSessionID();
                 if (null != otherSessionID && false == otherSessionID.equals(sessionid)) {
-                    clearSession(otherSessionID);
+                    SessionControl removedSession = clearSession(otherSessionID, false);
+                    if (null != removedSession) {
+                        removedSessions.add(removedSession);
+                    }
                 }
             }
+            if (!removedSessions.isEmpty()) {
+                postContainerRemoval(userSessionControls, true);
+            }
         }
         /*
          * Invalidate all further user sessions known on remote cluster members
@@ -1316,7 +1360,7 @@ public final class SessionHandler {
                             return storageService.getSessionByRandomToken(randomToken, newIP);
                         }
                     };
-                    Session unwrappedSession = getObfuscator().unwrap(getFrom(c, null), getRemoteParameterNames());
+                    Session unwrappedSession = getObfuscator().unwrap(getFrom(c, null));
                     if (null != unwrappedSession) {
                         return unwrappedSession;
                     }
@@ -1385,46 +1429,61 @@ public final class SessionHandler {
      */
     protected static SessionControl getSession(String sessionId, final boolean considerLocalStorage, final boolean considerSessionStorage) {
         LOG.debug("getSession <{}>", sessionId);
+
         SessionData sessionData = SESSION_DATA_REF.get();
         if (null == sessionData) {
             LOG.warn("\tSessionData instance is null.");
             return null;
         }
-        SessionControl sessionControl = considerLocalStorage ? sessionData.getSession(sessionId) : null;
+
+        if (false == considerLocalStorage) {
+            if (false == considerSessionStorage) {
+                return null;
+            }
+
+            return optSessionFromSessionStorage(sessionId, sessionData);
+        }
+
+        SessionControl sessionControl = sessionData.getSession(sessionId);
         if (considerSessionStorage && null == sessionControl) {
-            SessionStorageService storageService = Services.optService(SessionStorageService.class);
-            if (storageService != null) {
-                try {
-                    SessionImpl unwrappedSession = getSessionFrom(sessionId, timeout(), storageService);
-                    if (null != unwrappedSession) {
-                        SessionControl sc = sessionData.addSession(unwrappedSession, noLimit, true);
-                        if (unwrappedSession == sc.getSession()) {
-                            // we restored the session first
-                            for (SessionSerializationInterceptor interceptor : interceptors) {
-                                interceptor.deserialize(unwrappedSession);
-                            }
-                        }
-                        SessionControl retval = null == sc ? new SessionControl(unwrappedSession) : sc;
+            sessionControl = optSessionFromSessionStorage(sessionId, sessionData);
+        }
 
-                        // Post event for restored session
-                        postSessionRestauration(retval.getSession());
+        return sessionControl;
+    }
 
-                        return retval;
-                    }
-                } catch (OXException e) {
-                    if (!SessionStorageExceptionCodes.NO_SESSION_FOUND.equals(e)) {
-                        LOG.warn("Session look-up failed in session storage.", e);
-                    }
+    private static SessionControl optSessionFromSessionStorage(String sessionId, SessionData sessionData) {
+        SessionStorageService storageService = Services.optService(SessionStorageService.class);
+        if (storageService == null) {
+            // No session storage available
+            return null;
+        }
+
+        try {
+            SessionImpl unwrappedSession = getSessionFrom(sessionId, timeout(), storageService);
+            if (null == unwrappedSession) {
+                return null;
+            }
+
+            SessionControl sc = sessionData.addSession(unwrappedSession, noLimit, true);
+            if (unwrappedSession == sc.getSession()) {
+                // This thread restored the session first
+                for (SessionSerializationInterceptor interceptor : interceptors) {
+                    interceptor.deserialize(unwrappedSession);
                 }
             }
+
+            // Post event for restored session
+            postSessionRestauration(sc.getSession());
+
+            return sc;
+        } catch (OXException e) {
+            if (!SessionStorageExceptionCodes.NO_SESSION_FOUND.equals(e)) {
+                LOG.warn("Session look-up failed in session storage.", e);
+            }
         }
-        /*-
-         * Ensure session is available in session storage
-        if (null != sessionControl) {
-            storeSession(sessionControl.getSession(), Services.optService(SessionStorageService.class), true);
-        }
-         */
-        return sessionControl;
+
+        return null;
     }
 
     /**
@@ -1476,7 +1535,7 @@ public final class SessionHandler {
                             return storageService.getSessionByAlternativeId(altId);
                         }
                     };
-                    SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null), getRemoteParameterNames());
+                    SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null));
                     if (null != unwrappedSession) {
                         return new SessionControl(unwrappedSession);
                     }
@@ -1508,7 +1567,7 @@ public final class SessionHandler {
                         return storageService.getCachedSession(sessionId);
                     }
                 };
-                SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null), getRemoteParameterNames());
+                SessionImpl unwrappedSession = getObfuscator().unwrap(getFrom(c, null));
                 if (null != unwrappedSession) {
                     return new SessionControl(unwrappedSession);
                 }
@@ -1547,7 +1606,7 @@ public final class SessionHandler {
                     List<SessionControl> result = new ArrayList<SessionControl>();
                     Obfuscator obfuscator = getObfuscator();
                     for (Session s : list) {
-                        SessionImpl unwrappedSession = obfuscator.unwrap(s, getRemoteParameterNames());
+                        SessionImpl unwrappedSession = obfuscator.unwrap(s);
                         if (null != unwrappedSession) {
                             result.add(new SessionControl(unwrappedSession));
                         }
@@ -1567,16 +1626,18 @@ public final class SessionHandler {
             return;
         }
         List<SessionControl> controls = sessionData.rotateShort();
-        if (config.isAutoLogin()) {
-            for (final SessionControl sessionControl : controls) {
-                LOG.info("Session is moved to long life time container. All temporary session data will be cleaned up. ID: {}", sessionControl.getSession().getSessionID());
+        if (!controls.isEmpty()) {
+            if (config.isAutoLogin()) {
+                for (final SessionControl sessionControl : controls) {
+                    LOG.info("Session is moved to long life time container. All temporary session data will be cleaned up. ID: {}", sessionControl.getSession().getSessionID());
+                }
+                postSessionDataRemoval(controls);
+            } else {
+                for (final SessionControl sessionControl : controls) {
+                    LOG.info("Session timed out. ID: {}", sessionControl.getSession().getSessionID());
+                }
+                postContainerRemoval(controls, true);
             }
-            postSessionDataRemoval(controls);
-        } else {
-            for (final SessionControl sessionControl : controls) {
-                LOG.info("Session timed out. ID: {}", sessionControl.getSession().getSessionID());
-            }
-            postContainerRemoval(controls, true);
         }
     }
 
@@ -1587,30 +1648,11 @@ public final class SessionHandler {
             return;
         }
         List<SessionControl> controls = sessionData.rotateLongTerm();
-        for (SessionControl control : controls) {
-            LOG.info("Session timed out. ID: {}", control.getSession().getSessionID());
-        }
-        postContainerRemoval(controls, true);
-    }
-
-    public static void close() {
-        if (initialized.compareAndSet(true, false)) {
-            SessionData sd = SESSION_DATA_REF.get();
-            if (null != sd) {
-                postContainerRemoval(sd.getShortTermSessions(), false);
-                sd.clear();
-                SESSION_DATA_REF.set(null);
-            } else {
-                LOG.warn("\tSessionData instance is null.");
+        if (!controls.isEmpty()) {
+            for (SessionControl control : controls) {
+                LOG.info("Session timed out. ID: {}", control.getSession().getSessionID());
             }
-            Obfuscator o = obfuscatr;
-            if (null != o) {
-                obfuscatr = null;
-                o.destroy();
-            }
-            sessionIdGenerator = null;
-            config = null;
-            noLimit = false;
+            postContainerRemoval(controls, true);
         }
     }
 
@@ -1678,11 +1720,12 @@ public final class SessionHandler {
     }
 
     private static void postSessionRemoval(final SessionImpl session) {
+        Future<Void> dropSessionFromHz = null;
         if (useSessionStorage(session)) {
             // Asynchronous remove from session storage
             final SessionStorageService sessionStorageService = Services.optService(SessionStorageService.class);
             if (sessionStorageService != null) {
-                ThreadPools.getThreadPool().submit(new AbstractTask<Void>() {
+                dropSessionFromHz = ThreadPools.getThreadPool().submit(new AbstractTask<Void>() {
 
                     @Override
                     public Void call() {
@@ -1717,6 +1760,23 @@ public final class SessionHandler {
                 }
             }
         }
+
+        // Await session removal from session storage
+        if (null != dropSessionFromHz) {
+            int tout = 2;
+            try {
+                dropSessionFromHz.get(tout, TimeUnit.SECONDS);
+            } catch (InterruptedException e) {
+                Thread.currentThread().interrupt();
+                LOG.warn("Interrupted while waiting for session removal from session storage", e);
+            } catch (ExecutionException e) {
+                // Cannot occur
+                LOG.warn("Session could not be removed from session storage: {}", session.getSessionID(), e.getCause());
+            } catch (TimeoutException e) {
+                // Ignore...
+                LOG.debug("Session could not be removed from session storage within {} seconds: {}", I(tout), session.getSessionID(), e);
+            }
+        }
     }
 
     private static void postLastSessionGone(int userId, int contextId, EventAdmin eventAdmin) {
@@ -1750,7 +1810,12 @@ public final class SessionHandler {
             // Asynchronous remove from session storage
             final SessionStorageService sessionStorageService = Services.optService(SessionStorageService.class);
             if (sessionStorageService != null) {
-                final List<SessionControl> tSessionControls = new ArrayList<SessionControl>(sessionControls);
+                final List<SessionControl> tSessionControls = new ArrayList<SessionControl>(sessionControls.size());
+                for (SessionControl sessionControl : sessionControls) {
+                    if (useSessionStorage(sessionControl.getSession())) {
+                        tSessionControls.add(sessionControl);
+                    }
+                }
                 ThreadPools.getThreadPool().submit(new AbstractTask<Void>() {
 
                     @Override
@@ -1954,15 +2019,15 @@ public final class SessionHandler {
         }
 
         @Override
-        public Void call() {
+        public Void call() throws OXException {
             try {
                 if (addIfAbsent) {
-                    if (sessionStorageService.addSessionIfAbsent(getObfuscator().wrap(session, config.getRemoteParameterNames()))) {
+                    if (sessionStorageService.addSessionIfAbsent(getObfuscator().wrap(session))) {
                         LOG.info("Put session {} with auth Id {} into session storage.", session.getSessionID(), session.getAuthId());
                         postSessionStored(session);
                     }
                 } else {
-                    sessionStorageService.addSession(getObfuscator().wrap(session, config.getRemoteParameterNames()));
+                    sessionStorageService.addSession(getObfuscator().wrap(session));
                     LOG.info("Put session {} with auth Id {} into session storage.", session.getSessionID(), session.getAuthId());
                     postSessionStored(session);
                 }
@@ -2007,7 +2072,7 @@ public final class SessionHandler {
      */
     private static SessionImpl getSessionFrom(String sessionId, long timeoutMillis, SessionStorageService storageService) throws OXException {
         try {
-            return getObfuscator().unwrap(storageService.lookupSession(sessionId, timeoutMillis), getRemoteParameterNames());
+            return getObfuscator().unwrap(storageService.lookupSession(sessionId, timeoutMillis));
         } catch (OXException e) {
             if (SessionStorageExceptionCodes.INTERRUPTED.equals(e)) {
                 // Expected...
