@@ -49,8 +49,6 @@
 
 package com.openexchange.sessiond.impl;
 
-import java.util.List;
-
 /**
  * SessionConfig
  *
@@ -97,11 +95,4 @@ public interface SessiondConfigInterface {
      */
     String getObfuscationKey();
 
-    /**
-     * Gets the names of such parameters that are supposed to be taken over from session to stored session representation.
-     *
-     * @return The parameter names
-     */
-    List<String> getRemoteParameterNames();
-
 }
