@@ -49,7 +49,6 @@
 
 package com.openexchange.sessiond.impl;
 
-import static com.openexchange.sessiond.impl.SessionHandler.getRemoteParameterNames;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
@@ -220,7 +219,7 @@ public final class TokenSessionContainer {
             IMap<String, PortableTokenSessionControl> serverTokenHzMap = hzMap(serverTokenMapName);
 
             // Generate a portable session from token's session...
-            PortableSession portableSession = new PortableSession(SessionHandler.getObfuscator().wrap(control.getSession(), getRemoteParameterNames()));
+            PortableSession portableSession = new PortableSession(SessionHandler.getObfuscator().wrap(control.getSession()));
 
             // ... and put into HZ map
             serverTokenHzMap.put(serverToken, new PortableTokenSessionControl(portableSession, control.getClientToken(), control.getServerToken(), control.getCreationStamp()));
@@ -241,7 +240,7 @@ public final class TokenSessionContainer {
         }
 
         // Create the session instance from its portable representation
-        SessionImpl unwrappedSession = SessionHandler.getObfuscator().unwrap(removed.getSession(), getRemoteParameterNames());
+        SessionImpl unwrappedSession = SessionHandler.getObfuscator().unwrap(removed.getSession());
 
         // Return appropriate TokenSessionControl
         return new TokenSessionControl(unwrappedSession, removed.getClientToken(), removed.getServerToken(), removed.getCreationStamp());
