@@ -53,7 +53,11 @@ import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.BitSet;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.LinkedHashSet;
 import java.util.List;
+import java.util.Set;
 import org.apache.commons.codec.DecoderException;
 import org.apache.commons.codec.net.URLCodec;
 import com.hazelcast.nio.serialization.ClassDefinition;
@@ -76,6 +80,8 @@ public class PortableSession extends StoredSession implements CustomPortable {
 
     private static final long serialVersionUID = -2346327568417617677L;
 
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(PortableSession.class);
+
     /**
      * BitSet of www-form-url safe characters.
      */
@@ -118,6 +124,7 @@ public class PortableSession extends StoredSession implements CustomPortable {
     public static final String PARAMETER_ALT_ID = "altId";
     public static final String PARAMETER_REMOTE_PARAMETER_NAMES = "remoteParameterNames";
     public static final String PARAMETER_REMOTE_PARAMETER_VALUES = "remoteParameterValues";
+    public static final String PARAMETER_NAME_XOAUTH2_TOKEN = "xoauth2";
 
     /** The class definition for PortableCacheEvent */
     public static ClassDefinition CLASS_DEFINITION = new ClassDefinitionBuilder(FACTORY_ID, CLASS_ID)
@@ -141,11 +148,14 @@ public class PortableSession extends StoredSession implements CustomPortable {
 
     // -------------------------------------------------------------------------------------------------
 
+    private Set<String> remoteParameterNames;
+
     /**
      * Initializes a new {@link PortableSession}.
      */
     public PortableSession() {
         super();
+        remoteParameterNames = Collections.emptySet();
     }
 
     /**
@@ -155,6 +165,15 @@ public class PortableSession extends StoredSession implements CustomPortable {
      */
     public PortableSession(final Session session) {
         super(session);
+        Collection<String> configuredRemoteParameterNames = SessionStorageConfiguration.getInstance().getRemoteParameterNames(userId, contextId);
+        Set<String> remoteParameterNames = new LinkedHashSet<>(configuredRemoteParameterNames.size() + 2); // Keep order
+
+        // Add static remote parameters
+        remoteParameterNames.add(PARAM_OAUTH_ACCESS_TOKEN);
+
+        // Add configured remote parameters
+        remoteParameterNames.addAll(configuredRemoteParameterNames);
+        this.remoteParameterNames = remoteParameterNames;
     }
 
     @Override
@@ -193,39 +212,33 @@ public class PortableSession extends StoredSession implements CustomPortable {
             writer.writeUTF(PARAMETER_ALT_ID, null == altId ? null : altId.toString());
         }
         {
-            List<String> remoteParameterNames = SessionStorageConfiguration.getInstance().getRemoteParameterNames();
-            int size = remoteParameterNames.size();
-            if (size <= 0) {
+            Set<String> remoteParameterNames = this.remoteParameterNames;
+            StringAppender names = null;
+            StringAppender values = null;
+            for (String parameterName : remoteParameterNames) {
+                Object value = parameters.get(parameterName);
+                if (null != value) {
+                    if (isSerializablePojo(value)) {
+                        String sValue = value.toString();
+                        if (null == names) {
+                            int capacity = remoteParameterNames.size() << 4;
+                            names = new StringAppender(':', capacity);
+                            values = new StringAppender(':', capacity);
+                        }
+                        names.append(parameterName);
+                        values.append(getSafeValue(sValue));
+                        LOG.debug("Put remote parameter '{}' with value '{}' into portable session {} ({}@{})", parameterName, value, sessionId, Integer.valueOf(userId), Integer.valueOf(contextId));
+                    } else {
+                        LOG.warn("Denied remote parameter for name {}. Seems to be no ordinary Java object.", value.getClass().getName());
+                    }
+                }
+            }
+            if (null == names || null == values) {
                 writer.writeUTF(PARAMETER_REMOTE_PARAMETER_NAMES, null);
                 writer.writeUTF(PARAMETER_REMOTE_PARAMETER_VALUES, null);
             } else {
-                StringAppender names = null;
-                StringAppender values = null;
-                for (String parameterName : remoteParameterNames) {
-                    Object value = parameters.get(parameterName);
-                    if (null != value) {
-                        if (isSerializablePojo(value)) {
-                            String sValue = value.toString();
-                            if (null == names) {
-                                int capacity = size << 4;
-                                names = new StringAppender(':', capacity);
-                                values = new StringAppender(':', capacity);
-                            }
-                            names.append(parameterName);
-                            values.append(getSafeValue(sValue));
-                        } else {
-                            org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(PortableSession.class);
-                            logger.warn("Denied remote parameter for name {}. Seems to be no ordinary Java object.", value.getClass().getName());
-                        }
-                    }
-                }
-                if (null == names || null == values) {
-                    writer.writeUTF(PARAMETER_REMOTE_PARAMETER_NAMES, null);
-                    writer.writeUTF(PARAMETER_REMOTE_PARAMETER_VALUES, null);
-                } else {
-                    writer.writeUTF(PARAMETER_REMOTE_PARAMETER_NAMES, names.toString());
-                    writer.writeUTF(PARAMETER_REMOTE_PARAMETER_VALUES, values.toString());
-                }
+                writer.writeUTF(PARAMETER_REMOTE_PARAMETER_NAMES, names.toString());
+                writer.writeUTF(PARAMETER_REMOTE_PARAMETER_VALUES, values.toString());
             }
         }
     }
@@ -262,14 +275,18 @@ public class PortableSession extends StoredSession implements CustomPortable {
             if (null != sNames) {
                 List<String> names = parseColonString(sNames);
                 List<String> values = parseColonString(reader.readUTF(PARAMETER_REMOTE_PARAMETER_VALUES)); // Expect them, too
+                Set<String> remoteParameterNames = new LinkedHashSet<>(names.size()); // Keep order
                 for (int i = 0, size = names.size(); i < size; i++) {
                     try {
                         Object value = parseToSerializablePojo(decodeSafeValue(values.get(i)));
-                        parameters.put(names.get(i), value);
+                        String name = names.get(i);
+                        parameters.put(name, value);
+                        remoteParameterNames.add(name);
                     } catch (DecoderException e) {
                         // Ignore
                     }
                 }
+                this.remoteParameterNames = remoteParameterNames;
             }
         }
     }
