@@ -98,8 +98,9 @@ public class PeriodicCleaner implements Runnable {
             LOG.info("Periodic share cleanup task starting, going to check {} contexts...", I(size));
             long logTimeDistance = TimeUnit.SECONDS.toMillis(10);
             long lastLogTime = start;
-            for (int i = 0, k = size; k-- > 0; i++) {
-                int contextID = contextIDs.get(i).intValue();
+            int i = 0;
+            for (Integer ctxId : contextIDs) {
+                int contextID = ctxId.intValue();
                 for (int retry = 0; retry < 3; retry++) {
                     if (false == active.get()) {
                         LOG.info("Periodic share cleanup task stopping.");
@@ -126,6 +127,7 @@ public class PeriodicCleaner implements Runnable {
                         }
                     }
                 }
+                i++;
             }
         } catch (InterruptedException e) {
             Thread.currentThread().interrupt();
@@ -151,9 +153,7 @@ public class PeriodicCleaner implements Runnable {
      * @param guestExpiry the timespan (in milliseconds) after which an unused guest user can be deleted permanently
      */
     private void cleanupContext(int contextID) throws OXException {
-        /*
-         * execute context- and resulting guest cleanup tasks in current thread
-         */
+        // Execute context- and resulting guest cleanup tasks in current thread
         try {
             List<GuestCleanupTask> guestCleanupTasks = new ContextCleanupTask(services, contextID, guestExpiry).call();
             for (GuestCleanupTask guestCleanupTask : guestCleanupTasks) {
