@@ -51,8 +51,10 @@ package com.openexchange.share.servlet.internal;
 
 import java.io.IOException;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.configuration.ServerProperty;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXExceptionStrings;
 import com.openexchange.groupware.contexts.impl.ContextExceptionCodes;
@@ -94,18 +96,29 @@ public class ShareServlet extends AbstractShareServlet {
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ShareServlet.class);
 
     private final RankingAwareNearRegistryServiceTracker<ShareHandler> shareHandlerRegistry;
+    private final AtomicReference<UserAgentBlacklist> userAgentBlacklistRef;
 
     /**
      * Initializes a new {@link ShareServlet}.
      *
-     * @param shareLoginConfig The share login configuration to use
+     * @param userAgentBlacklist The User-Agent black-list to use
      * @param shareHandlerRegistry The handler registry
      */
-    public ShareServlet(RankingAwareNearRegistryServiceTracker<ShareHandler> shareHandlerRegistry) {
+    public ShareServlet(UserAgentBlacklist userAgentBlacklist, RankingAwareNearRegistryServiceTracker<ShareHandler> shareHandlerRegistry) {
         super();
+        this.userAgentBlacklistRef = new AtomicReference<UserAgentBlacklist>(userAgentBlacklist);
         this.shareHandlerRegistry = shareHandlerRegistry;
     }
 
+    /**
+     * Sets a new User-Agent black-list that shall be used by this servlet.
+     *
+     * @param newBlacklist The new black-list to apply
+     */
+    public void setUserAgentBlacklist(UserAgentBlacklist newBlacklist) {
+        this.userAgentBlacklistRef.set(newBlacklist);
+    }
+
     @Override
     protected void service(HttpServletRequest request, HttpServletResponse response) throws IOException {
         Tools.disableCaching(response);
@@ -130,6 +143,18 @@ public class ShareServlet extends AbstractShareServlet {
                 return;
             }
 
+            {
+                UserAgentBlacklist userAgentBlacklist = userAgentBlacklistRef.get();
+                if (null != userAgentBlacklist) {
+                    String userAgent = request.getHeader("User-Agent");
+                    if (userAgentBlacklist.isBlacklisted(userAgent)) {
+                        LOG.info("User-Agent black-listed: '{}'", userAgent);
+                        sendNotFound(response, translator, ShareServletStrings.SHARE_NOT_ACCESSIBLE, "client_blacklisted");
+                        return;
+                    }
+                }
+            }
+
             GuestInfo guest = ShareServiceLookup.getService(ShareService.class, true).resolveGuest(paths.get(0));
             if (guest == null) {
                 LOG.debug("No guest with token '{}' found at '{}'", paths.get(0), pathInfo);
@@ -213,6 +238,16 @@ public class ShareServlet extends AbstractShareServlet {
         return false;
     }
 
+    /**
+     * Sends a redirect with an {@link ShareServletStrings#SHARE_NOT_FOUND appropriate error message} for a not found share.
+     *
+     * @param response The HTTP servlet response to redirect
+     * @param translator The translator
+     */
+    private static void sendNotFound(HttpServletResponse response, Translator translator) throws IOException {
+        sendNotFound(response, translator, ShareServletStrings.SHARE_NOT_FOUND, "not_found");
+    }
+
     /**
      * Handles the specified OXException
      * 
@@ -229,13 +264,13 @@ public class ShareServlet extends AbstractShareServlet {
         }
 
         if (ContextExceptionCodes.LOCATED_IN_ANOTHER_SERVER.equals(e)) {
-            LOG.warn("Could not process share '{}': {}", request.getPathInfo(), e.getMessage(), e);
+            LOG.debug("Could not process share '{}': {}", request.getPathInfo(), e.getMessage(), e);
             SegmentedUpdateService segmentedUpdateService = ShareServiceLookup.getService(SegmentedUpdateService.class);
             try {
                 String migrationRedirectURL = segmentedUpdateService.getMigrationRedirectURL(request.getServerName());
                 if (Strings.isEmpty(migrationRedirectURL)) {
-                    LOG.warn("Cannot redirect. The property 'com.openexchange.share.migrationRedirectURL' is not set.");
-                    LoginLocation location = new LoginLocation().loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
+                    LOG.error("Cannot redirect. The property '{}' is not set.", ServerProperty.migrationRedirectURL.getFQPropertyName());
+                    LoginLocation location = new LoginLocation().status("internal_error").loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
                     LoginLocationRegistry.getInstance().putAndRedirect(location, response);
                     return;
                 }
@@ -243,14 +278,14 @@ public class ShareServlet extends AbstractShareServlet {
                 return;
             } catch (OXException ex) {
                 LOG.error("Cannot redirect. An error was encountered while getting the migration URL property: {}", e.getMessage(), e);
-                LoginLocation location = new LoginLocation().loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
+                LoginLocation location = new LoginLocation().status("internal_error").loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
                 LoginLocationRegistry.getInstance().putAndRedirect(location, response);
                 return;
             }
         }
 
         LOG.error("Error processing share '{}': {}", request.getPathInfo(), e.getMessage(), e);
-        LoginLocation location = new LoginLocation().loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
+        LoginLocation location = new LoginLocation().status("internal_error").loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(OXExceptionStrings.MESSAGE_RETRY));
         LoginLocationRegistry.getInstance().putAndRedirect(location, response);
     }
 
@@ -259,9 +294,11 @@ public class ShareServlet extends AbstractShareServlet {
      *
      * @param response The HTTP servlet response to redirect
      * @param translator The translator
+     * @param displayMessage The message displayed to the user
+     * @param status The status to signal
      */
-    private void sendNotFound(HttpServletResponse response, Translator translator) throws IOException {
-        LoginLocation location = new LoginLocation().loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(ShareServletStrings.SHARE_NOT_FOUND));
+    private static void sendNotFound(HttpServletResponse response, Translator translator, String displayMessage, String status) throws IOException {
+        LoginLocation location = new LoginLocation().status(status).parameter("status", status).loginType(LoginType.MESSAGE).message(MessageType.ERROR, translator.translate(displayMessage));
         LoginLocationRegistry.getInstance().putAndRedirect(location, response);
         return;
     }
