@@ -171,6 +171,17 @@ public class LoginLocation {
         return null != targetPath ? parameter("target", targetPath.get()) : this;
     }
 
+    /**
+     * Appends the status parameter to pass to the client.
+     *
+     * @param status The message status
+     * @return The builder
+     */
+    public LoginLocation status(String status) {
+        parameter("status", status);
+        return this;
+    }
+
     /**
      * Appends a message to pass to the client along with the redirect location.
      *
