@@ -72,7 +72,7 @@ public class ShareTargetPath {
     private final int module;
     private final String folder;
     private final String item;
-    private Map<String, String> additionals;
+    private final Map<String, String> additionals;
 
     /**
      * Initializes a new {@link ShareTargetPath}.
@@ -322,25 +322,33 @@ public class ShareTargetPath {
 
     @Override
     public boolean equals(Object obj) {
-        if (this == obj)
+        if (this == obj) {
             return true;
-        if (obj == null)
+        }
+        if (obj == null) {
             return false;
-        if (getClass() != obj.getClass())
+        }
+        if (getClass() != obj.getClass()) {
             return false;
+        }
         ShareTargetPath other = (ShareTargetPath) obj;
         if (folder == null) {
-            if (other.folder != null)
+            if (other.folder != null) {
                 return false;
-        } else if (!folder.equals(other.folder))
+            }
+        } else if (!folder.equals(other.folder)) {
             return false;
+        }
         if (item == null) {
-            if (other.item != null)
+            if (other.item != null) {
                 return false;
-        } else if (!item.equals(other.item))
+            }
+        } else if (!item.equals(other.item)) {
             return false;
-        if (module != other.module)
+        }
+        if (module != other.module) {
             return false;
+        }
         return true;
     }
 
