@@ -59,9 +59,6 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.server.ServiceLookup;
@@ -78,14 +75,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(
-    name = "get"
-    , description = "Deletes a specific snippet."
-    , method = RequestMethod.GET
-    , parameters = {
-        @Parameter(name = "id", description = "The identifier of the snippet.")
-    }
-)
 public final class DeleteAction extends SnippetAction {
 
     private final List<Method> restMethods;
