@@ -57,15 +57,12 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.snippet.json.SnippetRequest;
 import com.openexchange.snippet.Snippet;
 import com.openexchange.snippet.SnippetService;
-import com.openexchange.snippet.json.SnippetRequest;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
 /**
@@ -73,14 +70,6 @@ import com.openexchange.tools.servlet.AjaxExceptionCodes;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(
-    name = "get"
-    , description = "Get a specific snippet."
-    , method = RequestMethod.GET
-    , parameters = {
-        @Parameter(name = "id", description = "The identifier of the snippet.")
-    }
-)
 public final class GetAction extends SnippetAction {
 
     private final List<Method> restMethods;
