@@ -58,20 +58,17 @@ import com.openexchange.ajax.container.ThresholdFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.ETagAwareAJAXActionService;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.snippet.json.SnippetRequest;
 import com.openexchange.snippet.Attachment;
 import com.openexchange.snippet.Snippet;
 import com.openexchange.snippet.SnippetExceptionCodes;
 import com.openexchange.snippet.SnippetService;
-import com.openexchange.snippet.json.SnippetRequest;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -79,15 +76,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(
-    name = "getattachment"
-    , description = "Gets a specific snippet attachment."
-    , method = RequestMethod.GET
-    , parameters = {
-        @Parameter(name = "id", description = "The identifier of the snippet."),
-        @Parameter(name = "attachmentid", description = "The identifier of the snippet attachment.")
-    }
-)
 public final class GetAttachmentAction extends SnippetAction implements ETagAwareAJAXActionService {
 
     private static String extractFilename(final Attachment attachment) {
