@@ -50,13 +50,13 @@
 package com.openexchange.snippet.mime;
 
 import static com.openexchange.mail.mime.MimeDefaultSession.getDefaultSession;
-import static com.openexchange.snippet.SnippetUtils.sanitizeContent;
 import static com.openexchange.snippet.mime.Services.getService;
-import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
-import java.io.ByteArrayOutputStream;
+import static com.openexchange.snippet.utils.SnippetUtils.sanitizeContent;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.net.URI;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -86,21 +86,33 @@ import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 import javax.mail.internet.MimePart;
 import javax.mail.internet.MimeUtility;
+import javax.mail.util.ByteArrayDataSource;
 import org.slf4j.Logger;
+import com.openexchange.ajax.container.ThresholdFileHolder;
+import com.openexchange.ajax.container.ThresholdFileHolder.ThresholdFileHolderInputStream;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
+import com.openexchange.filestore.FileStorage;
 import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.FileStorages;
-import com.openexchange.filestore.QuotaFileStorage;
+import com.openexchange.filestore.Info;
 import com.openexchange.id.IDGeneratorService;
 import com.openexchange.image.ImageLocation;
 import com.openexchange.image.ImageUtility;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
+import com.openexchange.java.util.Pair;
 import com.openexchange.java.util.UUIDs;
+import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MessageHeaders;
+import com.openexchange.mail.mime.MimeDefaultSession;
+import com.openexchange.mail.mime.MimeMailException;
+import com.openexchange.mail.mime.converters.FileBackedMimeMessage;
+import com.openexchange.mail.mime.datasource.FileDataSource;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
 import com.openexchange.mail.mime.utils.MimeMessageUtility;
 import com.openexchange.mail.utils.MessageUtility;
@@ -110,17 +122,17 @@ import com.openexchange.quota.QuotaExceptionCodes;
 import com.openexchange.quota.QuotaProvider;
 import com.openexchange.quota.QuotaType;
 import com.openexchange.session.Session;
+import com.openexchange.snippet.mime.groupware.QuotaMode;
+import com.openexchange.snippet.utils.SnippetUtils;
 import com.openexchange.snippet.Attachment;
 import com.openexchange.snippet.DefaultAttachment;
-import com.openexchange.snippet.DefaultAttachment.InputStreamProvider;
 import com.openexchange.snippet.DefaultSnippet;
 import com.openexchange.snippet.Property;
 import com.openexchange.snippet.ReferenceType;
 import com.openexchange.snippet.Snippet;
 import com.openexchange.snippet.SnippetExceptionCodes;
 import com.openexchange.snippet.SnippetManagement;
-import com.openexchange.snippet.SnippetUtils;
-import com.openexchange.tools.sql.DBUtils;
+import com.openexchange.snippet.DefaultAttachment.InputStreamProvider;
 
 /**
  * {@link MimeSnippetManagement}
@@ -131,11 +143,49 @@ public final class MimeSnippetManagement implements SnippetManagement {
 
     private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(MimeSnippetManagement.class);
 
+    private static final String PROP_QUOTA_MODE = "com.openexchange.snippet.filestore.quota.mode";
+
+    private static volatile QuotaMode MODE;
+
+    /**
+     * Retrieves the configured {@link QuotaMode}
+     *
+     * @return The {@link QuotaMode}
+     */
+    public static QuotaMode getMode() {
+        QuotaMode tmp = MODE;
+        if (null == tmp) {
+            synchronized (MimeSnippetManagement.class) {
+                tmp = MODE;
+                if (null == tmp) {
+                    ConfigurationService configurationService = Services.getService(ConfigurationService.class);
+                    if (null == configurationService) {
+                        return QuotaMode.CONTEXT;
+                    }
+
+                    tmp = QuotaMode.getModeByName(configurationService.getProperty(PROP_QUOTA_MODE, QuotaMode.CONTEXT.getName()));
+                    MODE = tmp;
+                    LOGGER.info("Using '{}' as the filestore quota mode for snippets.", tmp.getName());
+                }
+            }
+        }
+        return tmp;
+    }
+
     /**
      * The file storage reference type identifier: <b><code>1</code></b>.
      */
     private static final int FS_TYPE = ReferenceType.FILE_STORAGE.getType();
 
+    /**
+     * Gets the file storage reference type identifier: <b><code>1</code></b>.
+     *
+     * @return The file storage reference type identifier: <b><code>1</code></b>.
+     */
+    public static int getFsType() {
+        return FS_TYPE;
+    }
+
     private static final class InputStreamProviderImpl implements InputStreamProvider {
 
         private final MimePart part;
@@ -162,8 +212,13 @@ public final class MimeSnippetManagement implements SnippetManagement {
         return getService(IDGeneratorService.class);
     }
 
-    private static QuotaFileStorage getFileStorage(int contextId) throws OXException {
-        return FileStorages.getQuotaFileStorageService().getQuotaFileStorage(contextId);
+    private static FileStorage getFileStorage(int contextId) throws OXException {
+        if (QuotaMode.CONTEXT.equals(getMode())) {
+            return FileStorages.getQuotaFileStorageService().getQuotaFileStorage(contextId, Info.general());
+        }
+
+        URI uri = FileStorages.getQuotaFileStorageService().getFileStorageUriFor(-1, contextId);
+        return FileStorages.getFileStorageService().getFileStorage(uri);
     }
 
     // ----------------------------------------------------------------------------------------------------------------------------
@@ -223,7 +278,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
             do {
                 ids.add(rs.getString(1));
             } while (rs.next());
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             rs = null;
             stmt = null;
             if (ids.isEmpty()) {
@@ -238,39 +293,22 @@ public final class MimeSnippetManagement implements SnippetManagement {
                         throw e;
                     }
 
-                    LOGGER.warn("Missing file for snippet {} for user {} in context {}. Maybe file storage is (temporary) not available.", id, userId, contextId, e);
+                    LOGGER.warn("Missing file for snippet {} for user {} in context {}. Maybe file storage is (temporary) not available.", id, Integer.valueOf(userId), Integer.valueOf(contextId), e);
                 }
             }
             return list;
         } catch (SQLException e) {
             throw SnippetExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             databaseService.backReadOnly(contextId, con);
         }
     }
 
     @Override
     public int getOwnSnippetsCount() throws OXException {
-        final DatabaseService databaseService = getDatabaseService();
-        final int contextId = this.contextId;
-        final Connection con = databaseService.getReadOnly(contextId);
-        PreparedStatement stmt = null;
-        ResultSet rs = null;
-        try {
-            final StringBuilder sql = new StringBuilder("SELECT COUNT(id) FROM snippet WHERE cid=? AND user=? AND refType=").append(FS_TYPE);
-            stmt = con.prepareStatement(sql.toString());
-            int pos = 0;
-            stmt.setInt(++pos, contextId);
-            stmt.setInt(++pos, userId);
-            rs = stmt.executeQuery();
-            return rs.next() ? rs.getInt(1) : 0;
-        } catch (final SQLException e) {
-            throw SnippetExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-        } finally {
-            closeSQLStuff(rs, stmt);
-            databaseService.backReadOnly(contextId, con);
-        }
+        AccountQuota quota = getQuota();
+        return (int) quota.getQuota(QuotaType.AMOUNT).getUsage();
     }
 
     @Override
@@ -294,7 +332,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
             do {
                 ids.add(rs.getString(1));
             } while (rs.next());
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             rs = null;
             stmt = null;
             if (ids.isEmpty()) {
@@ -314,7 +352,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
         } catch (final SQLException e) {
             throw SnippetExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
             databaseService.backReadOnly(contextId, con);
         }
     }
@@ -367,51 +405,13 @@ public final class MimeSnippetManagement implements SnippetManagement {
                 module = rs.getString(4);
                 type = rs.getString(5);
                 shared = rs.getInt(6) > 0;
-                closeSQLStuff(rs, stmt);
+                Databases.closeSQLStuff(rs, stmt);
                 rs = null;
                 stmt = null;
             }
-            MimeMessage mimeMessage;
-            {
-                InputStream in = null;
-                try {
-                    QuotaFileStorage fileStorage = getFileStorage(session.getContextId());
-                    in = fileStorage.getFile(file);
-                    mimeMessage = new MimeMessage(getDefaultSession(), in);
-                } catch (OXException e) {
-                    if (!FileStorageCodes.FILE_NOT_FOUND.equals(e)) {
-                        throw e;
-                    }
-                    throw SnippetExceptionCodes.SNIPPET_NOT_FOUND.create(e, identifier);
-                } finally {
-                    Streams.close(in);
-                }
-            }
-            com.openexchange.mail.mime.converters.MimeMessageConverter.saveChanges(mimeMessage);
-            final DefaultSnippet snippet = new DefaultSnippet().setId(identifier).setCreatedBy(creator);
-            final String lcct;
-            {
-                final String tmp = mimeMessage.getHeader(MessageHeaders.HDR_CONTENT_TYPE, null);
-                if (!isEmpty(tmp)) {
-                    lcct = tmp.trim().toLowerCase(Locale.US);
-                } else {
-                    lcct = "text/plain; charset=us-ascii";
-                }
-            }
-            if (lcct.startsWith("multipart/", 0)) {
-                final Multipart multipart = MimeMessageUtility.getMultipartContentFrom(mimeMessage);
-                parseSnippet(mimeMessage, (MimePart) multipart.getBodyPart(0), snippet);
-                final int count = multipart.getCount();
-                if (count > 1) {
-                    for (int i = 1; i < count; i++) {
-                        parsePart((MimePart) multipart.getBodyPart(i), snippet);
-                    }
-                }
-            } else {
-                parseSnippet(mimeMessage, mimeMessage, snippet);
-            }
-            snippet.setDisplayName(displayName).setModule(module).setType(type).setShared(shared);
-            return snippet;
+            Pair<MimeMessage, Long> messageAndSize = createMimeMessage(identifier, file);
+            com.openexchange.mail.mime.converters.MimeMessageConverter.saveChanges(messageAndSize.getFirst());
+            return createSnippet(identifier, creator, displayName, module, type, shared, messageAndSize.getFirst());
         } catch (SQLException e) {
             throw SnippetExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } catch (MessagingException e) {
@@ -421,11 +421,90 @@ public final class MimeSnippetManagement implements SnippetManagement {
         } catch (RuntimeException e) {
             throw SnippetExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
         }
     }
 
-    private static void parsePart(MimePart part, DefaultSnippet snippet) throws OXException, MessagingException, IOException {
+    protected static DefaultSnippet createSnippet(String identifier, final int creator, final String displayName, final String module, final String type, final boolean shared, MimeMessage mimeMessage) throws MessagingException, IOException, OXException {
+        final DefaultSnippet snippet = new DefaultSnippet().setId(identifier).setCreatedBy(creator);
+        final String lcct;
+        {
+            final String tmp = mimeMessage.getHeader(MessageHeaders.HDR_CONTENT_TYPE, null);
+            if (!isEmpty(tmp)) {
+                lcct = tmp.trim().toLowerCase(Locale.US);
+            } else {
+                lcct = "text/plain; charset=us-ascii";
+            }
+        }
+        if (lcct.startsWith("multipart/", 0)) {
+            final Multipart multipart = MimeMessageUtility.getMultipartContentFrom(mimeMessage);
+            if (multipart != null) {
+                parseSnippet(mimeMessage, (MimePart) multipart.getBodyPart(0), snippet);
+                final int count = multipart.getCount();
+                if (count > 1) {
+                    for (int i = 1; i < count; i++) {
+                        parsePart((MimePart) multipart.getBodyPart(i), snippet);
+                    }
+                }
+            }
+        } else {
+            parseSnippet(mimeMessage, mimeMessage, snippet);
+        }
+        snippet.setDisplayName(displayName).setModule(module).setType(type).setShared(shared).setCreatedBy(creator);
+        return snippet;
+    }
+
+    private Pair<MimeMessage, Long> createMimeMessage(String identifier, String file) throws OXException {
+        InputStream in = null;
+        try {
+            FileStorage fileStorage = getFileStorage(session.getContextId());
+            in = fileStorage.getFile(file);
+            return newMimeMessage(in);
+        } catch (OXException e) {
+            if (!FileStorageCodes.FILE_NOT_FOUND.equals(e)) {
+                throw e;
+            }
+            throw SnippetExceptionCodes.SNIPPET_NOT_FOUND.create(e, identifier);
+        } finally {
+            Streams.close(in);
+        }
+    }
+
+    private static Pair<MimeMessage, Long> newMimeMessage(InputStream is) throws OXException {
+        InputStream msgSrc = is;
+        ThresholdFileHolder sink = null;
+        boolean closeSink = false;
+        try {
+            sink = new ThresholdFileHolder();
+            closeSink = true;
+
+            sink.write(msgSrc);
+            msgSrc = null;
+
+            Long size = Long.valueOf(sink.getLength());
+            File tempFile = sink.getTempFile();
+            MimeMessage tmp;
+            if (null == tempFile) {
+                tmp = new MimeMessage(MimeDefaultSession.getDefaultSession(), sink.getStream());
+            } else {
+                tmp = new FileBackedMimeMessage(MimeDefaultSession.getDefaultSession(), tempFile, null);
+            }
+            closeSink = false;
+            return new Pair<MimeMessage, Long>(tmp, size);
+        } catch (MessagingException e) {
+            throw MimeMailException.handleMessagingException(e);
+        } catch (IOException e) {
+            throw MailExceptionCode.IO_ERROR.create(e, e.getMessage());
+        } catch (RuntimeException e) {
+            throw MailExceptionCode.UNEXPECTED_ERROR.create(e, e.getMessage());
+        } finally {
+            if (closeSink && null != sink) {
+                sink.close();
+            }
+        }
+    }
+
+    private static void parsePart(MimePart part, DefaultSnippet snippet) throws OXException, MessagingException {
         String header = part.getHeader(MessageHeaders.HDR_CONTENT_TYPE, null);
         final ContentType contentType = isEmpty(header) ? ContentType.DEFAULT_CONTENT_TYPE : new ContentType(header);
         if (contentType.startsWith("text/javascript")) {
@@ -455,7 +534,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
         }
     }
 
-    private static void parseSnippet(MimeMessage mimeMessage, MimePart part, DefaultSnippet snippet) throws OXException, MessagingException {
+    protected static void parseSnippet(MimeMessage mimeMessage, MimePart part, DefaultSnippet snippet) throws OXException, MessagingException {
         // Read content from part
         final String header = part.getHeader(MessageHeaders.HDR_CONTENT_TYPE, null);
         final ContentType contentType = isEmpty(header) ? ContentType.DEFAULT_CONTENT_TYPE : new ContentType(header);
@@ -481,17 +560,22 @@ public final class MimeSnippetManagement implements SnippetManagement {
     @Override
     public String createSnippet(Snippet snippet) throws OXException {
         AccountQuota quota = getQuota();
-        if (null != quota && quota.hasQuota(QuotaType.AMOUNT)) {
+        if (null != quota) {
             Quota amountQuota = quota.getQuota(QuotaType.AMOUNT);
-            if (amountQuota.isExceeded() || amountQuota.willExceed(1)) {
+            if (null != amountQuota && (amountQuota.isExceeded() || amountQuota.willExceed(1))) {
                 throw QuotaExceptionCodes.QUOTA_EXCEEDED_SNIPPETS.create(amountQuota.getUsage(), amountQuota.getLimit());
             }
+            // Check if size is already exceeded
+            Quota sizeQuota = quota.getQuota(QuotaType.SIZE);
+            if (null != sizeQuota && sizeQuota.isExceeded()) {
+                throw QuotaExceptionCodes.QUOTA_EXCEEDED_SIGNATURES.create(bytesToReadableString(sizeQuota.getLimit()));
+            }
         }
-
         final DatabaseService databaseService = getDatabaseService();
         final int contextId = this.contextId;
         final Connection con = databaseService.getWritable(contextId);
         PreparedStatement stmt = null;
+        boolean backAfterRead=false;
         try {
             final MimeMessage mimeMessage = new MimeMessage(getDefaultSession());
             mimeMessage.setHeader(Property.CREATED_BY.getPropName(), Integer.toString(userId));
@@ -549,22 +633,32 @@ public final class MimeSnippetManagement implements SnippetManagement {
             mimeMessage.removeHeader("Message-ID");
             mimeMessage.removeHeader("MIME-Version");
             // Save MIME content to file storage
-            QuotaFileStorage fileStorage = getFileStorage(session.getContextId());
+            FileStorage fileStorage = getFileStorage(session.getContextId());
             String file;
+            long size = -1L;
             {
-                InputStream mimeStream = null;
+                ThresholdFileHolder fileHolder = new ThresholdFileHolder();
                 try {
-                    mimeStream = MimeMessageUtility.getStreamFromPart(mimeMessage);
-                    file = fileStorage.saveNewFile(mimeStream);
+                    mimeMessage.writeTo(fileHolder.asOutputStream());
+                    size = fileHolder.getLength();
+                    if (null != quota) {
+                        Quota sizeQuota = quota.getQuota(QuotaType.SIZE);
+                        if (null != sizeQuota && (sizeQuota.isExceeded() || sizeQuota.willExceed(size))) {
+                            backAfterRead = true;
+                            throw QuotaExceptionCodes.QUOTA_EXCEEDED_SIGNATURES.create(bytesToReadableString(sizeQuota.getLimit()));
+                        }
+                    }
+                    file = fileStorage.saveNewFile(fileHolder.getClosingStream());
                 } finally {
-                    Streams.close(mimeStream);
+                    fileHolder.close();
                 }
             }
             // Store in DB, too
-            String newId = Integer.toString(getIdGeneratorService().getId("com.openexchange.snippet.mime", contextId));
+            String newId = null;
             boolean error = true;
             try {
-                stmt = con.prepareStatement("INSERT INTO snippet (cid, user, id, accountId, displayName, module, type, shared, lastModified, refId, refType) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, " + FS_TYPE + ")");
+                newId = Integer.toString(getIdGeneratorService().getId("com.openexchange.snippet.mime", contextId));
+                stmt = con.prepareStatement("INSERT INTO snippet (cid, user, id, accountId, displayName, module, type, shared, lastModified, refId, refType, size) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, " + FS_TYPE + ", ?)");
                 stmt.setInt(1, contextId);
                 stmt.setInt(2, userId);
                 stmt.setString(3, newId);
@@ -582,6 +676,11 @@ public final class MimeSnippetManagement implements SnippetManagement {
                 stmt.setInt(8, snippet.isShared() ? 1 : 0);
                 stmt.setLong(9, System.currentTimeMillis());
                 stmt.setString(10, file);
+                if (size > 0) {
+                    stmt.setLong(11, size);
+                } else {
+                    stmt.setNull(11, Types.INTEGER);
+                }
                 stmt.executeUpdate();
                 error = false;
             } finally {
@@ -602,19 +701,38 @@ public final class MimeSnippetManagement implements SnippetManagement {
         } catch (RuntimeException e) {
             throw SnippetExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(stmt);
-            databaseService.backWritable(contextId, con);
+            Databases.closeSQLStuff(stmt);
+            if(backAfterRead){
+                databaseService.backWritableAfterReading(contextId, con);
+            }else {
+                databaseService.backWritable(contextId, con);
+            }
         }
     }
 
+    private String bytesToReadableString(long bytes) {
+        int x = 0;
+        double tmp = bytes;
+        while (tmp > 1024) {
+            x++;
+            tmp = tmp / 1024;
+        }
+
+        StringBuilder builder = new StringBuilder(String.valueOf(Integer.valueOf((int) Math.floor(tmp))));
+        builder.append(" ");
+        builder.append(Arrays.asList("B", "KB", "MB", "GB", "TB").get(x));
+        return builder.toString();
+    }
+
     @Override
     public String updateSnippet(String identifier, Snippet snippet, Set<Property> properties, Collection<Attachment> addAttachments, Collection<Attachment> removeAttachments) throws OXException {
         if (null == identifier) {
             return null;
         }
+        AccountQuota quota = getQuota();
         final DatabaseService databaseService = getDatabaseService();
         final int contextId = this.contextId;
-        final QuotaFileStorage fileStorage = getFileStorage(session.getContextId());
+        final FileStorage fileStorage = getFileStorage(session.getContextId());
         boolean error = true;
         String oldFile = null;
         String newFile = null;
@@ -624,12 +742,13 @@ public final class MimeSnippetManagement implements SnippetManagement {
             final String module;
             final String type;
             final boolean shared;
+            final long oldSize;
             {
                 final Connection con = databaseService.getReadOnly(contextId);
                 PreparedStatement stmt = null;
                 ResultSet rs = null;
                 try {
-                    stmt = con.prepareStatement("SELECT refId, displayName, module, type, shared FROM snippet WHERE cid=? AND id=? AND refType=" + FS_TYPE);
+                    stmt = con.prepareStatement("SELECT refId, displayName, module, type, shared, size FROM snippet WHERE cid=? AND id=? AND refType=" + FS_TYPE);
                     int pos = 0;
                     stmt.setInt(++pos, contextId);
                     stmt.setString(++pos, identifier);
@@ -645,8 +764,9 @@ public final class MimeSnippetManagement implements SnippetManagement {
                     module = rs.getString(3);
                     type = rs.getString(4);
                     shared = rs.getInt(5) > 0;
+                    oldSize = rs.getLong(6);
                 } finally {
-                    closeSQLStuff(rs, stmt);
+                    Databases.closeSQLStuff(rs, stmt);
                     databaseService.backReadOnly(contextId, con);
                 }
             }
@@ -867,17 +987,25 @@ public final class MimeSnippetManagement implements SnippetManagement {
             updateMessage.removeHeader("Message-ID");
             updateMessage.removeHeader("MIME-Version");
 
-            // ... and write to byte array
-            byte[] byteArray;
-            {
-                final ByteArrayOutputStream outputStream = Streams.newByteArrayOutputStream(8192);
-                updateMessage.writeTo(outputStream);
-                byteArray = outputStream.toByteArray();
+            ThresholdFileHolder fileHolder = new ThresholdFileHolder();
+            long size = 0;
+            try {
+                updateMessage.writeTo(fileHolder.asOutputStream());
+                size = fileHolder.getLength();
+                long difference = size - oldSize;
+                if (difference > 0 && null != quota) {
+                    Quota sizeQuota = quota.getQuota(QuotaType.SIZE);
+                    if (null != sizeQuota && (sizeQuota.isExceeded() || sizeQuota.willExceed(difference))) {
+                        throw QuotaExceptionCodes.QUOTA_EXCEEDED_SIGNATURES.create(Integer.valueOf(bytesToReadableString(sizeQuota.getLimit())));
+                    }
+                }
+
+                // Create file carrying new MIME data
+                newFile = fileStorage.saveNewFile(fileHolder.getClosingStream());
+            } finally {
+                fileHolder.close();
             }
 
-            // Create file carrying new MIME data
-            newFile = fileStorage.saveNewFile(Streams.newByteArrayInputStream(byteArray), byteArray.length);
-            byteArray = null; // Drop immediately
             {
                 Connection con = databaseService.getWritable(contextId);
                 PreparedStatement stmt = null;
@@ -893,7 +1021,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
                     final String dummyId = "--" + identifier;
                     con.setAutoCommit(false); // BEGIN
                     rollback = true;
-                    stmt = con.prepareStatement("INSERT INTO snippet (cid, user, id, accountId, displayName, module, type, shared, lastModified, refId, refType) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, " + FS_TYPE + ")");
+                    stmt = con.prepareStatement("INSERT INTO snippet (cid, user, id, accountId, displayName, module, type, shared, lastModified, refId, refType, size) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, " + FS_TYPE + ", ?)");
                     int pos = 0;
                     stmt.setInt(++pos, contextId);
                     stmt.setInt(++pos, userId);
@@ -912,15 +1040,20 @@ public final class MimeSnippetManagement implements SnippetManagement {
                     stmt.setInt(++pos, properties.contains(Property.SHARED) ? (snippet.isShared() ? 1 : 0) : (shared ? 1 : 0));
                     stmt.setLong(++pos, System.currentTimeMillis());
                     stmt.setString(++pos, newFile);
+                    if (size > 0) {
+                        stmt.setLong(++pos, size);
+                    } else {
+                        stmt.setNull(++pos, Types.INTEGER);
+                    }
                     stmt.executeUpdate();
-                    closeSQLStuff(stmt);
+                    Databases.closeSQLStuff(stmt);
                     stmt = con.prepareStatement("DELETE FROM snippet WHERE cid=? AND user=? AND id=? AND refType=" + FS_TYPE);
                     pos = 0;
                     stmt.setLong(++pos, contextId);
                     stmt.setLong(++pos, userId);
                     stmt.setString(++pos, identifier);
                     stmt.executeUpdate();
-                    closeSQLStuff(stmt);
+                    Databases.closeSQLStuff(stmt);
                     stmt = con.prepareStatement("UPDATE snippet SET id=? WHERE cid=? AND user=? AND id=? AND refType=" + FS_TYPE);
                     pos = 0;
                     stmt.setString(++pos, identifier);
@@ -932,10 +1065,10 @@ public final class MimeSnippetManagement implements SnippetManagement {
                     rollback = false;
                 } finally {
                     if (rollback) {
-                        DBUtils.rollback(con);
+                        Databases.rollback(con);
                     }
-                    closeSQLStuff(stmt);
-                    DBUtils.autocommit(con);
+                    Databases.closeSQLStuff(stmt);
+                    Databases.autocommit(con);
                     databaseService.backWritable(contextId, con);
                 }
             }
@@ -990,7 +1123,7 @@ public final class MimeSnippetManagement implements SnippetManagement {
         return set;
     }
 
-    private static void deleteSafe(String file, QuotaFileStorage fileStorage) {
+    private static void deleteSafe(String file, FileStorage fileStorage) {
         if (null == file) {
             return;
         }
@@ -1088,12 +1221,12 @@ public final class MimeSnippetManagement implements SnippetManagement {
                     throw SnippetExceptionCodes.SNIPPET_NOT_FOUND.create(identifier);
                 }
                 file = rs.getString(1);
-                closeSQLStuff(rs, stmt);
+                Databases.closeSQLStuff(rs, stmt);
                 rs = null;
                 stmt = null;
             }
 
-            final QuotaFileStorage fileStorage = getFileStorage(contextId);
+            final FileStorage fileStorage = getFileStorage(contextId);
             deleteSafe(file, fileStorage);
             stmt = con.prepareStatement("DELETE FROM snippet WHERE cid=? AND user=? AND id=? AND refType=" + FS_TYPE);
             int pos = 0;
@@ -1106,18 +1239,45 @@ public final class MimeSnippetManagement implements SnippetManagement {
         } catch (RuntimeException e) {
             throw SnippetExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } finally {
-            closeSQLStuff(rs, stmt);
+            Databases.closeSQLStuff(rs, stmt);
         }
     }
 
-    private static MimeBodyPart attachment2MimePart(Attachment attachment) throws MessagingException, IOException {
+    private static MimeBodyPart attachment2MimePart(Attachment attachment) throws MessagingException, IOException, OXException {
         /*
          * Content-Type
          */
         String header = attachment.getContentType();
         final String contentType = isEmpty(header) ? "text/plain; charset=UTF-8" : header;
         final MimeBodyPart bodyPart = new MimeBodyPart();
-        bodyPart.setDataHandler(new DataHandler(new MessageDataSource(attachment.getInputStream(), contentType)));
+        /*
+         * Content
+         */
+        {
+            ThresholdFileHolder fileHolder;
+            InputStream inputStream = attachment.getInputStream();
+            try {
+                if (inputStream instanceof ThresholdFileHolderInputStream) {
+                    ThresholdFileHolderInputStream fileHolderInputStream = (ThresholdFileHolderInputStream) inputStream;
+                    fileHolder = fileHolderInputStream.getFileHolder();
+                } else {
+                    fileHolder = new ThresholdFileHolder();
+                    fileHolder.write(inputStream);
+                }
+            } finally {
+                Streams.close(inputStream);
+            }
+
+            File tempFile = fileHolder.getTempFile();
+            if (null == tempFile) {
+                bodyPart.setDataHandler(new DataHandler(new ByteArrayDataSource(fileHolder.getBuffer().toByteArray(), contentType)));
+            } else {
+                bodyPart.setDataHandler(new DataHandler(new FileDataSource(tempFile, contentType)));
+            }
+        }
+        /*
+         * Rest...
+         */
         bodyPart.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
         bodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MimeMessageUtility.foldContentType(contentType));
         String attachmentId = attachment.getId();
@@ -1159,4 +1319,5 @@ public final class MimeSnippetManagement implements SnippetManagement {
         final String ct = SnippetUtils.parseContentTypeFromMisc(misc);
         return new ContentType(ct).getSubType();
     }
+
 }
