@@ -54,8 +54,8 @@ import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.quota.QuotaProvider;
 import com.openexchange.session.Session;
-import com.openexchange.snippet.SnippetManagement;
-import com.openexchange.snippet.SnippetService;
+import com.openexchange.snippet.mime.groupware.QuotaMode;
+import com.openexchange.snippet.QuotaAwareSnippetService;
 
 /**
  * {@link MimeSnippetService} - The "filestore" using snippet service.
@@ -73,7 +73,7 @@ import com.openexchange.snippet.SnippetService;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public final class MimeSnippetService implements SnippetService {
+public final class MimeSnippetService implements QuotaAwareSnippetService {
 
     private final QuotaProvider quotaProvider;
 
@@ -86,7 +86,7 @@ public final class MimeSnippetService implements SnippetService {
     }
 
     @Override
-    public SnippetManagement getManagement(final Session session) throws OXException {
+    public MimeSnippetManagement getManagement(final Session session) throws OXException {
         return new MimeSnippetManagement(session, quotaProvider);
     }
 
@@ -95,4 +95,17 @@ public final class MimeSnippetService implements SnippetService {
         return Collections.singletonList("filestore");
     }
 
+    @Override
+    public List<String> getFilesToIgnore(int contextId) throws OXException {
+        if (!ignoreQuota()) {
+            return Collections.emptyList();
+        }
+        return MimeSnippetFileAccess.getFiles(contextId);
+    }
+
+    @Override
+    public boolean ignoreQuota() {
+       return QuotaMode.DEDICATED.equals(MimeSnippetManagement.getMode());
+    }
+
 }
