@@ -51,10 +51,9 @@ package com.openexchange.tasks.json;
 
 import java.util.Collection;
 import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.provider.resourceserver.annotations.OAuthModule;
 import com.openexchange.server.ServiceLookup;
@@ -76,7 +75,6 @@ import com.openexchange.tasks.json.actions.UpdatesAction;
  *
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
  */
-@Module(name = "tasks", description = "Provides access to task information.")
 @OAuthModule
 public class TaskActionFactory implements AJAXActionServiceFactory {
 
@@ -84,13 +82,14 @@ public class TaskActionFactory implements AJAXActionServiceFactory {
 
     public static final String OAUTH_WRITE_SCOPE = "write_tasks";
 
-    private final Map<String, TaskAction> actions = new ConcurrentHashMap<String, TaskAction>(10, 0.9f, 1);
+    private final Map<String, TaskAction> actions;
 
     /**
      * Initializes a new {@link TaskActionFactory}.
      */
     public TaskActionFactory(final ServiceLookup serviceLookup) {
         super();
+        ImmutableMap.Builder<String, TaskAction> actions = ImmutableMap.builder();
         actions.put("all", new AllAction(serviceLookup));
         actions.put("confirm", new ConfirmAction(serviceLookup));
         actions.put("copy", new CopyAction(serviceLookup));
@@ -101,6 +100,7 @@ public class TaskActionFactory implements AJAXActionServiceFactory {
         actions.put("search", new SearchAction(serviceLookup));
         actions.put("update", new UpdateAction(serviceLookup));
         actions.put("updates", new UpdatesAction(serviceLookup));
+        this.actions = actions.build();
     }
 
     @Override
