@@ -56,8 +56,6 @@ import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.parser.TaskParser;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.api2.TasksSQLInterface;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.groupware.tasks.TasksSQLImpl;
@@ -72,9 +70,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
  */
-@Action(method = RequestMethod.PUT, name = "new", description = "Create a task.", parameters = {},
-requestBody = "Task object as described in Common object data, Detailed task and appointment data and Detailed task data. The field id is not present.",
-responseDescription = "A json objekt with attribute id of the newly created task.")
 @OAuthAction(TaskActionFactory.OAUTH_WRITE_SCOPE)
 public class NewAction extends TaskAction {
 
