@@ -54,8 +54,9 @@ import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilitySet;
 import com.openexchange.data.conversion.ical.ICalEmitter;
 import com.openexchange.groupware.userconfiguration.Permission;
-import com.openexchange.oauth.provider.scope.AbstractScopeProvider;
-import com.openexchange.oauth.provider.scope.OAuthScopeProvider;
+import com.openexchange.oauth.provider.resourceserver.scope.AbstractScopeProvider;
+import com.openexchange.oauth.provider.resourceserver.scope.OAuthScopeProvider;
+import com.openexchange.objectusecount.ObjectUseCountService;
 import com.openexchange.tasks.json.TaskActionFactory;
 import com.openexchange.tasks.json.converters.TaskIcalResultConverter;
 import com.openexchange.tasks.json.converters.TaskResultConverter;
@@ -80,17 +81,22 @@ public class TaskJSONActivator extends AJAXModuleActivator {
         registerService(ResultConverter.class, new TaskIcalResultConverter(this));
 
         registerService(OAuthScopeProvider.class, new AbstractScopeProvider(TaskActionFactory.OAUTH_READ_SCOPE, OAuthScopeDescription.READ_ONLY) {
+
             @Override
             public boolean canBeGranted(CapabilitySet capabilities) {
                 return capabilities.contains(Permission.TASKS.getCapabilityName());
             }
         });
         registerService(OAuthScopeProvider.class, new AbstractScopeProvider(TaskActionFactory.OAUTH_WRITE_SCOPE, OAuthScopeDescription.WRITABLE) {
+
             @Override
             public boolean canBeGranted(CapabilitySet capabilities) {
                 return capabilities.contains(Permission.TASKS.getCapabilityName());
             }
         });
+
+        trackService(ObjectUseCountService.class);
+        openTrackers();
     }
 
 }
