@@ -62,6 +62,7 @@ public final class CustomThread extends Thread implements ThreadRenamer, OXThrea
     private volatile String originalName;
     private volatile String appendix;
     private volatile boolean changed;
+    private volatile boolean httpProcessing;
 
     /**
      * Initializes a new {@link CustomThread}.
@@ -80,6 +81,16 @@ public final class CustomThread extends Thread implements ThreadRenamer, OXThrea
         appendix = pos > 0 ? name.substring(pos) : null;
     }
 
+    @Override
+    public boolean isHttpRequestProcessing() {
+        return httpProcessing;
+    }
+
+    @Override
+    public void setHttpRequestProcessing(boolean httpProcessing) {
+        this.httpProcessing = httpProcessing;
+    }
+
     /**
      * Gets the original name.
      *
@@ -89,9 +100,7 @@ public final class CustomThread extends Thread implements ThreadRenamer, OXThrea
         return originalName;
     }
 
-    /**
-     * Restores the original name.
-     */
+    @Override
     public void restoreName() {
         if (!changed) {
             return;
