@@ -50,7 +50,6 @@
 package com.openexchange.tokenlogin.json.osgi;
 
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.tokenlogin.TokenLoginService;
 import com.openexchange.tokenlogin.json.TokenLoginActionFactory;
 
@@ -59,7 +58,6 @@ import com.openexchange.tokenlogin.json.TokenLoginActionFactory;
  *
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
  */
-@Module(name = "token", description = "One-time token login")
 public class TokenLoginJSONActivator extends AJAXModuleActivator {
 
     @Override
