@@ -50,12 +50,10 @@
 package com.openexchange.user.json.actions;
 
 import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.Map;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -65,7 +63,6 @@ import com.openexchange.tools.servlet.AjaxExceptionCodes;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Module(name = "user", description = "Provides access to user information.")
 public final class UserActionFactory implements AJAXActionServiceFactory {
 
     /** The map to store actions. */
@@ -106,7 +103,7 @@ public final class UserActionFactory implements AJAXActionServiceFactory {
      * @return The unmodifiable map with actions stored
      */
     private Map<String, AJAXActionService> initActions() {
-        final Map<String, AJAXActionService> tmp = new HashMap<String, AJAXActionService>(12);
+        ImmutableMap.Builder<String, AJAXActionService> tmp = ImmutableMap.builder();
         tmp.put(GetAction.ACTION, new GetAction(services));
         tmp.put(ListAction.ACTION, new ListAction(services));
         tmp.put(AllAction.ACTION, new AllAction(services));
@@ -114,7 +111,7 @@ public final class UserActionFactory implements AJAXActionServiceFactory {
         tmp.put(UpdateAction.ACTION, new UpdateAction(services));
         tmp.put(GetAttributeAction.ACTION, new GetAttributeAction(services));
         tmp.put(SetAttributeAction.ACTION, new SetAttributeAction(services));
-        return Collections.unmodifiableMap(tmp);
+        return tmp.build();
     }
 
 }
