@@ -50,12 +50,10 @@
 package com.openexchange.user.json.actions;
 
 import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.Map;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Module;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.provider.resourceserver.annotations.OAuthModule;
 import com.openexchange.server.ServiceLookup;
@@ -66,7 +64,6 @@ import com.openexchange.tools.servlet.AjaxExceptionCodes;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Module(name = "user/me", description = "Provides access to user information.")
 @OAuthModule
 public final class UserMeActionFactory implements AJAXActionServiceFactory {
 
@@ -108,9 +105,9 @@ public final class UserMeActionFactory implements AJAXActionServiceFactory {
      * @return The unmodifiable map with actions stored
      */
     private Map<String, AJAXActionService> initActions() {
-        final Map<String, AJAXActionService> tmp = new HashMap<String, AJAXActionService>(2);
+        ImmutableMap.Builder<String, AJAXActionService> tmp = ImmutableMap.builder();
         tmp.put(MeAction.ACTION, new MeAction(services));
-        return Collections.unmodifiableMap(tmp);
+        return tmp.build();
     }
 
 }
