@@ -52,7 +52,6 @@ package com.openexchange.user.json.anonymizer;
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
-import java.util.Set;
 import com.openexchange.ajax.anonymizer.AnonymizerService;
 import com.openexchange.ajax.anonymizer.Anonymizers;
 import com.openexchange.ajax.anonymizer.Module;
@@ -183,8 +182,8 @@ public class UserAnonymizerService implements AnonymizerService<User> {
         }
 
         @Override
-        public Map<String, Set<String>> getAttributes() {
-            return new HashMap<String, Set<String>>(0);
+        public Map<String, String> getAttributes() {
+            return new HashMap<String, String>(0);
         }
 
         @Override
