@@ -57,6 +57,7 @@ import com.openexchange.contact.storage.ContactUserStorage;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.guest.GuestService;
+import com.openexchange.mail.service.MailService;
 import com.openexchange.share.ShareService;
 import com.openexchange.user.UserService;
 import com.openexchange.user.json.Constants;
@@ -107,6 +108,7 @@ public class UserJSONActivator extends AJAXModuleActivator {
             trackService(ContactUserStorage.class);
             trackService(ShareService.class);
             trackService(GuestService.class);
+            trackService(MailService.class);
             openTrackers();
         } catch (Exception e) {
             org.slf4j.LoggerFactory.getLogger(UserJSONActivator.class).error("Failed to start bundle {}", context.getBundle().getSymbolicName(), e);
