@@ -52,9 +52,10 @@ package com.openexchange.version;
 import com.openexchange.version.internal.Numbers;
 
 /**
- * Stores the version of the backend
+ * Stores the version of the Middleware.
  *
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+ * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a> JavaDoc
  */
 public class Version {
 
@@ -65,10 +66,50 @@ public class Version {
 
     public static final Version SINGLETON = new Version();
 
-    private Numbers numbers = null;
-    private String buildDate = null;
-    private String versionString = null;
+    /**
+     * Gets the version instance
+     *
+     * @return The version instance
+     */
+    public static final Version getInstance() {
+        return SINGLETON;
+    }
 
+    // -----------------------------------------------------------------------------------------------------------------
+
+    private volatile Numbers numbers = null;
+    private volatile String buildDate = null;
+    private volatile String versionString = null;
+
+    protected Version() {
+        super();
+    }
+
+    /**
+     * Sets the numbers for this version instance.
+     *
+     * @param numbers The number to set
+     */
+    public void setNumbers(Numbers numbers) {
+        this.numbers = numbers;
+        versionString = null;
+    }
+
+    /**
+     * Sets the build date for this version instance.
+     *
+     * @param buildDate The build date to set
+     */
+    public void setBuildDate(String buildDate) {
+        this.buildDate = buildDate;
+    }
+
+    /**
+     * Gets the build date.
+     *
+     * @return The build date
+     * @throws IllegalStateException if version instance is not yet initialized
+     */
     public String getBuildDate() {
         if (null == buildDate) {
             IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
@@ -78,18 +119,77 @@ public class Version {
         return buildDate;
     }
 
+    /**
+     * Gets the major number.
+     *
+     * @return The major number
+     * @throws IllegalStateException if version instance is not yet initialized
+     */
+    public int getMajor() {
+        if (null == numbers) {
+            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
+            LOG.error("", e);
+            throw e;
+        }
+        return numbers.getMajor();
+    }
+
+    /**
+     * Gets the minor number.
+     *
+     * @return The minor number
+     * @throws IllegalStateException if version instance is not yet initialized
+     */
+    public int getMinor() {
+        if (null == numbers) {
+            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
+            LOG.error("", e);
+            throw e;
+        }
+        return numbers.getMinor();
+    }
+
+    /**
+     * Gets the patch number.
+     *
+     * @return The patch number
+     * @throws IllegalStateException if version instance is not yet initialized
+     */
+    public int getPatch() {
+        if (null == numbers) {
+            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
+            LOG.error("", e);
+            throw e;
+        }
+        return numbers.getPatch();
+    }
+
+    /**
+     * Gets the version string; e.g. <code>"7.8.3-Rev2"</code>.
+     *
+     * @return The version string
+     * @throws IllegalStateException if version instance is not yet initialized
+     */
     public String getVersionString() {
-        synchronized (this) {
-            if (null == versionString) {
-                if (null == numbers) {
-                    IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
-                    LOG.error("", e);
-                    throw e;
+        String tmp = this.versionString;
+        if (null == tmp) {
+            // Acquire lock...
+            synchronized (this) {
+                // ... and try again
+                tmp = this.versionString;
+                if (null == tmp) {
+                    // Initialize version string
+                    if (null == numbers) {
+                        IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
+                        LOG.error("", e);
+                        throw e;
+                    }
+                    tmp = numbers.getVersion() + "-Rev" + numbers.getBuildNumber();
+                    this.versionString = tmp;
                 }
-                versionString = numbers.getVersion() + "-Rev" + numbers.getBuildNumber();
             }
         }
-        return versionString;
+        return tmp;
     }
 
     /**
@@ -101,46 +201,4 @@ public class Version {
         return versionString;
     }
 
-    public int getMajor() {
-        if (null == numbers) {
-            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
-            LOG.error("", e);
-            throw e;
-        }
-        return numbers.getMajor();
-    }
-
-    public int getMinor() {
-        if (null == numbers) {
-            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
-            LOG.error("", e);
-            throw e;
-        }
-        return numbers.getMinor();
-    }
-
-    public int getPatch() {
-        if (null == numbers) {
-            IllegalStateException e = new IllegalStateException("Central backend version not initialized yet.");
-            LOG.error("", e);
-            throw e;
-        }
-        return numbers.getPatch();
-    }
-
-    protected Version() {
-        super();
-    }
-
-    public static final Version getInstance() {
-        return SINGLETON;
-    }
-
-    public void setNumbers(Numbers numbers) {
-        this.numbers = numbers;
-    }
-
-    public void setBuildDate(String buildDate) {
-        this.buildDate = buildDate;
-    }
 }
