@@ -84,7 +84,7 @@ public class IMAPInputStream extends InputStream {
 				boolean peek) {
 	this.msg = msg;
 	this.section = section;
-	this.max = max;
+	this.max = max > 0 ? max : -1;
 	this.peek = peek;
 	pos = 0;
 	blksize = msg.getFetchBlockSize();
@@ -101,10 +101,10 @@ public class IMAPInputStream extends InputStream {
 		msg.getProtocol().noop();
 	    } catch (ConnectionException cex) {
 		throw new FolderClosedIOException(msg.getFolder(),
-						cex.getMessage());
+						cex.getMessage(), cex);
 	    } catch (FolderClosedException fex) {
 		throw new FolderClosedIOException(fex.getFolder(),
-						fex.getMessage());
+						fex.getMessage(), fex);
 	    } catch (ProtocolException pex) {
 		// ignore it
 	    }
@@ -210,7 +210,7 @@ public class IMAPInputStream extends InputStream {
      * the return value to insure that they have obtained the
      * requisite number of bytes.
      */
-    public synchronized int read(byte b[], int off, int len) 
+    public synchronized int read(byte b[], int off, int len)
 		throws IOException {
 
 	int avail = bufcount - bufpos;
