@@ -45,14 +45,16 @@ import java.lang.reflect.Constructor;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.StringTokenizer;
 import java.util.Vector;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicReference;
+import java.util.concurrent.locks.LockSupport;
 import java.util.logging.Level;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.Folder;
@@ -67,10 +69,10 @@ import javax.mail.URLName;
 import javax.mail.event.StoreEvent;
 import com.sun.mail.iap.BadCommandException;
 import com.sun.mail.iap.CommandFailedException;
-import com.sun.mail.iap.ConnectQuotaExceededException;
 import com.sun.mail.iap.ConnectionException;
 import com.sun.mail.iap.ProtocolException;
 import com.sun.mail.iap.Response;
+import com.sun.mail.iap.ResponseCode;
 import com.sun.mail.iap.ResponseHandler;
 import com.sun.mail.imap.protocol.IMAPProtocol;
 import com.sun.mail.imap.protocol.ListInfo;
@@ -199,34 +201,54 @@ public class IMAPStore extends Store
     public static final String ID_ARGUMENTS = "arguments";
     public static final String ID_ENVIRONMENT = "environment";
 
-    private static final class StampAndError {
-        final AuthenticationFailedException error;
-        final long stamp;
-        StampAndError(AuthenticationFailedException error, long stamp) {
-            super();
-            this.error = error;
-            this.stamp = stamp;
+    private static final AtomicReference<List<ProtocolListener>> PROTOCOL_LISTENERS_REF = new AtomicReference<List<ProtocolListener>>(null);
+
+    /**
+     * Adds specified protocol listener
+     * 
+     * @param protocolListener The protocol listener to add
+     */
+    public static synchronized void addProtocolListener(ProtocolListener protocolListener) {
+        if (null == protocolListener) {
+            return;
+        }
+
+        List<ProtocolListener> listeners = PROTOCOL_LISTENERS_REF.get();
+        if (null == listeners) {
+            listeners = new CopyOnWriteArrayList<>();
+            PROTOCOL_LISTENERS_REF.set(listeners);
+        }
+        listeners.add(protocolListener);
+    }
+
+    /**
+     * Removes specified protocol listener
+     * 
+     * @param protocolListener The protocol listener to remove
+     */
+    public static synchronized void removeProtocolListener(ProtocolListener protocolListener) {
+        if (null == protocolListener) {
+            return;
+        }
+        
+        List<ProtocolListener> listeners = PROTOCOL_LISTENERS_REF.get();
+        if (null == listeners) {
+            return;
+        }
+        
+        listeners.remove(protocolListener);
+        if (listeners.isEmpty()) {
+            PROTOCOL_LISTENERS_REF.set(null);
         }
     }
 
-    private static final ConcurrentMap<String, StampAndError> FAILED_AUTHS = new ConcurrentHashMap<String, StampAndError>(32);
-
     /**
-     * Clean-up cached failed authentication attempts occurred within specified timeout range.
-     *
-     * @param timeout The timeout
+     * Gets the currently available protocol listeners.
+     * 
+     * @return The protocol listeners or <code>null</code> if none registered
      */
-    public static void cleanUpFailedAuths(final long timeout) {
-        if (timeout <= 0) {
-            return;
-        }
-        final long maxStamp = System.currentTimeMillis() - timeout;
-        final ConcurrentMap<String, StampAndError> map = FAILED_AUTHS;
-        for (final Iterator<StampAndError> it = map.values().iterator(); it.hasNext();) {
-            if (it.next().stamp < maxStamp) {
-                it.remove();
-            }
-        }
+    public static List<ProtocolListener> getProtocolListeners() {
+        return PROTOCOL_LISTENERS_REF.get();
     }
 
     protected final String name;		// name of this protocol
@@ -272,7 +294,6 @@ public class IMAPStore extends Store
     private Map<String, String> clientParameters = null;
     private ExternalIdGenerator externalIdGenerator = null;
     private boolean failOnNOFetch = false;
-    private int authTimeout = -1;
     private final String guid;			// for Yahoo! Mail IMAP
     private boolean throwSearchException = false;
     private boolean peek = false;
@@ -672,17 +693,6 @@ public class IMAPStore extends Store
         logger.log(Level.CONFIG, "mail.imap.failOnNOFetch: {0}", failOnNOFetch);
     }
 
-    // check temporary down
-    s = session.getProperty("mail." + name + ".authTimeout");
-    if (s != null) {
-        try {
-            authTimeout = Integer.parseInt(s.trim());
-        } catch (NumberFormatException e) {
-            authTimeout = -1;
-        }
-        logger.log(Level.CONFIG, "mail.imap.authTimeout: {0}", authTimeout);
-    }
-
 	guid = session.getProperty("mail." + name + ".yahoo.guid");
 	if (guid != null) {
         logger.log(Level.CONFIG, "mail.imap.yahoo.guid: {0}", guid);
@@ -801,32 +811,6 @@ public class IMAPStore extends Store
         return null == clientParameters ? null : clientParameters.get(name);
     }
 
-    private void checkFailedAuths(String host, int port, String u, String pw) throws AuthenticationFailedException {
-        if (authTimeout <= 0 || null == host || null == u || null == pw) {
-            return;
-        }
-        
-        ConcurrentMap<String, StampAndError> map = FAILED_AUTHS;
-        String key = new StringBuilder(u).append(':').append(pw).append('@').append(host).append(':').append(port).toString();
-        StampAndError sae = map.get(key);
-        if (sae != null) {
-            if ((System.currentTimeMillis() - sae.stamp) <= authTimeout) {
-                throw new AuthenticationFailedException(sae.error.getMessage(), sae.error.getNextException());
-            }
-            map.remove(key);
-        }
-    }
-
-    private void rememberFailedAuths(String host, int port, String u, String pw, AuthenticationFailedException failedAuth) {
-        if (authTimeout <= 0 || null == host || null == u || null == pw) {
-            return;
-        }
-        
-        ConcurrentMap<String, StampAndError> map = FAILED_AUTHS;
-        String key = new StringBuilder(u).append(':').append(pw).append('@').append(host).append(':').append(port).toString();
-        map.put(key, new StampAndError(failedAuth, System.currentTimeMillis()));
-    }
-
     /**
      * Gets the generated external session identifier.
      *
@@ -877,9 +861,8 @@ public class IMAPStore extends Store
 	    port = defaultPort;
 	}
 
-	// Check for known failed authentication attempt
-	checkFailedAuths(host, port, user, password);
-
+	int retry = 0;
+	LoginAttempt: while (true) {
 	try {
             boolean poolEmpty;
             synchronized (pool) {
@@ -925,10 +908,36 @@ public class IMAPStore extends Store
             protocol.disconnect();
         }
 	    protocol = null;
-	    AuthenticationFailedException e = new AuthenticationFailedException(
-					cex.getResponse().getRest(), cex);
-	    rememberFailedAuths(host, port, user, password, e);
-	    throw e;
+
+	    // Check for possibly available response code
+	    ResponseCode responseCode = cex.getKnownResponseCode();
+	    if (null != responseCode) {
+	        // Verify login really failed due to an authentication/authorization issue
+            switch (responseCode) {
+                case AUTHENTICATIONFAILED:
+                    throw new AuthenticationFailedException(cex.getResponse().getRest(), cex);
+                case AUTHORIZATIONFAILED:
+                    throw new javax.mail.AuthorizationFailedException(cex.getResponse().getRest(), cex);
+                case UNAVAILABLE:
+                    if (++retry > 5) {
+                        throw new javax.mail.TemporaryAuthenticationFailureException(cex.getResponse().getRest(), cex);
+                    }
+
+                    long nanosToWait = TimeUnit.NANOSECONDS.convert((retry * 1000) + ((long) (Math.random() * 1000)), TimeUnit.MILLISECONDS);
+                    LockSupport.parkNanos(nanosToWait);
+                    continue LoginAttempt;
+                case EXPIRED:
+                    throw new javax.mail.PasswordExpiredException(cex.getResponse().getRest(), cex);
+                case PRIVACYREQUIRED:
+                    throw new javax.mail.PrivacyRequiredException(cex.getResponse().getRest(), cex);
+                default:
+                    throw new javax.mail.LoginFailedException(cex.getMessage(), cex);
+            }
+        }
+
+	    // No response code given... Assume an authentication/authorization issue
+	    Response offendingResponse = cex.getResponse();
+        throw new AuthenticationFailedException(null == offendingResponse ? cex.getMessage() : offendingResponse.getRest(), cex);
 	} catch (ProtocolException pex) { // any other exception
 	    // failure in login command, close connection to server
 	    if (protocol != null) {
@@ -941,8 +950,10 @@ public class IMAPStore extends Store
 	} catch (IOException ioex) {
 	    throw new MessagingException(ioex.getMessage(), ioex);
 	}
+	
 
         return true;
+	}
     }
 
     /**
@@ -959,7 +970,7 @@ public class IMAPStore extends Store
      */
     protected IMAPProtocol newIMAPProtocol(String host, int port, String user, String password)
 				throws IOException, ProtocolException {
-    return new IMAPProtocol(name, host, port,
+    return new IMAPProtocol(name, host, port, user,
             session.getProperties(),
             isSSL,
             logger
@@ -1930,6 +1941,24 @@ public class IMAPStore extends Store
     }
     }
 
+    /**
+     * Gets the remote IP address of the end-point this instance is connected to, or <code>null</code> if it is unconnected.
+     * 
+     * @return The remote IP address, or <code>null</code> if it is unconnected.
+     */
+    public synchronized java.net.InetAddress getRemoteAddress()
+        throws MessagingException {
+    IMAPProtocol p = null;
+    try {
+    p = getStoreProtocol();
+        return p.getRemoteAddress();
+    } catch (ProtocolException pex) {
+    throw new MessagingException(pex.getMessage(), pex);
+    } finally {
+        releaseStoreProtocol(p);
+    }
+    }
+
     /**
      * Check whether this store is connected. Override superclass
      * method, to actually ping our server connection.
