@@ -59,6 +59,7 @@ import javax.mail.MessagingException;
 import javax.mail.Session;
 import javax.mail.URLName;
 import javax.security.auth.Subject;
+import com.sun.mail.iap.CommandFailedException;
 import com.sun.mail.iap.ProtocolException;
 import com.sun.mail.imap.protocol.IMAPProtocol;
 import com.sun.mail.util.PropUtil;
@@ -151,7 +152,7 @@ public class JavaIMAPStore extends IMAPStore {
     @Override
     protected IMAPProtocol newIMAPProtocol(String host, int port, String user, String password) throws IOException, ProtocolException {
         if (count) {
-            return new CountingIMAPProtocol(name, host, port, session.getProperties(), isSSL, logger);
+            return new CountingIMAPProtocol(name, host, port, user, session.getProperties(), isSSL, logger);
         }
         return super.newIMAPProtocol(host, port, user, password);
     }
@@ -183,6 +184,10 @@ public class JavaIMAPStore extends IMAPStore {
                 @Override
                 public Object run() throws Exception {
                     p.sasllogin(saslMechanisms, m_saslRealm, authzid, u, pw);
+                    if (!p.isAuthenticated()) {
+                        throw new CommandFailedException(
+                                    "SASL authentication failed");
+                    }
                     return null;
                 }
             });
