@@ -81,6 +81,7 @@ import javax.mail.Session;
 import javax.mail.URLName;
 import javax.security.auth.Subject;
 import org.slf4j.Logger;
+import com.sun.mail.iap.CommandFailedException;
 import com.sun.mail.iap.ConnectQuotaExceededException;
 import com.sun.mail.iap.ProtocolException;
 import com.sun.mail.imap.protocol.IMAPProtocol;
@@ -343,7 +344,7 @@ public class QueuingIMAPStore extends IMAPStore {
                         return protocol;
                     }
                     // Create a new protocol instance
-                    protocol = new QueuedIMAPProtocol(name, host, port, session.getProperties(), isSSL, logger, q, this);
+                    protocol = new QueuedIMAPProtocol(name, host, port, user, session.getProperties(), isSSL, logger, q, this);
                     if (debug) {
                         final String msg = "\nQueueingIMAPStore.newIMAPProtocol(): Created new protocol instance " + protocol.toString() + "\n\t(total=" + q.getNewCount() + ")";
                         logger.fine(msg);
@@ -391,6 +392,10 @@ public class QueuingIMAPStore extends IMAPStore {
                 @Override
                 public Object run() throws Exception {
                     p.sasllogin(saslMechanisms, m_saslRealm, authzid, u, pw);
+                    if (!p.isAuthenticated()) {
+                        throw new CommandFailedException(
+                                    "SASL authentication failed");
+                    }
                     return null;
                 }
             });
