@@ -48,7 +48,7 @@ package javax.mail;
  * @author Bill Shannon
  */
 
-public class AuthenticationFailedException extends MessagingException {
+public class AuthenticationFailedException extends LoginFailedException {
 
     private static final long serialVersionUID = 492080754054436511L;
 
@@ -81,5 +81,4 @@ public class AuthenticationFailedException extends MessagingException {
     public AuthenticationFailedException(String message, Exception e) {
 	super(message, e);
     }
-
 }
