@@ -40,20 +40,31 @@
 
 package javax.mail;
 
-import java.lang.reflect.*;
-import java.io.*;
-import java.net.*;
-import java.security.*;
-import java.util.Enumeration;
+import java.io.BufferedInputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.PrintStream;
+import java.lang.reflect.Constructor;
+import java.net.InetAddress;
+import java.net.URL;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
+import java.security.PrivilegedActionException;
+import java.security.PrivilegedExceptionAction;
+import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.Hashtable;
+import java.util.List;
+import java.util.Map;
 import java.util.Properties;
+import java.util.ServiceLoader;
 import java.util.StringTokenizer;
-import java.util.Vector;
 import java.util.logging.Level;
 import java.util.concurrent.Executor;
 
-import javax.activation.*;
-
 import com.sun.mail.util.LineInputStream;
 import com.sun.mail.util.MailLogger;
 
@@ -151,6 +162,29 @@ import com.sun.mail.util.MailLogger;
  * protocol=smtp; type=transport; class=com.sun.mail.smtp.SMTPTransport; vendor=Oracle;
  * </pre><p>
  *
+ * The current implementation also supports configuring providers using
+ * the Java SE {@link java.util.ServiceLoader ServiceLoader} mechanism.
+ * When creating your own provider, create a {@link Provider} subclass,
+ * for example:
+ * <pre>
+ * package com.example;
+ *
+ * import javax.mail.Provider;
+ *
+ * public class MyProvider extends Provider {
+ *     public MyProvider() {
+ *         super(Provider.Type.STORE, "myprot", MyStore.class.getName(),
+ *             "Example", null);
+ *     }
+ * }
+ * </pre>
+ * Then include a file named <code>META-INF/services/javax.mail.Provider</code>
+ * in your jar file that lists the name of your Provider class:
+ * <pre>
+ * com.example.MyProvider
+ * </pre>
+ * <p>
+ *
  * <b><code>javamail.address.map</code></b> and
  * <b><code>javamail.default.address.map</code></b><p>
  *
@@ -189,13 +223,12 @@ public final class Session {
     private boolean debug = false;
     private PrintStream out;			// debug output stream
     private MailLogger logger;
-    private final Vector<Provider> providers = new Vector<Provider>();
-    private final Hashtable<String, Provider> providersByProtocol
-	    = new Hashtable<String, Provider>();
-    private final Hashtable<String, Provider> providersByClassName
-	    = new Hashtable<String, Provider>();
+    private List<Provider> providers;
+    private final Map<String, Provider> providersByProtocol = new HashMap<>();
+    private final Map<String, Provider> providersByClassName = new HashMap<>();
     private final Properties addressMap = new Properties();
 						// maps type to protocol
+    private boolean loadedProviders;    // javamail.[default.]providers loaded?
     // the queue of events to be delivered, if mail.event.scope===session
     private final EventQueue q;
 
@@ -207,20 +240,21 @@ public final class Session {
 	this.props = props;
 	this.authenticator = authenticator;
 
-	if (Boolean.valueOf(props.getProperty("mail.debug")).booleanValue())
-	    debug = true;
+	if (Boolean.valueOf(props.getProperty("mail.debug")).booleanValue()) {
+        debug = true;
+    }
 
 	initLogger();
 	logger.log(Level.CONFIG, "JavaMail version {0}", "1.5.6");
 
 	// get the Class associated with the Authenticator
 	Class<?> cl;
-	if (authenticator != null)
-	    cl = authenticator.getClass();
-	else
-	    cl = this.getClass();
+	if (authenticator != null) {
+        cl = authenticator.getClass();
+    } else {
+        cl = this.getClass();
+    }
 	// load the resources
-	loadProviders(cl);
 	loadAddressMap(cl);
 	q = new EventQueue((Executor)props.get("mail.event.executor"));
     }
@@ -235,9 +269,9 @@ public final class Session {
      * @param	props	Properties object that hold relevant properties.<br>
      *                  It is expected that the client supplies values
      *                  for the properties listed in Appendix A of the
-     *                  JavaMail spec (particularly  mail.store.protocol, 
-     *                  mail.transport.protocol, mail.host, mail.user, 
-     *                  and mail.from) as the defaults are unlikely to 
+     *                  JavaMail spec (particularly  mail.store.protocol,
+     *                  mail.transport.protocol, mail.host, mail.user,
+     *                  and mail.from) as the defaults are unlikely to
      *                  work in all cases.
      * @param	authenticator Authenticator object used to call back to
      *			the application when a user name and password is
@@ -256,9 +290,9 @@ public final class Session {
      * @param	props	Properties object that hold relevant properties.<br>
      *                  It is expected that the client supplies values
      *                  for the properties listed in Appendix A of the
-     *                  JavaMail spec (particularly  mail.store.protocol, 
-     *                  mail.transport.protocol, mail.host, mail.user, 
-     *                  and mail.from) as the defaults are unlikely to 
+     *                  JavaMail spec (particularly  mail.store.protocol,
+     *                  mail.transport.protocol, mail.host, mail.user,
+     *                  and mail.from) as the defaults are unlikely to
      *                  work in all cases.
      * @return		a new Session object
      * @since		JavaMail 1.2
@@ -269,7 +303,7 @@ public final class Session {
 
     /**
      * Get the default Session object. If a default has not yet been
-     * setup, a new Session object is created and installed as the 
+     * setup, a new Session object is created and installed as the
      * default. <p>
      *
      * Since the default session is potentially available to all
@@ -305,12 +339,12 @@ public final class Session {
      *			object is created.<br>
      *                  It is expected that the client supplies values
      *                  for the properties listed in Appendix A of the
-     *                  JavaMail spec (particularly  mail.store.protocol, 
-     *                  mail.transport.protocol, mail.host, mail.user, 
-     *                  and mail.from) as the defaults are unlikely to 
+     *                  JavaMail spec (particularly  mail.store.protocol,
+     *                  mail.transport.protocol, mail.host, mail.user,
+     *                  and mail.from) as the defaults are unlikely to
      *                  work in all cases.
      * @param	authenticator Authenticator object.  Used only if a
-     *			new Session object is created.  Otherwise, 
+     *			new Session object is created.  Otherwise,
      *			it must match the Authenticator used to create
      *			the Session.
      * @return		the default Session object
@@ -319,21 +353,23 @@ public final class Session {
 					Authenticator authenticator) {
 	if (defaultSession == null) {
 	    SecurityManager security = System.getSecurityManager();
-	    if (security != null)
-		security.checkSetFactory();
+	    if (security != null) {
+            security.checkSetFactory();
+        }
 	    defaultSession = new Session(props, authenticator);
 	} else {
 	    // have to check whether caller is allowed to see default session
-	    if (defaultSession.authenticator == authenticator)
-		;	// either same object or both null, either way OK
-	    else if (defaultSession.authenticator != null &&
+	    if (defaultSession.authenticator == authenticator) {
+            ;	// either same object or both null, either way OK
+        } else if (defaultSession.authenticator != null &&
 		    authenticator != null &&
 		    defaultSession.authenticator.getClass().getClassLoader() ==
-			authenticator.getClass().getClassLoader())
-		;	// both objects came from the same class loader, OK
-	    else
-		// anything else is not allowed
-		throw new SecurityException("Access to default session denied");
+			authenticator.getClass().getClassLoader()) {
+            ;	// both objects came from the same class loader, OK
+        } else {
+            // anything else is not allowed
+            throw new SecurityException("Access to default session denied");
+        }
 	}
 
 	return defaultSession;
@@ -341,7 +377,7 @@ public final class Session {
 
     /**
      * Get the default Session object. If a default has not yet been
-     * setup, a new Session object is created and installed as the 
+     * setup, a new Session object is created and installed as the
      * default. <p>
      *
      * Note that a default session created with no Authenticator is
@@ -353,9 +389,9 @@ public final class Session {
      *			object is created.<br>
      *                  It is expected that the client supplies values
      *                  for the properties listed in Appendix A of the
-     *                  JavaMail spec (particularly  mail.store.protocol, 
-     *                  mail.transport.protocol, mail.host, mail.user, 
-     *                  and mail.from) as the defaults are unlikely to 
+     *                  JavaMail spec (particularly  mail.store.protocol,
+     *                  mail.transport.protocol, mail.host, mail.user,
+     *                  and mail.from) as the defaults are unlikely to
      *                  work in all cases.
      * @return		the default Session object
      * @since		JavaMail 1.2
@@ -418,22 +454,38 @@ public final class Session {
      * @since		JavaMail 1.3
      */
     public synchronized PrintStream getDebugOut() {
-	if (out == null)
-	    return System.out;
-	else
-	    return out;
+	if (out == null) {
+        return System.out;
+    } else {
+        return out;
+    }
     }
 
     /**
-     * This method returns an array of all the implementations installed 
+     * This method returns an array of all the implementations installed
      * via the javamail.[default.]providers files that can
      * be loaded using the ClassLoader available to this application.
      *
      * @return Array of configured providers
      */
     public synchronized Provider[] getProviders() {
-	Provider[] _providers = new Provider[providers.size()];
-	providers.copyInto(_providers);
+    List<Provider> plist = new ArrayList<Provider>();
+    boolean needFallback = true;
+    // first, add all the services
+    ServiceLoader<Provider> loader = ServiceLoader.load(Provider.class);
+    for (Provider p : loader) {
+        plist.add(p);
+        needFallback = false;
+    }
+    // then, add all the providers from config files
+    if (!loadedProviders) {
+        loadProviders(needFallback);
+    }
+    if (providers != null) {
+        plist.addAll(providers);
+    }
+    Provider[] _providers = new Provider[plist.size()];
+    plist.toArray(_providers);
 	return _providers;
     }
 
@@ -441,9 +493,9 @@ public final class Session {
      * Returns the default Provider for the protocol
      * specified. Checks mail.&lt;protocol&gt;.class property
      * first and if it exists, returns the Provider
-     * associated with this implementation. If it doesn't exist, 
-     * returns the Provider that appeared first in the 
-     * configuration files. If an implementation for the protocol 
+     * associated with this implementation. If it doesn't exist,
+     * returns the Provider that appeared first in the
+     * configuration files. If an implementation for the protocol
      * isn't found, throws NoSuchProviderException
      *
      * @param  protocol  Configured protocol (i.e. smtp, imap, etc)
@@ -465,19 +517,16 @@ public final class Session {
 	if (_className != null) {
 	    if (logger.isLoggable(Level.FINE)) {
 		logger.fine("mail."+protocol+
-				   ".class property exists and points to " + 
+				   ".class property exists and points to " +
 				   _className);
 	    }
-	    _provider = providersByClassName.get(_className);
-	} 
-
-	if (_provider != null) {
-	    return _provider;
-	} else {
-	    // returning currently default protocol in providersByProtocol
-	    _provider = providersByProtocol.get(protocol);
+	    _provider = getProviderByClassName(_className);
 	}
 
+	if (_provider == null) {
+        _provider = getProviderByProtocol(protocol);
+    }
+
 	if (_provider == null) {
 	    throw new NoSuchProviderException("No provider for " + protocol);
 	} else {
@@ -492,7 +541,7 @@ public final class Session {
      * Set the passed Provider to be the default implementation
      * for the protocol in Provider.protocol overriding any previous values.
      *
-     * @param provider Currently configured Provider which will be 
+     * @param provider Currently configured Provider which will be
      * set as the default for the protocol
      * @exception	NoSuchProviderException If the provider passed in
      *			is invalid.
@@ -503,7 +552,8 @@ public final class Session {
 	    throw new NoSuchProviderException("Can't set null provider");
 	}
 	providersByProtocol.put(provider.getProtocol(), provider);
-	props.put("mail." + provider.getProtocol() + ".class", 
+	providersByClassName.put(provider.getClassName(), provider);
+	props.put("mail." + provider.getProtocol() + ".class",
 		  provider.getClassName());
     }
 
@@ -511,10 +561,10 @@ public final class Session {
     /**
      * Get a Store object that implements this user's desired Store
      * protocol. The <code>mail.store.protocol</code> property specifies the
-     * desired protocol. If an appropriate Store object is not obtained, 
+     * desired protocol. If an appropriate Store object is not obtained,
      * NoSuchProviderException is thrown
      *
-     * @return 		a Store object 
+     * @return 		a Store object
      * @exception	NoSuchProviderException If a provider for the given
      *			protocol is not found.
      */
@@ -524,11 +574,11 @@ public final class Session {
 
     /**
      * Get a Store object that implements the specified protocol. If an
-     * appropriate Store object cannot be obtained, 
+     * appropriate Store object cannot be obtained,
      * NoSuchProviderException is thrown.
      *
      * @param	        protocol	the Store protocol
-     * @return		a Store object 
+     * @return		a Store object
      * @exception	NoSuchProviderException If a provider for the given
      *			protocol is not found.
      */
@@ -541,7 +591,7 @@ public final class Session {
      * Get a Store object for the given URLName. If the requested Store
      * object cannot be obtained, NoSuchProviderException is thrown.
      *
-     * The "scheme" part of the URL string (Refer RFC 1738) is used 
+     * The "scheme" part of the URL string (Refer RFC 1738) is used
      * to locate the Store protocol. <p>
      *
      * @param	url	URLName that represents the desired Store
@@ -560,7 +610,7 @@ public final class Session {
     /**
      * Get an instance of the store specified by Provider. Instantiates
      * the store and returns it.
-     * 
+     *
      * @param provider Store Provider that will be instantiated
      * @return Instantiated Store
      * @exception	NoSuchProviderException If a provider for the given
@@ -576,14 +626,14 @@ public final class Session {
      * is not null, uses it, otherwise creates a new one. Instantiates
      * the store and returns it. This is a private method used by
      * getStore(Provider) and getStore(URLName)
-     * 
+     *
      * @param provider Store Provider that will be instantiated
      * @param url      URLName used to instantiate the Store
      * @return Instantiated Store
      * @exception	NoSuchProviderException If a provider for the given
      *			Provider/URLName is not found.
      */
-    private Store getStore(Provider provider, URLName url) 
+    private Store getStore(Provider provider, URLName url)
 	throws NoSuchProviderException {
 
 	// make sure we have the correct type of provider
@@ -604,7 +654,7 @@ public final class Session {
      * in a protocol dependent manner to locate and instantiate the
      * appropriate Folder object. <p>
      *
-     * Note that RFC 1738 also specifies the syntax for the 
+     * Note that RFC 1738 also specifies the syntax for the
      * "schemepart" for IP-based protocols (IMAP4, POP3, etc.).
      * Providers of IP-based mail Stores should implement that
      * syntax for referring to Folders. <p>
@@ -615,7 +665,7 @@ public final class Session {
      * @see		javax.mail.URLName
      * @exception	NoSuchProviderException If a provider for the given
      *			URLName is not found.
-     * @exception	MessagingException if the Folder could not be 
+     * @exception	MessagingException if the Folder could not be
      *			located or created.
      */
     public Folder getFolder(URLName url)
@@ -627,22 +677,24 @@ public final class Session {
     }
 
     /**
-     * Get a Transport object that implements this user's desired 
-     * Transport protcol. The <code>mail.transport.protocol</code> property 
-     * specifies the desired protocol. If an appropriate Transport 
+     * Get a Transport object that implements this user's desired
+     * Transport protcol. The <code>mail.transport.protocol</code> property
+     * specifies the desired protocol. If an appropriate Transport
      * object cannot be obtained, MessagingException is thrown.
      *
-     * @return 		a Transport object 
+     * @return 		a Transport object
      * @exception	NoSuchProviderException If the provider is not found.
      */
     public Transport getTransport() throws NoSuchProviderException {
 	String prot = getProperty("mail.transport.protocol");
-	if (prot != null)
-	    return getTransport(prot);
+	if (prot != null) {
+        return getTransport(prot);
+    }
 	// if the property isn't set, use the protocol for "rfc822"
 	prot = (String)addressMap.get("rfc822");
-	if (prot != null)
-	    return getTransport(prot);
+	if (prot != null) {
+        return getTransport(prot);
+    }
 	return getTransport("smtp");	// if all else fails
     }
 
@@ -652,7 +704,7 @@ public final class Session {
      * returned.
      *
      * @param	protocol the Transport protocol
-     * @return 		a Transport object 
+     * @return 		a Transport object
      * @exception	NoSuchProviderException If provider for the given
      *			protocol is not found.
      */
@@ -663,10 +715,10 @@ public final class Session {
 
 
     /**
-     * Get a Transport object for the given URLName. If the requested 
+     * Get a Transport object for the given URLName. If the requested
      * Transport object cannot be obtained, NoSuchProviderException is thrown.
      *
-     * The "scheme" part of the URL string (Refer RFC 1738) is used 
+     * The "scheme" part of the URL string (Refer RFC 1738) is used
      * to locate the Transport protocol. <p>
      *
      * @param	url	URLName that represents the desired Transport
@@ -684,13 +736,13 @@ public final class Session {
     /**
      * Get an instance of the transport specified in the Provider. Instantiates
      * the transport and returns it.
-     * 
+     *
      * @param provider Transport Provider that will be instantiated
      * @return Instantiated Transport
      * @exception	NoSuchProviderException If provider for the given
      *			provider is not found.
      */
-    public Transport getTransport(Provider provider) 
+    public Transport getTransport(Provider provider)
 	                                     throws NoSuchProviderException {
 	return getTransport(provider, null);
     }
@@ -702,20 +754,22 @@ public final class Session {
      * @param	address	an address for which a Transport is needed
      * @return	A Transport object
      * @see javax.mail.Address
-     * @exception	NoSuchProviderException If provider for the 
+     * @exception	NoSuchProviderException If provider for the
      *			Address type is not found
      */
-    public Transport getTransport(Address address) 
+    public Transport getTransport(Address address)
 	                                     throws NoSuchProviderException {
 
 	String transportProtocol;
 	transportProtocol =
 	    getProperty("mail.transport.protocol." + address.getType());
-	if (transportProtocol != null)
-	    return getTransport(transportProtocol);
+	if (transportProtocol != null) {
+        return getTransport(transportProtocol);
+    }
 	transportProtocol = (String)addressMap.get(address.getType());
-	if (transportProtocol != null)
-	    return getTransport(transportProtocol);
+	if (transportProtocol != null) {
+        return getTransport(transportProtocol);
+    }
 	throw new NoSuchProviderException("No provider for Address type: "+
 						address.getType());
     }
@@ -727,7 +781,7 @@ public final class Session {
      * @param	url		urlname to use (can be null)
      * @return A Transport object
      * @exception	NoSuchProviderException	If no provider or the provider
-     *			was the wrong class.	
+     *			was the wrong class.
      */
 
     private Transport getTransport(Provider provider, URLName url)
@@ -763,47 +817,52 @@ public final class Session {
 
 	// create a url if needed
 	if (url == null) {
-	    url = new URLName(provider.getProtocol(), null, -1, 
+	    url = new URLName(provider.getProtocol(), null, -1,
 			      null, null, null);
 	}
 
 	Object service = null;
-	
+
 	// get the ClassLoader associated with the Authenticator
 	ClassLoader cl;
-	if (authenticator != null)
-	    cl = authenticator.getClass().getClassLoader();
-	else
-	    cl = this.getClass().getClassLoader();
+	if (authenticator != null) {
+        cl = authenticator.getClass().getClassLoader();
+    } else {
+        cl = this.getClass().getClassLoader();
+    }
 
 	// now load the class
 	Class<?> serviceClass = null;
 	try {
 	    // First try the "application's" class loader.
 	    ClassLoader ccl = getContextClassLoader();
-	    if (ccl != null)
-		try {
-		    serviceClass =
-			Class.forName(provider.getClassName(), false, ccl);
-		} catch (ClassNotFoundException ex) {
-		    // ignore it
-		}
-	    if (serviceClass == null || !type.isAssignableFrom(serviceClass))
-		serviceClass =
-		    Class.forName(provider.getClassName(), false, cl);
-            
-	    if (!type.isAssignableFrom(serviceClass))
-		throw new ClassCastException(
-				type.getName() + " " + serviceClass.getName());
+	    if (ccl != null) {
+            try {
+                serviceClass =
+            	Class.forName(provider.getClassName(), false, ccl);
+            } catch (ClassNotFoundException ex) {
+                // ignore it
+            }
+        }
+	    if (serviceClass == null || !type.isAssignableFrom(serviceClass)) {
+            serviceClass =
+                Class.forName(provider.getClassName(), false, cl);
+        }
+
+	    if (!type.isAssignableFrom(serviceClass)) {
+            throw new ClassCastException(
+            		type.getName() + " " + serviceClass.getName());
+        }
 	} catch (Exception ex1) {
 	    // That didn't work, now try the "system" class loader.
 	    // (Need both of these because JDK 1.1 class loaders
 	    // may not delegate to their parent class loader.)
 	    try {
 		serviceClass = Class.forName(provider.getClassName());
-		if (!type.isAssignableFrom(serviceClass))
-		    throw new ClassCastException(
+		if (!type.isAssignableFrom(serviceClass)) {
+            throw new ClassCastException(
 				type.getName() + " " + serviceClass.getName());
+        }
 	    } catch (Exception ex) {
 		// Nothing worked, give up.
 		logger.log(Level.FINE, "Exception loading provider", ex);
@@ -840,10 +899,11 @@ public final class Session {
      */
     public void setPasswordAuthentication(URLName url,
 					  PasswordAuthentication pw) {
-	if (pw == null)
-	    authTable.remove(url);
-	else
-	    authTable.put(url, pw);
+	if (pw == null) {
+        authTable.remove(url);
+    } else {
+        authTable.put(url, pw);
+    }
     }
 
     /**
@@ -874,7 +934,7 @@ public final class Session {
      * @param	prompt		any additional String to show as part of
      *                          the prompt; may be null.
      * @param	defaultUserName	the default username. may be null.
-     * @return	the authentication which was collected by the authenticator; 
+     * @return	the authentication which was collected by the authenticator;
      *          may be null.
      */
     public PasswordAuthentication requestPasswordAuthentication(
@@ -894,8 +954,8 @@ public final class Session {
      *
      * @return		Properties object
      */
-    public Properties getProperties() { 
-   	return props; 
+    public Properties getProperties() {
+   	return props;
     }
 
     /**
@@ -905,15 +965,75 @@ public final class Session {
      * @param	name	the property name
      * @return		String that is the property value
      */
-    public String getProperty(String name) { 
-   	return props.getProperty(name); 
+    public String getProperty(String name) {
+   	return props.getProperty(name);
+    }
+
+    /**
+     * Get the Provider that uses the specified class name.
+     *
+     * @param   className   the class name
+     * @return      the Provider
+     */
+    private Provider getProviderByClassName(String className) {
+    // first, try our local list of providers
+    Provider p = providersByClassName.get(className);
+    if (p != null) {
+        return p;
+    }
+
+    // now, try services
+    ServiceLoader<Provider> loader = ServiceLoader.load(Provider.class);
+    for (Provider pp : loader) {
+        if (className.equals(pp.getClassName())) {
+            return pp;
+        }
+    }
+
+    // finally, if we haven't loaded our config, load it and try again
+    if (!loadedProviders) {
+        loadProviders(true);
+        p = providersByClassName.get(className);
+    }
+    return p;
+    }
+
+    /**
+     * Get the Provider for the specified protocol.
+     *
+     * @param   protocol    the protocol
+     * @return      the Provider
+     */
+    private Provider getProviderByProtocol(String protocol) {
+    // first, try our local list of providers
+    Provider p = providersByProtocol.get(protocol);
+    if (p != null) {
+        return p;
+    }
+
+    // now, try services
+    ServiceLoader<Provider> loader = ServiceLoader.load(Provider.class);
+    for (Provider pp : loader) {
+        if (protocol.equals(pp.getProtocol())) {
+            return pp;
+        }
+    }
+
+    // finally, if we haven't loaded our config, load it and try again
+    if (!loadedProviders) {
+        loadProviders(true);
+        p = providersByProtocol.get(protocol);
+    }
+    return p;
     }
 
     /**
      * Load the protocol providers config files.
+     * If fallback is true, provide built in defaults if nothing is loaded.
      */
-    private void loadProviders(Class<?> cl) {
-	StreamLoader loader = new StreamLoader() {
+    private void loadProviders(boolean fallback) {
+    StreamLoader loader = new StreamLoader() {
+	    @Override
 	    public void load(InputStream is) throws IOException {
 		loadProvidersFromStream(is);
 	    }
@@ -921,21 +1041,33 @@ public final class Session {
 
 	// load system-wide javamail.providers from the <java.home>/lib dir
 	try {
-	    String res = System.getProperty("java.home") + 
-				File.separator + "lib" + 
+	    String res = System.getProperty("java.home") +
+				File.separator + "lib" +
 				File.separator + "javamail.providers";
 	    loadFile(res, loader);
 	} catch (SecurityException sex) {
 	    logger.log(Level.CONFIG, "can't get java.home", sex);
 	}
 
+	// get the Class associated with the Authenticator
+    Class<?> cl;
+    if (authenticator != null) {
+        cl = authenticator.getClass();
+    } else {
+        cl = this.getClass();
+    }
+
 	// load the META-INF/javamail.providers file supplied by an application
 	loadAllResources("META-INF/javamail.providers", cl, loader);
 
 	// load default META-INF/javamail.default.providers from mail.jar file
 	loadResource("/META-INF/javamail.default.providers", cl, loader);
 
-	if (providers.size() == 0) {
+	/*
+     * If we haven't loaded any providers and the fallback configuration
+     * is needed, fake it.
+     */
+    if ((providers == null || providers.size() == 0) && fallback) {
 	    logger.config("failed to load any providers, using defaults");
 	    // failed to load any providers, initialize with our defaults
 	    addProvider(new Provider(Provider.Type.STORE,
@@ -955,20 +1087,27 @@ public final class Session {
 			"Oracle", "1.5.6"));
 	    addProvider(new Provider(Provider.Type.TRANSPORT,
 			"smtps", "com.sun.mail.smtp.SMTPSSLTransport",
-			"Oracle", "1.5.6"));
+			"Oracle", "1.6.1"));
+	    addProvider(new Provider(Provider.Type.STORE,
+            "gimap", "com.sun.mail.gimap.GmailStore",
+            "Oracle", "1.6.1"));
+        addProvider(new Provider(Provider.Type.STORE,
+            "gimap", "com.sun.mail.gimap.GmailSSLStore",
+            "Oracle", "1.6.1"));
 	}
 
 	if (logger.isLoggable(Level.CONFIG)) {
 	    // dump the output of the tables for debugging
-	    logger.config("Tables of loaded providers");
-	    logger.config("Providers Listed By Class Name: " + 
+	    logger.config("Tables of loaded providers from javamail.providers");
+	    logger.config("Providers Listed By Class Name: " +
 	       providersByClassName.toString());
-	    logger.config("Providers Listed By Protocol: " + 
+	    logger.config("Providers Listed By Protocol: " +
 	       providersByProtocol.toString());
 	}
+	loadedProviders = true;
     }
 
-    private void loadProvidersFromStream(InputStream is) 
+    private void loadProvidersFromStream(InputStream is)
 				throws IOException {
 	if (is != null) {
 	    LineInputStream lis = new LineInputStream(is);
@@ -977,17 +1116,18 @@ public final class Session {
 	    // load and process one line at a time using LineInputStream
 	    while ((currLine = lis.readLine()) != null) {
 
-		if (currLine.startsWith("#"))
-		    continue;
+		if (currLine.startsWith("#")) {
+            continue;
+        }
 		Provider.Type type = null;
 		String protocol = null, className = null;
 		String vendor = null, version = null;
-		    
+
 		// separate line into key-value tuples
 		StringTokenizer tuples = new StringTokenizer(currLine,";");
 		while (tuples.hasMoreTokens()) {
 		    String currTuple = tuples.nextToken().trim();
-			
+
 		    // set the value of each attribute based on its key
 		    int sep = currTuple.indexOf("=");
 		    if (currTuple.startsWith("protocol=")) {
@@ -1009,9 +1149,9 @@ public final class Session {
 		}
 
 		// check if a valid Provider; else, continue
-		if (type == null || protocol == null || className == null 
+		if (type == null || protocol == null || className == null
 		    || protocol.length() <= 0 || className.length() <= 0) {
-			
+
 		    logger.log(Level.CONFIG, "Bad provider entry: {0}",
 						currLine);
 		    continue;
@@ -1032,17 +1172,22 @@ public final class Session {
      * @since	JavaMail 1.4
      */
     public synchronized void addProvider(Provider provider) {
-	providers.addElement(provider);
+    if (providers == null) {
+        providers = new ArrayList<Provider>();
+    }
+    providers.add(provider);
 	providersByClassName.put(provider.getClassName(), provider);
-	if (!providersByProtocol.containsKey(provider.getProtocol()))
-	    providersByProtocol.put(provider.getProtocol(), provider);
+	if (!providersByProtocol.containsKey(provider.getProtocol())) {
+        providersByProtocol.put(provider.getProtocol(), provider);
+    }
     }
 
     // load maps in reverse order of preference so that the preferred
     // map is loaded last since its entries will override the previous ones
     private void loadAddressMap(Class<?> cl) {
 	StreamLoader loader = new StreamLoader() {
-	    public void load(InputStream is) throws IOException {
+	    @Override
+        public void load(InputStream is) throws IOException {
 		addressMap.load(is);
 	    }
 	};
@@ -1055,8 +1200,8 @@ public final class Session {
 
 	// load system-wide javamail.address.map from the <java.home>/lib dir
 	try {
-	    String res = System.getProperty("java.home") + 
-				File.separator + "lib" + 
+	    String res = System.getProperty("java.home") +
+				File.separator + "lib" +
 				File.separator + "javamail.address.map";
 	    loadFile(res, loader);
 	} catch (SecurityException sex) {
@@ -1082,10 +1227,11 @@ public final class Session {
      */
     public synchronized void setProtocolForAddress(String addresstype,
 				String protocol) {
-	if (protocol == null)
-	    addressMap.remove(addresstype);
-	else
-	    addressMap.put(addresstype, protocol);
+	if (protocol == null) {
+        addressMap.remove(addresstype);
+    } else {
+        addressMap.put(addresstype, protocol);
+    }
     }
 
     /**
@@ -1100,15 +1246,18 @@ public final class Session {
 	} catch (FileNotFoundException fex) {
 	    // ignore it
 	} catch (IOException e) {
-	    if (logger.isLoggable(Level.CONFIG))
-		logger.log(Level.CONFIG, "not loading file: " + name, e);
+	    if (logger.isLoggable(Level.CONFIG)) {
+            logger.log(Level.CONFIG, "not loading file: " + name, e);
+        }
 	} catch (SecurityException sex) {
-	    if (logger.isLoggable(Level.CONFIG))
-		logger.log(Level.CONFIG, "not loading file: " + name, sex);
+	    if (logger.isLoggable(Level.CONFIG)) {
+            logger.log(Level.CONFIG, "not loading file: " + name, sex);
+        }
 	} finally {
 	    try {
-		if (clis != null)
-		    clis.close();
+		if (clis != null) {
+            clis.close();
+        }
 	    } catch (IOException ex) { }	// ignore it
 	}
     }
@@ -1135,8 +1284,9 @@ public final class Session {
 	    logger.log(Level.CONFIG, "Exception loading resource", sex);
 	} finally {
 	    try {
-		if (clis != null)
-		    clis.close();
+		if (clis != null) {
+            clis.close();
+        }
 	    } catch (IOException ex) { }	// ignore it
 	}
     }
@@ -1151,12 +1301,14 @@ public final class Session {
 	    ClassLoader cld = null;
 	    // First try the "application's" class loader.
 	    cld = getContextClassLoader();
-	    if (cld == null)
-		cld = cl.getClassLoader();
-	    if (cld != null)
-		urls = getResources(cld, name);
-	    else
-		urls = getSystemResources(name);
+	    if (cld == null) {
+            cld = cl.getClassLoader();
+        }
+	    if (cld != null) {
+            urls = getResources(cld, name);
+        } else {
+            urls = getSystemResources(name);
+        }
 	    if (urls != null) {
 		for (int i = 0; i < urls.length; i++) {
 		    URL url = urls[i];
@@ -1183,8 +1335,9 @@ public final class Session {
 				    sex);
 		    } finally {
 			try {
-			    if (clis != null)
-				clis.close();
+			    if (clis != null) {
+                    clis.close();
+                }
 			} catch (IOException cex) { }
 		    }
 		}
@@ -1209,7 +1362,8 @@ public final class Session {
     static ClassLoader getContextClassLoader() {
 	return AccessController.doPrivileged(
 		new PrivilegedAction<ClassLoader>() {
-		    public ClassLoader run() {
+		    @Override
+            public ClassLoader run() {
 			ClassLoader cl = null;
 			try {
 			    cl = Thread.currentThread().getContextClassLoader();
@@ -1226,7 +1380,8 @@ public final class Session {
 	try {
 	    return AccessController.doPrivileged(
 		    new PrivilegedExceptionAction<InputStream>() {
-			public InputStream run() throws IOException {
+			@Override
+            public InputStream run() throws IOException {
 			    try {
 				return c.getResourceAsStream(name);
 			    } catch (RuntimeException e) {
@@ -1246,7 +1401,8 @@ public final class Session {
 
     private static URL[] getResources(final ClassLoader cl, final String name) {
 	return AccessController.doPrivileged(new PrivilegedAction<URL[]>() {
-	    public URL[] run() {
+	    @Override
+        public URL[] run() {
 		URL[] ret = null;
 		try {
 		    java.util.List<URL> v = java.util.Collections.list(cl.getResources(name));
@@ -1263,7 +1419,8 @@ public final class Session {
 
     private static URL[] getSystemResources(final String name) {
 	return AccessController.doPrivileged(new PrivilegedAction<URL[]>() {
-	    public URL[] run() {
+	    @Override
+        public URL[] run() {
 		URL[] ret = null;
 		try {
 		    java.util.List<URL> v = java.util.Collections.list(
@@ -1283,7 +1440,8 @@ public final class Session {
 	try {
 	    return AccessController.doPrivileged(
 		    new PrivilegedExceptionAction<InputStream>() {
-			public InputStream run() throws IOException {
+			@Override
+            public InputStream run() throws IOException {
 			    return url.openStream();
 			}
 		    }
