@@ -145,7 +145,8 @@ public class InternetHeaders {
 	/**
 	 * Return the "value" part of the header line.
 	 */
-	public String getValue() {
+	@Override
+    public String getValue() {
 	    int i = line.indexOf(':');
 	    if (i < 0)
 		return line;
@@ -298,14 +299,12 @@ public class InternetHeaders {
      *
      * @since	JavaMail 1.4
      */
-    @SuppressWarnings("rawtypes")
-    protected List headers;
+    protected List<InternetHeader> headers;
 
     /**
      * Create an empty InternetHeaders object.  Placeholder entries
      * are inserted to indicate the preferred order of headers.
      */
-    @SuppressWarnings("unchecked")
     public InternetHeaders() { 
    	headers = new ArrayList<InternetHeader>(40); 
 	headers.add(new InternetHeader("Return-Path", null));
@@ -506,7 +505,6 @@ public class InternetHeaders {
      * @return		array of header values, or null if none
      */
     public String[] getHeader(String name) {
-	@SuppressWarnings("unchecked")
 	Iterator<InternetHeader> e = headers.iterator();
 	// XXX - should we just step through in index order?
 	List<String> v = new ArrayList<String>(); // accumulate return values
@@ -554,6 +552,107 @@ public class InternetHeaders {
 	return r.toString();
     }
 
+    /**
+     * Folds all header lines at linear whitespace so that each line is no
+     * longer than 76 characters, if possible.
+     * <p>
+     * If there are more than 76 non-whitespace characters consecutively,
+     * the string is folded at the first whitespace after that sequence.
+     */
+    public void foldAllHeaderLines() {
+        foldHeaderLines(null, false);
+    }
+
+    /**
+     * Folds matching header header lines at linear whitespace so that each
+     * line is no longer than 76 characters, if possible.
+     * <p>
+     * If there are more than 76 non-whitespace characters consecutively,
+     * the string is folded at the first whitespace after that sequence.
+     * 
+     * @param names The names of the headers to fold
+     */
+    public void foldMatchingHeaderLines(String[] names) {
+        foldHeaderLines(names, true);
+    }
+
+    /**
+     * Folds non-matching header header lines at linear whitespace so that
+     * each line is no longer than 76 characters, if possible.
+     * <p>
+     * If there are more than 76 non-whitespace characters consecutively,
+     * the string is folded at the first whitespace after that sequence.
+     * 
+     * @param names The names of the headers not to fold
+     */
+    public void foldNonMatchingHeaderLines(String[] names) {
+        foldHeaderLines(names, false);
+    }
+
+    private void foldHeaderLines(String[] names, boolean matching) {
+    java.util.Set<String> optNames = lowerCaseSetFor(names);
+    for (int i = 0; i < headers.size(); i++) {
+        InternetHeader h = headers.get(i);
+        int colonPos;
+        if (h.line != null && (colonPos = h.line.indexOf(':')) >= 0) {
+            int length = h.line.length();
+            if (length > 76) {
+                String name = h.getName();
+                if (null == optNames || (matching ? optNames.contains(MimeUtility.asciiLowerCase(name)) : false == optNames.contains(MimeUtility.asciiLowerCase(name)))) {                    
+                    // Determine value. Skip whitespace after ':'
+                    int j;
+                    for (j = colonPos + 1; j < length; j++) {
+                        char c = h.line.charAt(j);
+                        if (!(c == ' ' || c == '\t' || c == '\r' || c == '\n'))
+                            break;
+                    }
+                    String value = h.line.substring(j);
+                    
+                    // Already used number if characters in the first line
+                    int used = name.length() + 2;
+                    if ((j = value.indexOf('\r', 0)) < 0 && (j = value.indexOf('\n', 0)) < 0) {
+                        // Not folded
+                        if (used + value.length() > 76) {
+                            value = MimeUtility.fold(used, value);
+                            h.line = h.line.substring(0, colonPos + 1) + ' ' + value;
+                        }
+                    } else {
+                        // Folded
+                        String[] lines = value.split("\r?\n", 0);
+                        boolean needsFolding = false;
+                        for (int k = lines.length; !needsFolding && k-- > 0;) {
+                            String line = lines[k];
+                            if ((0 == k ? (used + line.length()) : line.length()) > 76) {
+                                needsFolding = true;
+                            }
+                        }
+                        if (needsFolding) {
+                            // Unfold & re-fold
+                            value = MimeUtility.unfold(value);
+                            value = MimeUtility.fold(used, value);
+                            h.line = h.line.substring(0, colonPos + 1) + ' ' + value;
+                        }
+                    }
+                }
+            }
+        }
+    }
+    }
+
+    private static java.util.Set<String> lowerCaseSetFor(String[] names) {
+        if (null == names || names.length == 0) {
+            return null;
+        }
+        
+        java.util.Set<String> set = new java.util.HashSet<>(names.length);
+        for (int i = names.length; i-- > 0;) {
+            String name = names[i];
+            if (null != name)
+                set.add(MimeUtility.asciiLowerCase(name));
+        }
+        return set;
+    }
+
     /**
      * Change the first header line that matches name
      * to have value, adding a new header if no existing header
@@ -567,8 +666,8 @@ public class InternetHeaders {
     public void setHeader(String name, String value) {
 	boolean found = false;
 
-	for (int i = 0, k = headers.size(); k-- > 0; i++) {
-	    InternetHeader h = (InternetHeader)headers.get(i);
+	for (int i = 0; i < headers.size(); i++) {
+	    InternetHeader h = headers.get(i);
 	    if (name.equalsIgnoreCase(h.getName())) {
 		if (!found) {
 		    int j;
@@ -606,7 +705,6 @@ public class InternetHeaders {
      * @param	name	header name
      * @param	value	header value
      */ 
-    @SuppressWarnings("unchecked")
     public void addHeader(String name, String value) {
 	int pos = headers.size();
 	boolean addReverse =
@@ -615,7 +713,7 @@ public class InternetHeaders {
 	if (addReverse)
 	    pos = 0;
 	for (int i = headers.size() - 1; i >= 0; i--) {
-	    InternetHeader h = (InternetHeader)headers.get(i);
+	    InternetHeader h = headers.get(i);
 	    if (name.equalsIgnoreCase(h.getName())) {
 		if (addReverse) {
 		    pos = i;
@@ -637,7 +735,7 @@ public class InternetHeaders {
      */
     public void removeHeader(String name) { 
 	for (int i = 0, k = headers.size(); k-- > 0; i++) {
-	    InternetHeader h = (InternetHeader)headers.get(i);
+	    InternetHeader h = headers.get(i);
 	    if (name.equalsIgnoreCase(h.getName())) {
 		h.line = null;
 		//headers.remove(i);
@@ -652,7 +750,7 @@ public class InternetHeaders {
      *
      * @return	Enumeration of Header objects	
      */
-    @SuppressWarnings({"rawtypes", "unchecked"})
+    @SuppressWarnings({"rawtypes"})
     public Enumeration getAllHeaders() {
 	return (new MatchHeaderEnum(headers, null, false));
     }
@@ -663,7 +761,7 @@ public class InternetHeaders {
      * @param	names	the headers to return
      * @return	Enumeration of matching Header objects	
      */
-    @SuppressWarnings({"rawtypes", "unchecked"})
+    @SuppressWarnings({"rawtypes"})
     public Enumeration getMatchingHeaders(String[] names) {
 	return (new MatchHeaderEnum(headers, names, true));
     }
@@ -674,7 +772,7 @@ public class InternetHeaders {
      * @param	names	the headers to not return
      * @return	Enumeration of non-matching Header objects	
      */
-    @SuppressWarnings({"rawtypes", "unchecked"})
+    @SuppressWarnings({"rawtypes"})
     public Enumeration getNonMatchingHeaders(String[] names) {
 	return (new MatchHeaderEnum(headers, names, false));
     }
@@ -689,13 +787,12 @@ public class InternetHeaders {
      *
      * @param	line	raw RFC822 header line
      */
-    @SuppressWarnings("unchecked")
     public void addHeaderLine(String line) {
 	try {
 	    char c = line.charAt(0);
 	    if (c == ' ' || c == '\t') {
 		InternetHeader h =
-		    (InternetHeader)headers.get(headers.size() - 1);
+		    headers.get(headers.size() - 1);
 		h.line += "\r\n" + line;
 	    } else
 		headers.add(new InternetHeader(line));
@@ -723,7 +820,7 @@ public class InternetHeaders {
      * @param	names	the headers to return
      * @return	Enumeration of Strings of all matching header lines
      */
-    @SuppressWarnings({"rawtypes", "unchecked"})
+    @SuppressWarnings({"rawtypes"})
     public Enumeration getMatchingHeaderLines(String[] names) {
 	return (new MatchStringEnum(headers, names, true));	
     }
@@ -734,7 +831,7 @@ public class InternetHeaders {
      * @param	names	the headers to not return
      * @return	Enumeration of Strings of all non-matching header lines
      */
-    @SuppressWarnings({"rawtypes", "unchecked"})
+    @SuppressWarnings({"rawtypes"})
     public Enumeration getNonMatchingHeaderLines(String[] names) {
 	return (new MatchStringEnum(headers, names, false));
     }
