@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997-2015 Oracle and/or its affiliates. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common Development
@@ -53,7 +53,7 @@ import com.sun.mail.util.*;
  * objects. <p>
  *
  * MimeBodyPart uses the <code>InternetHeaders</code> class to parse
- * and store the headers of that body part. <p>
+ * and store the headers of that body part.
  *
  * <hr><strong>A note on RFC 822 and MIME headers</strong><p>
  *
@@ -169,6 +169,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * the delimiter strings.
      *
      * @param	is	the body part Input Stream
+     * @exception	MessagingException for failures
      */
     public MimeBodyPart(InputStream is) throws MessagingException {
 	if (!(is instanceof ByteArrayInputStream) &&
@@ -199,6 +200,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      *
      * @param	headers	The header of this part
      * @param	content	bytes representing the body of this part.
+     * @exception	MessagingException for failures
      */
     public MimeBodyPart(InternetHeaders headers, byte[] content) 
 			throws MessagingException {
@@ -288,13 +290,15 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * If the <code>subType</code> of <code>mimeType</code> is the
      * special character '*', then the subtype is ignored during the
      * comparison.
+     *
+     * @exception	MessagingException for failures
      */
     public boolean isMimeType(String mimeType) throws MessagingException {
 	return isMimeType(this, mimeType);
     }
 
     /**
-     * Returns the value of the "Content-Disposition" header field.
+     * Returns the disposition from the "Content-Disposition" header field.
      * This represents the disposition of this part. The disposition
      * describes how the part should be presented to the user. <p>
      *
@@ -304,6 +308,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * This implementation uses <code>getHeader(name)</code>
      * to obtain the requisite header field.
      *
+     * @exception	MessagingException for failures
      * @see #headers
      */
     public String getDisposition() throws MessagingException {
@@ -311,14 +316,15 @@ public class MimeBodyPart extends BodyPart implements MimePart {
     }
 
     /**
-     * Set the "Content-Disposition" header field of this body part.
-     * If the disposition is null, any existing "Content-Disposition"
-     * header field is removed.
+     * Set the disposition in the "Content-Disposition" header field
+     * of this body part.  If the disposition is null, any existing
+     * "Content-Disposition" header field is removed.
      *
      * @exception	IllegalWriteException if the underlying
      *			implementation does not support modification
      * @exception	IllegalStateException if this body part is
      *			obtained from a READ_ONLY folder.
+     * @exception	MessagingException for other failures
      */
     public void setDisposition(String disposition) throws MessagingException {
 	setDisposition(this, disposition);
@@ -356,11 +362,12 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * If the <code>cid</code> parameter is null, any existing 
      * "Content-ID" is removed.
      *
+     * @param	cid	the Content-ID
      * @exception	IllegalWriteException if the underlying
      *			implementation does not support modification
      * @exception	IllegalStateException if this body part is
      *			obtained from a READ_ONLY folder.
-     * @exception	MessagingException
+     * @exception	MessagingException for other failures
      * @since		JavaMail 1.3
      */
     public void setContentID(String cid) throws MessagingException {
@@ -536,10 +543,12 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * characters in filenames.  The default value of this property
      * is false.
      *
+     * @param	filename	the file name
      * @exception	IllegalWriteException if the underlying
      *			implementation does not support modification
      * @exception	IllegalStateException if this body part is
      *			obtained from a READ_ONLY folder.
+     * @exception	MessagingException for other failures
      */
     public void setFileName(String filename) throws MessagingException {
 	setFileName(this, filename);
@@ -552,10 +561,10 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * That is, it invokes getDataHandler().getInputStream();
      *
      * @return 		an InputStream
-     * @exception	MessagingException
      * @exception       IOException this is typically thrown by the
      *			DataHandler. Refer to the documentation for
      *			javax.activation.DataHandler for more details.
+     * @exception	MessagingException for other failures
      *
      * @see	#getContentStream
      * @see 	javax.activation.DataHandler#getInputStream
@@ -571,6 +580,8 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * that can provide a separate input stream for just the Part
      * content might want to override this method. <p>
      * 
+     * @return	an InputStream containing the raw bytes
+     * @exception	MessagingException for failures
      * @see #content
      * @see MimeMessage#getContentStream
      */
@@ -594,6 +605,8 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * This implementation simply calls the <code>getContentStream</code>
      * method.
      *
+     * @return	an InputStream containing the raw bytes
+     * @exception	MessagingException for failures
      * @see	#getInputStream
      * @see	#getContentStream
      * @since	JavaMail 1.2
@@ -631,10 +644,10 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * calls so that modifications to the content will not be lost.
      *
      * @return          Object
-     * @exception       MessagingException
      * @exception       IOException this is typically thrown by the
      *			DataHandler. Refer to the documentation for
      *			javax.activation.DataHandler for more details.
+     * @exception       MessagingException for other failures
      */  
     public Object getContent() throws IOException, MessagingException {
 	if (cachedContent != null)
@@ -937,10 +950,10 @@ public class MimeBodyPart extends BodyPart implements MimePart {
     /**
      * Output the body part as an RFC 822 format stream.
      *
-     * @exception MessagingException
      * @exception IOException	if an error occurs writing to the
      *				stream or if an error is generated
      *				by the javax.activation layer.
+     * @exception MessagingException for other failures
      * @see javax.activation.DataHandler#writeTo
      */
     public void writeTo(OutputStream os)
@@ -971,7 +984,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * @param delimiter		delimiter between fields in returned string
      * @return			the value fields for all headers with 
      *				this name
-     * @exception       	MessagingException
+     * @exception       	MessagingException for failures
      */
     public String getHeader(String name, String delimiter)
 				throws MessagingException {
@@ -1020,14 +1033,16 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * Return all the headers from this Message as an Enumeration of
      * Header objects.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getAllHeaders() throws MessagingException {
 	return headers.getAllHeaders();
     }
    
     /**
      * Return matching headers from this Message as an Enumeration of
-     * Header objects. <p>
+     * Header objects.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getMatchingHeaders(String[] names)
                         throws MessagingException {
 	return headers.getMatchingHeaders(names);
@@ -1037,6 +1052,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * Return non-matching headers from this Message as an
      * Enumeration of Header objects.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getNonMatchingHeaders(String[] names)
                         throws MessagingException {
 	return headers.getNonMatchingHeaders(names);
@@ -1054,6 +1070,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * line is a raw RFC 822 header line, containing both the "name"
      * and "value" field.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getAllHeaderLines() throws MessagingException {
   	return headers.getAllHeaderLines(); 
     }
@@ -1063,6 +1080,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * A Header line is a raw RFC 822 header line, containing both
      * the "name" and "value" field.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getMatchingHeaderLines(String[] names)
                                     throws MessagingException {
 	return headers.getMatchingHeaderLines(names);
@@ -1073,6 +1091,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * A Header line is a raw RFC 822 header line, containing both
      * the "name"  and "value" field.
      */
+    @SuppressWarnings("rawtypes")
     public Enumeration getNonMatchingHeaderLines(String[] names)  
                                         throws MessagingException {
 	return headers.getNonMatchingHeaderLines(names);
@@ -1105,6 +1124,8 @@ public class MimeBodyPart extends BodyPart implements MimePart {
      * that object is used to set a new DataHandler, any
      * stream data used to create this object is discarded,
      * and the {@link #cachedContent} field is cleared.
+     *
+     * @exception	MessagingException for failures
      */
     protected void updateHeaders() throws MessagingException {
 	updateHeaders(this);
@@ -1135,11 +1156,18 @@ public class MimeBodyPart extends BodyPart implements MimePart {
     static boolean isMimeType(MimePart part, String mimeType)
 				throws MessagingException {
 	// XXX - lots of room for optimization here!
+	String type = part.getContentType();
 	try {
-	    ContentType ct = new ContentType(part.getContentType());
-	    return ct.match(mimeType);
+	    return new ContentType(type).match(mimeType);
 	} catch (ParseException ex) {
-	    return part.getContentType().equalsIgnoreCase(mimeType);
+	    // we only need the type and subtype so throw away the rest
+	    try {
+		int i = type.indexOf(';');
+		if (i > 0)
+		    return new ContentType(type.substring(0, i)).match(mimeType);
+	    } catch (ParseException pex2) {
+	    }
+	    return type.equalsIgnoreCase(mimeType);
 	}
     }
 
@@ -1260,7 +1288,17 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 	String s = part.getHeader("Content-Disposition", null);
 	ContentDisposition cd = 
 		new ContentDisposition(s == null ? Part.ATTACHMENT : s);
-	cd.setParameter("filename", name);
+	// ensure that the filename is encoded if necessary
+	String charset = MimeUtility.getDefaultMIMECharset();
+	ParameterList p = cd.getParameterList();
+	if (p == null) {
+	    p = new ParameterList();
+	    cd.setParameterList(p);
+	}
+	if (encodeFileName)
+	    p.setLiteral("filename", name);
+	else
+	    p.set("filename", name, charset);
 	part.setHeader("Content-Disposition", cd.toString());
 
 	/*
@@ -1273,7 +1311,16 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 	    if (s != null) {
 		try {
 		    ContentType cType = new ContentType(s);
-		    cType.setParameter("name", name);
+		    // ensure that the filename is encoded if necessary
+		    p = cType.getParameterList();
+		    if (p == null) {
+			p = new ParameterList();
+			cType.setParameterList(p);
+		    }
+		    if (encodeFileName)
+			p.setLiteral("name", name);
+		    else
+			p.set("name", name, charset);
 		    part.setHeader("Content-Type", cType.toString());
 		} catch (ParseException pex) { }	// ignore it
 	    }
@@ -1289,7 +1336,7 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 
 	// Tokenize the header to obtain the Language-tags (skip comments)
 	HeaderTokenizer h = new HeaderTokenizer(s, HeaderTokenizer.MIME);
-	Vector v = new Vector();
+	List<String> v = new ArrayList<String>();
 
 	HeaderTokenizer.Token tk;
 	int tkType;
@@ -1300,22 +1347,22 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 	    if (tkType == HeaderTokenizer.Token.EOF)
 		break; // done
 	    else if (tkType == HeaderTokenizer.Token.ATOM)
-		v.addElement(tk.getValue());
+		v.add(tk.getValue());
 	    else // invalid token, skip it.
 		continue;
 	}
 
-	if (v.size() == 0)
+	if (v.isEmpty())
 	    return null;
 
 	String[] language = new String[v.size()];
-	v.copyInto(language);
+	v.toArray(language);
 	return language;	
     }
 
     static void setContentLanguage(MimePart part, String[] languages)
 			throws MessagingException {
-	StringBuilder sb = new StringBuilder(languages[0]);
+	StringBuffer sb = new StringBuffer(languages[0]);
 	int len = "Content-Language".length() + 2 + languages[0].length();
 	for (int i = 1; i < languages.length; i++) {
 	    sb.append(',');
@@ -1463,14 +1510,19 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 		MimePartDataHandler mdh = (MimePartDataHandler)dh;
 		MimePart mpart = mdh.getPart();
 		if (mpart != part) {
-		    // XXX - can't change the encoding of the data from the
-		    // other part without decoding and reencoding it, so
-		    // we just force it to match the original
-		    setEncoding(part, mpart.getEncoding());
 		    if (needCTHeader)
 			part.setHeader("Content-Type", mpart.getContentType());
-		}
-		return;
+		    // XXX - can't change the encoding of the data from the
+		    // other part without decoding and reencoding it, so
+		    // we just force it to match the original, but if the
+		    // original has no encoding we'll consider reencoding it
+		    String enc = mpart.getEncoding();
+		    if (enc != null) {
+			setEncoding(part, enc);
+			return;
+		    }
+		} else
+		    return;
 	    }
 
 	    // Content-Transfer-Encoding, but only if we don't
@@ -1513,14 +1565,26 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 		 * satisfy older MUAs (DtMail, Roam and probably
 		 * a bunch of others).
 		 */
-		String s = part.getHeader("Content-Disposition", null);
-		if (s != null) {
-		    // Parse the header ..
-		    ContentDisposition cd = new ContentDisposition(s);
-		    String filename = cd.getParameter("filename");
-		    if (filename != null) {
-			cType.setParameter("name", filename);
-			type = cType.toString();
+		if (setContentTypeFileName) {
+		    String s = part.getHeader("Content-Disposition", null);
+		    if (s != null) {
+			// Parse the header ..
+			ContentDisposition cd = new ContentDisposition(s);
+			String filename = cd.getParameter("filename");
+			if (filename != null) {
+			    ParameterList p = cType.getParameterList();
+			    if (p == null) {
+				p = new ParameterList();
+				cType.setParameterList(p);
+			    }
+			    if (encodeFileName)
+				p.setLiteral("name",
+					MimeUtility.encodeText(filename));
+			    else
+				p.set("name", filename,
+					MimeUtility.getDefaultMIMECharset());
+			    type = cType.toString();
+			}
 		    }
 		}
 		
@@ -1549,9 +1613,11 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 	}
 
 	// First, write out the header
-	Enumeration hdrLines = part.getNonMatchingHeaderLines(ignoreList);
+	@SuppressWarnings("unchecked")
+	Enumeration<String> hdrLines
+		= part.getNonMatchingHeaderLines(ignoreList);
 	while (hdrLines.hasMoreElements())
-	    los.writeln((String)hdrLines.nextElement());
+	    los.writeln(hdrLines.nextElement());
 
 	// The CRLF separator between header and content
 	los.writeln();
@@ -1563,23 +1629,16 @@ public class MimeBodyPart extends BodyPart implements MimePart {
 	try {
 	    /*
 	     * If the data for this part comes from a stream,
+	     * and is already encoded,
 	     * just copy it to the output stream without decoding
 	     * and reencoding it.
 	     */
 	    DataHandler dh = part.getDataHandler();
 	    if (dh instanceof MimePartDataHandler) {
-		// call getContentStream to give subclass a chance to
-		// provide the data on demand
-		is = ((MimePartDataHandler)dh).getContentStream();
-		/*
-		if (part instanceof MimeBodyPart) {
-		    MimeBodyPart mbp = (MimeBodyPart)part;
-		    is = mbp.getContentStream();
-		} else if (part instanceof MimeMessage) {
-		    MimeMessage msg = (MimeMessage)part;
-		    is = msg.getContentStream();
-		}
-		*/
+		MimePartDataHandler mpdh = (MimePartDataHandler)dh;
+		MimePart mpart = mpdh.getPart();
+		if (mpart.getEncoding() != null)
+		    is = mpdh.getContentStream();
 	    }
 	    if (is != null) {
 		// now copy the data to the output stream
