@@ -114,6 +114,11 @@ import com.sun.mail.util.PropUtil;
 
 public class MimeMultipart extends Multipart {
 
+    /**
+     * The string constant for a new line: <code>"\r\n"</code>
+     */
+    private static final String NEWLINE = "\r\n";
+
     /**
      * The DataSource supplying our InputStream.
      */
@@ -559,25 +564,21 @@ public class MimeMultipart extends Multipart {
 
 	// if there's a preamble, write it out
 	if (preamble != null) {
+        // make sure it ends with a newline
 	    String p = preamble;
-	    if (!p.endsWith("\r\n")) {
-            char c = p.charAt(p.length() - 1);
+        if (!p.endsWith(NEWLINE)) {
+            int mlen = p.length() - 1;
+            char c = p.charAt(mlen);
             if (c == '\n') {
-                p = p.substring(0, p.length()-1) + "\r\n";
+                p = p.substring(0, mlen) + NEWLINE;
             } else if (c == '\r') {
-                p = p.substring(0, p.length()-1) + "\r\n";
+                p = p.substring(0, mlen) + NEWLINE;
             } else {
-                p = p + "\r\n";
+                p = p + NEWLINE;
             }
         }
-        byte[] pb = ASCIIUtility.getBytes(p);
-	    los.write(pb);
-	    // make sure it ends with a newline
-	    //if (pb.length > 0 &&
-		//    !(pb[pb.length-1] == '\r' || pb[pb.length-1] == '\n')) {
-		los.writeln();
-	    //}
-	    // XXX - could force a blank line before start boundary
+	    byte[] pb = ASCIIUtility.getBytes(p);
+        los.write(pb);
 	}
 
 	int size = parts.size();
@@ -649,9 +650,8 @@ public class MimeMultipart extends Multipart {
 	try {
 	    // Skip and save the preamble
 	    LineInputStream lin = new LineInputStream(in);
-	    StringBuffer preamblesb = null;
+	    StringBuilder preamblesb = null;
 	    String line;
-	    String lineSeparator = null;
 	    while ((line = lin.readLine()) != null) {
 		/*
 		 * Strip trailing whitespace.  Can't use trim method
@@ -695,23 +695,13 @@ public class MimeMultipart extends Multipart {
 		    }
 		}
 
-		// save the preamble after skipping blank lines
-		if (line.length() > 0) {
-		    // if we haven't figured out what the line separator
-		    // is, do it now
-		    if (lineSeparator == null) {
-			try {
-			    lineSeparator =
-				System.getProperty("line.separator", "\n");
-			} catch (SecurityException ex) {
-			    lineSeparator = "\n";
-			}
-		    }
-		    // accumulate the preamble
-		    if (preamblesb == null)
-			preamblesb = new StringBuffer(line.length() + 2);
-		    preamblesb.append(line).append(lineSeparator);
-		}
+        // accumulate the preamble
+        if (preamblesb == null)
+            preamblesb = new StringBuilder(line.length() + 2);
+        if (line.length() > 0) {
+            preamblesb.append(line);
+        }
+        preamblesb.append(NEWLINE);
 	    }
 
 	    if (preamblesb != null)
