@@ -56,7 +56,12 @@ import javax.activation.CommandMap;
 import javax.activation.MailcapCommandMap;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
+import org.osgi.framework.ServiceReference;
+import org.osgi.util.tracker.ServiceTracker;
+import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.sun.mail.imap.IMAPStore;
 import com.sun.mail.imap.QueuingIMAPStore;
+import com.sun.mail.imap.ProtocolListener;
 import com.sun.mail.util.MailLogger;
 
 
@@ -67,6 +72,8 @@ import com.sun.mail.util.MailLogger;
  */
 public final class JavaMailActivator implements BundleActivator {
 
+    private ServiceTracker<ProtocolListener, ProtocolListener> protocolListenerTracker;
+
     /**
      * Initializes a new {@link JavaMailActivator}.
      */
@@ -75,7 +82,7 @@ public final class JavaMailActivator implements BundleActivator {
     }
 
     @Override
-    public void start(final BundleContext context) throws Exception {
+    public synchronized void start(final BundleContext context) throws Exception {
         try {
             /*-
              * Add handlers for mail MIME types
@@ -115,6 +122,29 @@ public final class JavaMailActivator implements BundleActivator {
                 mc.addMailcap("message/rfc822;; x-java-content-handler=com.sun.mail.handlers.message_rfc822");
             }
             CommandMap.setDefaultCommandMap(mc);
+
+            ServiceTracker<ProtocolListener, ProtocolListener> protocolListenerTracker = new ServiceTracker<>(context, ProtocolListener.class, new ServiceTrackerCustomizer<ProtocolListener, ProtocolListener>() {
+
+                @Override
+                public void removedService(ServiceReference<ProtocolListener> reference, ProtocolListener protocolListener) {
+                    IMAPStore.removeProtocolListener(protocolListener);
+                    context.ungetService(reference);
+                }
+
+                @Override
+                public void modifiedService(ServiceReference<ProtocolListener> reference, ProtocolListener protocolListener) {
+                    // Ignore
+                }
+
+                @Override
+                public ProtocolListener addingService(ServiceReference<ProtocolListener> reference) {
+                    ProtocolListener protocolListener = context.getService(reference);
+                    IMAPStore.addProtocolListener(protocolListener);
+                    return protocolListener;
+                }
+            });
+            this.protocolListenerTracker = protocolListenerTracker;
+            protocolListenerTracker.open();
         } catch (final Exception e) {
             final MailLogger logger = new MailLogger(JavaMailActivator.class, "JavaMail Activator", true, System.out);
             logger.log(Level.SEVERE, "Error starting JavaMail bundle.", e);
@@ -123,9 +153,14 @@ public final class JavaMailActivator implements BundleActivator {
     }
 
     @Override
-    public void stop(final BundleContext context) throws Exception {
+    public synchronized void stop(final BundleContext context) throws Exception {
         try {
             QueuingIMAPStore.shutdown();
+            ServiceTracker<ProtocolListener, ProtocolListener> protocolListenerTracker = this.protocolListenerTracker;
+            if (null != protocolListenerTracker) {
+                this.protocolListenerTracker = null;
+                protocolListenerTracker.close();
+            }
         } catch (final Exception e) {
             final MailLogger logger = new MailLogger(JavaMailActivator.class, "JavaMail Activator", true, System.out);
             logger.log(Level.SEVERE, "Error stopping JavaMail bundle.", e);
