@@ -90,6 +90,9 @@ public class JSONObject extends AbstractJSONValue {
 
     private static final long serialVersionUID = 3666538885751033341L;
 
+    /** The (immutable) empty JSON object */
+    public static final JSONObject EMPTY_OBJECT = ImmutableJSONObject.immutableFor(new JSONObject(0));
+
     /**
      * The logger reference.
      */
@@ -615,9 +618,13 @@ public class JSONObject extends AbstractJSONValue {
      */
     public boolean getBoolean(final String key) throws JSONException {
         final Object o = get(key);
-        if (o.equals(Boolean.FALSE) || (o instanceof String && ((String) o).equalsIgnoreCase(STR_FALSE))) {
+        if (o.equals(Boolean.FALSE)) {
             return false;
-        } else if (o.equals(Boolean.TRUE) || (o instanceof String && ((String) o).equalsIgnoreCase(STR_TRUE))) {
+        } else if (o.equals(Boolean.TRUE)) {
+            return true;
+        } else if (o instanceof String && ((String) o).equalsIgnoreCase(STR_FALSE)) {
+            return false;
+        } else if (o instanceof String && ((String) o).equalsIgnoreCase(STR_TRUE)) {
             return true;
         }
         throw new JSONException("JSONObject[" + quote(key) + "] is not a Boolean.");
@@ -829,6 +836,20 @@ public class JSONObject extends AbstractJSONValue {
         return key == null ? null : this.myHashMap.get(key);
     }
 
+    /**
+     * Get an optional value associated with a key that is supposed not to be {@link JSONObject#NULL <code>NULL</code>}.
+     *
+     * @param key A key string.
+     * @return An object which is the value, or null if there is no value.
+     */
+    public Object optIfNotNull(final String key) {
+        if (key == null) {
+            return null;
+        }
+        Object object = this.myHashMap.get(key);
+        return NULL == object ? null : object;
+    }
+
     /**
      * Get an optional boolean associated with a key. It returns false if there is no such key, or if the value is not Boolean.TRUE or the
      * String "true".
